@@ -1,3 +1,24 @@
+/*
+ * Copyright (C) Advanced Micro Devices, Inc.
+ *
+ * Permission is hereby granted, free of charge, to any person obtaining a
+ * copy of this software and associated documentation files (the "Software"),
+ * to deal in the Software without restriction, including without limitation
+ * the rights to use, copy, modify, merge, publish, distribute, sublicense,
+ * and/or sell copies of the Software, and to permit persons to whom the
+ * Software is furnished to do so, subject to the following conditions:
+ *
+ * The above copyright notice and this permission notice shall be included
+ * in all copies or substantial portions of the Software.
+ *
+ * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
+ * OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
+ * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.  IN NO EVENT SHALL
+ * THE COPYRIGHT HOLDER(S) BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN
+ * AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
+ * CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+ */
+
 #include <cstdlib>
 #include <hip_test_common.hh>
 #include <picojson.h>
@@ -114,7 +135,7 @@ std::string TestContext::getMatchingConfigFile(std::string config_dir) {
     std::string cur_arch = getCurrentArch();
     LogPrintf("The arch present: %s", cur_arch.c_str());
     configFileToUse = config_dir + "/config_" + getConfig().platform + "_" + getConfig().os + "_" +
-        cur_arch + ".json";
+                      cur_arch + ".json";
   } else {
     configFileToUse =
         config_dir + "/config_" + getConfig().platform + "_" + getConfig().os + ".json";
@@ -164,11 +185,10 @@ void TestContext::getConfigFiles() {
   }
 
   std::string env_config = TestContext::getEnvVar("HIP_CATCH_EXCLUDE_FILE");
-  LogPrintf("Env Config file: %s",
-            (!env_config.empty()) ? env_config.c_str() : "Not found");
+  LogPrintf("Env Config file: %s", (!env_config.empty()) ? env_config.c_str() : "Not found");
   // HIP_CATCH_EXCLUDE_FILE is set for custom file path
   if (!env_config.empty()) {
-    if(fs::exists(env_config)) {
+    if (fs::exists(env_config)) {
       config_.json_files.push_back(env_config);
     }
   } else {
@@ -236,7 +256,8 @@ bool TestContext::parseJsonFiles() {
     }
     // Open the file
     std::ifstream js_file(fl);
-    std::string json_str((std::istreambuf_iterator<char>(js_file)), std::istreambuf_iterator<char>());
+    std::string json_str((std::istreambuf_iterator<char>(js_file)),
+                         std::istreambuf_iterator<char>());
     LogPrintf("Json contents:: %s", json_str.data());
 
     picojson::value v;
