@@ -41,9 +41,8 @@ static __global__ void kerTestDeviceMalloc(size_t size) {
   int myId = threadIdx.x + blockDim.x * blockIdx.x;
   // Allocate
   if (myId == 0) {
-    dev_common_ptr = reinterpret_cast<char*> (malloc(size));
+    dev_common_ptr = reinterpret_cast<char*>(malloc(size));
     if (dev_common_ptr == nullptr) {
-      printf("Device Allocation Failed! \n");
       return;
     }
   }
@@ -57,7 +56,6 @@ static __global__ void kerTestDeviceWrite() {
   int myId = threadIdx.x + blockDim.x * blockIdx.x;
   // Allocate
   if (dev_common_ptr == nullptr) {
-    printf("Device Allocation Failed! \n");
     return;
   }
   *(dev_common_ptr + myId) = SCHAR_MAX;
@@ -67,13 +65,13 @@ static __global__ void kerTestDeviceWrite() {
  * This kernel frees the memory chunk allocated in kernel
  * kerTestDeviceMalloc using free().
  */
-static __global__ void kerTestDeviceFree(int *result) {
+static __global__ void kerTestDeviceFree(int* result) {
   int myId = threadIdx.x + blockDim.x * blockIdx.x;
   // Allocate
   if (myId == 0) {
     if (dev_common_ptr != nullptr) {
       *result = 1;
-      for (int idx = 0; idx < (BLOCKSIZE*GRIDSIZE); idx++) {
+      for (int idx = 0; idx < (BLOCKSIZE * GRIDSIZE); idx++) {
         if (*(dev_common_ptr + myId) != SCHAR_MAX) {
           *result = 0;
           break;
@@ -95,7 +93,6 @@ static __global__ void kerTestDeviceNew(size_t size) {
   if (myId == 0) {
     dev_common_ptr = new char[size];
     if (dev_common_ptr == nullptr) {
-      printf("Device Allocation Failed! \n");
       return;
     }
   }
@@ -105,13 +102,13 @@ static __global__ void kerTestDeviceNew(size_t size) {
  * This kernel frees the memory chunk allocated in kernel
  * kerTestDeviceNew using delete operator.
  */
-static __global__ void kerTestDeviceDelete(int *result) {
+static __global__ void kerTestDeviceDelete(int* result) {
   int myId = threadIdx.x + blockDim.x * blockIdx.x;
   // Allocate
   if (myId == 0) {
     if (dev_common_ptr != nullptr) {
       *result = 1;
-      for (int idx = 0; idx < (BLOCKSIZE*GRIDSIZE); idx++) {
+      for (int idx = 0; idx < (BLOCKSIZE * GRIDSIZE); idx++) {
         if (*(dev_common_ptr + myId) != SCHAR_MAX) {
           *result = 0;
           break;
@@ -140,6 +137,8 @@ static bool testDeviceAllocMulProc(bool testmalloc) {
   childpid = fork();
   if (childpid > 0) {  // Parent
     close(fd[1]);
+    int* result_d{nullptr};
+    HIP_CHECK(hipMalloc(&result_d, sizeof(int)));
     // Allocate in parent
     if (testmalloc) {
       kerTestDeviceMalloc<<<1, 1>>>(SIZE);
@@ -150,6 +149,16 @@ static bool testDeviceAllocMulProc(bool testmalloc) {
     // Check allocated memory size
     HIP_CHECK(hipMemGetInfo(&avail, &tot));
     if ((tot - avail) < SIZE) {
+      // Clean up memory before return
+      if (testmalloc) {
+        kerTestDeviceFree<<<1, 1>>>(result_d);
+      } else {
+        kerTestDeviceDelete<<<1, 1>>>(result_d);
+      }
+      HIP_CHECK(hipDeviceSynchronize());
+      HIP_CHECK(hipFree(result_d));
+      close(fd[0]);
+      wait(NULL);
       return false;
     }
     // parent will wait to read the device cnt
@@ -164,8 +173,17 @@ static bool testDeviceAllocMulProc(bool testmalloc) {
     if ((tot - avail) < SIZE) {
       testResult = false;
     }
+    if (testmalloc) {
+      kerTestDeviceFree<<<1, 1>>>(result_d);
+    } else {
+      kerTestDeviceDelete<<<1, 1>>>(result_d);
+    }
+    HIP_CHECK(hipDeviceSynchronize());
+    HIP_CHECK(hipFree(result_d));
   } else if (!childpid) {  // Child
     // Wait for hipDeviceSetLimit() completion in parent.
+    int* result_d{nullptr};
+    HIP_CHECK(hipMalloc(&result_d, sizeof(int)));
     close(fd[0]);
     // Allocate in child
     if (testmalloc) {
@@ -185,6 +203,13 @@ static bool testDeviceAllocMulProc(bool testmalloc) {
     write(fd[1], &testResult, sizeof(testResult));
     // close the write descriptor:
     close(fd[1]);
+    if (testmalloc) {
+      kerTestDeviceFree<<<1, 1>>>(result_d);
+    } else {
+      kerTestDeviceDelete<<<1, 1>>>(result_d);
+    }
+    HIP_CHECK(hipDeviceSynchronize());
+    HIP_CHECK(hipFree(result_d));
     exit(0);
   }
   return testResult;
@@ -202,7 +227,7 @@ static bool testDeviceMemMulProc(bool testmalloc) {
   bool testResult = false;
   pid_t childpid;
   int testResultChild = 0;
-  size_t size = BLOCKSIZE*GRIDSIZE;
+  size_t size = BLOCKSIZE * GRIDSIZE;
   // create pipe descriptors
   pipe(fd);
   // fork process
@@ -211,7 +236,7 @@ static bool testDeviceMemMulProc(bool testmalloc) {
     close(fd[1]);
     int *result_d{nullptr}, *result_h{nullptr};
     HIP_CHECK(hipMalloc(&result_d, sizeof(int)));
-    result_h = reinterpret_cast<int*> (malloc(sizeof(int)));
+    result_h = reinterpret_cast<int*>(malloc(sizeof(int)));
     REQUIRE(result_h != nullptr);
     // Allocate in parent
     if (testmalloc) {
@@ -229,8 +254,7 @@ static bool testDeviceMemMulProc(bool testmalloc) {
     }
     HIP_CHECK(hipDeviceSynchronize());
     *result_h = 0;
-    HIP_CHECK(hipMemcpy(result_h, result_d, sizeof(int),
-              hipMemcpyDefault));
+    HIP_CHECK(hipMemcpy(result_h, result_d, sizeof(int), hipMemcpyDefault));
     if (*result_h == 0) {
       testResult = false;
     } else {
@@ -254,7 +278,7 @@ static bool testDeviceMemMulProc(bool testmalloc) {
     close(fd[0]);
     int *result_d{nullptr}, *result_h{nullptr};
     HIP_CHECK(hipMalloc(&result_d, sizeof(int)));
-    result_h = reinterpret_cast<int*> (malloc(sizeof(int)));
+    result_h = reinterpret_cast<int*>(malloc(sizeof(int)));
     REQUIRE(result_h != nullptr);
     // Allocate in child
     if (testmalloc) {
@@ -272,8 +296,7 @@ static bool testDeviceMemMulProc(bool testmalloc) {
     }
     HIP_CHECK(hipDeviceSynchronize());
     *result_h = 0;
-    HIP_CHECK(hipMemcpy(result_h, result_d, sizeof(int),
-              hipMemcpyDefault));
+    HIP_CHECK(hipMemcpy(result_h, result_d, sizeof(int), hipMemcpyDefault));
     // send the value on the write-descriptor:
     write(fd[1], result_h, sizeof(int));
     // close the write descriptor:
