@@ -22,5 +22,4 @@ THE SOFTWARE.
 
 #include "hip/hip_runtime.h"
 
-extern "C" __global__ void dummy_ker() {
-}
+extern "C" __global__ void dummy_ker() {}
