@@ -34,7 +34,7 @@ THE SOFTWARE.
 /**
  * Fetches Gpu device count
  */
-static void getDeviceCount(int *pdevCnt) {
+static void getDeviceCount(int* pdevCnt) {
   int fd[2], val = 0;
   pid_t childpid;
 
@@ -109,15 +109,13 @@ static bool getTotalMemoryOfMaskedDevices(int actualNumGPUs) {
     setenv("HIP_VISIBLE_DEVICES", visibleDeviceString, 1);
 #endif
 
-    for (int count = 1;
-        count < actualNumGPUs; count++) {
+    for (int count = 1; count < actualNumGPUs; count++) {
       size_t totMem;
       err = hipDeviceTotalMem(&totMem, count);
       if (err == hipSuccess) {
         testResult &= false;
       } else {
-        printf("hipDeviceTotalMem: Error Code Returned: '%s'(%d)\n",
-              hipGetErrorString(err), err);
+        printf("hipDeviceTotalMem: Error Code Returned: '%s'(%d)\n", hipGetErrorString(err), err);
       }
     }
     close(fd[0]);
