@@ -33,7 +33,7 @@ THE SOFTWARE.
  * @{
  * @ingroup DeviceTest
  * `hipIpcOpenMemHandle(void** devPtr, hipIpcMemHandle_t handle, unsigned int flags)` -
- * Opens an interprocess memory handle exported from another process 
+ * Opens an interprocess memory handle exported from another process
  * and returns a device pointer usable in the local process.
  */
 
@@ -48,7 +48,6 @@ typedef struct mem_handle {
 } hip_ipc_t;
 
 
-
 // This testcase verifies the hipIpcMemAccess APIs as follows
 // The following program spawns a child process and does the following
 // Parent iterate through each device, create memory -- create hipIpcMemhandle
@@ -78,7 +77,7 @@ typedef struct mem_handle {
  *  - HIP_VERSION >= 5.2
  */
 TEST_CASE("Unit_hipIpcMemAccess_Semaphores") {
-  hip_ipc_t *shrd_mem = NULL;
+  hip_ipc_t* shrd_mem = NULL;
   pid_t pid;
   size_t N = 1024;
   size_t Nbytes = N * sizeof(int);
@@ -90,19 +89,16 @@ TEST_CASE("Unit_hipIpcMemAccess_Semaphores") {
   std::string cmd_line = "rm -rf /dev/shm/sem.my-sem-object*";
   int res = system(cmd_line.c_str());
   REQUIRE(res != -1);
-  sem_ob1 = sem_open("/my-sem-object1", O_CREAT|O_EXCL, 0660, 0);
-  sem_ob2 = sem_open("/my-sem-object2", O_CREAT|O_EXCL, 0660, 0);
+  sem_ob1 = sem_open("/my-sem-object1", O_CREAT | O_EXCL, 0660, 0);
+  sem_ob2 = sem_open("/my-sem-object2", O_CREAT | O_EXCL, 0660, 0);
   REQUIRE(sem_ob1 != SEM_FAILED);
   REQUIRE(sem_ob2 != SEM_FAILED);
 
-  shrd_mem = reinterpret_cast<hip_ipc_t *>(mmap(NULL, sizeof(hip_ipc_t),
-                                           PROT_READ | PROT_WRITE,
-                                           MAP_SHARED | MAP_ANONYMOUS,
-                                           0, 0));
+  shrd_mem = reinterpret_cast<hip_ipc_t*>(
+      mmap(NULL, sizeof(hip_ipc_t), PROT_READ | PROT_WRITE, MAP_SHARED | MAP_ANONYMOUS, 0, 0));
   REQUIRE(shrd_mem != NULL);
   shrd_mem->IfTestPassed = true;
-  HipTest::initArrays<int>(nullptr, nullptr, nullptr,
-                           &A_h, nullptr, &C_h, N, false);
+  HipTest::initArrays<int>(nullptr, nullptr, nullptr, &A_h, nullptr, &C_h, N, false);
   pid = fork();
   if (pid != 0) {
     // Parent process
@@ -111,9 +107,8 @@ TEST_CASE("Unit_hipIpcMemAccess_Semaphores") {
       if (shrd_mem->IfTestPassed == true) {
         HIP_CHECK(hipSetDevice(i));
         HIP_CHECK(hipMalloc(&A_d, Nbytes));
-        HIP_CHECK(hipIpcGetMemHandle(reinterpret_cast<hipIpcMemHandle_t *>
-                                     (&shrd_mem->memHandle),
-                                     A_d));
+        HIP_CHECK(
+            hipIpcGetMemHandle(reinterpret_cast<hipIpcMemHandle_t*>(&shrd_mem->memHandle), A_d));
         HIP_CHECK(hipMemcpy(A_d, A_h, Nbytes, hipMemcpyHostToDevice));
         shrd_mem->device = i;
         if ((sem_post(sem_ob1)) == -1) {
@@ -132,7 +127,7 @@ TEST_CASE("Unit_hipIpcMemAccess_Semaphores") {
     // Child process
     HIP_CHECK(hipGetDeviceCount(&Num_devices));
     for (int j = 0; j < Num_devices; ++j) {
-        HIP_CHECK(hipSetDevice(j));
+      HIP_CHECK(hipSetDevice(j));
       if ((sem_wait(sem_ob1)) == -1) {
         shrd_mem->IfTestPassed = false;
         WARN("sem_wait() call failed in child process.");
@@ -143,12 +138,13 @@ TEST_CASE("Unit_hipIpcMemAccess_Semaphores") {
         }
       }
       for (int i = 0; i < Num_devices; ++i) {
-        HIP_CHECK(hipSetDevice(i));
+        
         HIP_CHECK(hipDeviceCanAccessPeer(&CanAccessPeer, i, shrd_mem->device));
         if (CanAccessPeer == 1) {
+          HIP_CHECK(hipDeviceEnablePeerAccess(i, 0));
+          HIP_CHECK(hipSetDevice(i));
           HIP_CHECK(hipMalloc(&C_d, Nbytes));
-          HIP_CHECK(hipIpcOpenMemHandle(reinterpret_cast<void **>(&B_d),
-                                        shrd_mem->memHandle,
+          HIP_CHECK(hipIpcOpenMemHandle(reinterpret_cast<void**>(&B_d), shrd_mem->memHandle,
                                         hipIpcMemLazyEnablePeerAccess));
           HIP_CHECK(hipMemcpy(C_d, B_d, Nbytes, hipMemcpyDeviceToDevice));
           HIP_CHECK(hipMemcpy(C_h, C_d, Nbytes, hipMemcpyDeviceToHost));
@@ -157,8 +153,8 @@ TEST_CASE("Unit_hipIpcMemAccess_Semaphores") {
           // Checking if the data obtained from Ipc shared memory is consistent
           HIP_CHECK(hipMemcpy(C_h, B_d, Nbytes, hipMemcpyDeviceToHost));
           HipTest::checkTest<int>(A_h, C_h, N);
-        HIP_CHECK(hipIpcCloseMemHandle(reinterpret_cast<void*>(B_d)));
-        HIP_CHECK(hipFree(C_d));
+          HIP_CHECK(hipIpcCloseMemHandle(reinterpret_cast<void*>(B_d)));
+          HIP_CHECK(hipFree(C_d));
         }
       }
       if ((sem_post(sem_ob2)) == -1) {
@@ -178,8 +174,7 @@ TEST_CASE("Unit_hipIpcMemAccess_Semaphores") {
   int rFlag = 0;
   waitpid(pid, &rFlag, 0);
   REQUIRE(shrd_mem->IfTestPassed == true);
-  HipTest::freeArrays<int>(nullptr, nullptr, nullptr,
-                           A_h, nullptr, C_h, false);
+  HipTest::freeArrays<int>(nullptr, nullptr, nullptr, A_h, nullptr, C_h, false);
 }
 
 /**
@@ -246,14 +241,12 @@ TEST_CASE("Unit_hipIpcMemAccess_ParameterValidation") {
   }
 
   SECTION("Open mem handle with devptr as nullptr") {
-    ret = hipIpcOpenMemHandle(nullptr, MemHandle,
-                                           hipIpcMemLazyEnablePeerAccess);
+    ret = hipIpcOpenMemHandle(nullptr, MemHandle, hipIpcMemLazyEnablePeerAccess);
     REQUIRE(ret == hipErrorInvalidValue);
   }
 
   SECTION("Open mem handle with handle as un-initialized") {
-    ret = hipIpcOpenMemHandle(&Ad2, MemHandleUninit,
-                                           hipIpcMemLazyEnablePeerAccess);
+    ret = hipIpcOpenMemHandle(&Ad2, MemHandleUninit, hipIpcMemLazyEnablePeerAccess);
     REQUIRE((ret == hipErrorInvalidValue || ret == hipErrorInvalidDevicePointer));
   }
 #if HT_AMD
