@@ -37,9 +37,7 @@ class MemPoolExportPointerBenchmark : public Benchmark<MemPoolExportPointerBench
     HIP_CHECK(hipMallocFromPoolAsync(&device_ptr, array_size * sizeof(float), mem_pool, nullptr));
     HIP_CHECK(hipStreamSynchronize(nullptr));
 
-    TIMED_SECTION(kTimerTypeCpu) {
-      HIP_CHECK(hipMemPoolExportPointer(&exp_data, device_ptr));
-    }
+    TIMED_SECTION(kTimerTypeCpu) { HIP_CHECK(hipMemPoolExportPointer(&exp_data, device_ptr)); }
 
     HIP_CHECK(hipFreeAsync(device_ptr, nullptr));
     HIP_CHECK(hipMemPoolDestroy(mem_pool));
@@ -75,8 +73,9 @@ static void RunBenchmark(const size_t array_size) {
  */
 TEST_CASE("Performance_hipMemPoolExportPointer") {
   if (!AreMemPoolsSupported(0)) {
-    HipTest::HIP_SKIP_TEST("GPU 0 doesn't support hipDeviceAttributeMemoryPoolsSupported "
-                           "attribute. Hence skipping the testing with Pass result.\n");
+    HipTest::HIP_SKIP_TEST(
+        "GPU 0 doesn't support hipDeviceAttributeMemoryPoolsSupported "
+        "attribute. Hence skipping the testing with Pass result.\n");
     return;
   }
   size_t array_size = GENERATE(4_KB, 4_MB, 16_MB);
@@ -84,6 +83,6 @@ TEST_CASE("Performance_hipMemPoolExportPointer") {
 }
 
 /**
-* End doxygen group PerformanceTest.
-* @}
-*/
+ * End doxygen group PerformanceTest.
+ * @}
+ */
