@@ -32,17 +32,9 @@ class MemPoolSetAccessBenchmark : public Benchmark<MemPoolSetAccessBenchmark> {
     hipMemPoolProps pool_props = CreateMemPoolProps(0, hipMemHandleTypeNone);
     HIP_CHECK(hipMemPoolCreate(&mem_pool, &pool_props));
 
-    hipMemAccessDesc desc_list = {
-      {
-        hipMemLocationTypeDevice,
-        0
-      },
-      hipMemAccessFlagsProtReadWrite
-    };
+    hipMemAccessDesc desc_list = {{hipMemLocationTypeDevice, 0}, hipMemAccessFlagsProtReadWrite};
 
-    TIMED_SECTION(kTimerTypeCpu) {
-      HIP_CHECK(hipMemPoolSetAccess(mem_pool, &desc_list, 1));
-    }
+    TIMED_SECTION(kTimerTypeCpu) { HIP_CHECK(hipMemPoolSetAccess(mem_pool, &desc_list, 1)); }
 
     HIP_CHECK(hipMemPoolDestroy(mem_pool));
   }
@@ -71,14 +63,15 @@ static void RunBenchmark() {
  */
 TEST_CASE("Performance_hipMemPoolSetAccess") {
   if (!AreMemPoolsSupported(0)) {
-    HipTest::HIP_SKIP_TEST("GPU 0 doesn't support hipDeviceAttributeMemoryPoolsSupported "
-                           "attribute. Hence skipping the testing with Pass result.\n");
+    HipTest::HIP_SKIP_TEST(
+        "GPU 0 doesn't support hipDeviceAttributeMemoryPoolsSupported "
+        "attribute. Hence skipping the testing with Pass result.\n");
     return;
   }
   RunBenchmark();
 }
 
 /**
-* End doxygen group PerformanceTest.
-* @}
-*/
+ * End doxygen group PerformanceTest.
+ * @}
+ */
