@@ -18,15 +18,15 @@
  */
 
 /**
-* @addtogroup hipMemcpy hipMemcpy
-* @{
-* @ingroup perfMemoryTest
-* `hipMemcpy(void* dst, const void* src, size_t count, hipMemcpyKind kind)` -
-* Copies data between host and device.
-*/
+ * @addtogroup hipMemcpy hipMemcpy
+ * @{
+ * @ingroup perfMemoryTest
+ * `hipMemcpy(void* dst, const void* src, size_t count, hipMemcpyKind kind)` -
+ * Copies data between host and device.
+ */
 
 #include <hip_test_common.hh>
-
+// #define ENABLE_DEBUG 1
 #define NUM_SIZE 14
 #define NUM_ITER 1000
 // max BW number for DevicetoDeviceNoCU
@@ -35,7 +35,8 @@
 class hipPerfMemcpy {
  private:
   size_t totalSizes_[NUM_SIZE];
-  void setHostBuffer(int *A, int val, size_t size);
+  void setHostBuffer(int* A, int val, size_t size);
+
  public:
   hipPerfMemcpy();
   ~hipPerfMemcpy() {}
@@ -53,7 +54,7 @@ hipPerfMemcpy::hipPerfMemcpy() {
   }
 }
 
-void hipPerfMemcpy::setHostBuffer(int *A, int val, size_t size) {
+void hipPerfMemcpy::setHostBuffer(int* A, int val, size_t size) {
   size_t len = size / sizeof(int);
   for (int i = 0; i < len; i++) {
     A[i] = val;
@@ -61,36 +62,31 @@ void hipPerfMemcpy::setHostBuffer(int *A, int val, size_t size) {
 }
 
 void hipPerfMemcpy::TestResult(unsigned int numTests,
-                              std::chrono::duration<double, std::micro> diff, hipMemcpyKind type)
-{
+                               std::chrono::duration<double, std::micro> diff, hipMemcpyKind type) {
   // BW in GB/s
-  double perf = (static_cast<double>(totalSizes_[numTests] * NUM_ITER) *
-                   static_cast<double>(1e-03)) / diff.count();
+  double perf =
+      (static_cast<double>(totalSizes_[numTests] * NUM_ITER) * static_cast<double>(1e-03)) /
+      diff.count();
 
-  const char *typestr = NULL;
+  const char* typestr = NULL;
 
-  if(type == hipMemcpyHostToDevice){
-      typestr = "Host to Device";
-  }
-  else if(type == hipMemcpyDeviceToHost){
-      typestr = "Device to Host";
-  }
-  else if(type == hipMemcpyDeviceToDevice){
-      typestr = "Device to Device";
-      perf *= 2.0;
-  }
-  else if(type == hipMemcpyDeviceToDeviceNoCU){
-      typestr = "Device to Device No CU";
-      perf *= 2.0;
+  if (type == hipMemcpyHostToDevice) {
+    typestr = "Host to Device";
+  } else if (type == hipMemcpyDeviceToHost) {
+    typestr = "Device to Host";
+  } else if (type == hipMemcpyDeviceToDevice) {
+    typestr = "Device to Device";
+    perf *= 2.0;
+  } else if (type == hipMemcpyDeviceToDeviceNoCU) {
+    typestr = "Device to Device No CU";
+    perf *= 2.0;
   }
 
-  UNSCOPED_INFO("hipPerfMemcpy[" << numTests << "] " << typestr << " copy BW "
-       << perf << "  GB/s for memory size of " <<
-       totalSizes_[numTests] << " Bytes.");
-
-  if(totalSizes_[numTests] == 4194304 && type == hipMemcpyDeviceToDeviceNoCU)
-          REQUIRE(perf < NOCU_MAX_BW);
+  CONSOLE_PRINT("hipPerfMemcpy[%d] %s copy BW %.2f GB/s for memory size of %lu Bytes.\n", numTests,
+                typestr, perf, totalSizes_[numTests]);
 
+  if (totalSizes_[numTests] == 4194304 && type == hipMemcpyDeviceToDeviceNoCU)
+    REQUIRE(perf < NOCU_MAX_BW);
 }
 
 bool hipPerfMemcpy::run_h2d(unsigned int numTests) {
@@ -115,7 +111,7 @@ bool hipPerfMemcpy::run_h2d(unsigned int numTests) {
   TestResult(numTests, diff, hipMemcpyHostToDevice);
 
   HIP_CHECK(hipHostUnregister(A));
-  delete [] A;
+  delete[] A;
   HIP_CHECK(hipFree(Ad));
 
   return true;
@@ -143,7 +139,7 @@ bool hipPerfMemcpy::run_d2h(unsigned int numTests) {
   TestResult(numTests, diff, hipMemcpyDeviceToHost);
 
   HIP_CHECK(hipHostUnregister(A));
-  delete [] A;
+  delete[] A;
   HIP_CHECK(hipFree(Ad));
 
   return true;
@@ -186,8 +182,8 @@ bool hipPerfMemcpy::run_d2d_nocu(unsigned int numTests) {
   auto all_start = std::chrono::steady_clock::now();
 
   for (int j = 0; j < NUM_ITER; j++) {
-    HIP_CHECK(hipMemcpyAsync(Ad1, Ad2, totalSizes_[numTests], hipMemcpyDeviceToDeviceNoCU,
-                                                                                      nullptr));
+    HIP_CHECK(
+        hipMemcpyAsync(Ad1, Ad2, totalSizes_[numTests], hipMemcpyDeviceToDeviceNoCU, nullptr));
   }
 
   HIP_CHECK(hipDeviceSynchronize());
@@ -204,16 +200,16 @@ bool hipPerfMemcpy::run_d2d_nocu(unsigned int numTests) {
 }
 
 /**
-* Test Description
-* ------------------------
-*  - Verify hipPerfMemcpy status.
-* Test source
-* ------------------------
-*  - perftests/memory/hipPerfMemcpy.cc
-* Test requirements
-* ------------------------
-*  - HIP_VERSION >= 5.6
-*/
+ * Test Description
+ * ------------------------
+ *  - Verify hipPerfMemcpy status.
+ * Test source
+ * ------------------------
+ *  - perftests/memory/hipPerfMemcpy.cc
+ * Test requirements
+ * ------------------------
+ *  - HIP_VERSION >= 5.6
+ */
 
 TEST_CASE("Perf_hipPerfMemcpy_test") {
   int numDevices = 0;
@@ -227,35 +223,34 @@ TEST_CASE("Perf_hipPerfMemcpy_test") {
     hipDeviceProp_t props;
     HIP_CHECK(hipGetDeviceProperties(&props, deviceId));
 
-    UNSCOPED_INFO("info: running on bus " << "0x" << props.pciBusID << " " <<
-         props.name << " with " << props.multiProcessorCount << " CUs "
-         << " and device id: " << deviceId);
+    CONSOLE_PRINT("info: running on bus 0x%x %s with %d CUs and device id: %d\n", props.pciBusID,
+                  props.name, props.multiProcessorCount, deviceId);
 
     hipPerfMemcpy hipPerfMemcpy;
-    SECTION("Perf test Host Memory to Device Memory"){
+    SECTION("Perf test Host Memory to Device Memory") {
       for (auto testCase = 0; testCase < NUM_SIZE; testCase++) {
-         REQUIRE(true == hipPerfMemcpy.run_h2d(testCase));
+        REQUIRE(true == hipPerfMemcpy.run_h2d(testCase));
       }
     }
-    SECTION("Perf test Device Memory to Host Memory"){
+    SECTION("Perf test Device Memory to Host Memory") {
       for (auto testCase = 0; testCase < NUM_SIZE; testCase++) {
-         REQUIRE(true == hipPerfMemcpy.run_d2h(testCase));
+        REQUIRE(true == hipPerfMemcpy.run_d2h(testCase));
       }
     }
-    SECTION("Perf test Device Memory to Device Memory"){
+    SECTION("Perf test Device Memory to Device Memory") {
       for (auto testCase = 0; testCase < NUM_SIZE; testCase++) {
-         REQUIRE(true == hipPerfMemcpy.run_d2d(testCase));
+        REQUIRE(true == hipPerfMemcpy.run_d2d(testCase));
       }
     }
-    SECTION("Perf test Device Memory to Device Memory No CU"){
+    SECTION("Perf test Device Memory to Device Memory No CU") {
       for (auto testCase = 0; testCase < NUM_SIZE; testCase++) {
-         REQUIRE(true == hipPerfMemcpy.run_d2d_nocu(testCase));
+        REQUIRE(true == hipPerfMemcpy.run_d2d_nocu(testCase));
       }
     }
   }
 }
 
 /**
-* End doxygen group perfMemoryTest.
-* @}
-*/
+ * End doxygen group perfMemoryTest.
+ * @}
+ */
