@@ -18,12 +18,12 @@
  */
 
 /**
-* @addtogroup hipPerfDeviceConcurrency hipPerfDeviceConcurrency
-* @{
-* @ingroup perfStreamTest
-* `hipError_t hipStreamCreate(hipStream_t* stream)` -
-* Create an asynchronous stream.
-*/
+ * @addtogroup hipPerfDeviceConcurrency hipPerfDeviceConcurrency
+ * @{
+ * @ingroup perfStreamTest
+ * `hipError_t hipStreamCreate(hipStream_t* stream)` -
+ * Create an asynchronous stream.
+ */
 
 #include <hip_test_common.hh>
 
@@ -34,28 +34,28 @@ typedef struct {
 } coordRec;
 
 static coordRec coords[] = {
-    {0.0, 0.0, 0.00001},         // All black
+    {0.0, 0.0, 0.00001},  // All black
 };
 
 static unsigned int numCoords = sizeof(coords) / sizeof(coordRec);
 
-__global__ void mandelbrot(uint *out, uint width, float xPos,
-                          float yPos, float xStep, float yStep, uint maxIter) {
+__global__ void mandelbrot(uint* out, uint width, float xPos, float yPos, float xStep, float yStep,
+                           uint maxIter) {
   int tid = (blockIdx.x * blockDim.x + threadIdx.x);
   int i = tid % width;
   int j = tid / width;
-  float x0 = static_cast<float>(xPos + xStep*i);
-  float y0 = static_cast<float>(yPos + yStep*j);
+  float x0 = static_cast<float>(xPos + xStep * i);
+  float y0 = static_cast<float>(yPos + yStep * j);
 
   float x = x0;
   float y = y0;
 
   uint iter = 0;
   float tmp;
-  for (iter = 0; (x*x + y*y <= 4.0f) && (iter < maxIter); iter++) {
+  for (iter = 0; (x * x + y * y <= 4.0f) && (iter < maxIter); iter++) {
     tmp = x;
     x = fma(-y, y, fma(x, x, x0));
-    y = fma(2.0f*tmp, y, y0);
+    y = fma(2.0f * tmp, y, y0);
   }
   out[tid] = iter;
 };
@@ -65,20 +65,16 @@ class hipPerfDeviceConcurrency {
   hipPerfDeviceConcurrency();
   ~hipPerfDeviceConcurrency();
 
-  void setNumGpus(unsigned int num) {
-    numDevices = num;
-  }
-  unsigned int getNumGpus() {
-    return numDevices;
-  }
+  void setNumGpus(unsigned int num) { numDevices = num; }
+  unsigned int getNumGpus() { return numDevices; }
 
   void open(void);
   void close(void);
   bool run(unsigned int testCase, int numGpus);
 
  private:
-  void setData(void *ptr, unsigned int value);
-  void checkData(uint *ptr);
+  void setData(void* ptr, unsigned int value);
+  void checkData(uint* ptr);
 
   unsigned int numDevices;
   unsigned int width_;
@@ -100,17 +96,16 @@ void hipPerfDeviceConcurrency::open(void) {
   }
 }
 
-void hipPerfDeviceConcurrency::close() {
-}
+void hipPerfDeviceConcurrency::close() {}
 
 bool hipPerfDeviceConcurrency::run(unsigned int testCase, int numGpus) {
   static int deviceId;
-  uint ** hPtr = new uint*[numGpus];
-  uint ** dPtr = new uint*[numGpus];
-  hipStream_t * streams = new hipStream_t[numGpus];
-  int *numCUs = new int[numGpus];
-  unsigned int *maxIter = new unsigned int[numGpus];
-  unsigned long long *expectedIters = new unsigned long long[numGpus];
+  uint** hPtr = new uint*[numGpus];
+  uint** dPtr = new uint*[numGpus];
+  hipStream_t* streams = new hipStream_t[numGpus];
+  int* numCUs = new int[numGpus];
+  unsigned int* maxIter = new unsigned int[numGpus];
+  unsigned long long* expectedIters = new unsigned long long[numGpus];
 
   int threads, threads_per_block, blocks;
   float xStep, yStep, xPos, yPos;
@@ -124,25 +119,21 @@ bool hipPerfDeviceConcurrency::run(unsigned int testCase, int numGpus) {
     hipDeviceProp_t props;
     HIP_CHECK(hipGetDeviceProperties(&props, i));
     if (testCase != 0) {
-    std::cout << "info: running on bus " << "0x" << props.pciBusID
-              << " " << props.name << " with " << props.multiProcessorCount
-              << " CUs" << " and device ID: " << i << std::endl;
+      CONSOLE_PRINT("info: running on bus 0x%x %s with %d CUs and device ID: %d", props.pciBusID,
+                    props.name, props.multiProcessorCount, i);
     }
-
     numCUs[i] = props.multiProcessorCount;
     int clkFrequency = 0;
-    HIP_CHECK(hipDeviceGetAttribute(&clkFrequency,
-                                    hipDeviceAttributeClockRate, i));
+    HIP_CHECK(hipDeviceGetAttribute(&clkFrequency, hipDeviceAttributeClockRate, i));
     if (clkFrequency == 0) {
-      std::cout << "clkFrequency = 0, set it to 1000000\n";
+      CONSOLE_PRINT("clkFrequency = 0, set it to 1000000");
       clkFrequency = 1000000;
     }
-    clkFrequency =(unsigned int)clkFrequency/1000;
+    clkFrequency = (unsigned int)clkFrequency / 1000;
 
     // Maximum iteration count
     // maxIter = 8388608 * (engine_clock / 1000).serial execution
-    maxIter[i] = (unsigned int)(((8388608 * ((float)clkFrequency / 1000))
-                                              * numCUs[i]) / 128);
+    maxIter[i] = (unsigned int)(((8388608 * ((float)clkFrequency / 1000)) * numCUs[i]) / 128);
     maxIter[i] = (maxIter[i] + 15) & ~15;
 
     // Width is divisible by 4 because the mandelbrot
@@ -153,15 +144,14 @@ bool hipPerfDeviceConcurrency::run(unsigned int testCase, int numGpus) {
     HIP_CHECK(hipStreamCreate(&streams[i]));
 
     // Allocate memory on the host and device
-    HIP_CHECK(hipHostMalloc(reinterpret_cast<void **>(&hPtr[i]),
-                            bufSize, hipHostMallocDefault));
+    HIP_CHECK(hipHostMalloc(reinterpret_cast<void**>(&hPtr[i]), bufSize, hipHostMallocDefault));
     setData(hPtr[i], 0xdeadbeef);
-    HIP_CHECK(hipMalloc(reinterpret_cast<uint **>(&dPtr[i]), bufSize))
+    HIP_CHECK(hipMalloc(reinterpret_cast<uint**>(&dPtr[i]), bufSize))
 
     // Prepare kernel launch parameters
-    threads = (bufSize/sizeof(uint));
-    threads_per_block  = 64;
-    blocks = (threads/threads_per_block) + (threads % threads_per_block);
+    threads = (bufSize / sizeof(uint));
+    threads_per_block = 64;
+    blocks = (threads / threads_per_block) + (threads % threads_per_block);
 
     coordIdx = testCase % numCoords;
     xStep = static_cast<float>(coords[coordIdx].width / static_cast<double>(width_));
@@ -180,10 +170,9 @@ bool hipPerfDeviceConcurrency::run(unsigned int testCase, int numGpus) {
       deviceId = i;
     }
 
-  HIP_CHECK(hipSetDevice(deviceId));
-  hipLaunchKernelGGL(mandelbrot, dim3(blocks), dim3(threads_per_block), 0,
-                    streams[i], dPtr[i], width_, xPos, yPos, xStep,
-                    yStep, maxIter[i]);
+    HIP_CHECK(hipSetDevice(deviceId));
+    hipLaunchKernelGGL(mandelbrot, dim3(blocks), dim3(threads_per_block), 0, streams[i], dPtr[i],
+                       width_, xPos, yPos, xStep, yStep, maxIter[i]);
   }
   for (int i = 0; i < numGpus; i++) {
     HIP_CHECK(hipStreamSynchronize(0));
@@ -192,8 +181,8 @@ bool hipPerfDeviceConcurrency::run(unsigned int testCase, int numGpus) {
   auto all_end = std::chrono::steady_clock::now();
   std::chrono::duration<double> all_kernel_time = all_end - all_start;
 
-  for(int i = 0; i < numGpus; i++) {
-    if(testCase != 0) {
+  for (int i = 0; i < numGpus; i++) {
+    if (testCase != 0) {
       deviceId = i;
     }
     HIP_CHECK(hipSetDevice(deviceId));
@@ -201,11 +190,11 @@ bool hipPerfDeviceConcurrency::run(unsigned int testCase, int numGpus) {
     // Copy data back from device to the host
     HIP_CHECK(hipMemcpy(hPtr[i], dPtr[i], bufSize, hipMemcpyDeviceToHost));
     checkData(hPtr[i]);
-    expectedIters[i] = width_ * width_ * (unsigned long long) maxIter[i];
+    expectedIters[i] = width_ * width_ * (unsigned long long)maxIter[i];
     if (testCase != 0) {
       checkData(hPtr[i]);
       if (totalIters != expectedIters[i]) {
-        std::cout << "Incorrect iteration count detected" << std::endl;
+        CONSOLE_PRINT("Incorrect iteration count detected");
       }
     }
 
@@ -216,31 +205,30 @@ bool hipPerfDeviceConcurrency::run(unsigned int testCase, int numGpus) {
   }
 
   if (testCase != 0) {
-  std::cout << '\n' << "Measured time for kernel computation on " << numGpus
-            << " device (s): " << all_kernel_time.count() << " (s) "
-            << '\n' << std::endl;
+    CONSOLE_PRINT("\nMeasured time for kernel computation on %d device(s): %.6f (s)\n", numGpus,
+                  all_kernel_time.count());
   }
 
   if (testCase == 0) {
     deviceId++;
   }
-  delete [] hPtr;
-  delete [] dPtr;
-  delete [] streams;
-  delete [] numCUs;
-  delete [] maxIter;
-  delete [] expectedIters;
+  delete[] hPtr;
+  delete[] dPtr;
+  delete[] streams;
+  delete[] numCUs;
+  delete[] maxIter;
+  delete[] expectedIters;
   return true;
 }
 
-void hipPerfDeviceConcurrency::setData(void *ptr, unsigned int value) {
-  unsigned int *ptr2 = (unsigned int *)ptr;
-  for (unsigned int i = 0; i < width_ * width_ ; i++) {
-      ptr2[i] = value;
+void hipPerfDeviceConcurrency::setData(void* ptr, unsigned int value) {
+  unsigned int* ptr2 = (unsigned int*)ptr;
+  for (unsigned int i = 0; i < width_ * width_; i++) {
+    ptr2[i] = value;
   }
 }
 
-void hipPerfDeviceConcurrency::checkData(uint *ptr) {
+void hipPerfDeviceConcurrency::checkData(uint* ptr) {
   totalIters = 0;
   for (unsigned int i = 0; i < width_ * width_; i++) {
     totalIters += ptr[i];
@@ -248,16 +236,16 @@ void hipPerfDeviceConcurrency::checkData(uint *ptr) {
 }
 
 /**
-* Test Description
-* ------------------------
-*  - Verify the different levels of device concurrency.
-* Test source
-* ------------------------
-*  - perftests/stream/hipPerfDeviceConcurrency.cc
-* Test requirements
-* ------------------------
-*  - HIP_VERSION >= 5.6
-*/
+ * Test Description
+ * ------------------------
+ *  - Verify the different levels of device concurrency.
+ * Test source
+ * ------------------------
+ *  - perftests/stream/hipPerfDeviceConcurrency.cc
+ * Test requirements
+ * ------------------------
+ *  - HIP_VERSION >= 5.6
+ */
 
 TEST_CASE("Perf_hipPerfDeviceConcurrency") {
   hipPerfDeviceConcurrency deviceConcurrency;
@@ -279,6 +267,6 @@ TEST_CASE("Perf_hipPerfDeviceConcurrency") {
 }
 
 /**
-* End doxygen group perfStreamTest.
-* @}
-*/
+ * End doxygen group perfStreamTest.
+ * @}
+ */
