@@ -18,12 +18,12 @@
  */
 
 /**
-* @addtogroup hipPerfStreamConcurrency hipPerfStreamConcurrency
-* @{
-* @ingroup perfComputeTest
-* `hipError_t hipStreamCreate(hipStream_t* stream)` -
-* Create an asynchronous stream.
-*/
+ * @addtogroup hipPerfStreamConcurrency hipPerfStreamConcurrency
+ * @{
+ * @ingroup perfComputeTest
+ * `hipError_t hipStreamCreate(hipStream_t* stream)` -
+ * Create an asynchronous stream.
+ */
 
 #include <hip_test_common.hh>
 #include <hip/hip_vector_types.h>
@@ -55,23 +55,23 @@ static coordRec coords[] = {
 
 static unsigned int numCoords = sizeof(coords) / sizeof(coordRec);
 
-__global__ static void mandelbrot(uint *out, uint width, float xPos, float yPos,
-         float xStep, float yStep, uint maxIter) {
+__global__ static void mandelbrot(uint* out, uint width, float xPos, float yPos, float xStep,
+                                  float yStep, uint maxIter) {
   int tid = (blockIdx.x * blockDim.x + threadIdx.x);
-  int i = tid % (width/4);
-  int j = tid / (width/4);
-  int4 veci = make_int4(4*i, 4*i+1, 4*i+2, 4*i+3);
+  int i = tid % (width / 4);
+  int j = tid / (width / 4);
+  int4 veci = make_int4(4 * i, 4 * i + 1, 4 * i + 2, 4 * i + 3);
   int4 vecj = make_int4(j, j, j, j);
   float4 x0;
-  x0.x = static_cast<float>(xPos + xStep*veci.x);
-  x0.y = static_cast<float>(xPos + xStep*veci.y);
-  x0.z = static_cast<float>(xPos + xStep*veci.z);
-  x0.w = static_cast<float>(xPos + xStep*veci.w);
+  x0.x = static_cast<float>(xPos + xStep * veci.x);
+  x0.y = static_cast<float>(xPos + xStep * veci.y);
+  x0.z = static_cast<float>(xPos + xStep * veci.z);
+  x0.w = static_cast<float>(xPos + xStep * veci.w);
   float4 y0;
-  y0.x = static_cast<float>(yPos + yStep*vecj.x);
-  y0.y = static_cast<float>(yPos + yStep*vecj.y);
-  y0.z = static_cast<float>(yPos + yStep*vecj.z);
-  y0.w = static_cast<float>(yPos + yStep*vecj.w);
+  y0.x = static_cast<float>(yPos + yStep * vecj.x);
+  y0.y = static_cast<float>(yPos + yStep * vecj.y);
+  y0.z = static_cast<float>(yPos + yStep * vecj.z);
+  y0.w = static_cast<float>(yPos + yStep * vecj.w);
   float4 x = x0;
   float4 y = y0;
   uint iter = 0;
@@ -80,53 +80,52 @@ __global__ static void mandelbrot(uint *out, uint width, float xPos, float yPos,
   int4 ccount = make_int4(0, 0, 0, 0);
   float4 savx = x;
   float4 savy = y;
-  stay.x = (x.x*x.x+y.x*y.x) <= static_cast<float>(4.0f);
-  stay.y = (x.y*x.y+y.y*y.y) <= static_cast<float>(4.0f);
-  stay.z = (x.z*x.z+y.z*y.z) <= static_cast<float>(4.0f);
-  stay.w = (x.w*x.w+y.w*y.w) <= static_cast<float>(4.0f);
-  for (iter = 0; (stay.x | stay.y | stay.z | stay.w) && (iter < maxIter);
-  iter+=16) {
+  stay.x = (x.x * x.x + y.x * y.x) <= static_cast<float>(4.0f);
+  stay.y = (x.y * x.y + y.y * y.y) <= static_cast<float>(4.0f);
+  stay.z = (x.z * x.z + y.z * y.z) <= static_cast<float>(4.0f);
+  stay.w = (x.w * x.w + y.w * y.w) <= static_cast<float>(4.0f);
+  for (iter = 0; (stay.x | stay.y | stay.z | stay.w) && (iter < maxIter); iter += 16) {
     x = savx;
     y = savy;
     // Two iterations
-    tmp = x*x + x0 - y*y;
+    tmp = x * x + x0 - y * y;
     y = 2.0f * x * y + y0;
-    x = tmp*tmp + x0 - y*y;
+    x = tmp * tmp + x0 - y * y;
     y = 2.0f * tmp * y + y0;
     // Two iterations
-    tmp = x*x + x0 - y*y;
+    tmp = x * x + x0 - y * y;
     y = 2.0f * x * y + y0;
-    x = tmp*tmp + x0 - y*y;
+    x = tmp * tmp + x0 - y * y;
     y = 2.0f * tmp * y + y0;
     // Two iterations
-    tmp = x*x + x0 - y*y;
+    tmp = x * x + x0 - y * y;
     y = 2.0f * x * y + y0;
-    x = tmp*tmp + x0 - y*y;
+    x = tmp * tmp + x0 - y * y;
     y = 2.0f * tmp * y + y0;
     // Two iterations
-    tmp = x*x + x0 - y*y;
+    tmp = x * x + x0 - y * y;
     y = 2.0f * x * y + y0;
-    x = tmp*tmp + x0 - y*y;
+    x = tmp * tmp + x0 - y * y;
     y = 2.0f * tmp * y + y0;
     // Two iterations
-    tmp = x*x + x0 - y*y;
+    tmp = x * x + x0 - y * y;
     y = 2.0f * x * y + y0;
-    x = tmp*tmp + x0 - y*y;
+    x = tmp * tmp + x0 - y * y;
     y = 2.0f * tmp * y + y0;
     // Two iterations
-    tmp = x*x + x0 - y*y;
+    tmp = x * x + x0 - y * y;
     y = 2.0f * x * y + y0;
-    x = tmp*tmp + x0 - y*y;
+    x = tmp * tmp + x0 - y * y;
     y = 2.0f * tmp * y + y0;
     // Two iterations
-    tmp = x*x + x0 - y*y;
+    tmp = x * x + x0 - y * y;
     y = 2.0f * x * y + y0;
-    x = tmp*tmp + x0 - y*y;
+    x = tmp * tmp + x0 - y * y;
     y = 2.0f * tmp * y + y0;
-    stay.x = (x.x*x.x+y.x*y.x) <= static_cast<float>(4.0f);
-    stay.y = (x.y*x.y+y.y*y.y) <= static_cast<float>(4.0f);
-    stay.z = (x.z*x.z+y.z*y.z) <= static_cast<float>(4.0f);
-    stay.w = (x.w*x.w+y.w*y.w) <= static_cast<float>(4.0f);
+    stay.x = (x.x * x.x + y.x * y.x) <= static_cast<float>(4.0f);
+    stay.y = (x.y * x.y + y.y * y.y) <= static_cast<float>(4.0f);
+    stay.z = (x.z * x.z + y.z * y.z) <= static_cast<float>(4.0f);
+    stay.w = (x.w * x.w + y.w * y.w) <= static_cast<float>(4.0f);
     savx.x = static_cast<bool>(stay.x ? x.x : savx.x);
     savx.y = static_cast<bool>(stay.y ? x.y : savx.y);
     savx.z = static_cast<bool>(stay.z ? x.z : savx.z);
@@ -135,10 +134,10 @@ __global__ static void mandelbrot(uint *out, uint width, float xPos, float yPos,
     savy.y = static_cast<bool>(stay.y ? y.y : savy.y);
     savy.z = static_cast<bool>(stay.z ? y.z : savy.z);
     savy.w = static_cast<bool>(stay.w ? y.w : savy.w);
-    ccount.x -= stay.x*16;
-    ccount.y -= stay.y*16;
-    ccount.z -= stay.z*16;
-    ccount.w -= stay.w*16;
+    ccount.x -= stay.x * 16;
+    ccount.y -= stay.y * 16;
+    ccount.z -= stay.z * 16;
+    ccount.w -= stay.w * 16;
   }
   // Handle remainder
   if (!(stay.x & stay.y & stay.z & stay.w)) {
@@ -146,13 +145,13 @@ __global__ static void mandelbrot(uint *out, uint width, float xPos, float yPos,
     do {
       x = savx;
       y = savy;
-      stay.x = ((x.x*x.x+y.x*y.x) <= 4.0f) && (ccount.x <  maxIter);
-      stay.y = ((x.y*x.y+y.y*y.y) <= 4.0f) && (ccount.y <  maxIter);
-      stay.z = ((x.z*x.z+y.z*y.z) <= 4.0f) && (ccount.z <  maxIter);
-      stay.w = ((x.w*x.w+y.w*y.w) <= 4.0f) && (ccount.w <  maxIter);
+      stay.x = ((x.x * x.x + y.x * y.x) <= 4.0f) && (ccount.x < maxIter);
+      stay.y = ((x.y * x.y + y.y * y.y) <= 4.0f) && (ccount.y < maxIter);
+      stay.z = ((x.z * x.z + y.z * y.z) <= 4.0f) && (ccount.z < maxIter);
+      stay.w = ((x.w * x.w + y.w * y.w) <= 4.0f) && (ccount.w < maxIter);
       tmp = x;
-      x = x*x + x0 - y*y;
-      y = 2.0f*tmp*y + y0;
+      x = x * x + x0 - y * y;
+      y = 2.0f * tmp * y + y0;
       ccount.x += stay.x;
       ccount.y += stay.y;
       ccount.z += stay.z;
@@ -168,7 +167,7 @@ __global__ static void mandelbrot(uint *out, uint width, float xPos, float yPos,
       savy.w = (stay.w ? y.w : savy.w);
     } while ((stay.x | stay.y | stay.z | stay.w) && iter);
   }
-  uint4 *vecOut = reinterpret_cast<uint4 *>(out);
+  uint4* vecOut = reinterpret_cast<uint4*>(out);
   vecOut[tid].x = (uint)(ccount.x);
   vecOut[tid].y = (uint)(ccount.y);
   vecOut[tid].z = (uint)(ccount.z);
@@ -180,27 +179,19 @@ class hipPerfStreamConcurrency {
   hipPerfStreamConcurrency();
   ~hipPerfStreamConcurrency();
 
-  void setNumKernels(unsigned int num) {
-    numKernels = num;
-  }
-  void setNumStreams(unsigned int num) {
-    numStreams = num;
-  }
-  unsigned int getNumStreams() {
-    return numStreams;
-  }
+  void setNumKernels(unsigned int num) { numKernels = num; }
+  void setNumStreams(unsigned int num) { numStreams = num; }
+  unsigned int getNumStreams() { return numStreams; }
 
-  unsigned int getNumKernels() {
-    return numKernels;
-  }
+  unsigned int getNumKernels() { return numKernels; }
 
   bool open(int deviceID);
   bool run(unsigned int testCase, unsigned int deviceId);
   void close(void);
 
  private:
-  void setData(void *ptr, unsigned int value);
-  void checkData(uint *ptr);
+  void setData(void* ptr, unsigned int value);
+  void checkData(uint* ptr);
 
   unsigned int numKernels;
   unsigned int numStreams;
@@ -227,38 +218,34 @@ bool hipPerfStreamConcurrency::open(int deviceId) {
   HIP_CHECK(hipSetDevice(deviceId));
   hipDeviceProp_t props;
   HIP_CHECK(hipGetDeviceProperties(&props, deviceId));
-  std::cout << "info: running on bus " << "0x" << props.pciBusID
-    << " " << props.name << " with " << props.multiProcessorCount << " CUs"
-     << " and device id: " << deviceId  << std::endl;
+  CONSOLE_PRINT("info: running on bus 0x%x %s with %d CUs and device ID: %d", props.pciBusID,
+                props.name, props.multiProcessorCount, deviceId);
+
   numCUs = props.multiProcessorCount;
   return true;
 }
 
-void hipPerfStreamConcurrency::close() {
-}
+void hipPerfStreamConcurrency::close() {}
 
-bool hipPerfStreamConcurrency::run(unsigned int testCase,
-                               unsigned int deviceId) {
+bool hipPerfStreamConcurrency::run(unsigned int testCase, unsigned int deviceId) {
   int clkFrequency = 0;
   unsigned int numStreams = getNumStreams();
   unsigned int numKernels = getNumKernels();
 
-  HIP_CHECK(hipDeviceGetAttribute(&clkFrequency,
-             hipDeviceAttributeClockRate, deviceId));
+  HIP_CHECK(hipDeviceGetAttribute(&clkFrequency, hipDeviceAttributeClockRate, deviceId));
   if (clkFrequency == 0) {
-    std::cout << "clkFrequency = 0, set it to 1000000\n";
+    CONSOLE_PRINT("clkFrequency = 0, set it to 1000000\n");
     clkFrequency = 1000000;
   }
-  clkFrequency =(unsigned int)clkFrequency/1000;
+  clkFrequency = (unsigned int)clkFrequency / 1000;
 
   // Maximum iteration count
   // maxIter = 8388608 * (engine_clock / 1000).serial execution
-  maxIter = (unsigned int)(((8388608 * (static_cast<float>(clkFrequency) / 1000))
-                                                        * numCUs) / 128);
+  maxIter = (unsigned int)(((8388608 * (static_cast<float>(clkFrequency) / 1000)) * numCUs) / 128);
   maxIter = (maxIter + 15) & ~15;
-  hipStream_t *streams = new hipStream_t[numStreams];
-  uint ** hPtr = new uint*[numKernels];
-  uint ** dPtr = new uint*[numKernels];
+  hipStream_t* streams = new hipStream_t[numStreams];
+  uint** hPtr = new uint*[numKernels];
+  uint** dPtr = new uint*[numKernels];
 
   // Width is divisible by 4 because the mandelbrot kernel
   // processes 4 pixels at once.
@@ -271,16 +258,15 @@ bool hipPerfStreamConcurrency::run(unsigned int testCase,
 
   // Allocate memory on the host and device
   for (uint i = 0; i < numKernels; i++) {
-    HIP_CHECK(hipHostMalloc(reinterpret_cast<void **>(&hPtr[i]),
-                            bufSize, hipHostMallocDefault));
+    HIP_CHECK(hipHostMalloc(reinterpret_cast<void**>(&hPtr[i]), bufSize, hipHostMallocDefault));
     setData(hPtr[i], 0xdeadbeef);
-    HIP_CHECK(hipMalloc(reinterpret_cast<void **>(&dPtr[i]), bufSize))
+    HIP_CHECK(hipMalloc(reinterpret_cast<void**>(&dPtr[i]), bufSize))
   }
 
   // Prepare kernel launch parameters
-  int threads = (bufSize/sizeof(uint));
-  int threads_per_block  = 64;
-  int blocks = (threads/threads_per_block) + (threads % threads_per_block);
+  int threads = (bufSize / sizeof(uint));
+  int threads_per_block = 64;
+  int blocks = (threads / threads_per_block) + (threads % threads_per_block);
   coordIdx = testCase % numCoords;
   float xStep = static_cast<float>(coords[coordIdx].width / static_cast<double>(width_));
   float yStep = static_cast<float>(-coords[coordIdx].width / static_cast<double>(width_));
@@ -289,8 +275,8 @@ bool hipPerfStreamConcurrency::run(unsigned int testCase,
 
   // Copy memory asynchronously and concurrently from host to device
   for (uint i = 0; i < numKernels; i++) {
-    HIP_CHECK(hipMemcpyHtoDAsync(reinterpret_cast<hipDeviceptr_t>(dPtr[i]),
-                                 hPtr[i], bufSize, streams[i % numStreams]));
+    HIP_CHECK(hipMemcpyHtoDAsync(reinterpret_cast<hipDeviceptr_t>(dPtr[i]), hPtr[i], bufSize,
+                                 streams[i % numStreams]));
   }
 
   // Synchronize to make sure all the copies are completed
@@ -305,9 +291,8 @@ bool hipPerfStreamConcurrency::run(unsigned int testCase,
   auto all_start = std::chrono::steady_clock::now();
 
   for (uint i = 0; i < numKernels; i++) {
-    hipLaunchKernelGGL(mandelbrot, dim3(blocks), dim3(threads_per_block),
-    0, streams[i%numStreams], dPtr[i], width_, xPos, yPos, xStep,
-     yStep, maxIter);
+    hipLaunchKernelGGL(mandelbrot, dim3(blocks), dim3(threads_per_block), 0,
+                       streams[i % numStreams], dPtr[i], width_, xPos, yPos, xStep, yStep, maxIter);
   }
 
   // Synchronize all the concurrent streans to have completed execution
@@ -320,17 +305,16 @@ bool hipPerfStreamConcurrency::run(unsigned int testCase,
 
   // Copy data back from device to the host
   for (uint i = 0; i < numKernels; i++) {
-    HIP_CHECK(hipMemcpyDtoHAsync(hPtr[i],
-     reinterpret_cast<hipDeviceptr_t>(dPtr[i]), bufSize,
-      streams[i % numStreams]));
+    HIP_CHECK(hipMemcpyDtoHAsync(hPtr[i], reinterpret_cast<hipDeviceptr_t>(dPtr[i]), bufSize,
+                                 streams[i % numStreams]));
   }
 
   if (testCase != 0) {
-  std::cout <<"Measured time for " << numKernels <<" kernels (s) on "
-  << numStreams <<" stream (s): " << all_kernel_time.count() << std::endl;
+    CONSOLE_PRINT("Measured time for %d kernels (s) on %d stream(s): %e\n", numKernels, numStreams,
+                  all_kernel_time.count());
   }
 
-  for (uint i = 0 ; i < numStreams; i++) {
+  for (uint i = 0; i < numStreams; i++) {
     HIP_CHECK(hipStreamDestroy(streams[i]));
   }
 
@@ -340,20 +324,20 @@ bool hipPerfStreamConcurrency::run(unsigned int testCase,
     HIP_CHECK(hipFree(dPtr[i]));
   }
 
-  delete [] streams;
-  delete [] hPtr;
-  delete [] dPtr;
+  delete[] streams;
+  delete[] hPtr;
+  delete[] dPtr;
   return true;
 }
 
-void hipPerfStreamConcurrency::setData(void *ptr, unsigned int value) {
-  unsigned int *ptr2 = (unsigned int *)ptr;
-  for (unsigned int i = 0; i < width_ ; i++) {
-      ptr2[i] = value;
+void hipPerfStreamConcurrency::setData(void* ptr, unsigned int value) {
+  unsigned int* ptr2 = (unsigned int*)ptr;
+  for (unsigned int i = 0; i < width_; i++) {
+    ptr2[i] = value;
   }
 }
 
-void hipPerfStreamConcurrency::checkData(uint *ptr) {
+void hipPerfStreamConcurrency::checkData(uint* ptr) {
   totalIters = 0;
   for (unsigned int i = 0; i < width_; i++) {
     totalIters += ptr[i];
@@ -361,16 +345,16 @@ void hipPerfStreamConcurrency::checkData(uint *ptr) {
 }
 
 /**
-* Test Description
-* ------------------------
-*  - Verify the different levels of stream concurrency.
-* Test source
-* ------------------------
-*  - perftests/stream/hipPerfStreamConcurrency.cc
-* Test requirements
-* ------------------------
-*  - HIP_VERSION >= 5.6
-*/
+ * Test Description
+ * ------------------------
+ *  - Verify the different levels of stream concurrency.
+ * Test source
+ * ------------------------
+ *  - perftests/stream/hipPerfStreamConcurrency.cc
+ * Test requirements
+ * ------------------------
+ *  - HIP_VERSION >= 5.6
+ */
 
 TEST_CASE("Perf_hipPerfStreamConcurrency") {
   hipPerfStreamConcurrency streamConcurrency;
@@ -386,10 +370,10 @@ TEST_CASE("Perf_hipPerfStreamConcurrency") {
         break;
 
       case 1:
-      // default stream executes serially
-      streamConcurrency.setNumStreams(1);
-      streamConcurrency.setNumKernels(1);
-      break;
+        // default stream executes serially
+        streamConcurrency.setNumStreams(1);
+        streamConcurrency.setNumKernels(1);
+        break;
 
       case 2:
         // 2-way concurrency
@@ -419,6 +403,6 @@ TEST_CASE("Perf_hipPerfStreamConcurrency") {
 }
 
 /**
-* End doxygen group perfComputeTest.
-* @}
-*/
+ * End doxygen group perfComputeTest.
+ * @}
+ */
