@@ -127,16 +127,16 @@ TEMPLATE_TEST_CASE("Unit_unsafeAtomicAdd_Positive_Multi_Kernel", "", float, doub
 }
 
 template <typename Type,
-          std::enable_if_t<std::is_same<Type, __half2>::value ||
-                               std::is_same<Type, __hip_bfloat162>::value ||
-                               std::is_same<Type, __hip_bfloat16>::value ||
-                               std::is_same<Type, __half>::value,
-                           bool> = true>
+          std::enable_if_t<
+              std::is_same<Type, __half2>::value || std::is_same<Type, __hip_bfloat162>::value ||
+                  std::is_same<Type, __hip_bfloat16>::value || std::is_same<Type, __half>::value,
+              bool> = true>
 __global__ void unsafe_add_kernel(Type* ptr, Type val) {
   (void)unsafeAtomicAdd(ptr, val);
 }
 
-TEMPLATE_TEST_CASE("Unit_unsafe_atomic_add_half_and_bfloat", "", __half2, __hip_bfloat162, __half, __hip_bfloat16) {
+TEMPLATE_TEST_CASE("Unit_unsafe_atomic_add_half_and_bfloat", "", __half2, __hip_bfloat162, __half,
+                   __hip_bfloat16) {
   auto kernel = unsafe_add_kernel<TestType>;
   TestType val;
   if constexpr (std::is_same<TestType, __half2>::value) {
@@ -164,7 +164,7 @@ TEMPLATE_TEST_CASE("Unit_unsafe_atomic_add_half_and_bfloat", "", __half2, __hip_
     hout = __bfloat1622float2(dout);
   } else if constexpr (std::is_same<TestType, __half>::value) {
     hout.x = 32.0f;
-    hout.y  = __half2float(dout);
+    hout.y = __half2float(dout);
   } else {
     hout.x = 32.0f;
     hout.y = __bfloat162float(dout);
@@ -172,9 +172,10 @@ TEMPLATE_TEST_CASE("Unit_unsafe_atomic_add_half_and_bfloat", "", __half2, __hip_
 
   REQUIRE(hout.x == 32.0f);
   REQUIRE(hout.y == 64.0f);
+  HIP_CHECK(hipFree(out));
 }
 
 /**
-* End doxygen group AtomicsTest.
-* @}
-*/
+ * End doxygen group AtomicsTest.
+ * @}
+ */
