@@ -54,7 +54,7 @@ __device__ int reduction_kernel_shfl_down(coalesced_group const& g, int val) {
   }
 }
 
-__global__ void kernel_shfl_down (int * dPtr, int *dResults, int lane_delta, int cg_sizes) {
+__global__ void kernel_shfl_down(int* dPtr, int* dResults, int lane_delta, int cg_sizes) {
   int id = threadIdx.x + blockIdx.x * blockDim.x;
 
   if (id % cg_sizes == 0) {
@@ -66,11 +66,11 @@ __global__ void kernel_shfl_down (int * dPtr, int *dResults, int lane_delta, int
   }
 }
 
-__global__ void kernel_cg_group_partition_shfl_down(int* result, unsigned int tileSz, int cg_sizes) {
-
+__global__ void kernel_cg_group_partition_shfl_down(int* result, unsigned int tileSz,
+                                                    int cg_sizes) {
   int id = threadIdx.x + blockIdx.x * blockDim.x;
   if (id % cg_sizes == 0) {
-    coalesced_group  threadBlockCGTy = coalesced_threads();
+    coalesced_group threadBlockCGTy = coalesced_threads();
     int input, outputSum, expectedSum;
 
     // Choose a leader thread to print the results
@@ -131,7 +131,6 @@ static void test_group_partition(unsigned int tileSz) {
 
   std::vector<unsigned int> cg_sizes = {1, 2, 3};
   for (auto i : cg_sizes) {
-
     int numTiles = ((blockSize * threadsPerBlock) / i) / tileSz;
     int expectedSum = ((tileSz - 1) * tileSz / 2);
     int* expectedResult = new int[numTiles];
@@ -156,7 +155,7 @@ static void test_group_partition(unsigned int tileSz) {
     // Launch Kernel
     hipLaunchKernelGGL(kernel_cg_group_partition_shfl_down, blockSize, threadsPerBlock,
                        threadsPerBlock * sizeof(int), 0, dResult, tileSz, i);
-    HIP_CHECK(hipGetLastError()); 
+    HIP_CHECK(hipGetLastError());
     err = hipDeviceSynchronize();
     if (err != hipSuccess) {
       fprintf(stderr, "Failed to launch kernel (error code %s)!\n", hipGetErrorString(err));
@@ -177,10 +176,8 @@ static void test_group_partition(unsigned int tileSz) {
 }
 
 static void test_shfl_down() {
-
   std::vector<unsigned int> cg_sizes = {1, 2, 3};
   for (auto i : cg_sizes) {
-
     hipError_t err;
     int blockSize = 1;
     int threadsPerBlock = WAVE_SIZE;
@@ -193,8 +190,9 @@ static void test_shfl_down() {
     int* dPtr = NULL;
     int* dResults = NULL;
     int lane_delta = rand() % group_size;
-    std::cout << "Testing coalesced_groups shfl_down with lane_delta " << lane_delta << "and group size "
-              << WAVE_SIZE << '\n' << std::endl;
+    std::cout << "Testing coalesced_groups shfl_down with lane_delta " << lane_delta
+              << "and group size " << WAVE_SIZE << '\n'
+              << std::endl;
 
     int arrSize = blockSize * threadsPerBlock * sizeof(int);
 
@@ -208,37 +206,37 @@ static void test_shfl_down() {
     for (int i = 0; i < group_size; i++) {
       cpuResultsArr[i] = (i + lane_delta >= group_size) ? hPtr[i] : hPtr[i + lane_delta];
     }
-    //printf("Array passed to GPU for computation\n");
-    //printResultsCoalescedGroupsShflDown(hPtr, WAVE_SIZE);
+    // printf("Array passed to GPU for computation\n");
+    // printResultsCoalescedGroupsShflDown(hPtr, WAVE_SIZE);
     HIPCHECK(hipMalloc(&dPtr, group_size_in_bytes));
     HIPCHECK(hipMalloc(&dResults, group_size_in_bytes));
 
     HIPCHECK(hipMemcpy(dPtr, hPtr, group_size_in_bytes, hipMemcpyHostToDevice));
     // Launch Kernel
-    hipLaunchKernelGGL(kernel_shfl_down, blockSize, threadsPerBlock,
-                       threadsPerBlock * sizeof(int), 0, dPtr, dResults, lane_delta, i);
-    HIP_CHECK(hipGetLastError()); 
+    hipLaunchKernelGGL(kernel_shfl_down, blockSize, threadsPerBlock, threadsPerBlock * sizeof(int),
+                       0, dPtr, dResults, lane_delta, i);
+    HIP_CHECK(hipGetLastError());
     HIPCHECK(hipMemcpy(hPtr, dResults, group_size_in_bytes, hipMemcpyDeviceToHost));
     err = hipDeviceSynchronize();
     if (err != hipSuccess) {
       fprintf(stderr, "Failed to launch kernel (error code %s)!\n", hipGetErrorString(err));
     }
-    //printf("GPU results: \n");
-    //printResultsCoalescedGroupsShflDown(hPtr, WAVE_SIZE);
-    //printf("Printing cpu to be verified array\n");
-    //printResultsCoalescedGroupsShflDown(cpuResultsArr, WAVE_SIZE);
+    // printf("GPU results: \n");
+    // printResultsCoalescedGroupsShflDown(hPtr, WAVE_SIZE);
+    // printf("Printing cpu to be verified array\n");
+    // printResultsCoalescedGroupsShflDown(cpuResultsArr, WAVE_SIZE);
 
     compareResultsCoalescedGroupsShflDown(hPtr, cpuResultsArr, group_size_in_bytes);
     std::cout << "Results verified!\n";
 
     HIPCHECK(hipHostFree(hPtr));
     HIPCHECK(hipFree(dPtr));
+    HIPCHECK(hipFree(dResults));
     free(cpuResultsArr);
   }
 }
 
 
-
 TEST_CASE("Unit_coalesced_groups_shfl_down") {
   // Use default device for validating the test
   int deviceId;
@@ -247,9 +245,9 @@ TEST_CASE("Unit_coalesced_groups_shfl_down") {
   ASSERT_EQUAL(hipGetDeviceProperties(&deviceProperties, deviceId), hipSuccess);
 
   // Test shfl_down with random group sizes
-    for (int i = 0; i < 100; i++) {
-      test_shfl_down();
-    }
+  for (int i = 0; i < 100; i++) {
+    test_shfl_down();
+  }
 
   std::cout << "Testing static tiled_partition for different tile sizes using shfl_down"
             << std::endl;
@@ -261,5 +259,4 @@ TEST_CASE("Unit_coalesced_groups_shfl_down") {
     test_group_partition(i);
     testNo++;
   }
-
 }
