@@ -47,7 +47,7 @@ __device__ int prefix_sum_kernel(coalesced_group const& g, int val) {
   return val;
 }
 
-__global__ void kernel_shfl_up (int * dPtr, int *dResults, int lane_delta, int cg_sizes) {
+__global__ void kernel_shfl_up(int* dPtr, int* dResults, int lane_delta, int cg_sizes) {
   int id = threadIdx.x + blockIdx.x * blockDim.x;
 
   if (id % cg_sizes == 0) {
@@ -55,13 +55,11 @@ __global__ void kernel_shfl_up (int * dPtr, int *dResults, int lane_delta, int c
     int rank = g.thread_rank();
     int val = dPtr[rank];
     dResults[rank] = g.shfl_up(val, lane_delta);
-  return;
+    return;
   }
-
 }
 
 __global__ void kernel_cg_group_partition_shfl_up(int* dPtr, unsigned int tileSz, int cg_sizes) {
-
   int id = threadIdx.x + blockIdx.x * blockDim.x;
   if (id % cg_sizes == 0) {
     coalesced_group threadBlockCGTy = coalesced_threads();
@@ -129,7 +127,6 @@ static void test_group_partition(unsigned tileSz) {
 
   std::vector<unsigned int> cg_sizes = {1, 2, 3};
   for (auto i : cg_sizes) {
-
     int arrSize = blockSize * threadsPerBlock * sizeof(int);
 
     HIPCHECK(hipHostMalloc(&hPtr, arrSize));
@@ -137,8 +134,8 @@ static void test_group_partition(unsigned tileSz) {
 
     // Launch Kernel
     hipLaunchKernelGGL(kernel_cg_group_partition_shfl_up, blockSize, threadsPerBlock,
-                     threadsPerBlock * sizeof(int), 0, dPtr, tileSz, i);
-    HIP_CHECK(hipGetLastError()); 
+                       threadsPerBlock * sizeof(int), 0, dPtr, tileSz, i);
+    HIP_CHECK(hipGetLastError());
     HIPCHECK(hipMemcpy(hPtr, dPtr, arrSize, hipMemcpyDeviceToHost));
     err = hipDeviceSynchronize();
     if (err != hipSuccess) {
@@ -147,11 +144,11 @@ static void test_group_partition(unsigned tileSz) {
 
     cpuPrefixSum = new int[tileSz];
     serialScan(cpuPrefixSum, tileSz);
-    //std::cout << "\nPrefix sum results on CPU\n";
-    //printResults(cpuPrefixSum, tileSz);
+    // std::cout << "\nPrefix sum results on CPU\n";
+    // printResults(cpuPrefixSum, tileSz);
 
-    //std::cout << "\nPrefix sum results on GPU\n";
-    //printResults(hPtr, tileSz);
+    // std::cout << "\nPrefix sum results on GPU\n";
+    // printResults(hPtr, tileSz);
     std::cout << "\n";
     verifyResultsCoalescedGroupsShflUp(hPtr, cpuPrefixSum, tileSz);
     std::cout << "Results verified!\n";
@@ -163,10 +160,8 @@ static void test_group_partition(unsigned tileSz) {
 }
 
 static void test_shfl_up() {
-
   std::vector<unsigned int> cg_sizes = {1, 2, 3};
   for (auto i : cg_sizes) {
-
     hipError_t err;
     int blockSize = 1;
 
@@ -178,10 +173,11 @@ static void test_shfl_up() {
     int* hPtr = NULL;
     int* dPtr = NULL;
     int* dResults = NULL;
-    int lane_delta =  (rand() % group_size);
+    int lane_delta = (rand() % group_size);
 
     std::cout << "Testing coalesced_groups shfl_up with lane_delta " << lane_delta
-              << " and group size " << WAVE_SIZE << '\n' << std::endl;
+              << " and group size " << WAVE_SIZE << '\n'
+              << std::endl;
 
     int arrSize = blockSize * threadsPerBlock * sizeof(int);
 
@@ -190,37 +186,38 @@ static void test_shfl_up() {
     for (int i = 0; i < WAVE_SIZE; i++) {
       hPtr[i] = rand() % 1000;
     }
-    //printResults(hPtr, WAVE_SIZE);
+    // printResults(hPtr, WAVE_SIZE);
 
     int* cpuResultsArr = (int*)malloc(group_size_in_bytes);
     for (int i = 0; i < group_size; i++) {
-      cpuResultsArr[i] = (i <= (lane_delta - 1)) ?  hPtr[i] : hPtr[i - lane_delta];
+      cpuResultsArr[i] = (i <= (lane_delta - 1)) ? hPtr[i] : hPtr[i - lane_delta];
     }
 
-    //printf("Printing cpu results arr\n");
-    //printResults(cpuResultsArr, WAVE_SIZE);
+    // printf("Printing cpu results arr\n");
+    // printResults(cpuResultsArr, WAVE_SIZE);
 
     HIPCHECK(hipMalloc(&dPtr, group_size_in_bytes));
     HIPCHECK(hipMalloc(&dResults, group_size_in_bytes));
 
     HIPCHECK(hipMemcpy(dPtr, hPtr, group_size_in_bytes, hipMemcpyHostToDevice));
     // Launch Kernel
-    hipLaunchKernelGGL(kernel_shfl_up, blockSize, threadsPerBlock,
-                       threadsPerBlock * sizeof(int), 0, dPtr, dResults, lane_delta, i);
+    hipLaunchKernelGGL(kernel_shfl_up, blockSize, threadsPerBlock, threadsPerBlock * sizeof(int), 0,
+                       dPtr, dResults, lane_delta, i);
     HIPCHECK(hipMemcpy(hPtr, dResults, group_size_in_bytes, hipMemcpyDeviceToHost));
-    HIP_CHECK(hipGetLastError()); 
+    HIP_CHECK(hipGetLastError());
     err = hipDeviceSynchronize();
     if (err != hipSuccess) {
       fprintf(stderr, "Failed to launch kernel (error code %s)!\n", hipGetErrorString(err));
     }
-    //printf("GPU computation array :\n");
-    //printResults(hPtr, WAVE_SIZE);
+    // printf("GPU computation array :\n");
+    // printResults(hPtr, WAVE_SIZE);
 
     verifyResultsCoalescedGroupsShflUp(hPtr, cpuResultsArr, group_size_in_bytes);
     std::cout << "Results verified!\n";
 
     HIPCHECK(hipHostFree(hPtr));
     HIPCHECK(hipFree(dPtr));
+    HIPCHECK(hipFree(dResults));
     free(cpuResultsArr);
   }
 }
@@ -233,7 +230,7 @@ TEST_CASE("Unit_coalesced_groups_shfl_up") {
   ASSERT_EQUAL(hipGetDeviceProperties(&deviceProperties, deviceId), hipSuccess);
 
   for (int i = 0; i < 100; i++) {
-      test_shfl_up();
+    test_shfl_up();
   }
 
   std::cout << "Testing coalesced_groups partitioning and shfl_up" << '\n' << std::endl;
