@@ -81,8 +81,8 @@ static __global__ void thread_block_non_member_thread_rank_getter(unsigned int*
 TEST_CASE("Unit_Thread_Block_Getters_Positive_Basic") {
   const auto blocks = GenerateBlockDimensions();
   const auto threads = GenerateThreadDimensions();
-  if (blocks.x <= 0 || blocks.y <= 0 || blocks.z <= 0 ||
-      threads.x <= 0 || threads.y <= 0 || threads.z <= 0) {
+  if (blocks.x <= 0 || blocks.y <= 0 || blocks.z <= 0 || threads.x <= 0 || threads.y <= 0 ||
+      threads.z <= 0) {
     return;
   }
   INFO("Grid dimensions: x " << blocks.x << ", y " << blocks.y << ", z " << blocks.z);
@@ -159,8 +159,8 @@ TEST_CASE("Unit_Thread_Block_Getters_Positive_Basic") {
 TEST_CASE("Unit_Thread_Block_Getters_Via_Base_Type_Positive_Basic") {
   const auto blocks = GenerateBlockDimensions();
   const auto threads = GenerateThreadDimensions();
-  if (blocks.x <= 0 || blocks.y <= 0 || blocks.z <= 0 ||
-      threads.x <= 0 || threads.y <= 0 || threads.z <= 0) {
+  if (blocks.x <= 0 || blocks.y <= 0 || blocks.z <= 0 || threads.x <= 0 || threads.y <= 0 ||
+      threads.z <= 0) {
     return;
   }
   INFO("Grid dimensions: x " << blocks.x << ", y " << blocks.y << ", z " << blocks.z);
@@ -210,8 +210,8 @@ TEST_CASE("Unit_Thread_Block_Getters_Via_Base_Type_Positive_Basic") {
 TEST_CASE("Unit_Thread_Block_Getters_Via_Non_Member_Functions_Positive_Basic") {
   const auto blocks = GenerateBlockDimensions();
   const auto threads = GenerateThreadDimensions();
-  if (blocks.x <= 0 || blocks.y <= 0 || blocks.z <= 0 ||
-      threads.x <= 0 || threads.y <= 0 || threads.z <= 0) {
+  if (blocks.x <= 0 || blocks.y <= 0 || blocks.z <= 0 || threads.x <= 0 || threads.y <= 0 ||
+      threads.z <= 0) {
     return;
   }
   INFO("Grid dimensions: x " << blocks.x << ", y " << blocks.y << ", z " << blocks.z);
@@ -363,6 +363,6 @@ TEMPLATE_TEST_CASE("Unit_Thread_Block_Sync_Positive_Basic", "", uint8_t, uint16_
 }
 
 /**
-* End doxygen group DeviceLanguageTest.
-* @}
-*/
+ * End doxygen group DeviceLanguageTest.
+ * @}
+ */
