@@ -31,7 +31,7 @@ THE SOFTWARE.
 #include <sstream>
 #include <vector>
 #include <thread>  // NOLINT
-#include <mutex>  //NOLINT
+#include <mutex>   //NOLINT
 
 #ifdef _WIN64
 #define setenv(x, y, z) _putenv_s(x, y)
@@ -40,7 +40,7 @@ THE SOFTWARE.
 #define COMMAND_LEN 256
 #define BUFFER_LEN 512
 
-std::atomic<int> tState { 1 }; // 0:fail, 1:pass, 2:skip
+std::atomic<int> tState{1};  // 0:fail, 1:pass, 2:skip
 
 /**
  * @addtogroup hipDeviceGetUuid hipDeviceGetUuid
@@ -149,10 +149,10 @@ TEST_CASE("Unit_hipDeviceGetUuid_From_RocmInfo") {
     std::string rocminfo_line(command_op);
     if (std::string::npos != rocminfo_line.find("CPU-")) {
       continue;
-    } else if (auto loc = rocminfo_line.find("GPU-");
-                    loc != std::string::npos) {
+    } else if (auto loc = rocminfo_line.find("GPU-"); loc != std::string::npos) {
       if (std::string::npos ==
-        rocminfo_line.find("GPU-XX")) {  // Only make an entry if the device is not an iGPU  // NOLINT
+          rocminfo_line.find(
+              "GPU-XX")) {  // Only make an entry if the device is not an iGPU  // NOLINT
         std::vector<char> t_uuid(16, 0);
         std::memcpy(t_uuid.data(), &rocminfo_line[loc + 4], 16);
         uuid_map[j] = t_uuid;
@@ -208,7 +208,7 @@ TEST_CASE("Unit_hipDeviceGetUuid_VerifyUuidFrm_hipGetDeviceProperties") {
 
 #if HT_AMD
 #ifdef __linux__
-auto  getUUIDlistFromRocmInfo() {
+auto getUUIDlistFromRocmInfo() {
   FILE* fpipe;
   char command[COMMAND_LEN] = "";
   const char* rocmInfo = "rocminfo";
@@ -228,10 +228,8 @@ auto  getUUIDlistFromRocmInfo() {
     std::string rocminfo_line(command_op);
     if (std::string::npos != rocminfo_line.find("CPU-")) {
       continue;
-    } else if (auto loc = rocminfo_line.find("GPU-");
-                    loc != std::string::npos) {
-      if (std::string::npos ==
-          rocminfo_line.find("GPU-XX")) {
+    } else if (auto loc = rocminfo_line.find("GPU-"); loc != std::string::npos) {
+      if (std::string::npos == rocminfo_line.find("GPU-XX")) {
         std::vector<char> t_uuid(20, 0);
         std::memcpy(t_uuid.data(), &rocminfo_line[loc], 20);
         uuid_map[j] = t_uuid;
@@ -269,7 +267,7 @@ auto getUUIDlistWithoutRocmInfo() {
  * ------------------------
  *  - All the tests contains the various cases of setting the Env
  *  - var HIP_VISIBLE_DEVICES in different process (parent/child)
- *  - and verifies the Env functionality by checking UUID'S in 
+ *  - and verifies the Env functionality by checking UUID'S in
  *  - different process.
  * Test source
  * ------------------------
@@ -280,11 +278,11 @@ auto getUUIDlistWithoutRocmInfo() {
  */
 TEST_CASE("Unit_Uuid_FntlTstsFor_SetEnv_HIP_VISIBLE_DEVICES") {
   std::map<int, std::vector<char>> uuid_map;
-  #ifdef __linux__
-    uuid_map = getUUIDlistFromRocmInfo();
-  #else
-    uuid_map = getUUIDlistWithoutRocmInfo();
-  #endif
+#ifdef __linux__
+  uuid_map = getUUIDlistFromRocmInfo();
+#else
+  uuid_map = getUUIDlistWithoutRocmInfo();
+#endif
   if (uuid_map.size() > 0) {
     SECTION("Set Env in parent and verify UUID in child ") {
       // Set Env Var with first GPU
@@ -297,7 +295,7 @@ TEST_CASE("Unit_Uuid_FntlTstsFor_SetEnv_HIP_VISIBLE_DEVICES") {
       REQUIRE(proc.run(t_uuid) == 1);
       unsetenv("HIP_VISIBLE_DEVICES");
     }
-    #if 0  // Disabling below 2 tests due to the defect SWDEV-467665
+#if 0  // Disabling below 2 tests due to the defect SWDEV-467665
     SECTION("Set Env in parent and verify UUID in Grand child") {
       std::string uuid = uuid_map[0].data();
       std::string uuidEnv = uuid.substr(0, 20);
@@ -321,7 +319,7 @@ TEST_CASE("Unit_Uuid_FntlTstsFor_SetEnv_HIP_VISIBLE_DEVICES") {
         HipTest::HIP_SKIP_TEST("Skipping because this machine has total GPUs < 2");  // NOLINT
       }
     }
-    #endif
+#endif
     SECTION("Get Dev Count from Child") {
       if (uuid_map.size() >= 2) {
         std::string uuid = uuid_map[0].data();
@@ -338,7 +336,7 @@ TEST_CASE("Unit_Uuid_FntlTstsFor_SetEnv_HIP_VISIBLE_DEVICES") {
         HipTest::HIP_SKIP_TEST("Skipping because this machine has total GPUs < 2");  // NOLINT
       }
     }
-  #ifdef __linux__
+#ifdef __linux__
     SECTION("Get UUID from Child proc rocminfo") {
       std::string setUuid = uuid_map[0].data();
       std::string uuidEnv = setUuid.substr(0, 20);
@@ -364,7 +362,7 @@ TEST_CASE("Unit_Uuid_FntlTstsFor_SetEnv_HIP_VISIBLE_DEVICES") {
       REQUIRE(proc.run(finalUuid) == 1);
       unsetenv("HIP_VISIBLE_DEVICES");
     }
-  #endif
+#endif
     SECTION("Set multiple uuid") {
       std::string wholeString;
       std::string uuid;
@@ -410,8 +408,7 @@ TEST_CASE("Unit_Uuid_FntlTstsFor_SetEnv_HIP_VISIBLE_DEVICES") {
         std::string uuidEnv1 = uuid1.substr(0, 20);
         std::string uuid2 = uuid_map[1].data();
         std::string uuidEnv2 = uuid2.substr(0, 20);
-        std::string totalString = uuid + "," + uuidEnv2 + ","
-                                  + uuidEnv1 + "," + uuid;
+        std::string totalString = uuid + "," + uuidEnv2 + "," + uuidEnv1 + "," + uuid;
         unsetenv("HIP_VISIBLE_DEVICES");
         setenv("HIP_VISIBLE_DEVICES", totalString.c_str(), 1);
         hip::SpawnProc proc("setuuidGetDevCount", true);
@@ -430,7 +427,7 @@ TEST_CASE("Unit_Uuid_FntlTstsFor_SetEnv_HIP_VISIBLE_DEVICES") {
       HIP_CHECK(hipGetDeviceCount(&devCount));
       REQUIRE(devCount == uuid_map.size());
     }
-  #ifdef __linux__
+#ifdef __linux__
     SECTION("Chk RocmInfo Uuid list before and after set Env") {
       std::map<int, std::vector<char>> uuid_map;
       uuid_map = getUUIDlistFromRocmInfo();
@@ -441,9 +438,9 @@ TEST_CASE("Unit_Uuid_FntlTstsFor_SetEnv_HIP_VISIBLE_DEVICES") {
       uuid_map1 = getUUIDlistFromRocmInfo();
       REQUIRE(uuid_map.size() == uuid_map1.size());
     }
-  #endif
+#endif
   } else {
-      HipTest::HIP_SKIP_TEST("Skipping because this machine has total GPUs < 1");  // NOLINT
+    HipTest::HIP_SKIP_TEST("Skipping because this machine has total GPUs < 1");  // NOLINT
   }
 }
 
@@ -463,11 +460,11 @@ void ChkUUID() {
   hipUUID d_uuid{0};
   HIP_CHECK(hipDeviceGetUuid(&d_uuid, device));
   std::map<int, std::vector<char>> uuid_map;
-  #ifdef __linux__
-    uuid_map = getUUIDlistFromRocmInfo();
-  #else
-    uuid_map = getUUIDlistWithoutRocmInfo();
-  #endif
+#ifdef __linux__
+  uuid_map = getUUIDlistFromRocmInfo();
+#else
+  uuid_map = getUUIDlistWithoutRocmInfo();
+#endif
   if (!uuid_map.empty()) {
     std::string uuid = uuid_map[0].data();
     std::string t_uuid = uuid.substr(4, 19);
@@ -479,11 +476,11 @@ void ChkUUID() {
 
 void setEnv() {
   std::map<int, std::vector<char>> uuid_map;
-  #ifdef __linux__
-    uuid_map = getUUIDlistFromRocmInfo();
-  #else
-    uuid_map = getUUIDlistWithoutRocmInfo();
-  #endif
+#ifdef __linux__
+  uuid_map = getUUIDlistFromRocmInfo();
+#else
+  uuid_map = getUUIDlistWithoutRocmInfo();
+#endif
   if (uuid_map.size() >= 2) {
     std::string uuid = uuid_map[1].data();
     std::string uuidEnv = uuid.substr(0, 20);
@@ -519,6 +516,6 @@ TEST_CASE("Unit_UUID_setEnv_Thread") {
 }
 #endif
 /**
-* End doxygen group DriverTest.
-* @}
-*/
+ * End doxygen group DriverTest.
+ * @}
+ */
