@@ -25,14 +25,13 @@ atomicAdd on fineGrain memory with -munsafe-fp-atomics flag
 This testcase works only on gfx90a, gfx942, gfx950.
 */
 
-#include<hip_test_checkers.hh>
-#include<hip_test_common.hh>
-#include<hip_test_features.hh>
+#include <hip_test_checkers.hh>
+#include <hip_test_common.hh>
+#include <hip_test_features.hh>
 
 #define INC_VAL 10
 #define INITIAL_VAL 5
-template<typename T>
-static __global__ void AtomicCheck(T* Ad, T* result) {
+template <typename T> static __global__ void AtomicCheck(T* Ad, T* result) {
   T inc_val = 10;
   *result = atomicAdd(Ad, inc_val);
 }
@@ -46,8 +45,7 @@ Output: atomicAdd API would return 0 and the 0/P is 5
         global_atomic_cmpswap instruction is generated
         or not */
 
-TEMPLATE_TEST_CASE("Unit_AtomicAdd_CoherentwithUnsafeflag", "",
-                   float, double) {
+TEMPLATE_TEST_CASE("Unit_AtomicAdd_CoherentwithUnsafeflag", "", float, double) {
   hipDeviceProp_t prop;
   int device;
   HIP_CHECK(hipGetDevice(&device));
@@ -59,33 +57,26 @@ TEMPLATE_TEST_CASE("Unit_AtomicAdd_CoherentwithUnsafeflag", "",
     } else {
       TestType *A_h{nullptr}, *result{nullptr};
       TestType *A_d{nullptr}, *result_d{nullptr};
-      HIP_CHECK(hipHostMalloc(reinterpret_cast<void**>(&A_h), sizeof(TestType),
-                              hipHostMallocCoherent));
+      HIP_CHECK(
+          hipHostMalloc(reinterpret_cast<void**>(&A_h), sizeof(TestType), hipHostMallocCoherent));
       A_h[0] = INITIAL_VAL;
-      HIP_CHECK(hipHostMalloc(reinterpret_cast<void**>(&result),
-                              sizeof(TestType),
+      HIP_CHECK(hipHostMalloc(reinterpret_cast<void**>(&result), sizeof(TestType),
                               hipHostMallocCoherent));
       result[0] = INITIAL_VAL;
-      HIP_CHECK(hipHostGetDevicePointer(reinterpret_cast<void**>(&A_d),
-                                        A_h, 0));
-      HIP_CHECK(hipHostGetDevicePointer(reinterpret_cast<void**>(&result_d),
-                                        result, 0));
-      hipLaunchKernelGGL(AtomicCheck<TestType>, dim3(1), dim3(1),
-                         0, 0, A_d,
-                         result_d);
-      HIP_CHECK(hipGetLastError()); 
+      HIP_CHECK(hipHostGetDevicePointer(reinterpret_cast<void**>(&A_d), A_h, 0));
+      HIP_CHECK(hipHostGetDevicePointer(reinterpret_cast<void**>(&result_d), result, 0));
+      hipLaunchKernelGGL(AtomicCheck<TestType>, dim3(1), dim3(1), 0, 0, A_d, result_d);
+      HIP_CHECK(hipGetLastError());
       HIP_CHECK(hipDeviceSynchronize());
-        bool testResult;
+      bool testResult;
 
       if ((std::is_same<TestType, float>::value)) {
         testResult = HipTest::assemblyFile_Verification<TestType>(
-                     "AtomicAdd_Coherent_withunsafeflag-hip-amdgcn(.*)\\.s",
-                     "global_atomic_add_f32");
+            "AtomicAdd_Coherent_withunsafeflag-hip-amdgcn(.*)\\.s", "global_atomic_add_f32");
         REQUIRE(testResult == true);
       } else {
         testResult = HipTest::assemblyFile_Verification<TestType>(
-                     "AtomicAdd_Coherent_withunsafeflag-hip-amdgcn(.*)\\.s",
-                     "global_atomic_add_f64");
+            "AtomicAdd_Coherent_withunsafeflag-hip-amdgcn(.*)\\.s", "global_atomic_add_f64");
         REQUIRE(testResult == true);
       }
       if ((gfxName == "gfx90a" || gfxName.find("gfx90a:")) == 0) {
@@ -99,7 +90,9 @@ TEMPLATE_TEST_CASE("Unit_AtomicAdd_CoherentwithUnsafeflag", "",
       HIP_CHECK(hipHostFree(result));
     }
   } else {
-    SUCCEED("Memory model feature is only supported for gfx90a, gfx942, gfx950,"
-        "Hence skipping the testcase for this GPU " << device);
+    SUCCEED(
+        "Memory model feature is only supported for gfx90a, gfx942, gfx950,"
+        "Hence skipping the testcase for this GPU "
+        << device);
   }
 }
