@@ -503,7 +503,7 @@ static void runFloatTest() {
   bool* dIActiveLanes;
   HIP_CHECK(hipMalloc(reinterpret_cast<void**>(&dOData), memSize));
   HIP_CHECK(hipMalloc(reinterpret_cast<bool**>(&dIActiveLanes), N * sizeof(bool)));
-  
+
   // copy host memory to device to initialize to zero
   HIP_CHECK(hipMemcpy(dOData, hOData, memSize, hipMemcpyHostToDevice));
   HIP_CHECK(hipMemcpy(dIActiveLanes, hIActiveLanes, N * sizeof(bool), hipMemcpyHostToDevice));
@@ -550,6 +550,7 @@ static void runFloatTest() {
 
   // Cleanup memory
   free(hOData);
+  free(hIActiveLanes);
   HIP_CHECK(hipFree(dOData));
   HIP_CHECK(hipFree(dIActiveLanes));
 }
@@ -592,7 +593,7 @@ template <typename T> static void runDivIntTest() {
   HIP_CHECK(hipMalloc(reinterpret_cast<void**>(&dOData), memSize));
   HIP_CHECK(hipMalloc(reinterpret_cast<bool**>(&dIActiveLanes), N * sizeof(bool)));
   HIP_CHECK(hipMalloc(reinterpret_cast<void**>(&dIDivValues), N * sizeof(T)));
-  
+
   // copy host memory to device to initialize to zero
   HIP_CHECK(hipMemcpy(dOData, hOData, memSize, hipMemcpyHostToDevice));
   HIP_CHECK(hipMemcpy(dIActiveLanes, hIActiveLanes, N * sizeof(bool), hipMemcpyHostToDevice));
@@ -768,8 +769,11 @@ static void runDivFloatTest() {
 
   // Cleanup memory
   free(hOData);
+  free(hIDivValues);
+  free(hIActiveLanes);
   HIP_CHECK(hipFree(dOData));
   HIP_CHECK(hipFree(dIActiveLanes));
+  HIP_CHECK(hipFree(dIDivValues));
 }
 
 /*
