@@ -28,9 +28,9 @@ THE SOFTWARE.
 #include <bitset>
 
 /*
-* Tests for fp8 conversions on host
-* Both FNUZ and OCP types are supported on host
-*/
+ * Tests for fp8 conversions on host
+ * Both FNUZ and OCP types are supported on host
+ */
 
 TEST_CASE("Unit_fp8_ocp_bool_host") {
   // clang-format off
@@ -126,99 +126,52 @@ TEMPLATE_TEST_CASE("Unit_fp8_ocp_correctness", "", float, double) {
     /* These are basically all the fp8 - e4m3_ocp type numbers.
      * They can be generated by iterating over 0'0000'000 and converting them to fp32 number
      * skipping the nan/inf */
-     std::vector<TestType> e4m3_ocp_nums = { 0,           0.00195312,    0.00390625,
-                                             0.00585938,  0.0078125,     0.00976562,
-                                             0.0117188,   0.0136719,     0.015625,
-                                             0.0175781,   0.0195312,     0.0214844,
-                                             0.0234375,   0.0253906,     0.0273438,
-                                             0.0292969,   0.03125,       0.0351562,
-                                             0.0390625,   0.0429688,     0.046875,
-                                             0.0507812,   0.0546875,     0.0585938,
-                                             0.0625,      0.0703125,     0.078125,
-                                             0.0859375,   0.09375,       0.101562,
-                                             0.109375,    0.117188,      0.125,
-                                             0.140625,    0.15625,       0.171875,
-                                             0.1875,      0.203125,      0.21875,
-                                             0.234375,    0.25,          0.28125,
-                                             0.3125,      0.34375,       0.375,
-                                             0.40625,     0.4375,        0.46875,
-                                             0.5,         0.5625,        0.625,
-                                             0.6875,      0.75,          0.8125,
-                                             0.875,       0.9375,        1,
-                                             1.125,       1.25,          1.375,
-                                             1.5,         1.625,         1.75,
-                                             1.875,       2,             2.25,
-                                             2.5,         2.75,          3,
-                                             3.25,        3.5,           3.75,
-                                             4,           4.5,           5,
-                                             5.5,         6,             6.5,
-                                             7,           7.5,           8,
-                                             9,           10,             11,
-                                             12,          13,             14,
-                                             15,          16,             18,
-                                             20,          22,             24,
-                                             26,          28,             30,
-                                             32,          36,             40,
-                                             44,          48,             52,
-                                             56,          60,             64,
-                                             72,          80,             88,
-                                             96,          104,            112,
-                                             120,         128,            144,
-                                             160,         176,            192,
-                                             208,         224,            240,
-                                             256,         288,            320,
-                                             352,         384,            416,
-                                             448,         -0,             -0.00195312,
-                                             -0.00390625, -0.00585938,    -0.0078125,
-                                             -0.00976562, -0.0117188,     -0.0136719,
-                                             -0.015625,   -0.0175781,     -0.0195312,
-                                             -0.0214844,  -0.0234375,     -0.0253906,
-                                             -0.0273438,  -0.0292969,     -0.03125,
-                                             -0.0351562,  -0.0390625,     -0.0429688,
-                                             -0.046875,   -0.0507812,     -0.0546875,
-                                             -0.0585938,  -0.0625,        -0.0703125,
-                                             -0.078125,   -0.0859375,     -0.09375,
-                                             -0.101562,   -0.109375,      -0.117188,
-                                             -0.125,      -0.140625,      -0.15625,
-                                             -0.171875,   -0.1875,        -0.203125,
-                                             -0.21875,    -0.234375,      -0.25,
-                                             -0.28125,    -0.3125,        -0.34375,
-                                             -0.375,      -0.40625,       -0.4375,
-                                             -0.46875,    -0.5,           -0.5625,
-                                             -0.625,      -0.6875,        -0.75,
-                                             -0.8125,     -0.875,         -0.9375,
-                                             -1,          -1.125,         -1.25,
-                                             -1.375,      -1.5,           -1.625,
-                                             -1.75,       -1.875,         -2,
-                                             -2.25,       -2.5,           -2.75,
-                                             -3,          -3.25,          -3.5,
-                                             -3.75,       -4,             -4.5,
-                                             -5,          -5.5,           -6,
-                                             -6.5,        -7,             -7.5,
-                                             -8,          -9,             -10,
-                                             -11,         -12,            -13,
-                                             -14,         -15,            -16,
-                                             -18,         -20,            -22,
-                                             -24,         -26,            -28,
-                                             -30,         -32,            -36,
-                                             -40,         -44,            -48,
-                                             -52,         -56,            -60,
-                                             -64,         -72,            -80,
-                                             -88,         -96,            -104,
-                                             -112,        -120,           -128,
-                                             -144,        -160,           -176,
-                                             -192,        -208,           -224,
-                                             -240,        -256,           -288,
-                                             -320,        -352,           -384,
-                                             -416,        -448};
+    std::vector<TestType> e4m3_ocp_nums = {
+        0,          0.00195312, 0.00390625,  0.00585938,  0.0078125,   0.00976562, 0.0117188,
+        0.0136719,  0.015625,   0.0175781,   0.0195312,   0.0214844,   0.0234375,  0.0253906,
+        0.0273438,  0.0292969,  0.03125,     0.0351562,   0.0390625,   0.0429688,  0.046875,
+        0.0507812,  0.0546875,  0.0585938,   0.0625,      0.0703125,   0.078125,   0.0859375,
+        0.09375,    0.101562,   0.109375,    0.117188,    0.125,       0.140625,   0.15625,
+        0.171875,   0.1875,     0.203125,    0.21875,     0.234375,    0.25,       0.28125,
+        0.3125,     0.34375,    0.375,       0.40625,     0.4375,      0.46875,    0.5,
+        0.5625,     0.625,      0.6875,      0.75,        0.8125,      0.875,      0.9375,
+        1,          1.125,      1.25,        1.375,       1.5,         1.625,      1.75,
+        1.875,      2,          2.25,        2.5,         2.75,        3,          3.25,
+        3.5,        3.75,       4,           4.5,         5,           5.5,        6,
+        6.5,        7,          7.5,         8,           9,           10,         11,
+        12,         13,         14,          15,          16,          18,         20,
+        22,         24,         26,          28,          30,          32,         36,
+        40,         44,         48,          52,          56,          60,         64,
+        72,         80,         88,          96,          104,         112,        120,
+        128,        144,        160,         176,         192,         208,        224,
+        240,        256,        288,         320,         352,         384,        416,
+        448,        -0,         -0.00195312, -0.00390625, -0.00585938, -0.0078125, -0.00976562,
+        -0.0117188, -0.0136719, -0.015625,   -0.0175781,  -0.0195312,  -0.0214844, -0.0234375,
+        -0.0253906, -0.0273438, -0.0292969,  -0.03125,    -0.0351562,  -0.0390625, -0.0429688,
+        -0.046875,  -0.0507812, -0.0546875,  -0.0585938,  -0.0625,     -0.0703125, -0.078125,
+        -0.0859375, -0.09375,   -0.101562,   -0.109375,   -0.117188,   -0.125,     -0.140625,
+        -0.15625,   -0.171875,  -0.1875,     -0.203125,   -0.21875,    -0.234375,  -0.25,
+        -0.28125,   -0.3125,    -0.34375,    -0.375,      -0.40625,    -0.4375,    -0.46875,
+        -0.5,       -0.5625,    -0.625,      -0.6875,     -0.75,       -0.8125,    -0.875,
+        -0.9375,    -1,         -1.125,      -1.25,       -1.375,      -1.5,       -1.625,
+        -1.75,      -1.875,     -2,          -2.25,       -2.5,        -2.75,      -3,
+        -3.25,      -3.5,       -3.75,       -4,          -4.5,        -5,         -5.5,
+        -6,         -6.5,       -7,          -7.5,        -8,          -9,         -10,
+        -11,        -12,        -13,         -14,         -15,         -16,        -18,
+        -20,        -22,        -24,         -26,         -28,         -30,        -32,
+        -36,        -40,        -44,         -48,         -52,         -56,        -60,
+        -64,        -72,        -80,         -88,         -96,         -104,       -112,
+        -120,       -128,       -144,        -160,        -176,        -192,       -208,
+        -224,       -240,       -256,        -288,        -320,        -352,       -384,
+        -416,       -448};
     for (const auto& orig : e4m3_ocp_nums) {
       __hip_fp8_e4m3 fp8(orig);
       float cvt1 = fp8;
 
       __hip_fp8_e4m3 tmp;
       tmp.__x = std::is_same<TestType, float>::value
-          ? __hip_cvt_float_to_fp8(orig, __HIP_SATFINITE, __HIP_E4M3)
-          : __hip_cvt_double_to_fp8(orig, __HIP_SATFINITE, __HIP_E4M3);
+                    ? __hip_cvt_float_to_fp8(orig, __HIP_SATFINITE, __HIP_E4M3)
+                    : __hip_cvt_double_to_fp8(orig, __HIP_SATFINITE, __HIP_E4M3);
       ;
       float cvt2 = tmp;
 
@@ -233,97 +186,262 @@ TEMPLATE_TEST_CASE("Unit_fp8_ocp_correctness", "", float, double) {
     /* These are basically all the fp8 - e5m2_ocp type numbers.
      * They can be generated by iterating over 0'00000'00 converting them to fp32 number skipping
      * the nan/inf */
-    std::vector<TestType> e5m2_ocp_nums = { 0,            1.52588e-05,   3.05176e-05,
-                                            4.57764e-05,  6.10352e-05,   7.62939e-05,
-                                            9.15527e-05,  0.000106812,   0.00012207,
-                                            0.000152588,  0.000183105,   0.000213623,
-                                            0.000244141,  0.000305176,   0.000366211,
-                                            0.000427246,  0.000488281,   0.000610352,
-                                            0.000732422,  0.000854492,   0.000976562,
-                                            0.0012207,    0.00146484,    0.00170898,
-                                            0.00195312,   0.00244141,    0.00292969,
-                                            0.00341797,   0.00390625,    0.00488281,
-                                            0.00585938,   0.00683594,    0.0078125,
-                                            0.00976562,   0.0117188,     0.0136719,
-                                            0.015625,     0.0195312,     0.0234375,
-                                            0.0273438,    0.03125,       0.0390625,
-                                            0.046875,     0.0546875,     0.0625,
-                                            0.078125,     0.09375,       0.109375,
-                                            0.125,        0.15625,       0.1875,
-                                            0.21875,      0.25,          0.3125,
-                                            0.375,        0.4375,        0.5,
-                                            0.625,        0.75,          0.875,
-                                            1,            1.25,          1.5,
-                                            1.75,         2,             2.5,
-                                            3,            3.5,           4,
-                                            5,            6,             7,
-                                            8,            10,            12,
-                                            14,           16,            20,
-                                            24,           28,            32,
-                                            40,           48,            56,
-                                            64,           80,            96,
-                                            112,          128,           160,
-                                            192,          224,           256,
-                                            320,          384,           448,
-                                            512,          640,           768,
-                                            896,          1024,          1280,
-                                            1536,         1792,          2048,
-                                            2560,         3072,          3584,
-                                            4096,         5120,          6144,
-                                            7168,         8192,          10240,
-                                            12288,        14336,         16384,
-                                            20480,        24576,         28672,
-                                            32768,        40960,         49152,
-                                            57344,        -0,            -1.52588e-05,
-                                            -3.05176e-05, -4.57764e-05,  -6.10352e-05,
-                                            -7.62939e-05, -9.15527e-05,  -0.000106812,
-                                            -0.00012207,  -0.000152588,  -0.000183105,
-                                            -0.000213623, -0.000244141,  -0.000305176,
-                                            -0.000366211, -0.000427246,  -0.000488281,
-                                            -0.000610352, -0.000732422,  -0.000854492,
-                                            -0.000976562, -0.0012207,    -0.00146484,
-                                            -0.00170898,  -0.00195312,   -0.00244141,
-                                            -0.00292969,  -0.00341797,   -0.00390625,
-                                            -0.00488281,  -0.00585938,   -0.00683594,
-                                            -0.0078125,   -0.00976562,   -0.0117188,
-                                            -0.0136719,   -0.015625,     -0.0195312,
-                                            -0.0234375,   -0.0273438,    -0.03125,
-                                            -0.0390625,   -0.046875,     -0.0546875,
-                                            -0.0625,      -0.078125,     -0.09375,
-                                            -0.109375,    -0.125,        -0.15625,
-                                            -0.1875,      -0.21875,      -0.25,
-                                            -0.3125,      -0.375,        -0.4375,
-                                            -0.5,         -0.625,        -0.75,
-                                            -0.875,       -1,            -1.25,
-                                            -1.5,         -1.75,         -2,
-                                            -2.5,         -3,            -3.5,
-                                            -4,           -5,            -6,
-                                            -7,           -8,            -10,
-                                            -12,          -14,           -16,
-                                            -20,          -24,           -28,
-                                            -32,          -40,           -48,
-                                            -56,          -64,           -80,
-                                            -96,          -112,          -128,
-                                            -160,         -192,          -224,
-                                            -256,         -320,          -384,
-                                            -448,         -512,          -640,
-                                            -768,         -896,          -1024,
-                                            -1280,        -1536,         -1792,
-                                            -2048,        -2560,         -3072,
-                                            -3584,        -4096,         -5120,
-                                            -6144,        -7168,         -8192,
-                                            -10240,       -12288,        -14336,
-                                            -16384,       -20480,        -24576,
-                                            -28672,       -32768,        -40960,
-                                            -49152,       -57344};
+    std::vector<TestType> e5m2_ocp_nums = {0,
+                                           1.52588e-05,
+                                           3.05176e-05,
+                                           4.57764e-05,
+                                           6.10352e-05,
+                                           7.62939e-05,
+                                           9.15527e-05,
+                                           0.000106812,
+                                           0.00012207,
+                                           0.000152588,
+                                           0.000183105,
+                                           0.000213623,
+                                           0.000244141,
+                                           0.000305176,
+                                           0.000366211,
+                                           0.000427246,
+                                           0.000488281,
+                                           0.000610352,
+                                           0.000732422,
+                                           0.000854492,
+                                           0.000976562,
+                                           0.0012207,
+                                           0.00146484,
+                                           0.00170898,
+                                           0.00195312,
+                                           0.00244141,
+                                           0.00292969,
+                                           0.00341797,
+                                           0.00390625,
+                                           0.00488281,
+                                           0.00585938,
+                                           0.00683594,
+                                           0.0078125,
+                                           0.00976562,
+                                           0.0117188,
+                                           0.0136719,
+                                           0.015625,
+                                           0.0195312,
+                                           0.0234375,
+                                           0.0273438,
+                                           0.03125,
+                                           0.0390625,
+                                           0.046875,
+                                           0.0546875,
+                                           0.0625,
+                                           0.078125,
+                                           0.09375,
+                                           0.109375,
+                                           0.125,
+                                           0.15625,
+                                           0.1875,
+                                           0.21875,
+                                           0.25,
+                                           0.3125,
+                                           0.375,
+                                           0.4375,
+                                           0.5,
+                                           0.625,
+                                           0.75,
+                                           0.875,
+                                           1,
+                                           1.25,
+                                           1.5,
+                                           1.75,
+                                           2,
+                                           2.5,
+                                           3,
+                                           3.5,
+                                           4,
+                                           5,
+                                           6,
+                                           7,
+                                           8,
+                                           10,
+                                           12,
+                                           14,
+                                           16,
+                                           20,
+                                           24,
+                                           28,
+                                           32,
+                                           40,
+                                           48,
+                                           56,
+                                           64,
+                                           80,
+                                           96,
+                                           112,
+                                           128,
+                                           160,
+                                           192,
+                                           224,
+                                           256,
+                                           320,
+                                           384,
+                                           448,
+                                           512,
+                                           640,
+                                           768,
+                                           896,
+                                           1024,
+                                           1280,
+                                           1536,
+                                           1792,
+                                           2048,
+                                           2560,
+                                           3072,
+                                           3584,
+                                           4096,
+                                           5120,
+                                           6144,
+                                           7168,
+                                           8192,
+                                           10240,
+                                           12288,
+                                           14336,
+                                           16384,
+                                           20480,
+                                           24576,
+                                           28672,
+                                           32768,
+                                           40960,
+                                           49152,
+                                           57344,
+                                           -0,
+                                           -1.52588e-05,
+                                           -3.05176e-05,
+                                           -4.57764e-05,
+                                           -6.10352e-05,
+                                           -7.62939e-05,
+                                           -9.15527e-05,
+                                           -0.000106812,
+                                           -0.00012207,
+                                           -0.000152588,
+                                           -0.000183105,
+                                           -0.000213623,
+                                           -0.000244141,
+                                           -0.000305176,
+                                           -0.000366211,
+                                           -0.000427246,
+                                           -0.000488281,
+                                           -0.000610352,
+                                           -0.000732422,
+                                           -0.000854492,
+                                           -0.000976562,
+                                           -0.0012207,
+                                           -0.00146484,
+                                           -0.00170898,
+                                           -0.00195312,
+                                           -0.00244141,
+                                           -0.00292969,
+                                           -0.00341797,
+                                           -0.00390625,
+                                           -0.00488281,
+                                           -0.00585938,
+                                           -0.00683594,
+                                           -0.0078125,
+                                           -0.00976562,
+                                           -0.0117188,
+                                           -0.0136719,
+                                           -0.015625,
+                                           -0.0195312,
+                                           -0.0234375,
+                                           -0.0273438,
+                                           -0.03125,
+                                           -0.0390625,
+                                           -0.046875,
+                                           -0.0546875,
+                                           -0.0625,
+                                           -0.078125,
+                                           -0.09375,
+                                           -0.109375,
+                                           -0.125,
+                                           -0.15625,
+                                           -0.1875,
+                                           -0.21875,
+                                           -0.25,
+                                           -0.3125,
+                                           -0.375,
+                                           -0.4375,
+                                           -0.5,
+                                           -0.625,
+                                           -0.75,
+                                           -0.875,
+                                           -1,
+                                           -1.25,
+                                           -1.5,
+                                           -1.75,
+                                           -2,
+                                           -2.5,
+                                           -3,
+                                           -3.5,
+                                           -4,
+                                           -5,
+                                           -6,
+                                           -7,
+                                           -8,
+                                           -10,
+                                           -12,
+                                           -14,
+                                           -16,
+                                           -20,
+                                           -24,
+                                           -28,
+                                           -32,
+                                           -40,
+                                           -48,
+                                           -56,
+                                           -64,
+                                           -80,
+                                           -96,
+                                           -112,
+                                           -128,
+                                           -160,
+                                           -192,
+                                           -224,
+                                           -256,
+                                           -320,
+                                           -384,
+                                           -448,
+                                           -512,
+                                           -640,
+                                           -768,
+                                           -896,
+                                           -1024,
+                                           -1280,
+                                           -1536,
+                                           -1792,
+                                           -2048,
+                                           -2560,
+                                           -3072,
+                                           -3584,
+                                           -4096,
+                                           -5120,
+                                           -6144,
+                                           -7168,
+                                           -8192,
+                                           -10240,
+                                           -12288,
+                                           -14336,
+                                           -16384,
+                                           -20480,
+                                           -24576,
+                                           -28672,
+                                           -32768,
+                                           -40960,
+                                           -49152,
+                                           -57344};
     for (const auto& orig : e5m2_ocp_nums) {
       __hip_fp8_e5m2 fp8(orig);
       float cvt1 = fp8;
 
       __hip_fp8_e5m2 tmp;
       tmp.__x = std::is_same<TestType, float>::value
-          ? __hip_cvt_float_to_fp8(orig, __HIP_SATFINITE, __HIP_E5M2)
-          : __hip_cvt_double_to_fp8(orig, __HIP_SATFINITE, __HIP_E5M2);
+                    ? __hip_cvt_float_to_fp8(orig, __HIP_SATFINITE, __HIP_E5M2)
+                    : __hip_cvt_double_to_fp8(orig, __HIP_SATFINITE, __HIP_E5M2);
       ;
       float cvt2 = tmp;
 
@@ -504,7 +622,6 @@ TEST_CASE("Unit_fp8_fnuz_bool_host") {
     INFO("Check for: " << fvals[i] << " expected: " << tvals[i] << " result: " << result[i]);
     REQUIRE(result[i] == tvals[i]);
   }
-
 }
 
 // test to check we are putting in data correctly in vector types
@@ -663,8 +780,8 @@ TEMPLATE_TEST_CASE("Unit_fp8_fnuz_correctness", "", float, double) {
 
       __hip_fp8_e4m3_fnuz tmp;
       tmp.__x = std::is_same<TestType, float>::value
-          ? __hip_cvt_float_to_fp8(orig, __HIP_SATFINITE, __HIP_E4M3_FNUZ)
-          : __hip_cvt_double_to_fp8(orig, __HIP_SATFINITE, __HIP_E4M3_FNUZ);
+                    ? __hip_cvt_float_to_fp8(orig, __HIP_SATFINITE, __HIP_E4M3_FNUZ)
+                    : __hip_cvt_double_to_fp8(orig, __HIP_SATFINITE, __HIP_E4M3_FNUZ);
       ;
       float cvt2 = tmp;
 
@@ -941,8 +1058,8 @@ TEMPLATE_TEST_CASE("Unit_fp8_fnuz_correctness", "", float, double) {
 
       __hip_fp8_e5m2_fnuz tmp;
       tmp.__x = std::is_same<TestType, float>::value
-          ? __hip_cvt_float_to_fp8(orig, __HIP_SATFINITE, __HIP_E5M2_FNUZ)
-          : __hip_cvt_double_to_fp8(orig, __HIP_SATFINITE, __HIP_E5M2_FNUZ);
+                    ? __hip_cvt_float_to_fp8(orig, __HIP_SATFINITE, __HIP_E5M2_FNUZ)
+                    : __hip_cvt_double_to_fp8(orig, __HIP_SATFINITE, __HIP_E5M2_FNUZ);
       ;
       float cvt2 = tmp;
 
