@@ -25,16 +25,14 @@ THE SOFTWARE.
 #include <sstream>
 #include <type_traits>
 
-using namespace std; // NOLINT
+using namespace std;  // NOLINT
 
-template<typename V,
-    enable_if_t<!is_integral<decltype(declval<V>().x)>{}>* = nullptr>
+template <typename V, enable_if_t<!is_integral<decltype(declval<V>().x)>{}>* = nullptr>
 bool integer_unary_tests(V&, V&) {
   return true;
 }
 
-template<typename V,
-    enable_if_t<!is_integral<decltype(declval<V>().x)>{}>* = nullptr>
+template <typename V, enable_if_t<!is_integral<decltype(declval<V>().x)>{}>* = nullptr>
 bool integer_binary_tests(V&, V&, V&...) {
   return true;
 }
@@ -74,26 +72,18 @@ void integer_binary_tests(V f1, V f2, V f3) {
   REQUIRE(f2 == MakeVector<V>(2));
 }
 
-template<typename V>
-bool constructor_tests() {
-  if (is_constructible<V, unsigned char>{} &&
-     is_constructible<V, signed char>{} &&
-     is_constructible<V, uint32_t>{} &&
-     is_constructible<V, int32_t>{} &&
-     is_constructible<V, unsigned int>{} &&
-     is_constructible<V, signed int>{} &&
-     is_constructible<V, uint64_t>{} &&
-     is_constructible<V, int64_t>{} &&
-     is_constructible<V, uint64_t>{} &&
-     is_constructible<V, int64_t>{} &&
-     is_constructible<V, float>{} &&
-     is_constructible<V, double>{}) {
+template <typename V> bool constructor_tests() {
+  if (is_constructible<V, unsigned char>{} && is_constructible<V, signed char>{} &&
+      is_constructible<V, uint32_t>{} && is_constructible<V, int32_t>{} &&
+      is_constructible<V, unsigned int>{} && is_constructible<V, signed int>{} &&
+      is_constructible<V, uint64_t>{} && is_constructible<V, int64_t>{} &&
+      is_constructible<V, uint64_t>{} && is_constructible<V, int64_t>{} &&
+      is_constructible<V, float>{} && is_constructible<V, double>{}) {
     return true;
   }
 }
 
-template<typename V>
-bool TestVectorType() {
+template <typename V> bool TestVectorType() {
   const V v1 = MakeVector<V>(1);
   const V v2 = MakeVector<V>(2);
   const V v3 = MakeVector<V>(3);
@@ -167,31 +157,22 @@ bool TestVectorType() {
   return true;
 }
 
-template<typename... Ts, enable_if_t<sizeof...(Ts) == 0>* = nullptr>
-bool TestVectorTypes() {
+template <typename... Ts, enable_if_t<sizeof...(Ts) == 0>* = nullptr> bool TestVectorTypes() {
   return true;
 }
 
-template<typename T, typename... Ts>
-bool TestVectorTypes() {
+template <typename T, typename... Ts> bool TestVectorTypes() {
   if (!TestVectorType<T>()) return false;
   return TestVectorTypes<Ts...>();
 }
 
 bool CheckVectorTypes() {
-  return TestVectorTypes<
-         char1, char2, char3, char4,
-         uchar1, uchar2, uchar3, uchar4,
-         short1, short2, short3, short4,
-         ushort1, ushort2, ushort3, ushort4,
-         int1, int2, int3, int4,
-         uint1, uint2, uint3, uint4,
-         long1, long2, long3, long4,
-         ulong1, ulong2, ulong3, ulong4,
-         longlong1, longlong2, longlong3, longlong4,
-         ulonglong1, ulonglong2, ulonglong3, ulonglong4,
-         float1, float2, float3, float4,
-         double1, double2, double3, double4>();
+  return TestVectorTypes<char1, char2, char3, char4, uchar1, uchar2, uchar3, uchar4, short1, short2,
+                         short3, short4, ushort1, ushort2, ushort3, ushort4, int1, int2, int3, int4,
+                         uint1, uint2, uint3, uint4, long1, long2, long3, long4, ulong1, ulong2,
+                         ulong3, ulong4, longlong1, longlong2, longlong3, longlong4, ulonglong1,
+                         ulonglong2, ulonglong3, ulonglong4, float1, float2, float3, float4,
+                         double1, double2, double3, double4>();
 }
 TEST_CASE("Unit_hipVectorTypes_test_on_host") {
   REQUIRE(sizeof(float1) == 4);
