@@ -1,22 +1,22 @@
 /*
-	 Copyright (c) 2021 Advanced Micro Devices, Inc. All rights reserved.
-	 Permission is hereby granted, free of charge, to any person obtaining a copy
-	 of this software and associated documentation files (the "Software"), to deal
-	 in the Software without restriction, including without limitation the rights
-	 to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
-	 copies of the Software, and to permit persons to whom the Software is
-	 furnished to do so, subject to the following conditions:
+         Copyright (c) 2021 Advanced Micro Devices, Inc. All rights reserved.
+         Permission is hereby granted, free of charge, to any person obtaining a copy
+         of this software and associated documentation files (the "Software"), to deal
+         in the Software without restriction, including without limitation the rights
+         to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
+         copies of the Software, and to permit persons to whom the Software is
+         furnished to do so, subject to the following conditions:
 
-	 The above copyright notice and this permission notice shall be included in
-	 all copies or substantial portions of the Software.
+         The above copyright notice and this permission notice shall be included in
+         all copies or substantial portions of the Software.
 
-	 THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
-	 IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
-	 FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.  IN NO EVENT SHALL THE
-	 AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
-	 LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
-	 OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
-	 THE SOFTWARE.
+         THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
+         IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
+         FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.  IN NO EVENT SHALL THE
+         AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
+         LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
+         OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
+         THE SOFTWARE.
  */
 
 /*
@@ -29,15 +29,15 @@ unsafeAtomicAdd Scenarios with hipRTC:
 6. CoarseGrainMemory without -munsafe-fp-atomics flag
 */
 
-#include<hip_test_checkers.hh>
-#include<hip_test_common.hh>
-#include<hip_test_features.hh>
+#include <hip_test_checkers.hh>
+#include <hip_test_common.hh>
+#include <hip_test_features.hh>
 #include <hip/hiprtc.h>
 #define INCREMENT_VAL 10
 #define INITIAL_VAL 5
 
 static constexpr auto fkernel{
-R"(
+    R"(
 extern "C"
 __global__ void AtomicCheck(float* Ad, float *result) {
 *result = unsafeAtomicAdd(Ad, 10);
@@ -45,7 +45,7 @@ __global__ void AtomicCheck(float* Ad, float *result) {
 )"};
 
 static constexpr auto dkernel{
-R"(
+    R"(
 extern "C"
 __global__ void AtomicCheck(double* Ad, double *result) {
 *result = unsafeAtomicAdd(Ad, 10);
@@ -60,8 +60,7 @@ __global__ void AtomicCheck(double* Ad, double *result) {
    Output: unsafeAtomicAdd API will not work and returns 0 so
    the initial value will be intact. expected O/P is 5
 */
-TEMPLATE_TEST_CASE("Unit_unsafeAtomicAdd_CoherentRTCnounsafeatomicflag", "",
-                   float, double) {
+TEMPLATE_TEST_CASE("Unit_unsafeAtomicAdd_CoherentRTCnounsafeatomicflag", "", float, double) {
   int device = 0;
   hipDeviceProp_t props;
   HIP_CHECK(hipGetDeviceProperties(&props, device));
@@ -70,15 +69,15 @@ TEMPLATE_TEST_CASE("Unit_unsafeAtomicAdd_CoherentRTCnounsafeatomicflag", "",
   if (CheckIfFeatSupported(CTFeatures::CT_FEATURE_FINEGRAIN_HWSUPPORT, gfxName)) {
     hiprtcProgram prog;
     if (std::is_same<TestType, float>::value) {
-    hiprtcCreateProgram(&prog,        // prog
-                        fkernel,       // buffer
-                        "kernel.cu",  // name
-                        0, nullptr, nullptr);
+      hiprtcCreateProgram(&prog,        // prog
+                          fkernel,      // buffer
+                          "kernel.cu",  // name
+                          0, nullptr, nullptr);
     } else {
-     hiprtcCreateProgram(&prog,        // prog
-                        dkernel,       // buffer
-                        "kernel.cu",  // name
-                        0, nullptr, nullptr);
+      hiprtcCreateProgram(&prog,        // prog
+                          dkernel,      // buffer
+                          "kernel.cu",  // name
+                          0, nullptr, nullptr);
     }
     std::string sarg = std::string("--gpu-architecture=") + props.gcnArchName;
     const char* options[] = {sarg.c_str(), "-mno-unsafe-fp-atomics"};
@@ -108,26 +107,21 @@ TEMPLATE_TEST_CASE("Unit_unsafeAtomicAdd_CoherentRTCnounsafeatomicflag", "",
     } else {
       TestType *A_h, *result;
       TestType *A_d, *result_d;
-      HIP_CHECK(hipHostMalloc(reinterpret_cast<void**>(&A_h), sizeof(TestType),
-                              hipHostMallocCoherent));
-      HIP_CHECK(hipHostMalloc(reinterpret_cast<void**>(&result),
-                              sizeof(TestType),
+      HIP_CHECK(
+          hipHostMalloc(reinterpret_cast<void**>(&A_h), sizeof(TestType), hipHostMallocCoherent));
+      HIP_CHECK(hipHostMalloc(reinterpret_cast<void**>(&result), sizeof(TestType),
                               hipHostMallocCoherent));
       A_h[0] = INITIAL_VAL;
-      HIP_CHECK(hipHostGetDevicePointer(reinterpret_cast<void**>(&A_d),
-            A_h, 0));
-      HIP_CHECK(hipHostGetDevicePointer(reinterpret_cast<void**>(&result_d),
-            result, 0));
+      HIP_CHECK(hipHostGetDevicePointer(reinterpret_cast<void**>(&A_d), A_h, 0));
+      HIP_CHECK(hipHostGetDevicePointer(reinterpret_cast<void**>(&result_d), result, 0));
       struct {
         TestType* p;
         TestType* result;
       } args_f{A_d, result_d};
       auto size = sizeof(args_f);
-      void* config_d[] = {HIP_LAUNCH_PARAM_BUFFER_POINTER, &args_f,
-        HIP_LAUNCH_PARAM_BUFFER_SIZE,
-        &size, HIP_LAUNCH_PARAM_END};
-      HIP_CHECK(hipModuleLaunchKernel(f_kernel, 1, 1, 1, 1, 1, 1, 0,
-                nullptr, nullptr, config_d));
+      void* config_d[] = {HIP_LAUNCH_PARAM_BUFFER_POINTER, &args_f, HIP_LAUNCH_PARAM_BUFFER_SIZE,
+                          &size, HIP_LAUNCH_PARAM_END};
+      HIP_CHECK(hipModuleLaunchKernel(f_kernel, 1, 1, 1, 1, 1, 1, 0, nullptr, nullptr, config_d));
       HIP_CHECK(hipDeviceSynchronize());
       if ((gfxName == "gfx90a" || gfxName.find("gfx90a:")) == 0) {
         REQUIRE(A_h[0] == INITIAL_VAL);
@@ -141,8 +135,10 @@ TEMPLATE_TEST_CASE("Unit_unsafeAtomicAdd_CoherentRTCnounsafeatomicflag", "",
     }
     HIP_CHECK(hipModuleUnload(module));
   } else {
-      SUCCEED("Memory model feature is only supported for gfx90a, gfx942, gfx950,"
-          "Hence skipping the testcase for this GPU " << device);
+    SUCCEED(
+        "Memory model feature is only supported for gfx90a, gfx942, gfx950,"
+        "Hence skipping the testcase for this GPU "
+        << device);
   }
 }
 
@@ -155,8 +151,7 @@ TEMPLATE_TEST_CASE("Unit_unsafeAtomicAdd_CoherentRTCnounsafeatomicflag", "",
    Output: unsafeAtomicAdd API will not work and r`eturns 0 so
    the initial value will be intact. expected O/P is 5
 */
-TEMPLATE_TEST_CASE("Unit_unsafeAtomicAdd_CoherentRTCunsafeatomicflag", "",
-                   float, double) {
+TEMPLATE_TEST_CASE("Unit_unsafeAtomicAdd_CoherentRTCunsafeatomicflag", "", float, double) {
   int device = 0;
   hipDeviceProp_t props;
   HIP_CHECK(hipGetDeviceProperties(&props, device));
@@ -165,15 +160,15 @@ TEMPLATE_TEST_CASE("Unit_unsafeAtomicAdd_CoherentRTCunsafeatomicflag", "",
   if (CheckIfFeatSupported(CTFeatures::CT_FEATURE_FINEGRAIN_HWSUPPORT, gfxName)) {
     hiprtcProgram prog;
     if (std::is_same<TestType, float>::value) {
-    hiprtcCreateProgram(&prog,        // prog
-                        fkernel,       // buffer
-                        "kernel.cu",  // name
-                        0, nullptr, nullptr);
+      hiprtcCreateProgram(&prog,        // prog
+                          fkernel,      // buffer
+                          "kernel.cu",  // name
+                          0, nullptr, nullptr);
     } else {
-     hiprtcCreateProgram(&prog,        // prog
-                        dkernel,       // buffer
-                        "kernel.cu",  // name
-                        0, nullptr, nullptr);
+      hiprtcCreateProgram(&prog,        // prog
+                          dkernel,      // buffer
+                          "kernel.cu",  // name
+                          0, nullptr, nullptr);
     }
     std::string sarg = std::string("--gpu-architecture=") + props.gcnArchName;
     const char* options[] = {sarg.c_str(), "-munsafe-fp-atomics"};
@@ -205,26 +200,21 @@ TEMPLATE_TEST_CASE("Unit_unsafeAtomicAdd_CoherentRTCunsafeatomicflag", "",
     } else {
       TestType *A_h, *result;
       TestType *A_d, *result_d;
-      HIP_CHECK(hipHostMalloc(reinterpret_cast<void**>(&A_h), sizeof(TestType),
-                              hipHostMallocCoherent));
-      HIP_CHECK(hipHostMalloc(reinterpret_cast<void**>(&result),
-                              sizeof(TestType),
+      HIP_CHECK(
+          hipHostMalloc(reinterpret_cast<void**>(&A_h), sizeof(TestType), hipHostMallocCoherent));
+      HIP_CHECK(hipHostMalloc(reinterpret_cast<void**>(&result), sizeof(TestType),
                               hipHostMallocCoherent));
       A_h[0] = INITIAL_VAL;
-      HIP_CHECK(hipHostGetDevicePointer(reinterpret_cast<void**>(&A_d),
-            A_h, 0));
-      HIP_CHECK(hipHostGetDevicePointer(reinterpret_cast<void**>(&result_d),
-            result, 0));
+      HIP_CHECK(hipHostGetDevicePointer(reinterpret_cast<void**>(&A_d), A_h, 0));
+      HIP_CHECK(hipHostGetDevicePointer(reinterpret_cast<void**>(&result_d), result, 0));
       struct {
         TestType* p;
         TestType* result;
       } args_f{A_d, result_d};
       auto size = sizeof(args_f);
-      void* config_d[] = {HIP_LAUNCH_PARAM_BUFFER_POINTER, &args_f,
-        HIP_LAUNCH_PARAM_BUFFER_SIZE,
-        &size, HIP_LAUNCH_PARAM_END};
-      HIP_CHECK(hipModuleLaunchKernel(f_kernel, 1, 1, 1, 1, 1, 1, 0,
-                nullptr, nullptr, config_d));
+      void* config_d[] = {HIP_LAUNCH_PARAM_BUFFER_POINTER, &args_f, HIP_LAUNCH_PARAM_BUFFER_SIZE,
+                          &size, HIP_LAUNCH_PARAM_END};
+      HIP_CHECK(hipModuleLaunchKernel(f_kernel, 1, 1, 1, 1, 1, 1, 0, nullptr, nullptr, config_d));
       HIP_CHECK(hipDeviceSynchronize());
       if ((gfxName == "gfx90a" || gfxName.find("gfx90a:")) == 0) {
         REQUIRE(A_h[0] == INITIAL_VAL);
@@ -238,8 +228,10 @@ TEMPLATE_TEST_CASE("Unit_unsafeAtomicAdd_CoherentRTCunsafeatomicflag", "",
     }
     HIP_CHECK(hipModuleUnload(module));
   } else {
-      SUCCEED("Memory model feature is only supported for gfx90a, gfx942, gfx950,"
-          "Hence skipping the testcase for this GPU " << device);
+    SUCCEED(
+        "Memory model feature is only supported for gfx90a, gfx942, gfx950,"
+        "Hence skipping the testcase for this GPU "
+        << device);
   }
 }
 
@@ -249,25 +241,24 @@ TEMPLATE_TEST_CASE("Unit_unsafeAtomicAdd_CoherentRTCunsafeatomicflag", "",
    Output: unsafeAtomicAdd API will not work and returns 0 so
    the initial value will be intact. expected O/P is 5*/
 
-TEMPLATE_TEST_CASE("Unit_unsafeAtomicAdd_CoherentRTCwithoutflag", "",
-                   float, double) {
+TEMPLATE_TEST_CASE("Unit_unsafeAtomicAdd_CoherentRTCwithoutflag", "", float, double) {
   int device = 0;
   hipDeviceProp_t props;
   HIP_CHECK(hipGetDeviceProperties(&props, device));
   std::string gfxName(props.gcnArchName);
 
-  if(CheckIfFeatSupported(CTFeatures::CT_FEATURE_FINEGRAIN_HWSUPPORT, gfxName)) {
-     hiprtcProgram prog;
+  if (CheckIfFeatSupported(CTFeatures::CT_FEATURE_FINEGRAIN_HWSUPPORT, gfxName)) {
+    hiprtcProgram prog;
     if (std::is_same<TestType, float>::value) {
-    hiprtcCreateProgram(&prog,        // prog
-                        fkernel,       // buffer
-                        "kernel.cu",  // name
-                        0, nullptr, nullptr);
+      hiprtcCreateProgram(&prog,        // prog
+                          fkernel,      // buffer
+                          "kernel.cu",  // name
+                          0, nullptr, nullptr);
     } else {
-     hiprtcCreateProgram(&prog,        // prog
-                        dkernel,       // buffer
-                        "kernel.cu",  // name
-                        0, nullptr, nullptr);
+      hiprtcCreateProgram(&prog,        // prog
+                          dkernel,      // buffer
+                          "kernel.cu",  // name
+                          0, nullptr, nullptr);
     }
     std::string sarg = std::string("--gpu-architecture=") + props.gcnArchName;
     const char* options[] = {sarg.c_str()};
@@ -299,25 +290,21 @@ TEMPLATE_TEST_CASE("Unit_unsafeAtomicAdd_CoherentRTCwithoutflag", "",
     } else {
       TestType *A_h, *result;
       TestType *A_d, *result_d;
-      HIP_CHECK(hipHostMalloc(reinterpret_cast<void**>(&A_h), sizeof(float),
-                              hipHostMallocCoherent));
-      HIP_CHECK(hipHostMalloc(reinterpret_cast<void**>(&result), sizeof(float),
-                              hipHostMallocCoherent));
+      HIP_CHECK(
+          hipHostMalloc(reinterpret_cast<void**>(&A_h), sizeof(float), hipHostMallocCoherent));
+      HIP_CHECK(
+          hipHostMalloc(reinterpret_cast<void**>(&result), sizeof(float), hipHostMallocCoherent));
       A_h[0] = INITIAL_VAL;
-      HIP_CHECK(hipHostGetDevicePointer(reinterpret_cast<void**>(&A_d),
-                                        A_h, 0));
-      HIP_CHECK(hipHostGetDevicePointer(reinterpret_cast<void**>(&result_d),
-                                        result, 0));
+      HIP_CHECK(hipHostGetDevicePointer(reinterpret_cast<void**>(&A_d), A_h, 0));
+      HIP_CHECK(hipHostGetDevicePointer(reinterpret_cast<void**>(&result_d), result, 0));
       struct {
         TestType* p;
         TestType* result;
       } args_f{A_d, result_d};
       auto size = sizeof(args_f);
-      void* config_d[] = {HIP_LAUNCH_PARAM_BUFFER_POINTER, &args_f,
-                          HIP_LAUNCH_PARAM_BUFFER_SIZE,
+      void* config_d[] = {HIP_LAUNCH_PARAM_BUFFER_POINTER, &args_f, HIP_LAUNCH_PARAM_BUFFER_SIZE,
                           &size, HIP_LAUNCH_PARAM_END};
-      HIP_CHECK(hipModuleLaunchKernel(f_kernel, 1, 1, 1, 1, 1,
-                            1, 0, nullptr, nullptr, config_d));
+      HIP_CHECK(hipModuleLaunchKernel(f_kernel, 1, 1, 1, 1, 1, 1, 0, nullptr, nullptr, config_d));
       HIP_CHECK(hipDeviceSynchronize());
       if ((gfxName == "gfx90a" || gfxName.find("gfx90a:")) == 0) {
         REQUIRE(A_h[0] == INITIAL_VAL);
@@ -331,8 +318,10 @@ TEMPLATE_TEST_CASE("Unit_unsafeAtomicAdd_CoherentRTCwithoutflag", "",
     }
     HIP_CHECK(hipModuleUnload(module));
   } else {
-      SUCCEED("Memory model feature is only supported for gfx90a, gfx942, gfx950,"
-          "Hence skipping the testcase for this GPU " << device);
+    SUCCEED(
+        "Memory model feature is only supported for gfx90a, gfx942, gfx950,"
+        "Hence skipping the testcase for this GPU "
+        << device);
   }
 }
 
@@ -341,25 +330,24 @@ TEMPLATE_TEST_CASE("Unit_unsafeAtomicAdd_CoherentRTCwithoutflag", "",
    is compiled using hipRTC and with compilation flag -mno-unsafe-fp-atomics
    Input: Ad{5}, INCREMENT_VAL{10}
    Output: Expected O/P is 15 */
-TEMPLATE_TEST_CASE("Unit_unsafeAtomicAdd_NonCoherentRTCnounsafeatomicflag", "",
-                   float, double) {
+TEMPLATE_TEST_CASE("Unit_unsafeAtomicAdd_NonCoherentRTCnounsafeatomicflag", "", float, double) {
   int device = 0;
   hipDeviceProp_t props;
   HIP_CHECK(hipGetDeviceProperties(&props, device));
   std::string gfxName(props.gcnArchName);
 
   if (CheckIfFeatSupported(CTFeatures::CT_FEATURE_FINEGRAIN_HWSUPPORT, gfxName)) {
-     hiprtcProgram prog;
+    hiprtcProgram prog;
     if (std::is_same<TestType, float>::value) {
-    hiprtcCreateProgram(&prog,        // prog
-                        fkernel,       // buffer
-                        "kernel.cu",  // name
-                        0, nullptr, nullptr);
+      hiprtcCreateProgram(&prog,        // prog
+                          fkernel,      // buffer
+                          "kernel.cu",  // name
+                          0, nullptr, nullptr);
     } else {
       hiprtcCreateProgram(&prog,        // prog
-                        dkernel,       // buffer
-                        "kernel.cu",  // name
-                        0, nullptr, nullptr);
+                          dkernel,      // buffer
+                          "kernel.cu",  // name
+                          0, nullptr, nullptr);
     }
     std::string sarg = std::string("--gpu-architecture=") + props.gcnArchName;
     const char* options[] = {sarg.c_str(), "-mno-unsafe-fp-atomics"};
@@ -392,23 +380,18 @@ TEMPLATE_TEST_CASE("Unit_unsafeAtomicAdd_NonCoherentRTCnounsafeatomicflag", "",
       TestType *A_d, *result_d;
       HIP_CHECK(hipHostMalloc(reinterpret_cast<void**>(&A_h), sizeof(TestType),
                               hipHostMallocNonCoherent));
-      HIP_CHECK(hipHostMalloc(reinterpret_cast<void**>(&result),
-                              sizeof(TestType)));
+      HIP_CHECK(hipHostMalloc(reinterpret_cast<void**>(&result), sizeof(TestType)));
       A_h[0] = INITIAL_VAL;
-      HIP_CHECK(hipHostGetDevicePointer(reinterpret_cast<void**>(&A_d),
-            A_h, 0));
-      HIP_CHECK(hipHostGetDevicePointer(reinterpret_cast<void**>(&result_d),
-            result, 0));
+      HIP_CHECK(hipHostGetDevicePointer(reinterpret_cast<void**>(&A_d), A_h, 0));
+      HIP_CHECK(hipHostGetDevicePointer(reinterpret_cast<void**>(&result_d), result, 0));
       struct {
         TestType* p;
         TestType* result;
       } args_f{A_d, result_d};
       auto size = sizeof(args_f);
-      void* config_d[] = {HIP_LAUNCH_PARAM_BUFFER_POINTER, &args_f,
-        HIP_LAUNCH_PARAM_BUFFER_SIZE,
-        &size, HIP_LAUNCH_PARAM_END};
-      HIP_CHECK(hipModuleLaunchKernel(f_kernel, 1, 1, 1, 1, 1, 1, 0,
-                            nullptr, nullptr, config_d));
+      void* config_d[] = {HIP_LAUNCH_PARAM_BUFFER_POINTER, &args_f, HIP_LAUNCH_PARAM_BUFFER_SIZE,
+                          &size, HIP_LAUNCH_PARAM_END};
+      HIP_CHECK(hipModuleLaunchKernel(f_kernel, 1, 1, 1, 1, 1, 1, 0, nullptr, nullptr, config_d));
       HIP_CHECK(hipDeviceSynchronize());
       REQUIRE(A_h[0] == INITIAL_VAL + INCREMENT_VAL);
       REQUIRE(*result == INITIAL_VAL);
@@ -417,8 +400,10 @@ TEMPLATE_TEST_CASE("Unit_unsafeAtomicAdd_NonCoherentRTCnounsafeatomicflag", "",
     }
     HIP_CHECK(hipModuleUnload(module));
   } else {
-      SUCCEED("Memory model feature is only supported for gfx90a, gfx942, gfx950,"
-          "Hence skipping the testcase for this GPU " << device);
+    SUCCEED(
+        "Memory model feature is only supported for gfx90a, gfx942, gfx950,"
+        "Hence skipping the testcase for this GPU "
+        << device);
   }
 }
 
@@ -428,25 +413,24 @@ TEMPLATE_TEST_CASE("Unit_unsafeAtomicAdd_NonCoherentRTCnounsafeatomicflag", "",
    Input: Ad{5}, INCREMENT_VAL{10}
    Output: Expected O/P is 15 */
 
-TEMPLATE_TEST_CASE("Unit_unsafeAtomicAdd_NonCoherentRTCunsafeatomicflag", "",
-                   float, double) {
+TEMPLATE_TEST_CASE("Unit_unsafeAtomicAdd_NonCoherentRTCunsafeatomicflag", "", float, double) {
   int device = 0;
   hipDeviceProp_t props;
   HIP_CHECK(hipGetDeviceProperties(&props, device));
   std::string gfxName(props.gcnArchName);
 
-  if(CheckIfFeatSupported(CTFeatures::CT_FEATURE_FINEGRAIN_HWSUPPORT, gfxName)) {
-     hiprtcProgram prog;
+  if (CheckIfFeatSupported(CTFeatures::CT_FEATURE_FINEGRAIN_HWSUPPORT, gfxName)) {
+    hiprtcProgram prog;
     if (std::is_same<TestType, float>::value) {
-    hiprtcCreateProgram(&prog,        // prog
-                        fkernel,       // buffer
-                        "kernel.cu",  // name
-                        0, nullptr, nullptr);
+      hiprtcCreateProgram(&prog,        // prog
+                          fkernel,      // buffer
+                          "kernel.cu",  // name
+                          0, nullptr, nullptr);
     } else {
-     hiprtcCreateProgram(&prog,        // prog
-                        dkernel,       // buffer
-                        "kernel.cu",  // name
-                        0, nullptr, nullptr);
+      hiprtcCreateProgram(&prog,        // prog
+                          dkernel,      // buffer
+                          "kernel.cu",  // name
+                          0, nullptr, nullptr);
     }
     std::string sarg = std::string("--gpu-architecture=") + props.gcnArchName;
     const char* options[] = {sarg.c_str(), "-munsafe-fp-atomics"};
@@ -480,23 +464,18 @@ TEMPLATE_TEST_CASE("Unit_unsafeAtomicAdd_NonCoherentRTCunsafeatomicflag", "",
       TestType *A_d, *result_d;
       HIP_CHECK(hipHostMalloc(reinterpret_cast<void**>(&A_h), sizeof(TestType),
                               hipHostMallocNonCoherent));
-      HIP_CHECK(hipHostMalloc(reinterpret_cast<void**>(&result),
-                              sizeof(TestType)));
+      HIP_CHECK(hipHostMalloc(reinterpret_cast<void**>(&result), sizeof(TestType)));
       A_h[0] = INITIAL_VAL;
-      HIP_CHECK(hipHostGetDevicePointer(reinterpret_cast<void**>(&A_d),
-            A_h, 0));
-      HIP_CHECK(hipHostGetDevicePointer(reinterpret_cast<void**>(&result_d),
-            result, 0));
+      HIP_CHECK(hipHostGetDevicePointer(reinterpret_cast<void**>(&A_d), A_h, 0));
+      HIP_CHECK(hipHostGetDevicePointer(reinterpret_cast<void**>(&result_d), result, 0));
       struct {
         TestType* p;
         TestType* result;
       } args_f{A_d, result_d};
       auto size = sizeof(args_f);
-      void* config_d[] = {HIP_LAUNCH_PARAM_BUFFER_POINTER, &args_f,
-        HIP_LAUNCH_PARAM_BUFFER_SIZE,
-        &size, HIP_LAUNCH_PARAM_END};
-      HIP_CHECK(hipModuleLaunchKernel(f_kernel, 1, 1, 1, 1, 1, 1, 0,
-                            nullptr, nullptr, config_d));
+      void* config_d[] = {HIP_LAUNCH_PARAM_BUFFER_POINTER, &args_f, HIP_LAUNCH_PARAM_BUFFER_SIZE,
+                          &size, HIP_LAUNCH_PARAM_END};
+      HIP_CHECK(hipModuleLaunchKernel(f_kernel, 1, 1, 1, 1, 1, 1, 0, nullptr, nullptr, config_d));
       HIP_CHECK(hipDeviceSynchronize());
       REQUIRE(A_h[0] == INITIAL_VAL + INCREMENT_VAL);
       REQUIRE(*result == INITIAL_VAL);
@@ -505,8 +484,10 @@ TEMPLATE_TEST_CASE("Unit_unsafeAtomicAdd_NonCoherentRTCunsafeatomicflag", "",
     }
     HIP_CHECK(hipModuleUnload(module));
   } else {
-      SUCCEED("Memory model feature is only supported for gfx90a, gfx942, gfx950,"
-          "Hence skipping the testcase for this GPU " << device);
+    SUCCEED(
+        "Memory model feature is only supported for gfx90a, gfx942, gfx950,"
+        "Hence skipping the testcase for this GPU "
+        << device);
   }
 }
 
@@ -516,8 +497,7 @@ TEMPLATE_TEST_CASE("Unit_unsafeAtomicAdd_NonCoherentRTCunsafeatomicflag", "",
    Input: Ad{5}, INCREMENT_VAL{10}
    Output: O/P is 15 */
 
-TEMPLATE_TEST_CASE("Unit_unsafeAtomicAdd_NonCoherentRTC", "",
-                   float, double) {
+TEMPLATE_TEST_CASE("Unit_unsafeAtomicAdd_NonCoherentRTC", "", float, double) {
   int device = 0;
   hipDeviceProp_t props;
   HIP_CHECK(hipGetDeviceProperties(&props, device));
@@ -526,15 +506,15 @@ TEMPLATE_TEST_CASE("Unit_unsafeAtomicAdd_NonCoherentRTC", "",
   if (CheckIfFeatSupported(CTFeatures::CT_FEATURE_FINEGRAIN_HWSUPPORT, gfxName)) {
     hiprtcProgram prog;
     if (std::is_same<TestType, float>::value) {
-    hiprtcCreateProgram(&prog,        // prog
-                        fkernel,       // buffer
-                        "kernel.cu",  // name
-                        0, nullptr, nullptr);
+      hiprtcCreateProgram(&prog,        // prog
+                          fkernel,      // buffer
+                          "kernel.cu",  // name
+                          0, nullptr, nullptr);
     } else {
-     hiprtcCreateProgram(&prog,        // prog
-                        dkernel,       // buffer
-                        "kernel.cu",  // name
-                        0, nullptr, nullptr);
+      hiprtcCreateProgram(&prog,        // prog
+                          dkernel,      // buffer
+                          "kernel.cu",  // name
+                          0, nullptr, nullptr);
     }
 
     std::string sarg = std::string("--gpu-architecture=") + props.gcnArchName;
@@ -568,23 +548,18 @@ TEMPLATE_TEST_CASE("Unit_unsafeAtomicAdd_NonCoherentRTC", "",
       TestType *A_d, *result_d;
       HIP_CHECK(hipHostMalloc(reinterpret_cast<void**>(&A_h), sizeof(TestType),
                               hipHostMallocNonCoherent));
-      HIP_CHECK(hipHostMalloc(reinterpret_cast<void**>(&result),
-                              sizeof(TestType)));
+      HIP_CHECK(hipHostMalloc(reinterpret_cast<void**>(&result), sizeof(TestType)));
       A_h[0] = INITIAL_VAL;
-      HIP_CHECK(hipHostGetDevicePointer(reinterpret_cast<void**>(&A_d),
-            A_h, 0));
-      HIP_CHECK(hipHostGetDevicePointer(reinterpret_cast<void**>(&result_d),
-           result, 0));
+      HIP_CHECK(hipHostGetDevicePointer(reinterpret_cast<void**>(&A_d), A_h, 0));
+      HIP_CHECK(hipHostGetDevicePointer(reinterpret_cast<void**>(&result_d), result, 0));
       struct {
         TestType* p;
         TestType* result;
       } args_f{A_d, result_d};
       auto size = sizeof(args_f);
-      void* config_d[] = {HIP_LAUNCH_PARAM_BUFFER_POINTER, &args_f,
-                          HIP_LAUNCH_PARAM_BUFFER_SIZE,
+      void* config_d[] = {HIP_LAUNCH_PARAM_BUFFER_POINTER, &args_f, HIP_LAUNCH_PARAM_BUFFER_SIZE,
                           &size, HIP_LAUNCH_PARAM_END};
-      HIP_CHECK(hipModuleLaunchKernel(f_kernel, 1, 1, 1, 1, 1, 1, 0,
-                            nullptr, nullptr, config_d));
+      HIP_CHECK(hipModuleLaunchKernel(f_kernel, 1, 1, 1, 1, 1, 1, 0, nullptr, nullptr, config_d));
       HIP_CHECK(hipDeviceSynchronize());
       REQUIRE(A_h[0] == INITIAL_VAL + INCREMENT_VAL);
       REQUIRE(*result == INITIAL_VAL);
@@ -593,7 +568,9 @@ TEMPLATE_TEST_CASE("Unit_unsafeAtomicAdd_NonCoherentRTC", "",
     }
     HIP_CHECK(hipModuleUnload(module));
   } else {
-      SUCCEED("Memory model feature is only supported for gfx90a, gfx942, gfx950,"
-          "Hence skipping the testcase for this GPU " << device);
+    SUCCEED(
+        "Memory model feature is only supported for gfx90a, gfx942, gfx950,"
+        "Hence skipping the testcase for this GPU "
+        << device);
   }
 }
