@@ -23,5 +23,15 @@ THE SOFTWARE.
 #include "execution_control_common.hh"
 
 #include <hip_test_common.hh>
+#include <hip/hip_cooperative_groups.h>
 
-__global__ void kernel() {}
\ No newline at end of file
+__global__ void kernel() {}
+
+__global__ void kernel2() {}
+
+__global__ void kernel_42(int* val) { *val = 42; }
+
+__global__ void coop_kernel() {
+  cooperative_groups::grid_group grid = cooperative_groups::this_grid();
+  grid.sync();
+}
\ No newline at end of file
