@@ -24,37 +24,35 @@
 #define KNRM "\x1B[0m"
 #define KRED "\x1B[31m"
 
-#define HIPCHECK(error)                                                                      \
-  {                                                                                          \
-    hipError_t localError = error;                                                           \
-    if ((localError != hipSuccess) && (localError != hipErrorPeerAccessAlreadyEnabled)) {    \
-      printf("%serror: '%s'(%d) from %s at %s:%d%s\n", KRED, hipGetErrorString(localError),  \
-               localError, #error, __FILE__, __LINE__, KNRM);                                \
-      printf("API returned error code.\n");                                                  \
-    }                                                                                        \
+#define HIPCHECK(error)                                                                            \
+  {                                                                                                \
+    hipError_t localError = error;                                                                 \
+    if ((localError != hipSuccess) && (localError != hipErrorPeerAccessAlreadyEnabled)) {          \
+      printf("%serror: '%s'(%d) from %s at %s:%d%s\n", KRED, hipGetErrorString(localError),        \
+             localError, #error, __FILE__, __LINE__, KNRM);                                        \
+      printf("API returned error code.\n");                                                        \
+    }                                                                                              \
   }
 
-bool LaunchKernelArg()
-{
-  dim3 blocks 	    = {1,1,1};
-  dim3 threads      = {1,1,1};
+bool LaunchKernelArg() {
+  dim3 blocks = {1, 1, 1};
+  dim3 threads = {1, 1, 1};
 
   HIPCHECK(hipLaunchKernel(getKernelFunc(mykernel), blocks, threads, NULL, 0, 0));
 
   return true;
 }
 
-bool LaunchKernelArg1()
-{
+bool LaunchKernelArg1() {
   int A = 0;
-  int *A_d = NULL;
-  dim3 blocks       = {1,1,1};
-  dim3 threads      = {1,1,1};
+  int* A_d = NULL;
+  dim3 blocks = {1, 1, 1};
+  dim3 threads = {1, 1, 1};
 
   // Allocate Device memory
   HIPCHECK(hipMalloc((void**)&A_d, sizeof(int)));
 
-  void* Args[]={&A_d};
+  void* Args[] = {&A_d};
 
   HIPCHECK(hipLaunchKernel(getKernelFunc(mykernel1), blocks, threads, Args, 0, 0));
 
@@ -63,21 +61,19 @@ bool LaunchKernelArg1()
 
   HIPCHECK(hipFree(A_d));
 
-  if(A != 333)
-	  return false;
+  if (A != 333) return false;
 
   return true;
 }
 
-bool LaunchKernelArg2()
-{
+bool LaunchKernelArg2() {
   int A = 0;
   int B = 123;
-  int *A_d = NULL;
-  int *B_d = NULL;
+  int* A_d = NULL;
+  int* B_d = NULL;
 
-  dim3 blocks       = {1,1,1};
-  dim3 threads      = {1,1,1};
+  dim3 blocks = {1, 1, 1};
+  dim3 threads = {1, 1, 1};
 
   // Allocate Device memory
   HIPCHECK(hipMalloc((void**)&A_d, sizeof(int)));
@@ -87,8 +83,8 @@ bool LaunchKernelArg2()
   // Copy data from host memory to device memory
   HIPCHECK(hipMemcpy(B_d, &B, sizeof(int), hipMemcpyHostToDevice));
 
-  void* Args[]={&A_d, &B_d};
-  HIPCHECK(hipLaunchKernel(getKernelFunc(mykernel2), blocks, threads, Args,0,0));
+  void* Args[] = {&A_d, &B_d};
+  HIPCHECK(hipLaunchKernel(getKernelFunc(mykernel2), blocks, threads, Args, 0, 0));
 
   // Get the result back to host memory
   HIPCHECK(hipMemcpy(&A, A_d, sizeof(int), hipMemcpyDeviceToHost));
@@ -96,23 +92,21 @@ bool LaunchKernelArg2()
   HIPCHECK(hipFree(A_d));
   HIPCHECK(hipFree(B_d));
 
-  if(A != 123)
-    return false;
+  if (A != 123) return false;
 
   return true;
 }
 
-bool LaunchKernelArg3()
-{
+bool LaunchKernelArg3() {
   int A = 321;
   int B = 123;
   int C = 0;
-  int *A_d = NULL;
-  int *B_d = NULL;
-  int *C_d = NULL;
+  int* A_d = NULL;
+  int* B_d = NULL;
+  int* C_d = NULL;
 
-  dim3 blocks       = {1,1,1};
-  dim3 threads      = {1,1,1};
+  dim3 blocks = {1, 1, 1};
+  dim3 threads = {1, 1, 1};
 
   // Allocate Device memory
   HIPCHECK(hipMalloc((void**)&A_d, sizeof(int)));
@@ -126,8 +120,8 @@ bool LaunchKernelArg3()
 
   HIPCHECK(hipMemcpy(B_d, &B, sizeof(int), hipMemcpyHostToDevice));
 
-  void* Args[]={&A_d, &B_d, &C_d};
-  HIPCHECK(hipLaunchKernel(getKernelFunc(mykernel3), blocks, threads, Args,0,0));
+  void* Args[] = {&A_d, &B_d, &C_d};
+  HIPCHECK(hipLaunchKernel(getKernelFunc(mykernel3), blocks, threads, Args, 0, 0));
 
   // Get the result back to host memory
   HIPCHECK(hipMemcpy(&C, C_d, sizeof(int), hipMemcpyDeviceToHost));
@@ -136,18 +130,16 @@ bool LaunchKernelArg3()
   HIPCHECK(hipFree(B_d));
   HIPCHECK(hipFree(C_d));
 
-  if(C != 444)
-    return false;
+  if (C != 444) return false;
 
   return true;
 }
 
-bool LaunchKernelArg4()
-{
+bool LaunchKernelArg4() {
   int A = 0;
-  int *A_d = NULL;
-  dim3 blocks       = {1,1,1};
-  dim3 threads      = {1,1,1};
+  int* A_d = NULL;
+  dim3 blocks = {1, 1, 1};
+  dim3 threads = {1, 1, 1};
 
   // Allocate Device memory
   HIPCHECK(hipMalloc((void**)&A_d, sizeof(int)));
@@ -155,9 +147,9 @@ bool LaunchKernelArg4()
   char c = 1;
   short s = 10;
   int i = 100;
-  struct things t = {2,20,200};
+  struct things t = {2, 20, 200};
 
-  void* Args[]={&A_d, &c, &s, &i, &t};
+  void* Args[] = {&A_d, &c, &s, &i, &t};
   HIPCHECK(hipLaunchKernel(getKernelFunc(mykernel4), blocks, threads, Args, 0, 0));
 
   // Get the result back to host memory
@@ -165,31 +157,23 @@ bool LaunchKernelArg4()
 
   HIPCHECK(hipFree(A_d));
 
-  if (A != (c + s + i + t.c + t.s + t.i))
-	  return false;
+  if (A != (c + s + i + t.c + t.s + t.i)) return false;
 
   return true;
 }
 
 #ifdef __cplusplus
-extern "C"
-{
+extern "C" {
 #endif
-int launchKernel()
-{
+int launchKernel() {
   printf("Calling LaunchKernel.c file\n");
-  if( LaunchKernelArg()  &&
-      LaunchKernelArg1() &&
-      LaunchKernelArg2() &&
-      LaunchKernelArg3() &&
-      LaunchKernelArg4())
-    {
-      printf("PASSED!\n");
-      return 1;
-    }
-  else
+  if (LaunchKernelArg() && LaunchKernelArg1() && LaunchKernelArg2() && LaunchKernelArg3() &&
+      LaunchKernelArg4()) {
+    printf("PASSED!\n");
+    return 1;
+  } else
     printf("FAILED\n");
-    return 0;
+  return 0;
 }
 #ifdef __cplusplus
 }
