@@ -68,8 +68,8 @@ static void init_input(float* a, size_t size) {
 /**
  * Regular procedure of using stream with async api calls
  */
-static void hipWithoutGraphs(float* inputVec_h, float* inputVec_d,
-  double* outputVec_d, double* result_d, size_t inputSize, size_t numOfBlocks) {
+static void hipWithoutGraphs(float* inputVec_h, float* inputVec_d, double* outputVec_d,
+                             double* result_d, size_t inputSize, size_t numOfBlocks) {
   hipStream_t stream1, stream2, stream3;
   hipEvent_t forkStreamEvent, memsetEvent1, memsetEvent2;
   double result_h = 0.0;
@@ -81,30 +81,25 @@ static void hipWithoutGraphs(float* inputVec_h, float* inputVec_d,
   HIP_CHECK(hipEventCreate(&memsetEvent2));
   auto start = std::chrono::high_resolution_clock::now();
   for (int i = 0; i < GRAPH_LAUNCH_ITERATIONS; i++) {
-    HIP_CHECK(hipMemcpyAsync(inputVec_d, inputVec_h, sizeof(float) * inputSize,
-                             hipMemcpyDefault, stream1));
-    HIP_CHECK(hipMemsetAsync(outputVec_d, 0, sizeof(double) * numOfBlocks,
-                                               stream2));
+    HIP_CHECK(hipMemcpyAsync(inputVec_d, inputVec_h, sizeof(float) * inputSize, hipMemcpyDefault,
+                             stream1));
+    HIP_CHECK(hipMemsetAsync(outputVec_d, 0, sizeof(double) * numOfBlocks, stream2));
     HIP_CHECK(hipEventRecord(memsetEvent1, stream2));
     HIP_CHECK(hipMemsetAsync(result_d, 0, sizeof(double), stream3));
     HIP_CHECK(hipEventRecord(memsetEvent2, stream3));
     HIP_CHECK(hipStreamWaitEvent(stream1, memsetEvent1, 0));
     hipLaunchKernelGGL(reduce, dim3(inputSize / THREADS_PER_BLOCK, 1, 1),
-                       dim3(THREADS_PER_BLOCK, 1, 1), 0, stream1, inputVec_d,
-                       outputVec_d);
+                       dim3(THREADS_PER_BLOCK, 1, 1), 0, stream1, inputVec_d, outputVec_d);
     HIP_CHECK(hipStreamWaitEvent(stream1, memsetEvent2, 0));
-    hipLaunchKernelGGL(reduceFinal, dim3(1, 1, 1),
-                                    dim3(THREADS_PER_BLOCK, 1, 1), 0, stream1,
-                                    outputVec_d, result_d);
-    HIP_CHECK(hipMemcpyAsync(&result_h, result_d, sizeof(double),
-                                                  hipMemcpyDefault, stream1));
+    hipLaunchKernelGGL(reduceFinal, dim3(1, 1, 1), dim3(THREADS_PER_BLOCK, 1, 1), 0, stream1,
+                       outputVec_d, result_d);
+    HIP_CHECK(hipMemcpyAsync(&result_h, result_d, sizeof(double), hipMemcpyDefault, stream1));
     HIP_CHECK(hipStreamSynchronize(stream1));
   }
   auto stop = std::chrono::high_resolution_clock::now();
   auto result = std::chrono::duration<double, std::milli>(stop - start);
   INFO("Time taken for hipWithoutGraphs : "
-      << std::chrono::duration_cast<std::chrono::milliseconds>(result).count()
-      << " millisecs ");
+       << std::chrono::duration_cast<std::chrono::milliseconds>(result).count() << " millisecs ");
   HIP_CHECK(hipEventDestroy(forkStreamEvent));
   HIP_CHECK(hipEventDestroy(memsetEvent1));
   HIP_CHECK(hipEventDestroy(memsetEvent2));
@@ -123,9 +118,8 @@ static void hipWithoutGraphs(float* inputVec_h, float* inputVec_d,
  * Capturing sequence of operations in stream and launching graph
  * with the nodes automatically added.
  */
-static void hipGraphsUsingStreamCapture(float* inputVec_h, float* inputVec_d,
-                                 double* outputVec_d, double* result_d,
-                                 size_t inputSize, size_t numOfBlocks) {
+static void hipGraphsUsingStreamCapture(float* inputVec_h, float* inputVec_d, double* outputVec_d,
+                                        double* result_d, size_t inputSize, size_t numOfBlocks) {
   hipStream_t stream1, stream2, stream3, streamForGraph;
   hipEvent_t forkStreamEvent, memsetEvent1, memsetEvent2;
   hipGraph_t graph;
@@ -142,31 +136,29 @@ static void hipGraphsUsingStreamCapture(float* inputVec_h, float* inputVec_d,
   HIP_CHECK(hipEventRecord(forkStreamEvent, stream1));
   HIP_CHECK(hipStreamWaitEvent(stream2, forkStreamEvent, 0));
   HIP_CHECK(hipStreamWaitEvent(stream3, forkStreamEvent, 0));
-  HIP_CHECK(hipMemcpyAsync(inputVec_d, inputVec_h, sizeof(float) * inputSize,
-                                                 hipMemcpyDefault, stream1));
-  HIP_CHECK(hipMemsetAsync(outputVec_d, 0, sizeof(double) * numOfBlocks,
-                                                                   stream2));
+  HIP_CHECK(
+      hipMemcpyAsync(inputVec_d, inputVec_h, sizeof(float) * inputSize, hipMemcpyDefault, stream1));
+  HIP_CHECK(hipMemsetAsync(outputVec_d, 0, sizeof(double) * numOfBlocks, stream2));
   HIP_CHECK(hipEventRecord(memsetEvent1, stream2));
   HIP_CHECK(hipMemsetAsync(result_d, 0, sizeof(double), stream3));
   HIP_CHECK(hipEventRecord(memsetEvent2, stream3));
   HIP_CHECK(hipStreamWaitEvent(stream1, memsetEvent1, 0));
   hipLaunchKernelGGL(reduce, dim3(inputSize / THREADS_PER_BLOCK, 1, 1),
-                     dim3(THREADS_PER_BLOCK, 1, 1), 0, stream1,
-                     inputVec_d, outputVec_d);
+                     dim3(THREADS_PER_BLOCK, 1, 1), 0, stream1, inputVec_d, outputVec_d);
   HIP_CHECK(hipStreamWaitEvent(stream1, memsetEvent2, 0));
-  hipLaunchKernelGGL(reduceFinal, dim3(1, 1, 1), dim3(THREADS_PER_BLOCK, 1, 1),
-                     0, stream1, outputVec_d, result_d);
-  HIP_CHECK(hipMemcpyAsync(&result_h, result_d, sizeof(double),
-                                                   hipMemcpyDefault, stream1));
+  hipLaunchKernelGGL(reduceFinal, dim3(1, 1, 1), dim3(THREADS_PER_BLOCK, 1, 1), 0, stream1,
+                     outputVec_d, result_d);
+  HIP_CHECK(hipMemcpyAsync(&result_h, result_d, sizeof(double), hipMemcpyDefault, stream1));
   HIP_CHECK(hipStreamEndCapture(stream1, &graph));
   hipGraphNode_t* nodes{nullptr};
   size_t numNodes = 0;
   HIP_CHECK(hipGraphGetNodes(graph, nodes, &numNodes));
-  INFO("Num of nodes in the graph created using stream capture API"
-                                                                  << numNodes);
+  INFO("Num of nodes in the graph created using stream capture API" << numNodes);
   HIP_CHECK(hipGraphGetRootNodes(graph, nodes, &numNodes));
-  INFO("Num of root nodes in the graph created using"
-                                            " stream capture API" << numNodes);
+  INFO(
+      "Num of root nodes in the graph created using"
+      " stream capture API"
+      << numNodes);
   hipGraphExec_t graphExec;
 
   HIP_CHECK(hipGraphInstantiate(&graphExec, graph, nullptr, nullptr, 0));
@@ -176,15 +168,13 @@ static void hipGraphsUsingStreamCapture(float* inputVec_h, float* inputVec_d,
   }
   HIP_CHECK(hipStreamSynchronize(streamForGraph));
   auto stop = std::chrono::high_resolution_clock::now();
-  auto withInit =
-                      std::chrono::duration<double, std::milli>(stop - start);
-  auto withoutInit =
-                      std::chrono::duration<double, std::milli>(stop - start1);
+  auto withInit = std::chrono::duration<double, std::milli>(stop - start);
+  auto withoutInit = std::chrono::duration<double, std::milli>(stop - start1);
   INFO("Time taken for hipGraphsUsingStreamCapture with Init: "
-  << std::chrono::duration_cast<std::chrono::milliseconds>(withInit).count()
-  << " milliseconds without Init:"
-  << std::chrono::duration_cast<std::chrono::milliseconds>(withoutInit).count()
-  << " milliseconds ");
+       << std::chrono::duration_cast<std::chrono::milliseconds>(withInit).count()
+       << " milliseconds without Init:"
+       << std::chrono::duration_cast<std::chrono::milliseconds>(withoutInit).count()
+       << " milliseconds ");
 
   HIP_CHECK(hipGraphExecDestroy(graphExec));
   HIP_CHECK(hipGraphDestroy(graph));
@@ -203,9 +193,8 @@ static void hipGraphsUsingStreamCapture(float* inputVec_h, float* inputVec_d,
 /**
  * Manual procedure of adding nodes to graphs and mapping dependencies.
  */
-static void hipGraphsManual(float* inputVec_h, float* inputVec_d,
-         double* outputVec_d, double* result_d, size_t inputSize,
-                                              size_t numOfBlocks) {
+static void hipGraphsManual(float* inputVec_h, float* inputVec_d, double* outputVec_d,
+                            double* result_d, size_t inputSize, size_t numOfBlocks) {
   hipStream_t streamForGraph;
   hipGraph_t graph;
   std::vector<hipGraphNode_t> nodeDependencies;
@@ -222,15 +211,13 @@ static void hipGraphsManual(float* inputVec_h, float* inputVec_d,
   memsetParams.width = numOfBlocks * 2;
   memsetParams.height = 1;
   HIP_CHECK(hipGraphCreate(&graph, 0));
-  HIP_CHECK(hipGraphAddMemcpyNode1D(&memcpyNode, graph, nullptr, 0, inputVec_d,
-                inputVec_h, sizeof(float) * inputSize, hipMemcpyHostToDevice));
-  HIP_CHECK(hipGraphAddMemsetNode(&memsetNode, graph, nullptr,
-                                                            0, &memsetParams));
+  HIP_CHECK(hipGraphAddMemcpyNode1D(&memcpyNode, graph, nullptr, 0, inputVec_d, inputVec_h,
+                                    sizeof(float) * inputSize, hipMemcpyHostToDevice));
+  HIP_CHECK(hipGraphAddMemsetNode(&memsetNode, graph, nullptr, 0, &memsetParams));
   nodeDependencies.push_back(memsetNode);
   nodeDependencies.push_back(memcpyNode);
   void* kernelArgs[4] = {reinterpret_cast<void*>(&inputVec_d),
-                         reinterpret_cast<void*>(&outputVec_d), &inputSize,
-                         &numOfBlocks};
+                         reinterpret_cast<void*>(&outputVec_d), &inputSize, &numOfBlocks};
   kernelNodeParams.func = reinterpret_cast<void*>(reduce);
   kernelNodeParams.gridDim = dim3(inputSize / THREADS_PER_BLOCK, 1, 1);
   kernelNodeParams.blockDim = dim3(THREADS_PER_BLOCK, 1, 1);
@@ -238,7 +225,7 @@ static void hipGraphsManual(float* inputVec_h, float* inputVec_d,
   kernelNodeParams.kernelParams = reinterpret_cast<void**>(kernelArgs);
   kernelNodeParams.extra = nullptr;
   HIP_CHECK(hipGraphAddKernelNode(&kernelNode, graph, nodeDependencies.data(),
-                                 nodeDependencies.size(), &kernelNodeParams));
+                                  nodeDependencies.size(), &kernelNodeParams));
   nodeDependencies.clear();
   nodeDependencies.push_back(kernelNode);
   memset(&memsetParams, 0, sizeof(memsetParams));
@@ -247,36 +234,36 @@ static void hipGraphsManual(float* inputVec_h, float* inputVec_d,
   memsetParams.elementSize = sizeof(float);
   memsetParams.width = 2;
   memsetParams.height = 1;
-  HIP_CHECK(hipGraphAddMemsetNode(&memsetNode, graph, nullptr, 0,
-                                                               &memsetParams));
+  HIP_CHECK(hipGraphAddMemsetNode(&memsetNode, graph, nullptr, 0, &memsetParams));
   nodeDependencies.push_back(memsetNode);
   memset(&kernelNodeParams, 0, sizeof(kernelNodeParams));
   kernelNodeParams.func = reinterpret_cast<void*>(reduceFinal);
   kernelNodeParams.gridDim = dim3(1, 1, 1);
   kernelNodeParams.blockDim = dim3(THREADS_PER_BLOCK, 1, 1);
   kernelNodeParams.sharedMemBytes = 0;
-  void* kernelArgs2[3] = {reinterpret_cast<void*>(&outputVec_d),
-                          reinterpret_cast<void*>(&result_d), &numOfBlocks};
+  void* kernelArgs2[3] = {reinterpret_cast<void*>(&outputVec_d), reinterpret_cast<void*>(&result_d),
+                          &numOfBlocks};
   kernelNodeParams.kernelParams = kernelArgs2;
   kernelNodeParams.extra = nullptr;
   HIP_CHECK(hipGraphAddKernelNode(&kernelNode, graph, nodeDependencies.data(),
-                                 nodeDependencies.size(), &kernelNodeParams));
+                                  nodeDependencies.size(), &kernelNodeParams));
   nodeDependencies.clear();
   nodeDependencies.push_back(kernelNode);
-  HIP_CHECK(hipGraphAddMemcpyNode1D(&memcpyNode, graph,
-                nodeDependencies.data(), nodeDependencies.size(), &result_h,
-                           result_d, sizeof(double), hipMemcpyDeviceToHost));
+  HIP_CHECK(hipGraphAddMemcpyNode1D(&memcpyNode, graph, nodeDependencies.data(),
+                                    nodeDependencies.size(), &result_h, result_d, sizeof(double),
+                                    hipMemcpyDeviceToHost));
   nodeDependencies.clear();
   nodeDependencies.push_back(memcpyNode);
   hipGraphExec_t graphExec;
   hipGraphNode_t* nodes{nullptr};
   size_t numNodes{};
   HIP_CHECK(hipGraphGetNodes(graph, nodes, &numNodes));
-  INFO("Num of nodes in the graph created using hipGraphs Manual"
-                                                                  << numNodes);
+  INFO("Num of nodes in the graph created using hipGraphs Manual" << numNodes);
   HIP_CHECK(hipGraphGetRootNodes(graph, nodes, &numNodes));
-  INFO("Num of root nodes in the graph created using"
-                                              " hipGraphs Manual" << numNodes);
+  INFO(
+      "Num of root nodes in the graph created using"
+      " hipGraphs Manual"
+      << numNodes);
   HIP_CHECK(hipGraphInstantiate(&graphExec, graph, nullptr, nullptr, 0));
   auto start1 = std::chrono::high_resolution_clock::now();
   for (int i = 0; i < GRAPH_LAUNCH_ITERATIONS; i++) {
@@ -284,16 +271,14 @@ static void hipGraphsManual(float* inputVec_h, float* inputVec_d,
   }
   HIP_CHECK(hipStreamSynchronize(streamForGraph));
   auto stop = std::chrono::high_resolution_clock::now();
-  auto withInit =
-    std::chrono::duration<double, std::milli>(stop - start);
-  auto withoutInit =
-    std::chrono::duration<double, std::milli>(stop - start1);
+  auto withInit = std::chrono::duration<double, std::milli>(stop - start);
+  auto withoutInit = std::chrono::duration<double, std::milli>(stop - start1);
 
   INFO("Time taken for hipGraphsManual with Init: "
-  << std::chrono::duration_cast<std::chrono::milliseconds>(withInit).count()
-  << " milliseconds without Init:"
-  << std::chrono::duration_cast<std::chrono::milliseconds>(withoutInit).count()
-  << " milliseconds ");
+       << std::chrono::duration_cast<std::chrono::milliseconds>(withInit).count()
+       << " milliseconds without Init:"
+       << std::chrono::duration_cast<std::chrono::milliseconds>(withoutInit).count()
+       << " milliseconds ");
 
   HIP_CHECK(hipGraphExecDestroy(graphExec));
   HIP_CHECK(hipGraphDestroy(graph));
@@ -328,18 +313,15 @@ TEST_CASE("Unit_hipGraph_BasicFunctional") {
   init_input(inputVec_h, size);
 
   SECTION("Execution Without HIPGraphs") {
-    hipWithoutGraphs(inputVec_h, inputVec_d, outputVec_d,
-                                                    result_d, size, maxBlocks);
+    hipWithoutGraphs(inputVec_h, inputVec_d, outputVec_d, result_d, size, maxBlocks);
   }
 
   SECTION("Manual HIPGraph") {
-    hipGraphsManual(inputVec_h, inputVec_d, outputVec_d,
-                                                    result_d, size, maxBlocks);
+    hipGraphsManual(inputVec_h, inputVec_d, outputVec_d, result_d, size, maxBlocks);
   }
 
   SECTION("HIPGraphs Using StreamCapture") {
-    hipGraphsUsingStreamCapture(inputVec_h, inputVec_d,
-                                       outputVec_d, result_d, size, maxBlocks);
+    hipGraphsUsingStreamCapture(inputVec_h, inputVec_d, outputVec_d, result_d, size, maxBlocks);
   }
 
   HIP_CHECK(hipFree(inputVec_d));
