@@ -22,15 +22,14 @@ THE SOFTWARE.
 Testcase Scenarios
 ------------------
 Functional:
-1) Start stream capture and get capture info. Verify api is success, capture status is hipStreamCaptureStatusActive
- and identifier returned is valid/non-zero.
-2) End stream capture and get capture info. Verify api is success, capture status is hipStreamCaptureStatusNone
- and identifier is not returned/updated by api.
-3) Begin capture on hipStreamPerThread and get capture info. Verify api is success, capture status is hipStreamCaptureStatusActive
- and identifier returned is valid/non-zero.
-4) End capture on hipStreamPerThread, get capture info. Verify api is success, capture status is hipStreamCaptureStatusNone
- and identifier is not returned/updated by api.
-5) Perform multiple captures and verify the identifier returned is unique.
+1) Start stream capture and get capture info. Verify api is success, capture status is
+hipStreamCaptureStatusActive and identifier returned is valid/non-zero. 2) End stream capture and
+get capture info. Verify api is success, capture status is hipStreamCaptureStatusNone and identifier
+is not returned/updated by api. 3) Begin capture on hipStreamPerThread and get capture info. Verify
+api is success, capture status is hipStreamCaptureStatusActive and identifier returned is
+valid/non-zero. 4) End capture on hipStreamPerThread, get capture info. Verify api is success,
+capture status is hipStreamCaptureStatusNone and identifier is not returned/updated by api. 5)
+Perform multiple captures and verify the identifier returned is unique.
 
 Argument Validation/Negative:
 1) Pass pId as nullptr and verify api doesn’t crash and returns success.
@@ -38,22 +37,25 @@ Argument Validation/Negative:
 
 Extended Scenarios
 ------------------
-1.Create 2 streams s1 and s2. Start capturing s1. Record event e1 on s1 and wait for event e1 on s2. Queue some operations
-in s1 and s2. Invoke hipStreamGetCaptureInfo on both s1 and s2. Verify that the capture info (status and id) of both s1 and s2
-are identical. Record event e2 on s2 and wait for event e2 on s1. End the capture of stream s1. Verify that the capture info
-(status and id) of both s1 and s2 are identical.
+1.Create 2 streams s1 and s2. Start capturing s1. Record event e1 on s1 and wait for event e1 on s2.
+Queue some operations in s1 and s2. Invoke hipStreamGetCaptureInfo on both s1 and s2. Verify that
+the capture info (status and id) of both s1 and s2 are identical. Record event e2 on s2 and wait for
+event e2 on s1. End the capture of stream s1. Verify that the capture info (status and id) of both
+s1 and s2 are identical.
 
-2.Create a stream s1. Start capturing s1. Get the capture info of s1. Launch a thread. In the thread get the capture info of s1
-using hipStreamGetCaptureInfo. Verify that it is in state hipStreamCaptureStatusActive and capture id inside thread is same as
-capture id in main function. Exit the thread and end the capture
+2.Create a stream s1. Start capturing s1. Get the capture info of s1. Launch a thread. In the thread
+get the capture info of s1 using hipStreamGetCaptureInfo. Verify that it is in state
+hipStreamCaptureStatusActive and capture id inside thread is same as capture id in main function.
+Exit the thread and end the capture
 
-3.Verify that the id remains same througout the capture. Create a stream s1. Start capturing s1. Get the capture info of s1.
-Queue some oprations in s1. Again get the capture info. Queue different operations in s1. Again get the capture info.
-Verify that all the capture info are identical.
+3.Verify that the id remains same througout the capture. Create a stream s1. Start capturing s1. Get
+the capture info of s1. Queue some oprations in s1. Again get the capture info. Queue different
+operations in s1. Again get the capture info. Verify that all the capture info are identical.
 
-4.Create a stream with default flag (hipStreamDefault). Start capturing the stream. Invoke hipStreamGetCaptureInfo() on the null
-stream. Verify hipErrorStreamCaptureImplicit is returned by hipStreamGetCaptureInfo(). Verify capture status of created stream.
-Do some operatoins. End the capture on the created stream.Verify the capture status. Execute the graph and verify the output
+4.Create a stream with default flag (hipStreamDefault). Start capturing the stream. Invoke
+hipStreamGetCaptureInfo() on the null stream. Verify hipErrorStreamCaptureImplicit is returned by
+hipStreamGetCaptureInfo(). Verify capture status of created stream. Do some operatoins. End the
+capture on the created stream.Verify the capture status. Execute the graph and verify the output
 from the operations.
 
 5. Test scenario 1 using hipStreamGetCaptureInfo_v2.
@@ -94,7 +96,7 @@ void validateStreamCaptureInfo(hipStream_t mstream) {
 
   // Initialize input buffer
   for (size_t i = 0; i < N; ++i) {
-      A_h[i] = 3.146f + i;  // Pi
+    A_h[i] = 3.146f + i;  // Pi
   }
 
   // Create cross stream dependencies.
@@ -117,8 +119,8 @@ void validateStreamCaptureInfo(hipStream_t mstream) {
   HIP_CHECK(hipStreamWaitEvent(mstream, memsetEvent1, 0));
   HIP_CHECK(hipStreamWaitEvent(mstream, memsetEvent2, 0));
   HIP_CHECK(hipMemcpyAsync(A_d, A_h, Nbytes, hipMemcpyHostToDevice, mstream));
-  hipLaunchKernelGGL(HipTest::vector_square, dim3(blocks),
-                              dim3(threadsPerBlock), 0, mstream, A_d, C_d, N);
+  hipLaunchKernelGGL(HipTest::vector_square, dim3(blocks), dim3(threadsPerBlock), 0, mstream, A_d,
+                     C_d, N);
 
   hipStreamCaptureStatus captureStatus{hipStreamCaptureStatusNone};
   unsigned long long capSequenceID = 0;  // NOLINT
@@ -163,8 +165,7 @@ void validateStreamCaptureInfo(hipStream_t mstream) {
   // Validate the computation
   for (size_t i = 0; i < N; i++) {
     if (C_h[i] != A_h[i] * A_h[i]) {
-      INFO("A and C not matching at " << i << " C_h[i] " << C_h[i]
-                                           << " A_h[i] " << A_h[i]);
+      INFO("A and C not matching at " << i << " C_h[i] " << C_h[i] << " A_h[i] " << A_h[i]);
       REQUIRE(false);
     }
   }
@@ -201,24 +202,22 @@ TEST_CASE("Unit_hipStreamGetCaptureInfo_UniqueID") {
   hipStream_t streams[numStreams]{};
   hipStreamCaptureStatus captureStatus{hipStreamCaptureStatusNone};
   std::vector<int> idlist;
-  unsigned long long capSequenceID{};  //NOLINT
+  unsigned long long capSequenceID{};  // NOLINT
   hipGraph_t graph{nullptr};
 
   for (int i = 0; i < numStreams; i++) {
     HIP_CHECK(hipStreamCreate(&streams[i]));
     HIP_CHECK(hipStreamBeginCapture(streams[i], hipStreamCaptureModeGlobal));
-    HIP_CHECK(hipStreamGetCaptureInfo(streams[i], &captureStatus,
-                                                            &capSequenceID));
+    HIP_CHECK(hipStreamGetCaptureInfo(streams[i], &captureStatus, &capSequenceID));
     REQUIRE(captureStatus == hipStreamCaptureStatusActive);
     REQUIRE(capSequenceID > 0);
     idlist.push_back(capSequenceID);
   }
 
   for (int i = 0; i < numStreams; i++) {
-    for (int j = i+1; j < numStreams; j++) {
+    for (int j = i + 1; j < numStreams; j++) {
       if (idlist[i] == idlist[j]) {
-        INFO("Same identifier returned for stream "
-                                          << i << " and stream " << j);
+        INFO("Same identifier returned for stream " << i << " and stream " << j);
         REQUIRE(false);
       }
     }
@@ -299,26 +298,23 @@ TEST_CASE("Unit_hipStreamGetCaptureInfo_ParentAndForkedStrm_CaptureStatus") {
   HIP_CHECK(hipMemcpyAsync(A_d, A_h, Nbytes, hipMemcpyHostToDevice, stream1));
   HIP_CHECK(hipMemcpyAsync(B_d, B_h, Nbytes, hipMemcpyHostToDevice, stream2));
   // Kernal Operations
-  hipLaunchKernelGGL(HipTest::vector_square, dim3(blocks),
-                              dim3(threadsPerBlock), 0, stream1, A_d, C_d, N);
-  hipLaunchKernelGGL(HipTest::vector_square, dim3(blocks),
-                              dim3(threadsPerBlock), 0, stream2, B_d, D_d, N);
+  hipLaunchKernelGGL(HipTest::vector_square, dim3(blocks), dim3(threadsPerBlock), 0, stream1, A_d,
+                     C_d, N);
+  hipLaunchKernelGGL(HipTest::vector_square, dim3(blocks), dim3(threadsPerBlock), 0, stream2, B_d,
+                     D_d, N);
   // Copy data back to the Host
   HIP_CHECK(hipMemcpyAsync(C_h, C_d, Nbytes, hipMemcpyDeviceToHost, stream1));
   HIP_CHECK(hipMemcpyAsync(D_h, D_d, Nbytes, hipMemcpyDeviceToHost, stream2));
 
   hipStreamCaptureStatus captureStatus1{hipStreamCaptureStatusNone},
-                         captureStatus2{hipStreamCaptureStatusNone},
-                         captureStatus3{hipStreamCaptureStatusNone},
-                         captureStatus4{hipStreamCaptureStatusNone};
-  unsigned long long capSequenceID1, capSequenceID2, capSequenceID3,  //NOLINT
-                     capSequenceID4;
+      captureStatus2{hipStreamCaptureStatusNone}, captureStatus3{hipStreamCaptureStatusNone},
+      captureStatus4{hipStreamCaptureStatusNone};
+  unsigned long long capSequenceID1, capSequenceID2, capSequenceID3,  // NOLINT
+      capSequenceID4;
   SECTION("hipStreamGetCaptureInfo verification before End capture") {
     // Capture info
-    HIP_CHECK(hipStreamGetCaptureInfo(stream1, &captureStatus1,
-                                             &capSequenceID1));
-    HIP_CHECK(hipStreamGetCaptureInfo(stream2, &captureStatus2,
-                                             &capSequenceID2));
+    HIP_CHECK(hipStreamGetCaptureInfo(stream1, &captureStatus1, &capSequenceID1));
+    HIP_CHECK(hipStreamGetCaptureInfo(stream2, &captureStatus2, &capSequenceID2));
     // Verfication of results
     REQUIRE(capSequenceID1 == capSequenceID2);
     REQUIRE(captureStatus1 == hipStreamCaptureStatusActive);
@@ -326,10 +322,10 @@ TEST_CASE("Unit_hipStreamGetCaptureInfo_ParentAndForkedStrm_CaptureStatus") {
   }
   SECTION("hipStreamGetCaptureInfo_v2 verification before End capture") {
     // Capture info
-    HIP_CHECK(hipStreamGetCaptureInfo_v2(stream1, &captureStatus1,
-                             &capSequenceID1, nullptr, nullptr, nullptr));
-    HIP_CHECK(hipStreamGetCaptureInfo_v2(stream2, &captureStatus2,
-                             &capSequenceID2, nullptr, nullptr, nullptr));
+    HIP_CHECK(hipStreamGetCaptureInfo_v2(stream1, &captureStatus1, &capSequenceID1, nullptr,
+                                         nullptr, nullptr));
+    HIP_CHECK(hipStreamGetCaptureInfo_v2(stream2, &captureStatus2, &capSequenceID2, nullptr,
+                                         nullptr, nullptr));
     // Verfication of results
     REQUIRE(capSequenceID1 == capSequenceID2);
     REQUIRE(captureStatus1 == hipStreamCaptureStatusActive);
@@ -344,20 +340,18 @@ TEST_CASE("Unit_hipStreamGetCaptureInfo_ParentAndForkedStrm_CaptureStatus") {
   REQUIRE(graph != nullptr);
   SECTION("hipStreamGetCaptureInfo verification after  End capture") {
     // Capture Info
-    HIP_CHECK(hipStreamGetCaptureInfo(stream1, &captureStatus3,
-                                             &capSequenceID3));
-    HIP_CHECK(hipStreamGetCaptureInfo(stream2, &captureStatus4,
-                                             &capSequenceID4));
+    HIP_CHECK(hipStreamGetCaptureInfo(stream1, &captureStatus3, &capSequenceID3));
+    HIP_CHECK(hipStreamGetCaptureInfo(stream2, &captureStatus4, &capSequenceID4));
     // Verification of results
     REQUIRE(captureStatus3 == hipStreamCaptureStatusNone);
     REQUIRE(captureStatus4 == hipStreamCaptureStatusNone);
   }
   SECTION("hipStreamGetCaptureInfo_v2 verification after  End capture") {
     // Capture Info
-    HIP_CHECK(hipStreamGetCaptureInfo_v2(stream1, &captureStatus3,
-                            &capSequenceID3, nullptr, nullptr, nullptr));
-    HIP_CHECK(hipStreamGetCaptureInfo_v2(stream2, &captureStatus4,
-                            &capSequenceID4, nullptr, nullptr, nullptr));
+    HIP_CHECK(hipStreamGetCaptureInfo_v2(stream1, &captureStatus3, &capSequenceID3, nullptr,
+                                         nullptr, nullptr));
+    HIP_CHECK(hipStreamGetCaptureInfo_v2(stream2, &captureStatus4, &capSequenceID4, nullptr,
+                                         nullptr, nullptr));
     // Verification of results
     REQUIRE(captureStatus3 == hipStreamCaptureStatusNone);
     REQUIRE(captureStatus4 == hipStreamCaptureStatusNone);
@@ -377,20 +371,20 @@ TEST_CASE("Unit_hipStreamGetCaptureInfo_ParentAndForkedStrm_CaptureStatus") {
   free(D_h);
 }
 // Thread Function
-static void thread_func(hipStream_t stream, unsigned long long capSequenceID1,  //NOLINT
-                        unsigned long long capSequenceID2) {  //NOLINT
+static void thread_func(hipStream_t stream, unsigned long long capSequenceID1,  // NOLINT
+                        unsigned long long capSequenceID2) {                    // NOLINT
   hipStreamCaptureStatus captureStatus{hipStreamCaptureStatusNone};
-  unsigned long long capSequenceID3, capSequenceID4;  //NOLINT
+  unsigned long long capSequenceID3, capSequenceID4;  // NOLINT
   SECTION("hipStreamGetCaptureInfo CaptureStatus in Thread") {
-  HIP_CHECK(hipStreamGetCaptureInfo(stream, &captureStatus, &capSequenceID3));
-  REQUIRE(capSequenceID1 == capSequenceID3);
-  REQUIRE(captureStatus == hipStreamCaptureStatusActive);
+    HIP_CHECK(hipStreamGetCaptureInfo(stream, &captureStatus, &capSequenceID3));
+    REQUIRE(capSequenceID1 == capSequenceID3);
+    REQUIRE(captureStatus == hipStreamCaptureStatusActive);
   }
   SECTION("hipStreamGetCaptureInfo_v2 CaptureStatus in Thread") {
-  HIP_CHECK(hipStreamGetCaptureInfo_v2(stream, &captureStatus,
-                                 &capSequenceID4, nullptr, nullptr, nullptr));
-  REQUIRE(capSequenceID2 == capSequenceID4);
-  REQUIRE(captureStatus == hipStreamCaptureStatusActive);
+    HIP_CHECK(hipStreamGetCaptureInfo_v2(stream, &captureStatus, &capSequenceID4, nullptr, nullptr,
+                                         nullptr));
+    REQUIRE(capSequenceID2 == capSequenceID4);
+    REQUIRE(captureStatus == hipStreamCaptureStatusActive);
   }
 }
 /*
@@ -408,12 +402,12 @@ TEST_CASE("Unit_hipStreamGetCaptureInfo_CaptureStatus_InThread") {
   HIP_CHECK(hipStreamBeginCapture(stream, hipStreamCaptureModeGlobal));
   // Capture info
   hipStreamCaptureStatus captureStatus{hipStreamCaptureStatusNone};
-  unsigned long long capSequenceID1, capSequenceID2;  //NOLINT
+  unsigned long long capSequenceID1, capSequenceID2;  // NOLINT
   // hipStreamGetCaptureInfo Capture status
   HIP_CHECK(hipStreamGetCaptureInfo(stream, &captureStatus, &capSequenceID1));
   // hipStreamGetCaptureInfo_v2 Capture status
-  HIP_CHECK(hipStreamGetCaptureInfo_v2(stream, &captureStatus,
-                                 &capSequenceID2, nullptr, nullptr, nullptr));
+  HIP_CHECK(hipStreamGetCaptureInfo_v2(stream, &captureStatus, &capSequenceID2, nullptr, nullptr,
+                                       nullptr));
   // Thread launch
   std::thread t(thread_func, stream, capSequenceID1, capSequenceID2);
   t.join();
@@ -429,7 +423,7 @@ TEST_CASE("Unit_hipStreamGetCaptureInfo_CaptureStatus_InThread") {
  * Again get the capture info. Queue different operations in s1. Again get the
  * capture info. Verify that all the capture info are identical.
  * The above scenario using hipStreamGetCaptureInfo_v2 API
-*/
+ */
 TEST_CASE("Unit_hipStreamGetCaptureInfo_CaptureStatus_Througout_Capture") {
   hipStream_t stream{nullptr};
   hipGraph_t graph{nullptr};
@@ -457,25 +451,23 @@ TEST_CASE("Unit_hipStreamGetCaptureInfo_CaptureStatus_Througout_Capture") {
   HIP_CHECK(hipStreamBeginCapture(stream, hipStreamCaptureModeGlobal));
   // Capture Info
   hipStreamCaptureStatus captureStatus1{hipStreamCaptureStatusNone},
-                         captureStatus2{hipStreamCaptureStatusNone},
-                         captureStatus3{hipStreamCaptureStatusNone},
-                         captureStatus4{hipStreamCaptureStatusNone},
-                         captureStatus5{hipStreamCaptureStatusNone},
-                         captureStatus6{hipStreamCaptureStatusNone};
+      captureStatus2{hipStreamCaptureStatusNone}, captureStatus3{hipStreamCaptureStatusNone},
+      captureStatus4{hipStreamCaptureStatusNone}, captureStatus5{hipStreamCaptureStatusNone},
+      captureStatus6{hipStreamCaptureStatusNone};
 
-  unsigned long long capSequenceID1, capSequenceID2, capSequenceID3,  //NOLINT
-                     capSequenceID4, capSequenceID5, capSequenceID6;
+  unsigned long long capSequenceID1, capSequenceID2, capSequenceID3,  // NOLINT
+      capSequenceID4, capSequenceID5, capSequenceID6;
 
   // hipStreamGetCaptureInfo Capture status
   HIP_CHECK(hipStreamGetCaptureInfo(stream, &captureStatus1, &capSequenceID1));
   // hipStreamGetCaptureInfo_v2 Capture status
-  HIP_CHECK(hipStreamGetCaptureInfo_v2(stream, &captureStatus2,
-                                &capSequenceID2, nullptr, nullptr, nullptr));
+  HIP_CHECK(hipStreamGetCaptureInfo_v2(stream, &captureStatus2, &capSequenceID2, nullptr, nullptr,
+                                       nullptr));
   // Copy data to Device
   HIP_CHECK(hipMemcpyAsync(A_d, A_h, Nbytes, hipMemcpyHostToDevice, stream));
   // Kernal Operations
-  hipLaunchKernelGGL(HipTest::vector_square, dim3(blocks),
-                              dim3(threadsPerBlock), 0, stream, A_d, C_d, N);
+  hipLaunchKernelGGL(HipTest::vector_square, dim3(blocks), dim3(threadsPerBlock), 0, stream, A_d,
+                     C_d, N);
   HIP_CHECK(hipMemcpyAsync(C_h, C_d, Nbytes, hipMemcpyDeviceToHost, stream));
 
   // hipStreamGetCaptureInfo Capture status
@@ -483,15 +475,15 @@ TEST_CASE("Unit_hipStreamGetCaptureInfo_CaptureStatus_Througout_Capture") {
   REQUIRE(captureStatus1 == captureStatus3);
   REQUIRE(capSequenceID1 == capSequenceID3);
   // hipStreamGetCaptureInfo_v2 Capture status
-  HIP_CHECK(hipStreamGetCaptureInfo_v2(stream, &captureStatus4,
-                                &capSequenceID4, nullptr, nullptr, nullptr));
+  HIP_CHECK(hipStreamGetCaptureInfo_v2(stream, &captureStatus4, &capSequenceID4, nullptr, nullptr,
+                                       nullptr));
   REQUIRE(captureStatus2 == captureStatus4);
   REQUIRE(capSequenceID2 == capSequenceID4);
 
   // Kernal Operations
   HIP_CHECK(hipMemcpyAsync(B_d, B_h, Nbytes, hipMemcpyHostToDevice, stream));
-  hipLaunchKernelGGL(HipTest::vectorADD, dim3(blocks),
-                         dim3(threadsPerBlock), 0, stream, A_d, B_d, D_d, N);
+  hipLaunchKernelGGL(HipTest::vectorADD, dim3(blocks), dim3(threadsPerBlock), 0, stream, A_d, B_d,
+                     D_d, N);
   HIP_CHECK(hipMemcpyAsync(D_h, D_d, Nbytes, hipMemcpyDeviceToHost, stream));
 
   // hipStreamGetCaptureInfo Capture status
@@ -499,8 +491,8 @@ TEST_CASE("Unit_hipStreamGetCaptureInfo_CaptureStatus_Througout_Capture") {
   REQUIRE(captureStatus3 == captureStatus5);
   REQUIRE(capSequenceID3 == capSequenceID5);
   // hipStreamGetCaptureInfo_v2 Capture status
-  HIP_CHECK(hipStreamGetCaptureInfo_v2(stream, &captureStatus6,
-                                 &capSequenceID6, nullptr, nullptr, nullptr));
+  HIP_CHECK(hipStreamGetCaptureInfo_v2(stream, &captureStatus6, &capSequenceID6, nullptr, nullptr,
+                                       nullptr));
   REQUIRE(captureStatus4 == captureStatus6);
   REQUIRE(capSequenceID4 == capSequenceID6);
 
@@ -525,7 +517,7 @@ TEST_CASE("Unit_hipStreamGetCaptureInfo_CaptureStatus_Througout_Capture") {
  * operatoins. End the capture on the created stream.Verify the capture status. Execute the
  * graph and verify the output from the operations.
  * The above scenario using hipStreamGetCaptureInfo_v2 API
-*/
+ */
 TEST_CASE("Unit_hipStreamGetCaptureInfo_Nullstream_CaptureInfo") {
   hipStream_t stream{nullptr}, streamForGraph{nullptr};
   hipGraph_t graph{nullptr};
@@ -556,10 +548,9 @@ TEST_CASE("Unit_hipStreamGetCaptureInfo_Nullstream_CaptureInfo") {
   HIP_CHECK(hipStreamBeginCapture(stream, hipStreamCaptureModeGlobal));
 
   hipStreamCaptureStatus captureStatus{hipStreamCaptureStatusNone},
-                         captureStatus1{hipStreamCaptureStatusNone},
-                         captureStatus2{hipStreamCaptureStatusNone};
+      captureStatus1{hipStreamCaptureStatusNone}, captureStatus2{hipStreamCaptureStatusNone};
   unsigned long long capSequenceID = 0,  // NOLINT
-                     capSequenceID1 = 0;
+      capSequenceID1 = 0;
 
   // Verify the Error returned with null stream.
   SECTION("hipStreamGetCaptureInfo with null stream") {
@@ -567,8 +558,7 @@ TEST_CASE("Unit_hipStreamGetCaptureInfo_Nullstream_CaptureInfo") {
     REQUIRE(ret == hipErrorStreamCaptureImplicit);
   }
   SECTION("hipStreamGetCaptureInfo_v2 with null stream") {
-    ret = hipStreamGetCaptureInfo_v2(0, &captureStatus, &capSequenceID,
-                                     nullptr, nullptr, nullptr);
+    ret = hipStreamGetCaptureInfo_v2(0, &captureStatus, &capSequenceID, nullptr, nullptr, nullptr);
     REQUIRE(ret == hipErrorStreamCaptureImplicit);
   }
 
@@ -581,8 +571,8 @@ TEST_CASE("Unit_hipStreamGetCaptureInfo_Nullstream_CaptureInfo") {
   HIP_CHECK(hipMemcpyAsync(A_d, A_h, Nbytes, hipMemcpyHostToDevice, stream));
 
   // Kernal Operation
-  hipLaunchKernelGGL(HipTest::vector_square, dim3(blocks),
-                              dim3(threadsPerBlock), 0, stream, A_d, C_d, N);
+  hipLaunchKernelGGL(HipTest::vector_square, dim3(blocks), dim3(threadsPerBlock), 0, stream, A_d,
+                     C_d, N);
   HIP_CHECK(hipMemcpyAsync(C_h, C_d, Nbytes, hipMemcpyDeviceToHost, stream));
 
   // End the capture
@@ -595,8 +585,8 @@ TEST_CASE("Unit_hipStreamGetCaptureInfo_Nullstream_CaptureInfo") {
     REQUIRE(ret == hipSuccess);
   }
   SECTION("hipStreamGetCaptureInfo_v2 with null stream after End capture") {
-    ret = hipStreamGetCaptureInfo_v2(0, &captureStatus2, &capSequenceID1,
-                                     nullptr, nullptr, nullptr);
+    ret =
+        hipStreamGetCaptureInfo_v2(0, &captureStatus2, &capSequenceID1, nullptr, nullptr, nullptr);
     REQUIRE(ret == hipSuccess);
   }
   // Launch graph
