@@ -38,7 +38,7 @@ static void MemoryAlloc3DDiffSizes(int gpu) {
   std::vector<size_t> array_size;
   array_size.push_back(SMALL_SIZE);
   array_size.push_back(BIG_SIZE);
-  for (auto &sizes : array_size) {
+  for (auto& sizes : array_size) {
     size_t width = sizes * sizeof(float);
     size_t height{sizes}, depth{sizes};
     hipPitchedPtr devPitchedPtr[CHUNK_LOOP];
@@ -54,31 +54,59 @@ static void MemoryAlloc3DDiffSizes(int gpu) {
   }
 }
 
-static void Malloc3DThreadFunc(int gpu) {
-  MemoryAlloc3DDiffSizes(gpu);
-}
+static void Malloc3DThreadFunc(int gpu) { MemoryAlloc3DDiffSizes(gpu); }
 
 /*
- * This verifies the hipMalloc3D API by
- * assigning width,height and depth as 10
+ * This test allocates via hipMalloc3D and deallotes via hipFree().
+ * To verify that the returned memory is again available, we use hipMemGetInfo().
+ * On Windows, allocating/deallocating small amounts of device memory will not make a difference in
+ * the reported available memory because they go into subheaps of size
+ * PalSettings::subAllocationChunkSize_ and only whenever we trigger a whole subheap
+ *  allocation/deallocation we will see a difference in the reported value.
+ * To make sure we make a difference in the reported available memory; we perform small several
+ * allocation whose combined size goes over PalSettings::subAllocationChunkSize_;
+ * hipMemGetInfo() should indicate the memory went down after we hipFree() all of them
  */
 TEST_CASE("Unit_hipMalloc3D_Basic") {
   CHECK_IMAGE_SUPPORT
 
-  size_t width = SMALL_SIZE * sizeof(char);
-  size_t height{SMALL_SIZE}, depth{SMALL_SIZE};
-  hipPitchedPtr devPitchedPtr;
+  static constexpr int ChunkSize = 64;  // (in megabytes)
+  static constexpr int NumAllocations = 3;
+
+  size_t width{(ChunkSize * 1024) / NumAllocations}, height{1024}, depth{1};
+  hipPitchedPtr devPitchedPtr[NumAllocations];
   hipExtent extent = make_hipExtent(width, height, depth);
-  size_t tot, avail, ptot, pavail;
+  size_t tot, avail, itot, iavail, ptot, pavail;
   HIP_CHECK(hipMemGetInfo(&pavail, &ptot));
 
-  REQUIRE(hipMalloc3D(&devPitchedPtr, extent) == hipSuccess);
-  HIPCHECK(hipFree(devPitchedPtr.ptr));
+  for (int i = 0; i < NumAllocations; i++) {
+    REQUIRE(hipMalloc3D(&devPitchedPtr[i], extent) == hipSuccess);
+  }
+
+  HIP_CHECK(hipMemGetInfo(&iavail, &itot));
+
+  if (iavail >= pavail)
+    WARN(
+        "hipMemGetInfo() did not report increased memory usage after calling hipMalloc3D(). "
+        "Before: "
+        << pavail << " after: " << iavail);
+
+  for (int i = 0; i < NumAllocations; i++) {
+    HIPCHECK(hipFree(devPitchedPtr[i].ptr));
+  }
 
   HIP_CHECK(hipMemGetInfo(&avail, &tot));
 
-  if (pavail != avail) {
-    WARN("Memory leak of hipMalloc3D API in multithreaded scenario");
+  // as the runtime might cache some of the allocations and also it is difficult the
+  // available amount returned is the same as the one we got the first time because of
+  // other processes running on the system; we consider a success if at least a size
+  // equivalent to two of the allocations has become available
+  // This test was too brittle before, when it was expecting avail to be equal to pavail
+  if (avail < pavail - height * width * depth) {
+    WARN("Memory leak of hipMalloc3D API in multithreaded scenario."
+         << " Available memory before the hipMalloc3D() call (bytes): " << pavail
+         << " Available memory after the call: " << iavail
+         << " Available memory after hipFree(): " << avail);
     REQUIRE(false);
   }
 }
@@ -110,7 +138,7 @@ TEST_CASE("Unit_hipMalloc3D_MultiThread") {
     threadlist.push_back(std::thread(Malloc3DThreadFunc, i));
   }
 
-  for (auto &t : threadlist) {
+  for (auto& t : threadlist) {
     t.join();
   }
 }
