@@ -77,14 +77,13 @@ THE SOFTWARE.
 #endif
 
 // Kernel function
-__global__ void MemAdvseKernel(int n, int *x) {
+__global__ void MemAdvseKernel(int n, int* x) {
   int index = blockIdx.x * blockDim.x + threadIdx.x;
-  if (index < n)
-    x[index] = x[index] * x[index];
+  if (index < n) x[index] = x[index] * x[index];
 }
 
 // Kernel
-__global__ void MemAdvise2(int *Hmm, int n) {
+__global__ void MemAdvise2(int* Hmm, int n) {
   int index = blockIdx.x * blockDim.x + threadIdx.x;
   int stride = blockDim.x * gridDim.x;
   for (int i = index; i < n; i += stride) {
@@ -93,7 +92,7 @@ __global__ void MemAdvise2(int *Hmm, int n) {
 }
 
 // Kernel
-__global__ void MemAdvise3(int *Hmm, int *Hmm1, int n) {
+__global__ void MemAdvise3(int* Hmm, int* Hmm1, int n) {
   int index = blockIdx.x * blockDim.x + threadIdx.x;
   int stride = blockDim.x * gridDim.x;
   for (int i = index; i < n; i += stride) {
@@ -113,23 +112,20 @@ static bool CheckError(hipError_t err, int LineNo) {
 
 static int HmmAttrPrint() {
   int managed = 0;
-  WARN("The following are the attribute values related to HMM for"
-         " device 0:\n");
-  HIP_CHECK(hipDeviceGetAttribute(&managed,
-              hipDeviceAttributeDirectManagedMemAccessFromHost, 0));
+  WARN(
+      "The following are the attribute values related to HMM for"
+      " device 0:\n");
+  HIP_CHECK(hipDeviceGetAttribute(&managed, hipDeviceAttributeDirectManagedMemAccessFromHost, 0));
   WARN("hipDeviceAttributeDirectManagedMemAccessFromHost: " << managed);
-  HIP_CHECK(hipDeviceGetAttribute(&managed,
-                                 hipDeviceAttributeConcurrentManagedAccess, 0));
+  HIP_CHECK(hipDeviceGetAttribute(&managed, hipDeviceAttributeConcurrentManagedAccess, 0));
   WARN("hipDeviceAttributeConcurrentManagedAccess: " << managed);
-  HIP_CHECK(hipDeviceGetAttribute(&managed,
-                                 hipDeviceAttributePageableMemoryAccess, 0));
+  HIP_CHECK(hipDeviceGetAttribute(&managed, hipDeviceAttributePageableMemoryAccess, 0));
   WARN("hipDeviceAttributePageableMemoryAccess: " << managed);
-  HIP_CHECK(hipDeviceGetAttribute(&managed,
-              hipDeviceAttributePageableMemoryAccessUsesHostPageTables, 0));
+  HIP_CHECK(
+      hipDeviceGetAttribute(&managed, hipDeviceAttributePageableMemoryAccessUsesHostPageTables, 0));
   WARN("hipDeviceAttributePageableMemoryAccessUsesHostPageTables:" << managed);
 
-  HIP_CHECK(hipDeviceGetAttribute(&managed, hipDeviceAttributeManagedMemory,
-                                  0));
+  HIP_CHECK(hipDeviceGetAttribute(&managed, hipDeviceAttributeManagedMemory, 0));
   WARN("hipDeviceAttributeManagedMemory: " << managed);
   return managed;
 }
@@ -142,8 +138,8 @@ TEST_CASE("Unit_hipMemAdvise_TstFlags") {
   if (MangdMem == 1) {
     bool IfTestPassed = true;
     int NumDevs = 0, *Outpt = nullptr;
-    int MEM_SIZE = 4*1024, A_CONST = 9999;
-    float *Hmm = nullptr;
+    int MEM_SIZE = 4 * 1024, A_CONST = 9999;
+    float* Hmm = nullptr;
     int AttrVal = 0;
     HIP_CHECK(hipGetDeviceCount(&NumDevs));
     Outpt = new int[NumDevs];
@@ -151,20 +147,17 @@ TEST_CASE("Unit_hipMemAdvise_TstFlags") {
     // With the following for loop we iterate through each of the Gpus in the
     // system set and unset the flags and check the behavior.
     for (int i = 0; i < NumDevs; ++i) {
-      HIP_CHECK(hipMemAdvise(Hmm , MEM_SIZE * 2, hipMemAdviseSetReadMostly, i));
-      HIP_CHECK(hipMemRangeGetAttribute(&AttrVal, sizeof(AttrVal),
-                                        hipMemRangeAttributeReadMostly, Hmm,
-                                       MEM_SIZE * 2));
+      HIP_CHECK(hipMemAdvise(Hmm, MEM_SIZE * 2, hipMemAdviseSetReadMostly, i));
+      HIP_CHECK(hipMemRangeGetAttribute(&AttrVal, sizeof(AttrVal), hipMemRangeAttributeReadMostly,
+                                        Hmm, MEM_SIZE * 2));
       if (AttrVal != 1) {
         WARN("Attempt to set hipMemAdviseSetReadMostly flag failed!\n");
         IfTestPassed = false;
       }
-      HIP_CHECK(hipMemAdvise(Hmm , MEM_SIZE * 2, hipMemAdviseUnsetReadMostly,
-                             i));
+      HIP_CHECK(hipMemAdvise(Hmm, MEM_SIZE * 2, hipMemAdviseUnsetReadMostly, i));
 
-      HIP_CHECK(hipMemRangeGetAttribute(&AttrVal, sizeof(AttrVal),
-                                       hipMemRangeAttributeReadMostly, Hmm,
-                                       (MEM_SIZE * 2)));
+      HIP_CHECK(hipMemRangeGetAttribute(&AttrVal, sizeof(AttrVal), hipMemRangeAttributeReadMostly,
+                                        Hmm, (MEM_SIZE * 2)));
       if (AttrVal != 0) {
         WARN("Attempt to Unset hipMemAdviseSetReadMostly flag failed!\n");
         IfTestPassed = false;
@@ -173,33 +166,28 @@ TEST_CASE("Unit_hipMemAdvise_TstFlags") {
       // Currently hipMemAdviseSetPreferredLocation and
       // hipMemAdviseSetAccessedBy
       // flags are resulting in issues: SWDEV-267357
-      HIP_CHECK(hipMemAdvise(Hmm , MEM_SIZE * 2,
-                            hipMemAdviseSetPreferredLocation, i));
-      HIP_CHECK(hipMemRangeGetAttribute(&AttrVal, sizeof(AttrVal),
-                                       hipMemRangeAttributePreferredLocation,
-                                       Hmm, (MEM_SIZE * 2)));
+      HIP_CHECK(hipMemAdvise(Hmm, MEM_SIZE * 2, hipMemAdviseSetPreferredLocation, i));
+      HIP_CHECK(hipMemRangeGetAttribute(
+          &AttrVal, sizeof(AttrVal), hipMemRangeAttributePreferredLocation, Hmm, (MEM_SIZE * 2)));
       if (AttrVal != i) {
         WARN("Attempt to set hipMemAdviseSetPreferredLocation flag failed!\n");
         IfTestPassed = false;
       }
       AttrVal = A_CONST;
-      HIP_CHECK(hipMemAdvise(Hmm , MEM_SIZE * 2,
-                            hipMemAdviseUnsetPreferredLocation, i));
-      HIP_CHECK(hipMemRangeGetAttribute(&AttrVal, sizeof(AttrVal),
-                                       hipMemRangeAttributePreferredLocation,
-                                       Hmm, (MEM_SIZE * 2)));
+      HIP_CHECK(hipMemAdvise(Hmm, MEM_SIZE * 2, hipMemAdviseUnsetPreferredLocation, i));
+      HIP_CHECK(hipMemRangeGetAttribute(
+          &AttrVal, sizeof(AttrVal), hipMemRangeAttributePreferredLocation, Hmm, (MEM_SIZE * 2)));
       if (AttrVal == i) {
-      WARN("Attempt to Unset hipMemAdviseUnsetPreferredLocation ");
-      WARN("flag failed!\n");
-      IfTestPassed = false;
+        WARN("Attempt to Unset hipMemAdviseUnsetPreferredLocation ");
+        WARN("flag failed!\n");
+        IfTestPassed = false;
       }
       for (int m = 0; m < NumDevs; ++m) {
         Outpt[m] = A_CONST;
       }
-      HIP_CHECK(hipMemAdvise(Hmm , MEM_SIZE * 2, hipMemAdviseSetAccessedBy, i));
-      HIP_CHECK(hipMemRangeGetAttribute(Outpt, sizeof(Outpt),
-                                       hipMemRangeAttributeAccessedBy, Hmm,
-                                       (MEM_SIZE * 2)));
+      HIP_CHECK(hipMemAdvise(Hmm, MEM_SIZE * 2, hipMemAdviseSetAccessedBy, i));
+      HIP_CHECK(hipMemRangeGetAttribute(Outpt, sizeof(Outpt), hipMemRangeAttributeAccessedBy, Hmm,
+                                        (MEM_SIZE * 2)));
       if ((Outpt[0]) != i) {
         WARN("Attempt to set hipMemAdviseSetAccessedBy flag failed!\n");
         IfTestPassed = false;
@@ -207,22 +195,21 @@ TEST_CASE("Unit_hipMemAdvise_TstFlags") {
       for (int m = 0; m < NumDevs; ++m) {
         Outpt[m] = A_CONST;
       }
-      HIP_CHECK(hipMemAdvise(Hmm , MEM_SIZE * 2, hipMemAdviseUnsetAccessedBy,
-                             i));
-      HIP_CHECK(hipMemRangeGetAttribute(Outpt, sizeof(Outpt),
-                                       hipMemRangeAttributeAccessedBy, Hmm,
-                                       (MEM_SIZE * 2)));
+      HIP_CHECK(hipMemAdvise(Hmm, MEM_SIZE * 2, hipMemAdviseUnsetAccessedBy, i));
+      HIP_CHECK(hipMemRangeGetAttribute(Outpt, sizeof(Outpt), hipMemRangeAttributeAccessedBy, Hmm,
+                                        (MEM_SIZE * 2)));
       if ((Outpt[0]) >= 0) {
         WARN("Attempt to Unset hipMemAdviseUnsetAccessedBy flag failed!\n");
         IfTestPassed = false;
       }
     }
-    delete [] Outpt;
+    delete[] Outpt;
     HIP_CHECK(hipFree(Hmm));
     REQUIRE(IfTestPassed);
   } else {
-    SUCCEED("GPU 0 doesn't support hipDeviceAttributeManagedMemory "
-           "attribute. Hence skipping the testing with Pass result.\n");
+    SUCCEED(
+        "GPU 0 doesn't support hipDeviceAttributeManagedMemory "
+        "attribute. Hence skipping the testing with Pass result.\n");
   }
 }
 
@@ -230,27 +217,27 @@ TEST_CASE("Unit_hipMemAdvise_NegtveTsts") {
   int MangdMem = HmmAttrPrint();
   if (MangdMem == 1) {
     bool IfTestPassed = true;
-    int NumDevs = 0, MEM_SIZE = 4*1024;
-    float *Hmm = nullptr;
+    int NumDevs = 0, MEM_SIZE = 4 * 1024;
+    float* Hmm = nullptr;
     std::string str;
     HIP_CHECK(hipGetDeviceCount(&NumDevs));
     HIP_CHECK(hipMallocManaged(&Hmm, MEM_SIZE * 2, hipMemAttachGlobal));
     // Passing NULL as first parameter instead of valid pointer to a memory
-    IfTestPassed &= CheckError(hipMemAdvise(NULL, MEM_SIZE * 2,
-                               hipMemAdviseSetReadMostly, 0), __LINE__);
+    IfTestPassed &=
+        CheckError(hipMemAdvise(NULL, MEM_SIZE * 2, hipMemAdviseSetReadMostly, 0), __LINE__);
 
     // Passing 0 for count(2nd param) parameter
-    IfTestPassed &= CheckError(hipMemAdvise(Hmm, 0, hipMemAdviseSetReadMostly,
-                                            0), __LINE__);
+    IfTestPassed &= CheckError(hipMemAdvise(Hmm, 0, hipMemAdviseSetReadMostly, 0), __LINE__);
 
     // Passing count much more than actually allocated value
-    IfTestPassed &= CheckError(hipMemAdvise(Hmm, MEM_SIZE * 6,
-                               hipMemAdviseSetReadMostly, 0), __LINE__);
+    IfTestPassed &=
+        CheckError(hipMemAdvise(Hmm, MEM_SIZE * 6, hipMemAdviseSetReadMostly, 0), __LINE__);
 
     REQUIRE(IfTestPassed);
   } else {
-    SUCCEED("GPU 0 doesn't support hipDeviceAttributeManagedMemory "
-           "attribute. Hence skipping the testing with Pass result.\n");
+    SUCCEED(
+        "GPU 0 doesn't support hipDeviceAttributeManagedMemory "
+        "attribute. Hence skipping the testing with Pass result.\n");
   }
 }
 
@@ -266,18 +253,16 @@ TEST_CASE("Unit_hipMemAdvise_PrefrdLoc") {
     bool IfTestPassed = true;
     HIP_CHECK(hipGetDeviceCount(&NumDevs));
     HIP_CHECK(hipMallocManaged(&Hmm, MEM_SIZE * 3, hipMemAttachGlobal));
-    for (int i = 0; i < ((MEM_SIZE * 3)/4); ++i) {
-        Hmm[i]  = 4;
+    for (int i = 0; i < ((MEM_SIZE * 3) / 4); ++i) {
+      Hmm[i] = 4;
     }
     for (int devId = 0; devId < NumDevs; ++devId) {
-      HIP_CHECK(hipMemAdvise(Hmm, MEM_SIZE * 3,
-                             hipMemAdviseSetPreferredLocation, devId));
-      int NumElms = ((MEM_SIZE * 3)/4);
-      MemAdvseKernel<<<NumElms/32, 32>>>(NumElms, Hmm);
+      HIP_CHECK(hipMemAdvise(Hmm, MEM_SIZE * 3, hipMemAdviseSetPreferredLocation, devId));
+      int NumElms = ((MEM_SIZE * 3) / 4);
+      MemAdvseKernel<<<NumElms / 32, 32>>>(NumElms, Hmm);
       int dev = A_CONST;
-      HIP_CHECK(hipMemRangeGetAttribute(&dev, sizeof(dev),
-                                       hipMemRangeAttributePreferredLocation,
-                                       Hmm, MEM_SIZE * 3));
+      HIP_CHECK(hipMemRangeGetAttribute(&dev, sizeof(dev), hipMemRangeAttributePreferredLocation,
+                                        Hmm, MEM_SIZE * 3));
       if (dev != devId) {
         WARN("Memory observed to be not available on expected location\n");
         WARN("line no: " << __LINE__);
@@ -293,13 +278,11 @@ TEST_CASE("Unit_hipMemAdvise_PrefrdLoc") {
     for (int devId = 0; devId < NumDevs; ++devId) {
       HIP_CHECK(hipSetDevice(devId));
       HIP_CHECK(hipStreamCreate(&strm));
-      HIP_CHECK(hipMemAdvise(Hmm, MEM_SIZE * 3,
-                             hipMemAdviseSetPreferredLocation, devId));
+      HIP_CHECK(hipMemAdvise(Hmm, MEM_SIZE * 3, hipMemAdviseSetPreferredLocation, devId));
       HIP_CHECK(hipMemPrefetchAsync(Hmm, MEM_SIZE * 3, devId, strm));
       HIP_CHECK(hipStreamSynchronize(strm));
-      HIP_CHECK(hipMemRangeGetAttribute(&dev, sizeof(dev),
-                                       hipMemRangeAttributeLastPrefetchLocation,
-                                       Hmm, MEM_SIZE * 3));
+      HIP_CHECK(hipMemRangeGetAttribute(&dev, sizeof(dev), hipMemRangeAttributeLastPrefetchLocation,
+                                        Hmm, MEM_SIZE * 3));
       if (dev != devId) {
         WARN("Memory reported to be not available at the Prefetched ");
         WARN("location with device id: " << devId);
@@ -312,8 +295,9 @@ TEST_CASE("Unit_hipMemAdvise_PrefrdLoc") {
     HIP_CHECK(hipFree(Hmm));
     REQUIRE(IfTestPassed);
   } else {
-    SUCCEED("GPU 0 doesn't support hipDeviceAttributeManagedMemory "
-           "attribute. Hence skipping the testing with Pass result.\n");
+    SUCCEED(
+        "GPU 0 doesn't support hipDeviceAttributeManagedMemory "
+        "attribute. Hence skipping the testing with Pass result.\n");
   }
 }
 
@@ -325,14 +309,14 @@ TEST_CASE("Unit_hipMemAdvise_ReadMostly") {
   if (MangdMem == 1) {
     bool IfTestPassed = true;
     int MEM_SIZE = 4096, A_CONST = 9999;
-    float *Hmm = nullptr;
+    float* Hmm = nullptr;
     HIP_CHECK(hipMallocManaged(&Hmm, MEM_SIZE));
-    for (uint64_t i = 0; i < (MEM_SIZE/sizeof(float)); ++i) {
+    for (uint64_t i = 0; i < (MEM_SIZE / sizeof(float)); ++i) {
       Hmm[i] = A_CONST;
     }
     HIP_CHECK(hipMemAdvise(Hmm, MEM_SIZE, hipMemAdviseSetReadMostly, 0));
     // Checking if the data can be read after setting hipMemAdviseSetReadMostly
-    for (uint64_t i = 0; i < (MEM_SIZE/sizeof(float)); ++i) {
+    for (uint64_t i = 0; i < (MEM_SIZE / sizeof(float)); ++i) {
       if (Hmm[i] != A_CONST) {
         WARN("Didn't find expected value in Hmm memory after setting");
         WARN(" hipMemAdviseSetReadMostly flag line no.: " << __LINE__);
@@ -341,11 +325,11 @@ TEST_CASE("Unit_hipMemAdvise_ReadMostly") {
     }
 
     // Checking if the memory region can be modified
-    for (uint64_t i = 0; i < (MEM_SIZE/sizeof(float)); ++i) {
+    for (uint64_t i = 0; i < (MEM_SIZE / sizeof(float)); ++i) {
       Hmm[i] = A_CONST;
     }
 
-    for (uint64_t i = 0; i < (MEM_SIZE/sizeof(float)); ++i) {
+    for (uint64_t i = 0; i < (MEM_SIZE / sizeof(float)); ++i) {
       if (Hmm[i] != A_CONST) {
         WARN("Didn't find expected value in Hmm memory after Modification\n");
         WARN("line no.: " << __LINE__);
@@ -354,8 +338,7 @@ TEST_CASE("Unit_hipMemAdvise_ReadMostly") {
     }
 
     int out = A_CONST;
-    HIP_CHECK(hipMemRangeGetAttribute(&out, 4, hipMemRangeAttributeReadMostly,
-                                      Hmm, MEM_SIZE));
+    HIP_CHECK(hipMemRangeGetAttribute(&out, 4, hipMemRangeAttributeReadMostly, Hmm, MEM_SIZE));
     if (out != 1) {
       WARN("out value: " << out);
       IfTestPassed = false;
@@ -363,9 +346,8 @@ TEST_CASE("Unit_hipMemAdvise_ReadMostly") {
     // Checking the advise attribute after prefetch
     HIP_CHECK(hipMemPrefetchAsync(Hmm, MEM_SIZE, 0, 0));
     HIP_CHECK(hipDeviceSynchronize());
-    HIP_CHECK(hipMemRangeGetAttribute(&out, sizeof(int),
-                                     hipMemRangeAttributeReadMostly, Hmm,
-                                     MEM_SIZE));
+    HIP_CHECK(
+        hipMemRangeGetAttribute(&out, sizeof(int), hipMemRangeAttributeReadMostly, Hmm, MEM_SIZE));
     if (out != 1) {
       WARN("Attribute assigned to memory changed after calling ");
       WARN("hipMemPrefetchAsync(). line no.: " << __LINE__);
@@ -380,8 +362,9 @@ TEST_CASE("Unit_hipMemAdvise_ReadMostly") {
     HIP_CHECK(hipFree(Hmm));
     REQUIRE(IfTestPassed);
   } else {
-    SUCCEED("GPU 0 doesn't support hipDeviceAttributeManagedMemory "
-           "attribute. Hence skipping the testing with Pass result.\n");
+    SUCCEED(
+        "GPU 0 doesn't support hipDeviceAttributeManagedMemory "
+        "attribute. Hence skipping the testing with Pass result.\n");
   }
 }
 
@@ -392,17 +375,16 @@ TEST_CASE("Unit_hipMemAdvise_TstFlgOverrideEffect") {
   int MangdMem = HmmAttrPrint();
   if (MangdMem == 1) {
     bool IfTestPassed = true;
-    int MEM_SIZE = 4*4096, A_CONST = 9999;
-    float *Hmm = nullptr;
+    int MEM_SIZE = 4 * 4096, A_CONST = 9999;
+    float* Hmm = nullptr;
     int NumDevs = 0, dev = A_CONST;
 
     HIP_CHECK(hipGetDeviceCount(&NumDevs));
     HIP_CHECK(hipMallocManaged(&Hmm, MEM_SIZE, hipMemAttachGlobal));
     for (int i = 0; i < NumDevs; ++i) {
       HIP_CHECK(hipMemAdvise(Hmm, MEM_SIZE, hipMemAdviseSetReadMostly, i));
-      HIP_CHECK(hipMemRangeGetAttribute(&dev, sizeof(int),
-                                       hipMemRangeAttributeReadMostly, Hmm,
-                                       MEM_SIZE));
+      HIP_CHECK(hipMemRangeGetAttribute(&dev, sizeof(int), hipMemRangeAttributeReadMostly, Hmm,
+                                        MEM_SIZE));
       if (dev != 1) {
         WARN("hipMemAdviseSetReadMostly flag did not take affect despite ");
         WARN("setting it using hipMemAdvise(). line no.: " << __LINE__);
@@ -410,11 +392,9 @@ TEST_CASE("Unit_hipMemAdvise_TstFlgOverrideEffect") {
         break;
       }
       dev = A_CONST;
-      HIP_CHECK(hipMemAdvise(Hmm, MEM_SIZE, hipMemAdviseSetPreferredLocation,
-                             i));
-      HIP_CHECK(hipMemRangeGetAttribute(&dev, sizeof(int),
-                                       hipMemRangeAttributePreferredLocation,
-                                       Hmm, MEM_SIZE));
+      HIP_CHECK(hipMemAdvise(Hmm, MEM_SIZE, hipMemAdviseSetPreferredLocation, i));
+      HIP_CHECK(hipMemRangeGetAttribute(&dev, sizeof(int), hipMemRangeAttributePreferredLocation,
+                                        Hmm, MEM_SIZE));
       if (dev != i) {
         WARN("hipMemAdviseSetPreferredLocation flag did not take affect ");
         WARN("despite setting it using hipMemAdvise()\n");
@@ -425,9 +405,8 @@ TEST_CASE("Unit_hipMemAdvise_TstFlgOverrideEffect") {
 
       HIP_CHECK(hipMemAdvise(Hmm, MEM_SIZE, hipMemAdviseSetAccessedBy, i));
       dev = A_CONST;
-      HIP_CHECK(hipMemRangeGetAttribute(&dev, sizeof(int),
-                                       hipMemRangeAttributeAccessedBy, Hmm,
-                                       MEM_SIZE));
+      HIP_CHECK(hipMemRangeGetAttribute(&dev, sizeof(int), hipMemRangeAttributeAccessedBy, Hmm,
+                                        MEM_SIZE));
       if (dev != i) {
         WARN("hipMemAdviseSetAccessedBy flag did not take affect despite ");
         WARN("setting it using hipMemAdvise(). line no.: " << __LINE__);
@@ -439,8 +418,9 @@ TEST_CASE("Unit_hipMemAdvise_TstFlgOverrideEffect") {
     HIP_CHECK(hipFree(Hmm));
     REQUIRE(IfTestPassed);
   } else {
-    SUCCEED("GPU 0 doesn't support hipDeviceAttributeManagedMemory "
-           "attribute. Hence skipping the testing with Pass result.\n");
+    SUCCEED(
+        "GPU 0 doesn't support hipDeviceAttributeManagedMemory "
+        "attribute. Hence skipping the testing with Pass result.\n");
   }
 }
 
@@ -452,33 +432,33 @@ TEST_CASE("Unit_hipMemAdvise_TstAccessedByPeer") {
   int MangdMem = HmmAttrPrint();
   if (MangdMem == 1) {
     bool IfTestPassed = true;
-    int *Hmm = nullptr, MEM_SIZE = 4*4096, A_CONST = 9999;;
+    int *Hmm = nullptr, MEM_SIZE = 4 * 4096, A_CONST = 9999;
+    ;
     int NumDevs = 0, CanAccessPeer = A_CONST, flag = 0;
 
     HIP_CHECK(hipGetDeviceCount(&NumDevs));
     if (NumDevs < 2) {
-      SUCCEED("Test TestSetAccessedByPeer() need atleast two Gpus to test"
-             " the scenario. This system has GPUs less than 2");
+      SUCCEED(
+          "Test TestSetAccessedByPeer() need atleast two Gpus to test"
+          " the scenario. This system has GPUs less than 2");
     }
     HIP_CHECK(hipMallocManaged(&Hmm, MEM_SIZE, hipMemAttachGlobal));
     for (int i = 0; i < NumDevs; ++i) {
       HIP_CHECK(hipMemPrefetchAsync(Hmm, MEM_SIZE, i, 0));
       for (int j = 0; j < NumDevs; ++j) {
-        if (i == j)
-          continue;
+        if (i == j) continue;
         HIP_CHECK(hipSetDevice(j));
         HIP_CHECK(hipDeviceCanAccessPeer(&CanAccessPeer, j, i));
         if (CanAccessPeer) {
           HIP_CHECK(hipMemAdvise(Hmm, MEM_SIZE, hipMemAdviseSetAccessedBy, j));
-          for (uint64_t m = 0; m < (MEM_SIZE/sizeof(int)); ++m) {
+          for (uint64_t m = 0; m < (MEM_SIZE / sizeof(int)); ++m) {
             Hmm[m] = 4;
           }
           HIP_CHECK(hipDeviceEnablePeerAccess(i, 0));
-          MemAdvseKernel<<<(MEM_SIZE/sizeof(int)/32), 32>>>(
-                           (MEM_SIZE/sizeof(int)), Hmm);
+          MemAdvseKernel<<<(MEM_SIZE / sizeof(int) / 32), 32>>>((MEM_SIZE / sizeof(int)), Hmm);
           HIP_CHECK(hipDeviceSynchronize());
           // Verifying the result
-          for (uint64_t m = 0; m < (MEM_SIZE/sizeof(int)); ++m) {
+          for (uint64_t m = 0; m < (MEM_SIZE / sizeof(int)); ++m) {
             if (Hmm[m] != 16) {
               flag = 1;
             }
@@ -495,8 +475,9 @@ TEST_CASE("Unit_hipMemAdvise_TstAccessedByPeer") {
     HIP_CHECK(hipFree(Hmm));
     REQUIRE(IfTestPassed);
   } else {
-    SUCCEED("GPU 0 doesn't support hipDeviceAttributeManagedMemory "
-           "attribute. Hence skipping the testing with Pass result.\n");
+    SUCCEED(
+        "GPU 0 doesn't support hipDeviceAttributeManagedMemory "
+        "attribute. Hence skipping the testing with Pass result.\n");
   }
 }
 #endif
@@ -508,18 +489,18 @@ TEST_CASE("Unit_hipMemAdvise_TstAccessedByFlg") {
   int managed = HmmAttrPrint();
   if (managed == 1) {
     int *Hmm = NULL, data = 999;
-    HIP_CHECK(hipMallocManaged(&Hmm, 2*4096));
-    HIP_CHECK(hipMemAdvise(Hmm, 2*4096, hipMemAdviseSetAccessedBy, 0));
-    HIP_CHECK(hipMemRangeGetAttribute(&data, sizeof(int),
-                                     hipMemRangeAttributeLastPrefetchLocation,
-                                     Hmm, 2*4096));
+    HIP_CHECK(hipMallocManaged(&Hmm, 2 * 4096));
+    HIP_CHECK(hipMemAdvise(Hmm, 2 * 4096, hipMemAdviseSetAccessedBy, 0));
+    HIP_CHECK(hipMemRangeGetAttribute(&data, sizeof(int), hipMemRangeAttributeLastPrefetchLocation,
+                                      Hmm, 2 * 4096));
     if (data != -2) {
       WARN("Didnt get expected value!!\n");
       REQUIRE(false);
     }
   } else {
-    SUCCEED("GPU 0 doesn't support hipDeviceAttributeManagedMemory "
-           "attribute. Hence skipping the testing with Pass result.\n");
+    SUCCEED(
+        "GPU 0 doesn't support hipDeviceAttributeManagedMemory "
+        "attribute. Hence skipping the testing with Pass result.\n");
   }
 }
 
@@ -534,27 +515,27 @@ TEST_CASE("Unit_hipMemAdvise_TstAccessedByFlg2") {
     if (Ngpus >= 2) {
       hipStream_t strm;
       HIP_CHECK(hipStreamCreate(&strm));
-      HIP_CHECK(hipMallocManaged(&Hmm, 2*4096));
-      HIP_CHECK(hipMemAdvise(Hmm, 2*4096, hipMemAdviseSetAccessedBy, 0));
-      HIP_CHECK(hipMemPrefetchAsync(Hmm, 2*4096, 1, strm));
-      HIP_CHECK(hipMemRangeGetAttribute(&data, sizeof(int),
-                hipMemRangeAttributeAccessedBy, Hmm, 2*4096));
+      HIP_CHECK(hipMallocManaged(&Hmm, 2 * 4096));
+      HIP_CHECK(hipMemAdvise(Hmm, 2 * 4096, hipMemAdviseSetAccessedBy, 0));
+      HIP_CHECK(hipMemPrefetchAsync(Hmm, 2 * 4096, 1, strm));
+      HIP_CHECK(hipMemRangeGetAttribute(&data, sizeof(int), hipMemRangeAttributeAccessedBy, Hmm,
+                                        2 * 4096));
       if (data != 0) {
         WARN("Didnt get expected behavior at line: " << __LINE__);
         REQUIRE(false);
       }
-      HIP_CHECK(hipMemAdvise(Hmm, 2*4096, hipMemAdviseUnsetAccessedBy, 0));
+      HIP_CHECK(hipMemAdvise(Hmm, 2 * 4096, hipMemAdviseUnsetAccessedBy, 0));
       HIP_CHECK(hipStreamDestroy(strm));
       HIP_CHECK(hipFree(Hmm));
     }
   } else {
-    SUCCEED("GPU 0 doesn't support hipDeviceAttributeManagedMemory "
-           "attribute. Hence skipping the testing with Pass result.\n");
+    SUCCEED(
+        "GPU 0 doesn't support hipDeviceAttributeManagedMemory "
+        "attribute. Hence skipping the testing with Pass result.\n");
   }
 }
 
 
-
 /* 1) Set AccessedBy to device 0 followed by PreferredLocation to device 1
    check for AccessedBy flag using hipMemRangeGetAttribute() it should
    return 0
@@ -568,20 +549,20 @@ TEST_CASE("Unit_hipMemAdvise_TstAccessedByFlg3") {
     int *Hmm = NULL, data = 999, Ngpus = 0;
     HIP_CHECK(hipGetDeviceCount(&Ngpus));
     if (Ngpus >= 2) {
-      HIP_CHECK(hipMallocManaged(&Hmm, 2*4096));
-      HIP_CHECK(hipMemAdvise(Hmm, 2*4096, hipMemAdviseSetAccessedBy, 0));
-      HIP_CHECK(hipMemAdvise(Hmm, 2*4096, hipMemAdviseSetPreferredLocation, 1));
-      HIP_CHECK(hipMemRangeGetAttribute(&data, sizeof(int),
-                hipMemRangeAttributeAccessedBy, Hmm, 2*4096));
+      HIP_CHECK(hipMallocManaged(&Hmm, 2 * 4096));
+      HIP_CHECK(hipMemAdvise(Hmm, 2 * 4096, hipMemAdviseSetAccessedBy, 0));
+      HIP_CHECK(hipMemAdvise(Hmm, 2 * 4096, hipMemAdviseSetPreferredLocation, 1));
+      HIP_CHECK(hipMemRangeGetAttribute(&data, sizeof(int), hipMemRangeAttributeAccessedBy, Hmm,
+                                        2 * 4096));
       if (data != 0) {
         WARN("Didnt get expected behavior at line: " << __LINE__);
         REQUIRE(false);
       }
-      HIP_CHECK(hipMemAdvise(Hmm, 2*4096, hipMemAdviseUnsetAccessedBy, 0));
-      HIP_CHECK(hipMemAdvise(Hmm, 2*4096, hipMemAdviseSetAccessedBy, 1));
-      HIP_CHECK(hipMemAdvise(Hmm, 2*4096, hipMemAdviseSetPreferredLocation, 0));
-      HIP_CHECK(hipMemRangeGetAttribute(&data, sizeof(int),
-                hipMemRangeAttributeAccessedBy, Hmm, 2*4096));
+      HIP_CHECK(hipMemAdvise(Hmm, 2 * 4096, hipMemAdviseUnsetAccessedBy, 0));
+      HIP_CHECK(hipMemAdvise(Hmm, 2 * 4096, hipMemAdviseSetAccessedBy, 1));
+      HIP_CHECK(hipMemAdvise(Hmm, 2 * 4096, hipMemAdviseSetPreferredLocation, 0));
+      HIP_CHECK(hipMemRangeGetAttribute(&data, sizeof(int), hipMemRangeAttributeAccessedBy, Hmm,
+                                        2 * 4096));
       if (data != 1) {
         WARN("Didnt get expected behavior at line: " << __LINE__);
         REQUIRE(false);
@@ -589,8 +570,9 @@ TEST_CASE("Unit_hipMemAdvise_TstAccessedByFlg3") {
       HIP_CHECK(hipFree(Hmm));
     }
   } else {
-    SUCCEED("GPU 0 doesn't support hipDeviceAttributeManagedMemory "
-           "attribute. Hence skipping the testing with Pass result.\n");
+    SUCCEED(
+        "GPU 0 doesn't support hipDeviceAttributeManagedMemory "
+        "attribute. Hence skipping the testing with Pass result.\n");
   }
 }
 
@@ -606,14 +588,13 @@ TEST_CASE("Unit_hipMemAdvise_TstAccessedByFlg4") {
     hipStream_t strm;
     HIP_CHECK(hipStreamCreate(&strm));
     HIP_CHECK(hipMallocManaged(&Hmm, (NumElms * sizeof(int))));
-    HIP_CHECK(hipMemAdvise(Hmm, (NumElms * sizeof(int)),
-                           hipMemAdviseSetAccessedBy, 0));
+    HIP_CHECK(hipMemAdvise(Hmm, (NumElms * sizeof(int)), hipMemAdviseSetAccessedBy, 0));
     // Initializing memory
     for (int i = 0; i < NumElms; ++i) {
       Hmm[i] = InitVal;
     }
     dim3 dimBlock(blockSize, 1, 1);
-    dim3 dimGrid((NumElms + blockSize -1)/blockSize, 1, 1);
+    dim3 dimGrid((NumElms + blockSize - 1) / blockSize, 1, 1);
     // launching kernel from each one of the gpus
     MemAdvise2<<<dimGrid, dimBlock, 0, strm>>>(Hmm, NumElms);
     HIP_CHECK(hipStreamSynchronize(strm));
@@ -630,13 +611,12 @@ TEST_CASE("Unit_hipMemAdvise_TstAccessedByFlg4") {
       REQUIRE(false);
     }
 
-    HIP_CHECK(hipMemAdvise(Hmm, (NumElms * sizeof(int)),
-                           hipMemAdviseUnsetAccessedBy, 0));
+    HIP_CHECK(hipMemAdvise(Hmm, (NumElms * sizeof(int)), hipMemAdviseUnsetAccessedBy, 0));
     MemAdvise2<<<dimGrid, dimBlock, 0, strm>>>(Hmm, NumElms);
     HIP_CHECK(hipStreamSynchronize(strm));
     // verifying the final result
     for (int i = 0; i < NumElms; ++i) {
-      if (Hmm[i] != (InitVal + (2*10))) {
+      if (Hmm[i] != (InitVal + (2 * 10))) {
         DataMismatch++;
       }
     }
@@ -648,8 +628,9 @@ TEST_CASE("Unit_hipMemAdvise_TstAccessedByFlg4") {
     HIP_CHECK(hipFree(Hmm));
     HIP_CHECK(hipStreamDestroy(strm));
   } else {
-    SUCCEED("GPU 0 doesn't support hipDeviceAttributeManagedMemory "
-           "attribute. Hence skipping the testing with Pass result.\n");
+    SUCCEED(
+        "GPU 0 doesn't support hipDeviceAttributeManagedMemory "
+        "attribute. Hence skipping the testing with Pass result.\n");
   }
 }
 
@@ -668,16 +649,14 @@ TEST_CASE("Unit_hipMemAdvise_TstAlignedAllocMem") {
 
   if (gfxName.find("xnack+") != std::string::npos) {
     int managedMem = 0, pageMemAccess = 0;
-    HIP_CHECK(hipDeviceGetAttribute(&pageMemAccess,
-              hipDeviceAttributePageableMemoryAccess, 0));
+    HIP_CHECK(hipDeviceGetAttribute(&pageMemAccess, hipDeviceAttributePageableMemoryAccess, 0));
     WARN("hipDeviceAttributePageableMemoryAccess:" << pageMemAccess);
-    HIP_CHECK(hipDeviceGetAttribute(&managedMem,
-                                    hipDeviceAttributeManagedMemory, 0));
+    HIP_CHECK(hipDeviceGetAttribute(&managedMem, hipDeviceAttributeManagedMemory, 0));
     WARN("hipDeviceAttributeManagedMemory: " << managedMem);
     if ((managedMem == 1) && (pageMemAccess == 1)) {
       int *Mllc = nullptr, MemSz = 4096 * 4, NumElms = 4096, InitVal = 123;
       // Mllc = reinterpret_cast<(int *)>(aligned_alloc(4096, MemSz));
-      Mllc = reinterpret_cast<int*>(aligned_alloc(4096, 4096*4));
+      Mllc = reinterpret_cast<int*>(aligned_alloc(4096, 4096 * 4));
       for (int i = 0; i < NumElms; ++i) {
         Mllc[i] = InitVal;
       }
@@ -689,7 +668,7 @@ TEST_CASE("Unit_hipMemAdvise_TstAlignedAllocMem") {
       HIP_CHECK(hipMemAdvise(Mllc, MemSz, hipMemAdviseSetPreferredLocation, 0));
       HIP_CHECK(hipMemPrefetchAsync(Mllc, MemSz, 0, strm));
       HIP_CHECK(hipStreamSynchronize(strm));
-      MemAdvise2<<<(NumElms/32), 32, 0, strm>>>(Mllc, NumElms);
+      MemAdvise2<<<(NumElms / 32), 32, 0, strm>>>(Mllc, NumElms);
       HIP_CHECK(hipStreamSynchronize(strm));
       for (int i = 0; i < NumElms; ++i) {
         if (Mllc[i] != (InitVal + 10)) {
@@ -734,16 +713,16 @@ TEST_CASE("Unit_hipMemAdvise_TstMemAdvisePrefrdLoc") {
     int *Hmm = NULL, data = 999;
     HIP_CHECK(hipMallocManaged(&Hmm, 4096));
     HIP_CHECK(hipMemAdvise(Hmm, 4096, hipMemAdviseSetPreferredLocation, 0));
-    HIP_CHECK(hipMemRangeGetAttribute(&data, sizeof(int),
-                                     hipMemRangeAttributeLastPrefetchLocation,
-                                     Hmm, 4096));
+    HIP_CHECK(hipMemRangeGetAttribute(&data, sizeof(int), hipMemRangeAttributeLastPrefetchLocation,
+                                      Hmm, 4096));
     if (data != -2) {
       WARN("Didnt receive expected value.");
       REQUIRE(false);
     }
   } else {
-    SUCCEED("GPU 0 doesn't support hipDeviceAttributeManagedMemory "
-           "attribute. Hence skipping the testing with Pass result.\n");
+    SUCCEED(
+        "GPU 0 doesn't support hipDeviceAttributeManagedMemory "
+        "attribute. Hence skipping the testing with Pass result.\n");
   }
 }
 
@@ -767,15 +746,15 @@ TEST_CASE("Unit_hipMemAdvise_TstMemAdviseLstPreftchLoc") {
       HIP_CHECK(hipMemPrefetchAsync(Hmm, 4096, 1, strm));
       HIP_CHECK(hipStreamSynchronize(strm));
       HIP_CHECK(hipMemRangeGetAttribute(&data, sizeof(int),
-                                       hipMemRangeAttributeLastPrefetchLocation,
-                                       Hmm, 4096));
+                                        hipMemRangeAttributeLastPrefetchLocation, Hmm, 4096));
       if (data != 1) {
         WARN("Didnt receive expected value!!");
         REQUIRE(false);
       }
     } else {
-      SUCCEED("GPU 0 doesn't support hipDeviceAttributeManagedMemory "
-             "attribute. Hence skipping the testing with Pass result.\n");
+      SUCCEED(
+          "GPU 0 doesn't support hipDeviceAttributeManagedMemory "
+          "attribute. Hence skipping the testing with Pass result.\n");
     }
   } else {
     SUCCEED("This system has less than 2 gpus hence skipping the test.\n");
@@ -796,29 +775,27 @@ TEST_CASE("Unit_hipMemAdvise_TstMemAdviseMultiFlag") {
     HIP_CHECK(hipMallocManaged(&Hmm, 4096));
     HIP_CHECK(hipMemAdvise(Hmm, 4096, hipMemAdviseSetReadMostly, 0));
     HIP_CHECK(hipMemAdvise(Hmm, 4096, hipMemAdviseSetPreferredLocation, 0));
-    HIP_CHECK(hipMemRangeGetAttribute(&data, sizeof(int),
-                                     hipMemRangeAttributeReadMostly, Hmm,
-                                     4096));
+    HIP_CHECK(
+        hipMemRangeGetAttribute(&data, sizeof(int), hipMemRangeAttributeReadMostly, Hmm, 4096));
     if (data != 1) {
       WARN("Didnt receive expected value at line: " << data);
       REQUIRE(false);
     }
-    HIP_CHECK(hipMemRangeGetAttribute(&data, sizeof(int),
-                                     hipMemRangeAttributePreferredLocation, Hmm,
-                                     4096));
+    HIP_CHECK(hipMemRangeGetAttribute(&data, sizeof(int), hipMemRangeAttributePreferredLocation,
+                                      Hmm, 4096));
     if (data != 0) {
       WARN("Didnt receive expected value at line: " << data);
       REQUIRE(false);
     }
     HIP_CHECK(hipFree(Hmm));
   } else {
-    SUCCEED("GPU 0 doesn't support hipDeviceAttributeManagedMemory "
-           "attribute. Hence skipping the testing with Pass result.\n");
+    SUCCEED(
+        "GPU 0 doesn't support hipDeviceAttributeManagedMemory "
+        "attribute. Hence skipping the testing with Pass result.\n");
   }
 }
 
 
-
 /*Allocate Hmm memory, advise it to ReadMostly for gpu: 0 and launch kernel
   on all other gpus except 0. This test case may discover any effect or
   access denial case arising due to setting ReadMostly only to a particular
@@ -830,28 +807,28 @@ TEST_CASE("Unit_hipMemAdvise_ReadMosltyMgpuTst") {
     int Ngpus = 0;
     HIP_CHECK(hipGetDeviceCount(&Ngpus));
     if (Ngpus < 2) {
-      SUCCEED("This test needs atleast two gpus to run."
-      "Hence skipping the test.\n");
+      SUCCEED(
+          "This test needs atleast two gpus to run."
+          "Hence skipping the test.\n");
     }
     int *Hmm = NULL, NumElms = (1024 * 1024), InitVal = 123, blockSize = 64;
     int *Hmm1 = NULL, DataMismatch = 0;
     hipStream_t strm;
-    HIP_CHECK(hipStreamCreate(&strm));
     HIP_CHECK(hipMallocManaged(&Hmm, (NumElms * sizeof(int))));
     // Initializing memory
     for (int i = 0; i < NumElms; ++i) {
       Hmm[i] = InitVal;
     }
-    HIP_CHECK(hipMemAdvise(Hmm, (NumElms * sizeof(int)),
-                           hipMemAdviseSetReadMostly, 0));
+    HIP_CHECK(hipMemAdvise(Hmm, (NumElms * sizeof(int)), hipMemAdviseSetReadMostly, 0));
     dim3 dimBlock(blockSize, 1, 1);
-    dim3 dimGrid((NumElms + blockSize -1)/blockSize, 1, 1);
+    dim3 dimGrid((NumElms + blockSize - 1) / blockSize, 1, 1);
 #if HT_AMD
     SECTION("Launch Kernel on all other gpus") {
       // launching kernel from each one of the gpus
       for (int i = 1; i < Ngpus; ++i) {
         DataMismatch = 0;
         HIP_CHECK(hipSetDevice(i));
+        HIP_CHECK(hipStreamCreate(&strm));
         HIP_CHECK(hipMallocManaged(&Hmm1, (NumElms * sizeof(int))));
         MemAdvise3<<<dimGrid, dimBlock, 0, strm>>>(Hmm, Hmm1, NumElms);
         HIP_CHECK(hipStreamSynchronize(strm));
@@ -865,6 +842,7 @@ TEST_CASE("Unit_hipMemAdvise_ReadMosltyMgpuTst") {
           WARN("DataMismatch is observed with the gpu: " << i);
           REQUIRE(false);
         }
+        HIP_CHECK(hipStreamDestroy(strm));
         HIP_CHECK(hipFree(Hmm1));
       }
     }
@@ -873,10 +851,11 @@ TEST_CASE("Unit_hipMemAdvise_ReadMosltyMgpuTst") {
       for (int i = 0; i < Ngpus; ++i) {
         DataMismatch = 0;
         HIP_CHECK(hipSetDevice(i));
-        HIP_CHECK(hipMemAdvise(Hmm, (NumElms * sizeof(int)),
-                               hipMemAdviseSetReadMostly, i));
+        HIP_CHECK(hipStreamCreate(&strm));
+        HIP_CHECK(hipMemAdvise(Hmm, (NumElms * sizeof(int)), hipMemAdviseSetReadMostly, i));
         MemAdvise2<<<dimGrid, dimBlock, 0, strm>>>(Hmm, NumElms);
         HIP_CHECK(hipStreamSynchronize(strm));
+        HIP_CHECK(hipStreamDestroy(strm));
       }
       // verifying the final result
       for (int i = 0; i < NumElms; ++i) {
@@ -892,10 +871,11 @@ TEST_CASE("Unit_hipMemAdvise_ReadMosltyMgpuTst") {
     }
 #endif
     HIP_CHECK(hipFree(Hmm));
-    HIP_CHECK(hipStreamDestroy(strm));
+
   } else {
-    SUCCEED("GPU 0 doesn't support hipDeviceAttributeManagedMemory "
-           "attribute. Hence skipping the testing with Pass result.\n");
+    SUCCEED(
+        "GPU 0 doesn't support hipDeviceAttributeManagedMemory "
+        "attribute. Hence skipping the testing with Pass result.\n");
   }
 }
 
@@ -904,23 +884,24 @@ TEST_CASE("Unit_hipMemAdvise_TstSetUnsetPrfrdLoc") {
   int managed = HmmAttrPrint();
   if (managed == 1) {
     int *Hmm = NULL, data = 999;
-    HIP_CHECK(hipMallocManaged(&Hmm, 2*4096));
-    HIP_CHECK(hipMemAdvise(Hmm, 2*4096, hipMemAdviseSetPreferredLocation, 0));
-    HIP_CHECK(hipMemRangeGetAttribute(&data, sizeof(int),
-                        hipMemRangeAttributePreferredLocation, Hmm, 2*4096));
+    HIP_CHECK(hipMallocManaged(&Hmm, 2 * 4096));
+    HIP_CHECK(hipMemAdvise(Hmm, 2 * 4096, hipMemAdviseSetPreferredLocation, 0));
+    HIP_CHECK(hipMemRangeGetAttribute(&data, sizeof(int), hipMemRangeAttributePreferredLocation,
+                                      Hmm, 2 * 4096));
     if (data != 0) {
       WARN("Didnt receive expected value!!");
       REQUIRE(false);
     }
-    HIP_CHECK(hipMemAdvise(Hmm, 2*4096, hipMemAdviseUnsetPreferredLocation, 0));
-    HIP_CHECK(hipMemRangeGetAttribute(&data, sizeof(int),
-                          hipMemRangeAttributePreferredLocation, Hmm, 2*4096));
+    HIP_CHECK(hipMemAdvise(Hmm, 2 * 4096, hipMemAdviseUnsetPreferredLocation, 0));
+    HIP_CHECK(hipMemRangeGetAttribute(&data, sizeof(int), hipMemRangeAttributePreferredLocation,
+                                      Hmm, 2 * 4096));
     if (data != -2) {
       WARN("Didnt receive expected value!!");
       REQUIRE(false);
     }
   } else {
-    SUCCEED("GPU 0 doesn't support hipDeviceAttributeManagedMemory "
-           "attribute. Hence skipping the testing with Pass result.\n");
+    SUCCEED(
+        "GPU 0 doesn't support hipDeviceAttributeManagedMemory "
+        "attribute. Hence skipping the testing with Pass result.\n");
   }
 }
