@@ -81,25 +81,17 @@ TEST_CASE("Unit_hipMemPoolApi_Basic") {
 
   HIP_CHECK(hipMemPoolGetAttribute(mem_pool, attr, &value));
 
-  hipMemAccessDesc desc_list = {
-    {
-      hipMemLocationTypeDevice,
-      0
-    },
-    hipMemAccessFlagsProtReadWrite
-  };
+  hipMemAccessDesc desc_list = {{hipMemLocationTypeDevice, 0}, hipMemAccessFlagsProtReadWrite};
   int count = 1;
   HIP_CHECK(hipMemPoolSetAccess(mem_pool, &desc_list, count));
 
   hipMemAccessFlags flags = hipMemAccessFlagsProtNone;
-  hipMemLocation location = {
-    hipMemLocationTypeDevice,
-    0
-  };
+  hipMemLocation location = {hipMemLocationTypeDevice, 0};
   HIP_CHECK(hipMemPoolGetAccess(&flags, mem_pool, &location));
   initMemPoolProps();
   HIP_CHECK(hipMemPoolCreate(&mem_pool, &kPoolProps));
-  HIP_CHECK(hipMallocFromPoolAsync(reinterpret_cast<void**>(&B), numElements * sizeof(float), mem_pool, stream));
+  HIP_CHECK(hipMallocFromPoolAsync(reinterpret_cast<void**>(&B), numElements * sizeof(float),
+                                   mem_pool, stream));
   HIP_CHECK(hipMemPoolDestroy(mem_pool));
 
   HIP_CHECK(hipStreamDestroy(stream));
@@ -114,22 +106,24 @@ TEST_CASE("Unit_hipMemPoolApi_BasicAlloc") {
     SUCCEED("Runtime doesn't support Memory Pool. Skip the test case.");
     return;
   }
-  unsigned int *notified = nullptr;
+  unsigned int* notified = nullptr;
   HIP_CHECK(hipHostMalloc(&notified, sizeof(unsigned int)));
   *notified = 0;
   initMemPoolProps();
   hipMemPool_t mem_pool;
   HIP_CHECK(hipMemPoolCreate(&mem_pool, &kPoolProps));
 
-  float* B, *C;
+  float *B, *C;
   hipStream_t stream;
   HIP_CHECK(hipStreamCreate(&stream));
 
   size_t numElements = 8 * 1024 * 1024;
-  HIP_CHECK(hipMallocFromPoolAsync(reinterpret_cast<void**>(&B), numElements * sizeof(float), mem_pool, stream));
+  HIP_CHECK(hipMallocFromPoolAsync(reinterpret_cast<void**>(&B), numElements * sizeof(float),
+                                   mem_pool, stream));
 
   numElements = 1024;
-  HIP_CHECK(hipMallocFromPoolAsync(reinterpret_cast<void**>(&C), numElements * sizeof(float), mem_pool, stream));
+  HIP_CHECK(hipMallocFromPoolAsync(reinterpret_cast<void**>(&C), numElements * sizeof(float),
+                                   mem_pool, stream));
 
   int blocks = 1024;
   hipMemPoolAttr attr;
@@ -142,7 +136,7 @@ TEST_CASE("Unit_hipMemPoolApi_BasicAlloc") {
   HIP_CHECK(hipMemPoolGetAttribute(mem_pool, attr, &res_before_sync));
 
   std::this_thread::sleep_for(std::chrono::milliseconds(500));
-  *notified = 1; // Notify kernel loop to exit
+  *notified = 1;  // Notify kernel loop to exit
 
   HIP_CHECK(hipStreamSynchronize(stream));
 
@@ -201,22 +195,24 @@ TEST_CASE("Unit_hipMemPoolApi_BasicTrim") {
     SUCCEED("Runtime doesn't support Memory Pool. Skip the test case.");
     return;
   }
-  unsigned int *notified = nullptr;
+  unsigned int* notified = nullptr;
   HIP_CHECK(hipHostMalloc(&notified, sizeof(unsigned int)));
   *notified = 0;
   initMemPoolProps();
   hipMemPool_t mem_pool;
   HIP_CHECK(hipMemPoolCreate(&mem_pool, &kPoolProps));
 
-  float* B, *C;
+  float *B, *C;
   hipStream_t stream;
   HIP_CHECK(hipStreamCreate(&stream));
 
   size_t numElements = 8 * 1024 * 1024;
-  HIP_CHECK(hipMallocFromPoolAsync(reinterpret_cast<void**>(&B), numElements * sizeof(float), mem_pool, stream));
+  HIP_CHECK(hipMallocFromPoolAsync(reinterpret_cast<void**>(&B), numElements * sizeof(float),
+                                   mem_pool, stream));
 
   numElements = 1024;
-  HIP_CHECK(hipMallocFromPoolAsync(reinterpret_cast<void**>(&C), numElements * sizeof(float), mem_pool, stream));
+  HIP_CHECK(hipMallocFromPoolAsync(reinterpret_cast<void**>(&C), numElements * sizeof(float),
+                                   mem_pool, stream));
 
   int blocks = 2;
   notifiedKernel<<<32, blocks, 0, stream>>>(B, notified);
@@ -244,7 +240,7 @@ TEST_CASE("Unit_hipMemPoolApi_BasicTrim") {
   REQUIRE(res_before_trim == res_after_trim);
 
   std::this_thread::sleep_for(std::chrono::milliseconds(500));
-  *notified = 1; // Notify kernel loop to exit
+  *notified = 1;  // Notify kernel loop to exit
   HIP_CHECK(hipStreamSynchronize(stream));
 
   std::uint64_t res_after_sync = 0;
@@ -287,7 +283,7 @@ TEST_CASE("Unit_hipMemPoolApi_BasicReuse") {
     SUCCEED("Runtime doesn't support Memory Pool. Skip the test case.");
     return;
   }
-  unsigned int *notified = nullptr;
+  unsigned int* notified = nullptr;
   HIP_CHECK(hipHostMalloc(&notified, sizeof(unsigned int)));
   *notified = 0;
   initMemPoolProps();
@@ -299,10 +295,12 @@ TEST_CASE("Unit_hipMemPoolApi_BasicReuse") {
   HIP_CHECK(hipStreamCreate(&stream));
 
   size_t numElements = 8 * 1024 * 1024;
-  HIP_CHECK(hipMallocFromPoolAsync(reinterpret_cast<void**>(&A), numElements * sizeof(float), mem_pool, stream));
+  HIP_CHECK(hipMallocFromPoolAsync(reinterpret_cast<void**>(&A), numElements * sizeof(float),
+                                   mem_pool, stream));
 
   numElements = 1024;
-  HIP_CHECK(hipMallocFromPoolAsync(reinterpret_cast<void**>(&C), numElements * sizeof(float), mem_pool, stream));
+  HIP_CHECK(hipMallocFromPoolAsync(reinterpret_cast<void**>(&C), numElements * sizeof(float),
+                                   mem_pool, stream));
 
   int blocks = 2;
   notifiedKernel<<<32, blocks, 0, stream>>>(A, notified);
@@ -312,12 +310,13 @@ TEST_CASE("Unit_hipMemPoolApi_BasicReuse") {
   HIP_CHECK(hipFreeAsync(reinterpret_cast<void*>(A), stream));
 
   numElements = 8 * 1024 * 1024;
-  HIP_CHECK(hipMallocFromPoolAsync(reinterpret_cast<void**>(&B), numElements * sizeof(float), mem_pool, stream));
+  HIP_CHECK(hipMallocFromPoolAsync(reinterpret_cast<void**>(&B), numElements * sizeof(float),
+                                   mem_pool, stream));
   // Runtime must reuse the pointer
   REQUIRE(A == B);
 
   std::this_thread::sleep_for(std::chrono::milliseconds(500));
-  *notified = 1; // Notify kernel loop to exit
+  *notified = 1;  // Notify kernel loop to exit
   // Make a sync before the second kernel launch to make sure memory B isn't gone
   HIP_CHECK(hipStreamSynchronize(stream));
 
@@ -326,7 +325,7 @@ TEST_CASE("Unit_hipMemPoolApi_BasicReuse") {
   notifiedKernel<<<32, blocks, 0, stream>>>(B, notified);
 
   std::this_thread::sleep_for(std::chrono::milliseconds(500));
-  *notified = 1; // Notify kernel loop to exit
+  *notified = 1;  // Notify kernel loop to exit
   HIP_CHECK(hipStreamSynchronize(stream));
 
   attr = hipMemPoolAttrUsedMemCurrent;
@@ -379,12 +378,14 @@ TEST_CASE("Unit_hipMemPoolApi_Opportunistic") {
   HIP_CHECK(hipStreamCreateWithFlags(&stream2, hipStreamNonBlocking));
 
   size_t numElements = 1024;
-  HIP_CHECK(hipMallocFromPoolAsync(reinterpret_cast<void**>(&C), numElements * sizeof(float), mem_pool, stream1));
+  HIP_CHECK(hipMallocFromPoolAsync(reinterpret_cast<void**>(&C), numElements * sizeof(float),
+                                   mem_pool, stream1));
   int value = 0;
 
   SECTION("Disallow Opportunistic - No Reuse") {
     numElements = 8 * 1024 * 1024;
-    HIP_CHECK(hipMallocFromPoolAsync(reinterpret_cast<void**>(&A), numElements * sizeof(float), mem_pool, stream1));
+    HIP_CHECK(hipMallocFromPoolAsync(reinterpret_cast<void**>(&A), numElements * sizeof(float),
+                                     mem_pool, stream1));
 
     // Disable all default pool states
     attr = hipMemPoolReuseFollowEventDependencies;
@@ -400,14 +401,15 @@ TEST_CASE("Unit_hipMemPoolApi_Opportunistic") {
     // Not a real free, since kernel isn't done
     HIP_CHECK(hipFreeAsync(reinterpret_cast<void*>(A), stream1));
     std::this_thread::sleep_for(std::chrono::milliseconds(500));
-    *notified1 = 1; // Notify kernel loop to exit
+    *notified1 = 1;  // Notify kernel loop to exit
 
     // Sleep for 1 second GPU should be idle by now
     std::this_thread::sleep_for(std::chrono::milliseconds(1000));
 
     numElements = 8 * 1024 * 1024;
     // Allocate memory for the second stream
-    HIP_CHECK(hipMallocFromPoolAsync(reinterpret_cast<void**>(&B), numElements * sizeof(float), mem_pool, stream2));
+    HIP_CHECK(hipMallocFromPoolAsync(reinterpret_cast<void**>(&B), numElements * sizeof(float),
+                                     mem_pool, stream2));
     // Without Opportunistic state runtime must allocate another buffer
     REQUIRE(A != B);
 
@@ -415,7 +417,7 @@ TEST_CASE("Unit_hipMemPoolApi_Opportunistic") {
     notifiedKernel<<<32, blocks, 0, stream2>>>(B, notified2);
 
     std::this_thread::sleep_for(std::chrono::milliseconds(500));
-    *notified2 = 1; // Notify kernel loop to exit
+    *notified2 = 1;  // Notify kernel loop to exit
     HIP_CHECK(hipStreamSynchronize(stream1));
     HIP_CHECK(hipStreamSynchronize(stream2));
 
@@ -424,7 +426,8 @@ TEST_CASE("Unit_hipMemPoolApi_Opportunistic") {
 
   SECTION("Allow Opportunistic - Reuse") {
     numElements = 8 * 1024 * 1024;
-    HIP_CHECK(hipMallocFromPoolAsync(reinterpret_cast<void**>(&A), numElements * sizeof(float), mem_pool, stream1));
+    HIP_CHECK(hipMallocFromPoolAsync(reinterpret_cast<void**>(&A), numElements * sizeof(float),
+                                     mem_pool, stream1));
 
     value = 1;
     attr = hipMemPoolReuseAllowOpportunistic;
@@ -437,14 +440,15 @@ TEST_CASE("Unit_hipMemPoolApi_Opportunistic") {
     // Not a real free, since kernel isn't done
     HIP_CHECK(hipFreeAsync(reinterpret_cast<void*>(A), stream1));
     std::this_thread::sleep_for(std::chrono::milliseconds(500));
-    *notified1 = 1; // Notify kernel loop to exit
+    *notified1 = 1;  // Notify kernel loop to exit
 
     // Sleep for 1 second GPU should be idle by now
     std::this_thread::sleep_for(std::chrono::milliseconds(1000));
 
     numElements = 8 * 1024 * 1024;
     // Allocate memory for the second stream
-    HIP_CHECK(hipMallocFromPoolAsync(reinterpret_cast<void**>(&B), numElements * sizeof(float), mem_pool, stream2));
+    HIP_CHECK(hipMallocFromPoolAsync(reinterpret_cast<void**>(&B), numElements * sizeof(float),
+                                     mem_pool, stream2));
     // With Opportunistic state runtime will reuse freed buffer A
     REQUIRE(A == B);
 
@@ -452,7 +456,7 @@ TEST_CASE("Unit_hipMemPoolApi_Opportunistic") {
     notifiedKernel<<<32, blocks, 0, stream2>>>(B, notified2);
 
     std::this_thread::sleep_for(std::chrono::milliseconds(500));
-    *notified2 = 1; // Notify kernel loop to exit
+    *notified2 = 1;  // Notify kernel loop to exit
 
     HIP_CHECK(hipStreamSynchronize(stream1));
     HIP_CHECK(hipStreamSynchronize(stream2));
@@ -462,7 +466,8 @@ TEST_CASE("Unit_hipMemPoolApi_Opportunistic") {
 
   SECTION("Allow Opportunistic - No Reuse") {
     numElements = 8 * 1024 * 1024;
-    HIP_CHECK(hipMallocFromPoolAsync(reinterpret_cast<void**>(&A), numElements * sizeof(float), mem_pool, stream1));
+    HIP_CHECK(hipMallocFromPoolAsync(reinterpret_cast<void**>(&A), numElements * sizeof(float),
+                                     mem_pool, stream1));
 
     value = 1;
     attr = hipMemPoolReuseAllowOpportunistic;
@@ -477,16 +482,18 @@ TEST_CASE("Unit_hipMemPoolApi_Opportunistic") {
 
     numElements = 8 * 1024 * 1024;
     // Allocate memory for the second stream
-    HIP_CHECK(hipMallocFromPoolAsync(reinterpret_cast<void**>(&B), numElements * sizeof(float), mem_pool, stream2));
-    // With Opportunistic state runtime can't reuse freed buffer A, because it's still busy with the kernel
+    HIP_CHECK(hipMallocFromPoolAsync(reinterpret_cast<void**>(&B), numElements * sizeof(float),
+                                     mem_pool, stream2));
+    // With Opportunistic state runtime can't reuse freed buffer A, because it's still busy with the
+    // kernel
     REQUIRE(A != B);
 
     // Run kernel with the new memory in the second stream
     notifiedKernel<<<32, blocks, 0, stream2>>>(B, notified2);
 
     std::this_thread::sleep_for(std::chrono::milliseconds(500));
-    *notified1 = 1; // Notify kernel loop to exit
-    *notified2 = 1; // Notify kernel loop to exit
+    *notified1 = 1;  // Notify kernel loop to exit
+    *notified2 = 1;  // Notify kernel loop to exit
     HIP_CHECK(hipStreamSynchronize(stream1));
     HIP_CHECK(hipStreamSynchronize(stream2));
 
@@ -508,7 +515,7 @@ TEST_CASE("Unit_hipMemPoolApi_Default") {
     SUCCEED("Runtime doesn't support Memory Pool. Skip the test case.");
     return;
   }
-  unsigned int *notified = nullptr;
+  unsigned int* notified = nullptr;
   HIP_CHECK(hipHostMalloc(&notified, sizeof(unsigned int)));
   *notified = 0;
   hipMemPool_t mem_pool;
@@ -538,7 +545,7 @@ TEST_CASE("Unit_hipMemPoolApi_Default") {
 
   // Make a sync before the second kernel launch to make sure memory B isn't gone
   std::this_thread::sleep_for(std::chrono::milliseconds(500));
-  *notified = 1; // Notify kernel loop to exit
+  *notified = 1;  // Notify kernel loop to exit
   HIP_CHECK(hipStreamSynchronize(stream));
 
   // Second kernel launch with new memory
@@ -548,7 +555,7 @@ TEST_CASE("Unit_hipMemPoolApi_Default") {
   HIP_CHECK(hipFreeAsync(reinterpret_cast<void*>(B), stream));
 
   std::this_thread::sleep_for(std::chrono::milliseconds(500));
-  *notified = 1; // Notify kernel loop to exit
+  *notified = 1;  // Notify kernel loop to exit
   HIP_CHECK(hipStreamSynchronize(stream));
 
   std::uint64_t value64 = 0;
