@@ -46,24 +46,20 @@ __global__ void MemPrftchAsyncKernel1(int* Hmm, size_t N) {
 
 static int HmmAttrPrint() {
   int managed = 0;
-  WARN("The following are the attribute values related to HMM for"
-         " device 0:\n");
-  HIP_CHECK(hipDeviceGetAttribute(&managed,
-              hipDeviceAttributeDirectManagedMemAccessFromHost, 0));
+  WARN(
+      "The following are the attribute values related to HMM for"
+      " device 0:\n");
+  HIP_CHECK(hipDeviceGetAttribute(&managed, hipDeviceAttributeDirectManagedMemAccessFromHost, 0));
   WARN("hipDeviceAttributeDirectManagedMemAccessFromHost: " << managed);
-  HIP_CHECK(hipDeviceGetAttribute(&managed,
-                                 hipDeviceAttributeConcurrentManagedAccess, 0));
+  HIP_CHECK(hipDeviceGetAttribute(&managed, hipDeviceAttributeConcurrentManagedAccess, 0));
   WARN("hipDeviceAttributeConcurrentManagedAccess: " << managed);
-  HIP_CHECK(hipDeviceGetAttribute(&managed,
-                                 hipDeviceAttributePageableMemoryAccess, 0));
+  HIP_CHECK(hipDeviceGetAttribute(&managed, hipDeviceAttributePageableMemoryAccess, 0));
   WARN("hipDeviceAttributePageableMemoryAccess: " << managed);
-  HIP_CHECK(hipDeviceGetAttribute(&managed,
-              hipDeviceAttributePageableMemoryAccessUsesHostPageTables, 0));
-  WARN("hipDeviceAttributePageableMemoryAccessUsesHostPageTables:"
-         << managed);
+  HIP_CHECK(
+      hipDeviceGetAttribute(&managed, hipDeviceAttributePageableMemoryAccessUsesHostPageTables, 0));
+  WARN("hipDeviceAttributePageableMemoryAccessUsesHostPageTables:" << managed);
 
-  HIP_CHECK(hipDeviceGetAttribute(&managed, hipDeviceAttributeManagedMemory,
-                                  0));
+  HIP_CHECK(hipDeviceGetAttribute(&managed, hipDeviceAttributeManagedMemory, 0));
   WARN("hipDeviceAttributeManagedMemory: " << managed);
   return managed;
 }
@@ -73,58 +69,62 @@ static int HmmAttrPrint() {
    AccessedBy, and PreferredLocation for gpus other than gpu 0 and verify
    the flags using hipMemGetAttribute()*/
 TEST_CASE("Unit_hipMemPrefetchAsyncAdviseFlgTst") {
-    int NGpus = 0;
-    HIP_CHECK(hipGetDeviceCount(&NGpus));
-    if (NGpus >= 2) {
-      int MangdMem = HmmAttrPrint();
-      if (MangdMem == 1) {
-        int *Hmm = nullptr, MemSz = (4096 * 4), InitVal = 123;
-        int Outpt = 9999, NumElms = MemSz/4;
-        bool IfTestPassed = true;
-        hipStream_t strm;
-        HIP_CHECK(hipStreamCreate(&strm));
-        HIP_CHECK(hipMallocManaged(&Hmm, MemSz));
-        // Initializing the memory
-        for (int i = 0; i < NumElms; ++i) {
-          Hmm[i] = InitVal;
-        }
-        HIP_CHECK(hipMemPrefetchAsync(Hmm, MemSz, 0, strm));
-        HIP_CHECK(hipStreamSynchronize(strm));
-        HIP_CHECK(hipMemAdvise(Hmm, MemSz, hipMemAdviseSetReadMostly, 1));
-        HIP_CHECK(hipMemRangeGetAttribute(&Outpt, sizeof(int),
-                  hipMemRangeAttributeReadMostly, Hmm, MemSz));
-        if (Outpt != 1) {
-          WARN("hipMemRangeAttributeReadMostly flag did not take effect"
-               " as expected!!");
-          IfTestPassed = false;
-        }
-        HIP_CHECK(hipMemAdvise(Hmm, MemSz, hipMemAdviseSetAccessedBy, 1));
-        HIP_CHECK(hipMemRangeGetAttribute(&Outpt, sizeof(int),
-                  hipMemRangeAttributeAccessedBy, Hmm, MemSz));
-        if (Outpt != 1) {
-          WARN("hipMemRangeAttributeAccessedBy flag did not take effect"
-               " as expected!!");
-          IfTestPassed = false;
-        }
-        HIP_CHECK(hipMemAdvise(Hmm, MemSz, hipMemAdviseSetPreferredLocation,
-                               1));
-        HIP_CHECK(hipMemRangeGetAttribute(&Outpt, sizeof(int),
-                  hipMemRangeAttributePreferredLocation, Hmm, MemSz));
-        if (Outpt != 1) {
-          WARN("hipMemRangeAttributePreferredLocation flag did not take effect"
-               " as expected!!");
-          IfTestPassed = false;
-        }
-        HIP_CHECK(hipStreamDestroy(strm));
-        HIP_CHECK(hipFree(Hmm));
-        REQUIRE(IfTestPassed);
+  int NGpus = 0;
+  HIP_CHECK(hipGetDeviceCount(&NGpus));
+  if (NGpus >= 2) {
+    int MangdMem = HmmAttrPrint();
+    if (MangdMem == 1) {
+      int *Hmm = nullptr, MemSz = (4096 * 4), InitVal = 123;
+      int Outpt = 9999, NumElms = MemSz / 4;
+      bool IfTestPassed = true;
+      hipStream_t strm;
+      HIP_CHECK(hipStreamCreate(&strm));
+      HIP_CHECK(hipMallocManaged(&Hmm, MemSz));
+      // Initializing the memory
+      for (int i = 0; i < NumElms; ++i) {
+        Hmm[i] = InitVal;
+      }
+      HIP_CHECK(hipMemPrefetchAsync(Hmm, MemSz, 0, strm));
+      HIP_CHECK(hipStreamSynchronize(strm));
+      HIP_CHECK(hipMemAdvise(Hmm, MemSz, hipMemAdviseSetReadMostly, 1));
+      HIP_CHECK(
+          hipMemRangeGetAttribute(&Outpt, sizeof(int), hipMemRangeAttributeReadMostly, Hmm, MemSz));
+      if (Outpt != 1) {
+        WARN(
+            "hipMemRangeAttributeReadMostly flag did not take effect"
+            " as expected!!");
+        IfTestPassed = false;
+      }
+      HIP_CHECK(hipMemAdvise(Hmm, MemSz, hipMemAdviseSetAccessedBy, 1));
+      HIP_CHECK(
+          hipMemRangeGetAttribute(&Outpt, sizeof(int), hipMemRangeAttributeAccessedBy, Hmm, MemSz));
+      if (Outpt != 1) {
+        WARN(
+            "hipMemRangeAttributeAccessedBy flag did not take effect"
+            " as expected!!");
+        IfTestPassed = false;
+      }
+      HIP_CHECK(hipMemAdvise(Hmm, MemSz, hipMemAdviseSetPreferredLocation, 1));
+      HIP_CHECK(hipMemRangeGetAttribute(&Outpt, sizeof(int), hipMemRangeAttributePreferredLocation,
+                                        Hmm, MemSz));
+      if (Outpt != 1) {
+        WARN(
+            "hipMemRangeAttributePreferredLocation flag did not take effect"
+            " as expected!!");
+        IfTestPassed = false;
+      }
+      HIP_CHECK(hipStreamDestroy(strm));
+      HIP_CHECK(hipFree(Hmm));
+      REQUIRE(IfTestPassed);
     } else {
-      SUCCEED("GPU 0 doesn't support hipDeviceAttributeManagedMemory "
-              "attribute. Hence skipping the testing with Pass result.\n");
+      SUCCEED(
+          "GPU 0 doesn't support hipDeviceAttributeManagedMemory "
+          "attribute. Hence skipping the testing with Pass result.\n");
     }
   } else {
-    SUCCEED("This test needs atleast 2 gpus, but the system has less than"
-            " 2 gpus hence skipping the test");
+    SUCCEED(
+        "This test needs atleast 2 gpus, but the system has less than"
+        " 2 gpus hence skipping the test");
   }
 }
 
@@ -139,7 +139,7 @@ TEST_CASE("Unit_hipMemPrefetchAsyncAccsdByTst") {
   if (NGpus >= 2) {
     int MangdMem = HmmAttrPrint();
     if (MangdMem == 1) {
-      int *Hmm = nullptr, MemSz = (4096 * 4), InitVal = 123, NumElms = MemSz/4;
+      int *Hmm = nullptr, MemSz = (4096 * 4), InitVal = 123, NumElms = MemSz / 4;
       int Outpt = 9999;
       bool IfTestPassed = true;
       hipStream_t strm;
@@ -153,11 +153,12 @@ TEST_CASE("Unit_hipMemPrefetchAsyncAccsdByTst") {
         HIP_CHECK(hipMemAdvise(Hmm, MemSz, hipMemAdviseSetAccessedBy, 1));
         HIP_CHECK(hipMemPrefetchAsync(Hmm, MemSz, 0, strm));
         HIP_CHECK(hipStreamSynchronize(strm));
-        HIP_CHECK(hipMemRangeGetAttribute(&Outpt, sizeof(int),
-                    hipMemRangeAttributeAccessedBy, Hmm, MemSz));
+        HIP_CHECK(hipMemRangeGetAttribute(&Outpt, sizeof(int), hipMemRangeAttributeAccessedBy, Hmm,
+                                          MemSz));
         if (Outpt != 1) {
-          WARN("hipMemRangeAttributeAccessedBy flag did not take effect"
-               " as expected!!");
+          WARN(
+              "hipMemRangeAttributeAccessedBy flag did not take effect"
+              " as expected!!");
           IfTestPassed = false;
         }
       }
@@ -165,13 +166,14 @@ TEST_CASE("Unit_hipMemPrefetchAsyncAccsdByTst") {
         HIP_CHECK(hipMemAdvise(Hmm, MemSz, hipMemAdviseSetReadMostly, 1));
         HIP_CHECK(hipMemPrefetchAsync(Hmm, MemSz, 0, strm));
         HIP_CHECK(hipStreamSynchronize(strm));
-        MemPrftchAsyncKernel1<<<(NumElms/32), 32, 0, strm>>>(Hmm, NumElms);
+        MemPrftchAsyncKernel1<<<(NumElms / 32), 32, 0, strm>>>(Hmm, NumElms);
         HIP_CHECK(hipStreamSynchronize(strm));
-        HIP_CHECK(hipMemRangeGetAttribute(&Outpt, sizeof(int),
-                    hipMemRangeAttributeReadMostly, Hmm, MemSz));
+        HIP_CHECK(hipMemRangeGetAttribute(&Outpt, sizeof(int), hipMemRangeAttributeReadMostly, Hmm,
+                                          MemSz));
         if (Outpt != 1) {
-          WARN("hipMemRangeAttributeReadMostly flag did not take effect"
-               " as expected!!");
+          WARN(
+              "hipMemRangeAttributeReadMostly flag did not take effect"
+              " as expected!!");
           IfTestPassed = false;
         }
         // Verifying the results
@@ -184,17 +186,17 @@ TEST_CASE("Unit_hipMemPrefetchAsyncAccsdByTst") {
         }
       }
       SECTION("Test PreferredLocation with Prefetch") {
-        HIP_CHECK(hipMemAdvise(Hmm, MemSz, hipMemAdviseSetPreferredLocation,
-                               1));
+        HIP_CHECK(hipMemAdvise(Hmm, MemSz, hipMemAdviseSetPreferredLocation, 1));
         HIP_CHECK(hipMemPrefetchAsync(Hmm, MemSz, 0, strm));
         HIP_CHECK(hipStreamSynchronize(strm));
-        MemPrftchAsyncKernel1<<<(NumElms/32), 32, 0, strm>>>(Hmm, NumElms);
+        MemPrftchAsyncKernel1<<<(NumElms / 32), 32, 0, strm>>>(Hmm, NumElms);
         HIP_CHECK(hipStreamSynchronize(strm));
         HIP_CHECK(hipMemRangeGetAttribute(&Outpt, sizeof(int),
-                    hipMemRangeAttributePreferredLocation, Hmm, MemSz));
+                                          hipMemRangeAttributePreferredLocation, Hmm, MemSz));
         if (Outpt != 1) {
-          WARN("hipMemRangeAttributePreferredLocation flag did not take effect"
-             " as expected!!");
+          WARN(
+              "hipMemRangeAttributePreferredLocation flag did not take effect"
+              " as expected!!");
           IfTestPassed = false;
         }
         // Verifying the results
@@ -210,12 +212,14 @@ TEST_CASE("Unit_hipMemPrefetchAsyncAccsdByTst") {
       HIP_CHECK(hipStreamDestroy(strm));
       REQUIRE(IfTestPassed);
     } else {
-      SUCCEED("GPU 0 doesn't support hipDeviceAttributeManagedMemory "
-             "attribute. Hence skipping the testing with Pass result.\n");
+      SUCCEED(
+          "GPU 0 doesn't support hipDeviceAttributeManagedMemory "
+          "attribute. Hence skipping the testing with Pass result.\n");
     }
   } else {
-    SUCCEED("This test needs atleast 2 gpus, but the system has less than"
-            " 2 gpus hence skipping the test");
+    SUCCEED(
+        "This test needs atleast 2 gpus, but the system has less than"
+        " 2 gpus hence skipping the test");
   }
 }
 
@@ -223,7 +227,7 @@ TEST_CASE("Unit_hipMemPrefetchAsyncAccsdByTst") {
 TEST_CASE("Unit_hipMemPrefetchAsyncNegativeTst") {
   int MangdMem = HmmAttrPrint();
   if (MangdMem == 1) {
-    int *Hmm = nullptr, MemSz = 4096*4, NumElms = MemSz/4, InitVal = 123;
+    int *Hmm = nullptr, MemSz = 4096 * 4, NumElms = MemSz / 4, InitVal = 123;
     bool IfTestPassed = true;
     HIP_CHECK(hipMallocManaged(&Hmm, MemSz));
     for (int i = 0; i < NumElms; ++i) {
@@ -245,32 +249,36 @@ TEST_CASE("Unit_hipMemPrefetchAsyncNegativeTst") {
       // expectation: Api should return error
       err = hipMemPrefetchAsync(Hmm, 0, 0, strm);
       if (err == hipSuccess) {
-        WARN("hipMemPrefetchAsync() gives hipSuccess when count size is"
-             " passed as zero!!");
+        WARN(
+            "hipMemPrefetchAsync() gives hipSuccess when count size is"
+            " passed as zero!!");
         IfTestPassed = false;
       }
       // Passing count size half of actually allocated
       // expectation: No issue should be observed
-      err = hipMemPrefetchAsync(Hmm, MemSz/2, 0, strm);
+      err = hipMemPrefetchAsync(Hmm, MemSz / 2, 0, strm);
       if (err != hipSuccess) {
-        WARN("hipMemPrefetchAsync() returned error when count size passed is"
-             " half of actually allocated!!");
+        WARN(
+            "hipMemPrefetchAsync() returned error when count size passed is"
+            " half of actually allocated!!");
         IfTestPassed = false;
       }
       // Passing count size double that of actually allocated
       // expectation: Api should return error
-      err = hipMemPrefetchAsync(Hmm, MemSz*2, 0, strm);
+      err = hipMemPrefetchAsync(Hmm, MemSz * 2, 0, strm);
       if (err == hipSuccess) {
-        WARN("hipMemPrefetchAsync() gives hipSuccess when count size passed is"
-             " double that of actually allocated!!");
+        WARN(
+            "hipMemPrefetchAsync() gives hipSuccess when count size passed is"
+            " double that of actually allocated!!");
         IfTestPassed = false;
       }
     }
     SECTION("Passing invalid device Ordinal") {
       err = hipMemPrefetchAsync(Hmm, MemSz, 9999, strm);
       if (err == hipSuccess) {
-        WARN("hipMemPrefetchAsync() gives hipSuccess when Invalid device"
-             " ordinal is passed!!");
+        WARN(
+            "hipMemPrefetchAsync() gives hipSuccess when Invalid device"
+            " ordinal is passed!!");
         IfTestPassed = false;
       }
     }
@@ -279,34 +287,37 @@ TEST_CASE("Unit_hipMemPrefetchAsyncNegativeTst") {
       // expectation: No issue should be observed
       err = hipMemPrefetchAsync(Hmm, MemSz, 0, 0);
       if (err != hipSuccess) {
-        WARN("hipMemPrefetchAsync() returns error when Null stream is"
-             "passed!!");
+        WARN(
+            "hipMemPrefetchAsync() returns error when Null stream is"
+            "passed!!");
         IfTestPassed = false;
       }
-    // Passing stream object belong to destination device
-    // expectation: No issue should be observed
-    int NGpus = 0;
-    HIP_CHECK(hipGetDeviceCount(&NGpus));
-    if (NGpus > 1) {
-      hipStream_t strm1;
-      HIP_CHECK(hipSetDevice(1));
-      HIP_CHECK(hipStreamCreate(&strm1));
-      err = hipMemPrefetchAsync(Hmm, MemSz, 1, strm1);
-      if (err != hipSuccess) {
-        WARN("hipMemPrefetchAsync() returns error when stream object"
-             " created in the context of destination gpu is passed!!");
-        IfTestPassed = false;
+      // Passing stream object belong to destination device
+      // expectation: No issue should be observed
+      int NGpus = 0;
+      HIP_CHECK(hipGetDeviceCount(&NGpus));
+      if (NGpus > 1) {
+        hipStream_t strm1;
+        HIP_CHECK(hipSetDevice(1));
+        HIP_CHECK(hipStreamCreate(&strm1));
+        err = hipMemPrefetchAsync(Hmm, MemSz, 1, strm1);
+        if (err != hipSuccess) {
+          WARN(
+              "hipMemPrefetchAsync() returns error when stream object"
+              " created in the context of destination gpu is passed!!");
+          IfTestPassed = false;
+        }
+        HIP_CHECK(hipStreamDestroy(strm1));
       }
-      HIP_CHECK(hipStreamDestroy(strm1));
     }
-  }
-  HIP_CHECK(hipFree(Hmm));
-  HIP_CHECK(hipStreamDestroy(strm));
-  REQUIRE(IfTestPassed);
+    HIP_CHECK(hipFree(Hmm));
+    HIP_CHECK(hipStreamDestroy(strm));
+    REQUIRE(IfTestPassed);
 
   } else {
-      SUCCEED("GPU 0 doesn't support hipDeviceAttributeManagedMemory "
-             "attribute. Hence skipping the testing with Pass result.\n");
+    SUCCEED(
+        "GPU 0 doesn't support hipDeviceAttributeManagedMemory "
+        "attribute. Hence skipping the testing with Pass result.\n");
   }
 }
 
@@ -315,7 +326,7 @@ TEST_CASE("Unit_hipMemPrefetchAsyncNegativeTst") {
    which is not multiple of page Size, but still trying to launch kernel and
    see if we are getting values as expected.*/
 TEST_CASE("Unit_hipMemPrefetchAsync_NonPageSz") {
-  int *Hmm = nullptr, NumElms = 4096*2, InitVal = 123;
+  int *Hmm = nullptr, NumElms = 4096 * 2, InitVal = 123;
   hipStream_t strm;
   bool IfTestPassed = true;
   HIP_CHECK(hipStreamCreate(&strm));
@@ -326,7 +337,7 @@ TEST_CASE("Unit_hipMemPrefetchAsync_NonPageSz") {
   }
   HIP_CHECK(hipMemPrefetchAsync(Hmm, (NumElms * sizeof(int) + 8), 0, strm));
   HIP_CHECK(hipStreamSynchronize(strm));
-  MemPrftchAsyncKernel1<<<((NumElms + 2)/32 + 1), 32, 0, strm>>>(Hmm, (NumElms + 2));
+  MemPrftchAsyncKernel1<<<((NumElms + 2) / 32 + 1), 32, 0, strm>>>(Hmm, (NumElms + 2));
   HIP_CHECK(hipStreamSynchronize(strm));
   for (int i = 0; i < (NumElms + 2); ++i) {
     if (Hmm[i] != (InitVal * InitVal)) {
