@@ -29,8 +29,7 @@ THE SOFTWARE.
 #ifdef __linux__
 static bool CheckError(hipError_t err, int LineNo) {
   if (err == hipSuccess) {
-    WARN("Error expected but received hipSuccess at line no.:"
-           << LineNo);
+    WARN("Error expected but received hipSuccess at line no.:" << LineNo);
     return false;
   } else {
     return true;
@@ -39,23 +38,19 @@ static bool CheckError(hipError_t err, int LineNo) {
 
 static int HmmAttrPrint() {
   int managed = 0;
-  WARN("The following are the attribute values related to HMM for"
-         " device 0:\n");
-  HIP_CHECK(hipDeviceGetAttribute(&managed,
-              hipDeviceAttributeDirectManagedMemAccessFromHost, 0));
+  WARN(
+      "The following are the attribute values related to HMM for"
+      " device 0:\n");
+  HIP_CHECK(hipDeviceGetAttribute(&managed, hipDeviceAttributeDirectManagedMemAccessFromHost, 0));
   WARN("hipDeviceAttributeDirectManagedMemAccessFromHost: " << managed);
-  HIP_CHECK(hipDeviceGetAttribute(&managed,
-                                 hipDeviceAttributeConcurrentManagedAccess, 0));
+  HIP_CHECK(hipDeviceGetAttribute(&managed, hipDeviceAttributeConcurrentManagedAccess, 0));
   WARN("hipDeviceAttributeConcurrentManagedAccess: " << managed);
-  HIP_CHECK(hipDeviceGetAttribute(&managed,
-                                 hipDeviceAttributePageableMemoryAccess, 0));
+  HIP_CHECK(hipDeviceGetAttribute(&managed, hipDeviceAttributePageableMemoryAccess, 0));
   WARN("hipDeviceAttributePageableMemoryAccess: " << managed);
-  HIP_CHECK(hipDeviceGetAttribute(&managed,
-              hipDeviceAttributePageableMemoryAccessUsesHostPageTables, 0));
-  WARN("hipDeviceAttributePageableMemoryAccessUsesHostPageTables:"
-         << managed);
-  HIP_CHECK(hipDeviceGetAttribute(&managed, hipDeviceAttributeManagedMemory,
-                                  0));
+  HIP_CHECK(
+      hipDeviceGetAttribute(&managed, hipDeviceAttributePageableMemoryAccessUsesHostPageTables, 0));
+  WARN("hipDeviceAttributePageableMemoryAccessUsesHostPageTables:" << managed);
+  HIP_CHECK(hipDeviceGetAttribute(&managed, hipDeviceAttributeManagedMemory, 0));
   WARN("hipDeviceAttributeManagedMemory: " << managed);
   return managed;
 }
@@ -69,17 +64,14 @@ TEST_CASE("Unit_hipMemRangeGetAttributes_TstFlgs") {
     bool IfTestPassed = true;
     int NumDevs = 0;
     int *Outpt[4], *AcsdBy = nullptr;
-    float *Hmm = nullptr;
+    float* Hmm = nullptr;
     hipStream_t strm;
-    hipMemRangeAttribute AttrArr[4] =
-                                {hipMemRangeAttributeReadMostly,
-                                hipMemRangeAttributePreferredLocation,
-                                hipMemRangeAttributeAccessedBy,
-                                hipMemRangeAttributeLastPrefetchLocation};
+    hipMemRangeAttribute AttrArr[4] = {
+        hipMemRangeAttributeReadMostly, hipMemRangeAttributePreferredLocation,
+        hipMemRangeAttributeAccessedBy, hipMemRangeAttributeLastPrefetchLocation};
     HIP_CHECK(hipGetDeviceCount(&NumDevs));
     AcsdBy = new int(NumDevs);
-    size_t dataSizes[4] = {sizeof(int), sizeof(int),
-                        (NumDevs * sizeof(int)), sizeof(int)};
+    size_t dataSizes[4] = {sizeof(int), sizeof(int), (NumDevs * sizeof(int)), sizeof(int)};
     Outpt[0] = new int;
     Outpt[1] = new int;
     Outpt[2] = new int[NumDevs];
@@ -87,28 +79,26 @@ TEST_CASE("Unit_hipMemRangeGetAttributes_TstFlgs") {
     HIP_CHECK(hipMallocManaged(&Hmm, MEM_SIZE, hipMemAttachGlobal));
     for (int i = 0; i < NumDevs; ++i) {
       HIP_CHECK(hipMemAdvise(Hmm, MEM_SIZE, hipMemAdviseSetReadMostly, i));
-      HIP_CHECK(hipMemRangeGetAttributes(reinterpret_cast<void**>(Outpt),
-                                        dataSizes, AttrArr, 4, Hmm,
-                                        MEM_SIZE));
+      HIP_CHECK(hipMemRangeGetAttributes(reinterpret_cast<void**>(Outpt), dataSizes, AttrArr, 4,
+                                         Hmm, MEM_SIZE));
       if (*(Outpt[0]) != 1) {
         WARN("Attempt to set hipMemAdviseSetReadMostly flag failed!\n");
         IfTestPassed = false;
       }
       HIP_CHECK(hipMemAdvise(Hmm, MEM_SIZE, hipMemAdviseUnsetReadMostly, i));
       HIP_CHECK(hipMemRangeGetAttributes(reinterpret_cast<void**>(Outpt),
-                                    reinterpret_cast<size_t*>(dataSizes),
-                                    AttrArr, 4, Hmm, MEM_SIZE));
+                                         reinterpret_cast<size_t*>(dataSizes), AttrArr, 4, Hmm,
+                                         MEM_SIZE));
 
       if (*(Outpt[0]) != 0) {
         WARN("Attempt to set hipMemAdviseUnsetReadMostly flag failed!\n");
         IfTestPassed = false;
       }
 
-      HIP_CHECK(hipMemAdvise(Hmm, MEM_SIZE,
-                            hipMemAdviseSetPreferredLocation, i));
+      HIP_CHECK(hipMemAdvise(Hmm, MEM_SIZE, hipMemAdviseSetPreferredLocation, i));
       HIP_CHECK(hipMemRangeGetAttributes(reinterpret_cast<void**>(Outpt),
-                                    reinterpret_cast<size_t*>(dataSizes),
-                                    AttrArr, 4, Hmm, MEM_SIZE));
+                                         reinterpret_cast<size_t*>(dataSizes), AttrArr, 4, Hmm,
+                                         MEM_SIZE));
       if (*(Outpt[1]) != i) {
         WARN("Attempt to set hipMemAdviseSetPreferredLocation flag");
         WARN(" failed!\n");
@@ -116,8 +106,8 @@ TEST_CASE("Unit_hipMemRangeGetAttributes_TstFlgs") {
       }
       HIP_CHECK(hipMemAdvise(Hmm, MEM_SIZE, hipMemAdviseSetAccessedBy, i));
       HIP_CHECK(hipMemRangeGetAttributes(reinterpret_cast<void**>(Outpt),
-                                     reinterpret_cast<size_t*>(dataSizes),
-                                     AttrArr, 4, Hmm, MEM_SIZE));
+                                         reinterpret_cast<size_t*>(dataSizes), AttrArr, 4, Hmm,
+                                         MEM_SIZE));
       if ((Outpt[2][0]) != i) {
         WARN("Attempt to set hipMemAdviseSetAccessedBy flag");
         WARN(" failed!\n");
@@ -126,8 +116,8 @@ TEST_CASE("Unit_hipMemRangeGetAttributes_TstFlgs") {
 
       HIP_CHECK(hipMemAdvise(Hmm, MEM_SIZE, hipMemAdviseUnsetAccessedBy, i));
       HIP_CHECK(hipMemRangeGetAttributes(reinterpret_cast<void**>(Outpt),
-                                     reinterpret_cast<size_t*>(dataSizes),
-                                     AttrArr, 4, Hmm, MEM_SIZE));
+                                         reinterpret_cast<size_t*>(dataSizes), AttrArr, 4, Hmm,
+                                         MEM_SIZE));
       if (!((Outpt[2][i]) < 0)) {
         WARN("Attempt to set hipMemAdviseUnsetAccessedBy flag failed!\n");
         IfTestPassed = false;
@@ -136,8 +126,8 @@ TEST_CASE("Unit_hipMemRangeGetAttributes_TstFlgs") {
       HIP_CHECK(hipMemPrefetchAsync(Hmm, MEM_SIZE, i, strm));
       HIP_CHECK(hipStreamSynchronize(strm));
       HIP_CHECK(hipMemRangeGetAttributes(reinterpret_cast<void**>(Outpt),
-                                     reinterpret_cast<size_t*>(dataSizes),
-                                     AttrArr, 4, Hmm, MEM_SIZE));
+                                         reinterpret_cast<size_t*>(dataSizes), AttrArr, 4, Hmm,
+                                         MEM_SIZE));
       if (*(Outpt[3]) != i) {
         WARN("Attempt to prefetch memory to device: " << i);
         WARN("failed!\n");
@@ -147,8 +137,8 @@ TEST_CASE("Unit_hipMemRangeGetAttributes_TstFlgs") {
       HIP_CHECK(hipMemPrefetchAsync(Hmm, MEM_SIZE, -1, strm));
       HIP_CHECK(hipStreamSynchronize(strm));
       HIP_CHECK(hipMemRangeGetAttributes(reinterpret_cast<void**>(Outpt),
-                                     reinterpret_cast<size_t*>(dataSizes),
-                                     AttrArr, 4, Hmm, MEM_SIZE));
+                                         reinterpret_cast<size_t*>(dataSizes), AttrArr, 4, Hmm,
+                                         MEM_SIZE));
       if (*(Outpt[3]) != -1) {
         WARN("Attempt to prefetch memory to Host failed!\n");
         IfTestPassed = false;
@@ -163,8 +153,9 @@ TEST_CASE("Unit_hipMemRangeGetAttributes_TstFlgs") {
     }
     REQUIRE(IfTestPassed);
   } else {
-    SUCCEED("GPU 0 doesn't support hipDeviceAttributeManagedMemory "
-           "attribute. Hence skipping the testing with Pass result.\n");
+    SUCCEED(
+        "GPU 0 doesn't support hipDeviceAttributeManagedMemory "
+        "attribute. Hence skipping the testing with Pass result.\n");
   }
 }
 
@@ -174,27 +165,24 @@ TEST_CASE("Unit_hipMemRangeGetAttributes_NegativeTst") {
   if (MangdMem == 1) {
     bool IfTestPassed = true;
     int NumDevs = 0, *Outpt[4];
-    float *Hmm = nullptr;
-    hipMemRangeAttribute AttrArr[4] =
-                                {hipMemRangeAttributeReadMostly,
-                                hipMemRangeAttributePreferredLocation,
-                                hipMemRangeAttributeAccessedBy,
-                                hipMemRangeAttributeLastPrefetchLocation};
+    float* Hmm = nullptr;
+    hipMemRangeAttribute AttrArr[4] = {
+        hipMemRangeAttributeReadMostly, hipMemRangeAttributePreferredLocation,
+        hipMemRangeAttributeAccessedBy, hipMemRangeAttributeLastPrefetchLocation};
     HIP_CHECK(hipGetDeviceCount(&NumDevs));
-    size_t dataSizes[4] = {sizeof(int), sizeof(int),
-                        (NumDevs * sizeof(int)), sizeof(int)};
+    size_t dataSizes[4] = {sizeof(int), sizeof(int), (NumDevs * sizeof(int)), sizeof(int)};
     Outpt[0] = new int;
     Outpt[1] = new int;
     Outpt[2] = new int[NumDevs];
     Outpt[3] = new int;
     HIP_CHECK(hipMallocManaged(&Hmm, MEM_SIZE, hipMemAttachGlobal));
-    HIP_CHECK(hipMemAdvise(Hmm , MEM_SIZE, hipMemAdviseSetReadMostly, 0));
+    HIP_CHECK(hipMemAdvise(Hmm, MEM_SIZE, hipMemAdviseSetReadMostly, 0));
     // passing zero for num of attributes param(4th)
     SECTION("passing zero for num of attributes param(4th)") {
-      if (!CheckError(hipMemRangeGetAttributes(
-                                      reinterpret_cast<void**>(Outpt),
-                                      reinterpret_cast<size_t*>(dataSizes),
-                                      AttrArr, 0, Hmm, MEM_SIZE), __LINE__)) {
+      if (!CheckError(hipMemRangeGetAttributes(reinterpret_cast<void**>(Outpt),
+                                               reinterpret_cast<size_t*>(dataSizes), AttrArr, 0,
+                                               Hmm, MEM_SIZE),
+                      __LINE__)) {
         IfTestPassed = false;
       }
     }
@@ -205,11 +193,10 @@ TEST_CASE("Unit_hipMemRangeGetAttributes_NegativeTst") {
     dataSizes[2] = NumDevs * sizeof(int);
     dataSizes[3] = sizeof(int);
     SECTION("the first dataSize element passed as 0") {
-      if (!CheckError(hipMemRangeGetAttributes(
-                                      reinterpret_cast<void**>(Outpt),
-                                      reinterpret_cast<size_t*>(dataSizes),
-                                      AttrArr, 4, Hmm, MEM_SIZE),
-                                      __LINE__)) {
+      if (!CheckError(hipMemRangeGetAttributes(reinterpret_cast<void**>(Outpt),
+                                               reinterpret_cast<size_t*>(dataSizes), AttrArr, 4,
+                                               Hmm, MEM_SIZE),
+                      __LINE__)) {
         IfTestPassed = false;
       }
     }
@@ -219,11 +206,10 @@ TEST_CASE("Unit_hipMemRangeGetAttributes_NegativeTst") {
     dataSizes[2] = NumDevs * sizeof(int);
     dataSizes[3] = sizeof(int);
     SECTION("datasize as 2 while the requirement is multiple of 4") {
-      if (!CheckError(hipMemRangeGetAttributes(
-                                      reinterpret_cast<void**>(Outpt),
-                                      reinterpret_cast<size_t*>(dataSizes),
-                                      AttrArr, 4, Hmm, MEM_SIZE),
-                                      __LINE__)) {
+      if (!CheckError(hipMemRangeGetAttributes(reinterpret_cast<void**>(Outpt),
+                                               reinterpret_cast<size_t*>(dataSizes), AttrArr, 4,
+                                               Hmm, MEM_SIZE),
+                      __LINE__)) {
         IfTestPassed = false;
       }
     }
@@ -233,11 +219,10 @@ TEST_CASE("Unit_hipMemRangeGetAttributes_NegativeTst") {
     dataSizes[2] = NumDevs * sizeof(int);
     dataSizes[3] = sizeof(int);
     SECTION("datasize as 6 while the requirement is multiple of 4") {
-      if (!CheckError(hipMemRangeGetAttributes(
-                                      reinterpret_cast<void**>(Outpt),
-                                      reinterpret_cast<size_t*>(dataSizes),
-                                      AttrArr, 4, Hmm, MEM_SIZE),
-                                      __LINE__)) {
+      if (!CheckError(hipMemRangeGetAttributes(reinterpret_cast<void**>(Outpt),
+                                               reinterpret_cast<size_t*>(dataSizes), AttrArr, 4,
+                                               Hmm, MEM_SIZE),
+                      __LINE__)) {
         IfTestPassed = false;
       }
     }
@@ -247,11 +232,10 @@ TEST_CASE("Unit_hipMemRangeGetAttributes_NegativeTst") {
     dataSizes[2] = NumDevs * sizeof(int);
     dataSizes[3] = sizeof(int);
     SECTION("datasize as 7 while the requirement is multiple of 4") {
-      if (!CheckError(hipMemRangeGetAttributes(
-                                      reinterpret_cast<void**>(Outpt),
-                                      reinterpret_cast<size_t*>(dataSizes),
-                                      AttrArr, 4, Hmm, MEM_SIZE),
-                                      __LINE__)) {
+      if (!CheckError(hipMemRangeGetAttributes(reinterpret_cast<void**>(Outpt),
+                                               reinterpret_cast<size_t*>(dataSizes), AttrArr, 4,
+                                               Hmm, MEM_SIZE),
+                      __LINE__)) {
         IfTestPassed = false;
       }
     }
@@ -259,50 +243,46 @@ TEST_CASE("Unit_hipMemRangeGetAttributes_NegativeTst") {
     hipMemRangeAttribute AttrArr1[1] = {hipMemRangeAttributeAccessedBy};
     dataSizes[2] = {7};
     SECTION("passing dataSize as 7 for attribute hipMemRangeAttrAccessedBy") {
-      if (!CheckError(hipMemRangeGetAttributes(
-                                      reinterpret_cast<void**>(Outpt),
-                                      reinterpret_cast<size_t*>(dataSizes),
-                                      AttrArr1, 1, Hmm, MEM_SIZE), __LINE__)) {
+      if (!CheckError(hipMemRangeGetAttributes(reinterpret_cast<void**>(Outpt),
+                                               reinterpret_cast<size_t*>(dataSizes), AttrArr1, 1,
+                                               Hmm, MEM_SIZE),
+                      __LINE__)) {
         IfTestPassed = false;
       }
     }
     // Passing NULL as first parameter
     SECTION("Passing NULL as first parameter") {
-      if (!CheckError(hipMemRangeGetAttributes(
-                                      reinterpret_cast<void**>(NULL),
-                                      reinterpret_cast<size_t*>(dataSizes),
-                                      AttrArr, 4, Hmm, MEM_SIZE),
-                                      __LINE__)) {
+      if (!CheckError(hipMemRangeGetAttributes(reinterpret_cast<void**>(NULL),
+                                               reinterpret_cast<size_t*>(dataSizes), AttrArr, 4,
+                                               Hmm, MEM_SIZE),
+                      __LINE__)) {
         IfTestPassed = false;
       }
     }
     // Passing count parameter as zero
     SECTION("Passing count parameter as zero") {
-      if (!CheckError(hipMemRangeGetAttributes(
-                                      reinterpret_cast<void**>(Outpt),
-                                      reinterpret_cast<size_t*>(dataSizes),
-                                      AttrArr, 4, Hmm, 0),
-                                      __LINE__)) {
+      if (!CheckError(
+              hipMemRangeGetAttributes(reinterpret_cast<void**>(Outpt),
+                                       reinterpret_cast<size_t*>(dataSizes), AttrArr, 4, Hmm, 0),
+              __LINE__)) {
         IfTestPassed = false;
       }
     }
     // Passing NULL for Attribute array(3rd param)
     SECTION("Passing NULL for Attribute array(3rd param)") {
-      if (!CheckError(hipMemRangeGetAttributes(
-                                      reinterpret_cast<void**>(Outpt),
-                                      reinterpret_cast<size_t*>(dataSizes),
-                                      NULL, 4, Hmm, MEM_SIZE),
-                                      __LINE__)) {
+      if (!CheckError(hipMemRangeGetAttributes(reinterpret_cast<void**>(Outpt),
+                                               reinterpret_cast<size_t*>(dataSizes), NULL, 4, Hmm,
+                                               MEM_SIZE),
+                      __LINE__)) {
         IfTestPassed = false;
       }
     }
     // Passing 0 for Attribute array(3rd param)
     SECTION("Passing 0 for Attribute array(3rd param)") {
-      if (!CheckError(hipMemRangeGetAttributes(
-                                      reinterpret_cast<void**>(Outpt),
-                                      reinterpret_cast<size_t*>(dataSizes),
-                                      0, 4, Hmm, MEM_SIZE),
-                                      __LINE__)) {
+      if (!CheckError(
+              hipMemRangeGetAttributes(reinterpret_cast<void**>(Outpt),
+                                       reinterpret_cast<size_t*>(dataSizes), 0, 4, Hmm, MEM_SIZE),
+              __LINE__)) {
         IfTestPassed = false;
       }
     }
@@ -319,8 +299,9 @@ TEST_CASE("Unit_hipMemRangeGetAttributes_NegativeTst") {
     // length of the list of dataSizes less than the number of
     // attributes being probed
   } else {
-    SUCCEED("GPU 0 doesn't support hipDeviceAttributeManagedMemory "
-           "attribute. Hence skipping the testing with Pass result.\n");
+    SUCCEED(
+        "GPU 0 doesn't support hipDeviceAttributeManagedMemory "
+        "attribute. Hence skipping the testing with Pass result.\n");
   }
 }
 #endif
