@@ -43,45 +43,42 @@ static constexpr auto width{10};
 static constexpr auto height{10};
 static constexpr auto depth{10};
 
-template <typename T>
-class Memcpy3DAsync {
-    int width, height, depth;
-    unsigned int size;
-    hipArray_t arr, arr1;
-    hipChannelFormatKind formatKind;
-    hipMemcpy3DParms myparms;
-    T* hData;
-    hipStream_t stream;
+template <typename T> class Memcpy3DAsync {
+  int width, height, depth;
+  unsigned int size;
+  hipArray_t arr, arr1;
+  hipChannelFormatKind formatKind;
+  hipMemcpy3DParms myparms;
+  T* hData;
+  hipStream_t stream;
+
  public:
-    Memcpy3DAsync(int l_width, int l_height, int l_depth,
-                  hipChannelFormatKind l_format);
-    void simple_Memcpy3DAsync();
-    void Extent_Validation();
-    void NegativeTests();
-    void AllocateMemory();
-    void DeAllocateMemory();
-    void SetDefaultData();
-    void D2D_SameDeviceMem_StreamDiffDevice();
-    void D2D_DeviceMem_OnDiffDevice();
-    void D2H_H2D_DeviceMem_OnDiffDevice();
+  Memcpy3DAsync(int l_width, int l_height, int l_depth, hipChannelFormatKind l_format);
+  void simple_Memcpy3DAsync();
+  void Extent_Validation();
+  void NegativeTests();
+  void AllocateMemory();
+  void DeAllocateMemory();
+  void SetDefaultData();
+  void D2D_SameDeviceMem_StreamDiffDevice();
+  void D2D_DeviceMem_OnDiffDevice();
+  void D2H_H2D_DeviceMem_OnDiffDevice();
 };
 
 /*
  * This API sets the default values of hipMemcpy3DParms structure
  */
-template <typename T>
-void Memcpy3DAsync<T>::SetDefaultData() {
+template <typename T> void Memcpy3DAsync<T>::SetDefaultData() {
   myparms.srcPos = make_hipPos(0, 0, 0);
   myparms.dstPos = make_hipPos(0, 0, 0);
-  myparms.extent = make_hipExtent(width , height, depth);
+  myparms.extent = make_hipExtent(width, height, depth);
 }
 
 /*
  * Constructor initalized width,depth and height
  */
-template <typename T>
-Memcpy3DAsync<T>::Memcpy3DAsync(int l_width, int l_height, int l_depth,
-                      hipChannelFormatKind l_format) {
+template <typename T> Memcpy3DAsync<T>::Memcpy3DAsync(int l_width, int l_height, int l_depth,
+                                                      hipChannelFormatKind l_format) {
   width = l_width;
   height = l_height;
   depth = l_depth;
@@ -92,31 +89,28 @@ Memcpy3DAsync<T>::Memcpy3DAsync(int l_width, int l_height, int l_depth,
  * Allocating Memory and initalizing data for both
  * device and host variables
  */
-template <typename T>
-void Memcpy3DAsync<T>::AllocateMemory() {
+template <typename T> void Memcpy3DAsync<T>::AllocateMemory() {
   size = width * height * depth * sizeof(T);
   hData = reinterpret_cast<T*>(malloc(size));
   memset(hData, 0, size);
   for (int i = 0; i < depth; i++) {
     for (int j = 0; j < height; j++) {
       for (int k = 0; k < width; k++) {
-        hData[i*width*height + j*width +k] = i*width*height + j*width + k;
+        hData[i * width * height + j * width + k] = i * width * height + j * width + k;
       }
     }
   }
-  hipChannelFormatDesc channelDesc = hipCreateChannelDesc(sizeof(T)*8,
-                                                          0, 0, 0, formatKind);
-  HIP_CHECK(hipMalloc3DArray(&arr, &channelDesc, make_hipExtent(width, height,
-                                                depth), hipArrayDefault));
-  HIP_CHECK(hipMalloc3DArray(&arr1, &channelDesc, make_hipExtent(width, height,
-                                                 depth), hipArrayDefault));
+  hipChannelFormatDesc channelDesc = hipCreateChannelDesc(sizeof(T) * 8, 0, 0, 0, formatKind);
+  HIP_CHECK(
+      hipMalloc3DArray(&arr, &channelDesc, make_hipExtent(width, height, depth), hipArrayDefault));
+  HIP_CHECK(
+      hipMalloc3DArray(&arr1, &channelDesc, make_hipExtent(width, height, depth), hipArrayDefault));
 }
 
 /*
  * DeAllocates the Memory of device and host variables
  */
-template <typename T>
-void Memcpy3DAsync<T>::DeAllocateMemory() {
+template <typename T> void Memcpy3DAsync<T>::DeAllocateMemory() {
   HIP_CHECK(hipFreeArray(arr));
   HIP_CHECK(hipFreeArray(arr1));
   free(hData);
@@ -137,8 +131,7 @@ void Memcpy3DAsync<T>::DeAllocateMemory() {
  *
  * Validating the result by comparing "hData" and "hOutputData" variables
  */
-template <typename T>
-void Memcpy3DAsync<T>::D2H_H2D_DeviceMem_OnDiffDevice() {
+template <typename T> void Memcpy3DAsync<T>::D2H_H2D_DeviceMem_OnDiffDevice() {
   HIP_CHECK(hipSetDevice(0));
   int peerAccess = 0;
   HIP_CHECK(hipDeviceCanAccessPeer(&peerAccess, 1, 0));
@@ -153,8 +146,7 @@ void Memcpy3DAsync<T>::D2H_H2D_DeviceMem_OnDiffDevice() {
     SetDefaultData();
 
     // Host to Device
-    myparms.srcPtr = make_hipPitchedPtr(hData, width * sizeof(T),
-        width, height);
+    myparms.srcPtr = make_hipPitchedPtr(hData, width * sizeof(T), width, height);
     myparms.dstArray = arr;
 #ifdef __HIP_PLATFORM_NVIDIA__
     myparms.kind = cudaMemcpyHostToDevice;
@@ -165,14 +157,12 @@ void Memcpy3DAsync<T>::D2H_H2D_DeviceMem_OnDiffDevice() {
     HIP_CHECK(hipStreamSynchronize(stream));
 
     memset(&myparms, 0x0, sizeof(hipMemcpy3DParms));
-    T *hOutputData = reinterpret_cast<T*>(malloc(size));
-    memset(hOutputData, 0,  size);
+    T* hOutputData = reinterpret_cast<T*>(malloc(size));
+    memset(hOutputData, 0, size);
     SetDefaultData();
 
     // Device to host
-    myparms.dstPtr = make_hipPitchedPtr(hOutputData,
-        width * sizeof(T),
-        width, height);
+    myparms.dstPtr = make_hipPitchedPtr(hOutputData, width * sizeof(T), width, height);
     myparms.srcArray = arr;
 #ifdef __HIP_PLATFORM_NVIDIA__
     myparms.kind = cudaMemcpyDeviceToHost;
@@ -208,8 +198,7 @@ void Memcpy3DAsync<T>::D2H_H2D_DeviceMem_OnDiffDevice() {
  *
  * Validating the result by comparing "hData" and "hOutputData" variables
  */
-template <typename T>
-void Memcpy3DAsync<T>::D2D_DeviceMem_OnDiffDevice() {
+template <typename T> void Memcpy3DAsync<T>::D2D_DeviceMem_OnDiffDevice() {
   HIP_CHECK(hipSetDevice(0));
   int peerAccess = 0;
   HIP_CHECK(hipDeviceCanAccessPeer(&peerAccess, 0, 1));
@@ -222,9 +211,7 @@ void Memcpy3DAsync<T>::D2D_DeviceMem_OnDiffDevice() {
     SetDefaultData();
 
     // Host to Device Scenario
-    myparms.srcPtr = make_hipPitchedPtr(hData,
-                                        width * sizeof(T),
-                                        width, height);
+    myparms.srcPtr = make_hipPitchedPtr(hData, width * sizeof(T), width, height);
     myparms.dstArray = arr;
 #ifdef __HIP_PLATFORM_NVIDIA__
     myparms.kind = cudaMemcpyHostToDevice;
@@ -238,11 +225,9 @@ void Memcpy3DAsync<T>::D2D_DeviceMem_OnDiffDevice() {
     HIP_CHECK(hipSetDevice(1));
     HIP_CHECK(hipStreamCreate(&stream));
     hipArray_t arr2;
-    hipChannelFormatDesc channelDesc1 = hipCreateChannelDesc(sizeof(T)*8,
-                                                    0, 0, 0, formatKind);
-    HIP_CHECK(hipMalloc3DArray(&arr2, &channelDesc1,
-                              make_hipExtent(width, height,
-                              depth), hipArrayDefault));
+    hipChannelFormatDesc channelDesc1 = hipCreateChannelDesc(sizeof(T) * 8, 0, 0, 0, formatKind);
+    HIP_CHECK(hipMalloc3DArray(&arr2, &channelDesc1, make_hipExtent(width, height, depth),
+                               hipArrayDefault));
     memset(&myparms, 0x0, sizeof(hipMemcpy3DParms));
     SetDefaultData();
 
@@ -260,21 +245,19 @@ void Memcpy3DAsync<T>::D2D_DeviceMem_OnDiffDevice() {
     // For validating the D2D copy copying it again to hOutputData and
     // verifying it with iniital data hData
     memset(&myparms, 0x0, sizeof(hipMemcpy3DParms));
-    T *hOutputData = reinterpret_cast<T*>(malloc(size));
+    T* hOutputData = reinterpret_cast<T*>(malloc(size));
     memset(hOutputData, 0, size);
     SetDefaultData();
 
     // Device to host
-    myparms.dstPtr = make_hipPitchedPtr(hOutputData,
-                                        width * sizeof(T),
-                                        width, height);
+    myparms.dstPtr = make_hipPitchedPtr(hOutputData, width * sizeof(T), width, height);
     myparms.srcArray = arr2;
 #ifdef __HIP_PLATFORM_NVIDIA__
     myparms.kind = cudaMemcpyDeviceToHost;
 #else
     myparms.kind = hipMemcpyDeviceToHost;
 #endif
-    REQUIRE(hipMemcpy3DAsync(&myparms, stream)== hipSuccess);
+    REQUIRE(hipMemcpy3DAsync(&myparms, stream) == hipSuccess);
     HIP_CHECK(hipStreamSynchronize(stream));
 
     // Validating the result
@@ -290,9 +273,8 @@ void Memcpy3DAsync<T>::D2D_DeviceMem_OnDiffDevice() {
 
 /*
  * This API verifies all the negative scenarios of hipMemcpy3D API
-*/
-template <typename T>
-void Memcpy3DAsync<T>::NegativeTests() {
+ */
+template <typename T> void Memcpy3DAsync<T>::NegativeTests() {
   HIP_CHECK(hipSetDevice(0));
   AllocateMemory();
   HIP_CHECK(hipStreamCreate(&stream));
@@ -301,7 +283,7 @@ void Memcpy3DAsync<T>::NegativeTests() {
   memset(&myparms, 0, sizeof(myparms));
   myparms.srcPos = make_hipPos(0, 0, 0);
   myparms.dstPos = make_hipPos(0, 0, 0);
-  myparms.extent = make_hipExtent(width , height, depth);
+  myparms.extent = make_hipExtent(width, height, depth);
 #ifdef __HIP_PLATFORM_NVIDIA__
   myparms.kind = cudaMemcpyHostToDevice;
 #else
@@ -309,109 +291,96 @@ void Memcpy3DAsync<T>::NegativeTests() {
 #endif
 
   SECTION("Nullptr to destination array") {
-    myparms.srcPtr = make_hipPitchedPtr(hData, width * sizeof(T),
-        width, height);
+    myparms.srcPtr = make_hipPitchedPtr(hData, width * sizeof(T), width, height);
     myparms.dstArray = nullptr;
     REQUIRE(hipMemcpy3DAsync(&myparms, stream) != hipSuccess);
   }
 
   SECTION("Nullptr to source array") {
     myparms.srcArray = nullptr;
-    myparms.dstPtr = make_hipPitchedPtr(hData, width * sizeof(T),
-        width, height);
+    myparms.dstPtr = make_hipPitchedPtr(hData, width * sizeof(T), width, height);
     REQUIRE(hipMemcpy3DAsync(&myparms, stream) != hipSuccess);
   }
 
   SECTION("Passing both Source ptr and array") {
-    myparms.srcPtr = make_hipPitchedPtr(hData, width * sizeof(T),
-                                        width, height);
+    myparms.srcPtr = make_hipPitchedPtr(hData, width * sizeof(T), width, height);
     myparms.srcArray = arr;
     myparms.dstArray = arr1;
     REQUIRE(hipMemcpy3DAsync(&myparms, stream) != hipSuccess);
   }
 
   SECTION("Passing both destination ptr and array") {
-    myparms.dstPtr = make_hipPitchedPtr(hData, width * sizeof(T),
-                                        width, height);
+    myparms.dstPtr = make_hipPitchedPtr(hData, width * sizeof(T), width, height);
     myparms.dstArray = arr;
     myparms.srcArray = arr1;
     REQUIRE(hipMemcpy3DAsync(&myparms, stream) != hipSuccess);
   }
 
   SECTION("Passing Max value to extent") {
-    myparms.srcPtr = make_hipPitchedPtr(hData, width * sizeof(T),
-                                        width, height);
+    myparms.srcPtr = make_hipPitchedPtr(hData, width * sizeof(T), width, height);
     myparms.dstArray = arr;
-    myparms.extent = make_hipExtent(std::numeric_limits<int>::max(),
-                                    std::numeric_limits<int>::max(),
-                                    std::numeric_limits<int>::max());
+    myparms.extent =
+        make_hipExtent(std::numeric_limits<int>::max(), std::numeric_limits<int>::max(),
+                       std::numeric_limits<int>::max());
     REQUIRE(hipMemcpy3DAsync(&myparms, stream) != hipSuccess);
   }
 
   SECTION("Passing Source pitchedPtr as nullptr") {
-    myparms.srcPtr = make_hipPitchedPtr(nullptr, width * sizeof(T),
-                                        width, height);
+    myparms.srcPtr = make_hipPitchedPtr(nullptr, width * sizeof(T), width, height);
     myparms.dstArray = arr;
     REQUIRE(hipMemcpy3DAsync(&myparms, stream) != hipSuccess);
   }
 
   SECTION("Passing Dst pitchedPtr as nullptr") {
-    myparms.dstPtr = make_hipPitchedPtr(nullptr, width * sizeof(T),
-                                        width, height);
+    myparms.dstPtr = make_hipPitchedPtr(nullptr, width * sizeof(T), width, height);
     myparms.srcArray = arr;
     REQUIRE(hipMemcpy3DAsync(&myparms, stream) != hipSuccess);
   }
 
   SECTION("Passing width > max width size in extent") {
-    myparms.extent = make_hipExtent(width+1 , height, depth);
+    myparms.extent = make_hipExtent(width + 1, height, depth);
     myparms.dstArray = arr;
-    myparms.srcPtr = make_hipPitchedPtr(hData, width * sizeof(T),
-                                        width, height);
+    myparms.srcPtr = make_hipPitchedPtr(hData, width * sizeof(T), width, height);
     REQUIRE(hipMemcpy3DAsync(&myparms, stream) != hipSuccess);
   }
 
   SECTION("Passing hgt > max width size in extent") {
-    myparms.extent = make_hipExtent(width , height+1, depth);
-    myparms.srcPtr = make_hipPitchedPtr(hData, width * sizeof(T),
-                                        width, height);
+    myparms.extent = make_hipExtent(width, height + 1, depth);
+    myparms.srcPtr = make_hipPitchedPtr(hData, width * sizeof(T), width, height);
     myparms.dstArray = arr;
     REQUIRE(hipMemcpy3DAsync(&myparms, stream) != hipSuccess);
   }
 
   SECTION("Passing depth > max width size in extent") {
-    myparms.extent = make_hipExtent(width , height, depth+1);
+    myparms.extent = make_hipExtent(width, height, depth + 1);
     myparms.dstArray = arr;
-    myparms.srcPtr = make_hipPitchedPtr(hData, width * sizeof(T),
-                                        width, height);
+    myparms.srcPtr = make_hipPitchedPtr(hData, width * sizeof(T), width, height);
     REQUIRE(hipMemcpy3DAsync(&myparms, stream) != hipSuccess);
   }
 
   SECTION("Passing dst width pos > max allocated width") {
-    myparms.dstPos = make_hipPos(width+1, 0, 0);
+    myparms.dstPos = make_hipPos(width + 1, 0, 0);
     myparms.dstArray = arr;
-    myparms.srcPtr = make_hipPitchedPtr(hData, width * sizeof(T),
-                                        width, height);
+    myparms.srcPtr = make_hipPitchedPtr(hData, width * sizeof(T), width, height);
     REQUIRE(hipMemcpy3DAsync(&myparms, stream) != hipSuccess);
   }
 
   SECTION("Passing dst height pos > max allocated hgt") {
-    myparms.dstPos = make_hipPos(0, height+1, 0);
+    myparms.dstPos = make_hipPos(0, height + 1, 0);
     myparms.dstArray = arr;
-    myparms.srcPtr = make_hipPitchedPtr(hData, width * sizeof(T),
-                                        width, height);
+    myparms.srcPtr = make_hipPitchedPtr(hData, width * sizeof(T), width, height);
     REQUIRE(hipMemcpy3DAsync(&myparms, stream) != hipSuccess);
   }
 
   SECTION("Passing dst depth pos > max allocated depth") {
-    myparms.dstPos = make_hipPos(0, 0, depth+1);
+    myparms.dstPos = make_hipPos(0, 0, depth + 1);
     myparms.dstArray = arr;
-    myparms.srcPtr = make_hipPitchedPtr(hData, width * sizeof(T),
-                                        width, height);
+    myparms.srcPtr = make_hipPitchedPtr(hData, width * sizeof(T), width, height);
     REQUIRE(hipMemcpy3DAsync(&myparms, stream) != hipSuccess);
   }
 
   SECTION("Passing src width pos > max allocated width") {
-    myparms.srcPos = make_hipPos(width+1, 0, 0);
+    myparms.srcPos = make_hipPos(width + 1, 0, 0);
     myparms.srcArray = arr;
     myparms.dstArray = arr1;
 #ifdef __HIP_PLATFORM_NVIDIA__
@@ -423,7 +392,7 @@ void Memcpy3DAsync<T>::NegativeTests() {
   }
 
   SECTION("Passing src height pos > max allocated hgt") {
-    myparms.srcPos = make_hipPos(0, height+1, 0);
+    myparms.srcPos = make_hipPos(0, height + 1, 0);
     myparms.srcArray = arr;
     myparms.dstArray = arr1;
 #ifdef __HIP_PLATFORM_NVIDIA__
@@ -435,7 +404,7 @@ void Memcpy3DAsync<T>::NegativeTests() {
   }
 
   SECTION("Passing src height pos > max allocated hgt") {
-    myparms.srcPos = make_hipPos(0, 0, depth+1);
+    myparms.srcPos = make_hipPos(0, 0, depth + 1);
     myparms.srcArray = arr;
     myparms.dstArray = arr1;
 #ifdef __HIP_PLATFORM_NVIDIA__
@@ -448,11 +417,8 @@ void Memcpy3DAsync<T>::NegativeTests() {
 
   SECTION("Passing src array size  > dst array size") {
     hipArray_t arr2;
-    hipChannelFormatDesc channelDesc1 = hipCreateChannelDesc(sizeof(T)*8,
-        0, 0, 0, formatKind);
-    HIP_CHECK(hipMalloc3DArray(&arr2, &channelDesc1,
-                              make_hipExtent(3, 3
-                              , 3), hipArrayDefault));
+    hipChannelFormatDesc channelDesc1 = hipCreateChannelDesc(sizeof(T) * 8, 0, 0, 0, formatKind);
+    HIP_CHECK(hipMalloc3DArray(&arr2, &channelDesc1, make_hipExtent(3, 3, 3), hipArrayDefault));
     myparms.srcArray = arr;
     myparms.dstArray = arr2;
 #ifdef __HIP_PLATFORM_NVIDIA__
@@ -485,8 +451,7 @@ void Memcpy3DAsync<T>::NegativeTests() {
  *
  * Validating the result by comparing "hData" and "hOutputData" variables
  */
-template <typename T>
-void Memcpy3DAsync<T>::D2D_SameDeviceMem_StreamDiffDevice() {
+template <typename T> void Memcpy3DAsync<T>::D2D_SameDeviceMem_StreamDiffDevice() {
   HIP_CHECK(hipSetDevice(0));
   // Allocating the Memory
   int peerAccess = 0;
@@ -521,14 +486,13 @@ void Memcpy3DAsync<T>::D2D_SameDeviceMem_StreamDiffDevice() {
 #endif
     REQUIRE(hipMemcpy3DAsync(&myparms, stream) == hipSuccess);
     HIP_CHECK(hipStreamSynchronize(stream));
-    T *hOutputData = reinterpret_cast<T*>(malloc(size));
-    memset(hOutputData, 0,  size);
+    T* hOutputData = reinterpret_cast<T*>(malloc(size));
+    memset(hOutputData, 0, size);
 
     // Device to host
     memset(&myparms, 0x0, sizeof(hipMemcpy3DParms));
     SetDefaultData();
-    myparms.dstPtr = make_hipPitchedPtr(hOutputData,
-        width * sizeof(T), width, height);
+    myparms.dstPtr = make_hipPitchedPtr(hOutputData, width * sizeof(T), width, height);
     myparms.srcArray = arr1;
 #ifdef __HIP_PLATFORM_NVIDIA__
     myparms.kind = cudaMemcpyDeviceToHost;
@@ -552,8 +516,7 @@ void Memcpy3DAsync<T>::D2D_SameDeviceMem_StreamDiffDevice() {
 /*
  * This API verifies the Extent validation Scenarios
  */
-template <typename T>
-void Memcpy3DAsync<T>::Extent_Validation() {
+template <typename T> void Memcpy3DAsync<T>::Extent_Validation() {
   HIP_CHECK(hipSetDevice(0));
   AllocateMemory();
   HIP_CHECK(hipStreamCreate(&stream));
@@ -569,19 +532,19 @@ void Memcpy3DAsync<T>::Extent_Validation() {
   myparms.kind = hipMemcpyHostToDevice;
 #endif
   SECTION("Passing Extent as 0") {
-    myparms.extent = make_hipExtent(0 , 0, 0);
+    myparms.extent = make_hipExtent(0, 0, 0);
     REQUIRE(hipMemcpy3DAsync(&myparms, stream) == hipSuccess);
   }
   SECTION("Passing Width 0 in Extent") {
-    myparms.extent = make_hipExtent(0 , height, depth);
+    myparms.extent = make_hipExtent(0, height, depth);
     REQUIRE(hipMemcpy3DAsync(&myparms, stream) == hipSuccess);
   }
   SECTION("Passing Height 0 in Extent") {
-    myparms.extent = make_hipExtent(width , 0, depth);
+    myparms.extent = make_hipExtent(width, 0, depth);
     REQUIRE(hipMemcpy3DAsync(&myparms, stream) == hipSuccess);
   }
   SECTION("Passing Depth 0 in Extent") {
-    myparms.extent = make_hipExtent(width , height, 0);
+    myparms.extent = make_hipExtent(width, height, 0);
     REQUIRE(hipMemcpy3DAsync(&myparms, stream) == hipSuccess);
   }
   DeAllocateMemory();
@@ -598,8 +561,7 @@ void Memcpy3DAsync<T>::Extent_Validation() {
  *
  * Validating the result by comparing "hData" and "hOutputData" variables
  */
-template <typename T>
-void Memcpy3DAsync<T>::simple_Memcpy3DAsync() {
+template <typename T> void Memcpy3DAsync<T>::simple_Memcpy3DAsync() {
   HIP_CHECK(hipSetDevice(0));
 
   // Allocating the Memory
@@ -637,14 +599,13 @@ void Memcpy3DAsync<T>::simple_Memcpy3DAsync() {
 #endif
   REQUIRE(hipMemcpy3DAsync(&myparms, stream) == hipSuccess);
   HIP_CHECK(hipStreamSynchronize(stream));
-  T *hOutputData = reinterpret_cast<T*>(malloc(size));
-  memset(hOutputData, 0,  size);
+  T* hOutputData = reinterpret_cast<T*>(malloc(size));
+  memset(hOutputData, 0, size);
 
   // Device to host
   memset(&myparms, 0x0, sizeof(hipMemcpy3DParms));
   SetDefaultData();
-  myparms.dstPtr = make_hipPitchedPtr(hOutputData,
-      width * sizeof(T), width, height);
+  myparms.dstPtr = make_hipPitchedPtr(hOutputData, width * sizeof(T), width, height);
   myparms.srcArray = arr1;
 #ifdef __HIP_PLATFORM_NVIDIA__
   myparms.kind = cudaMemcpyDeviceToHost;
@@ -674,32 +635,27 @@ void Memcpy3DAsync<T>::simple_Memcpy3DAsync() {
  *  - HIP_VERSION >= 6.0
  */
 
-TEMPLATE_TEST_CASE("Unit_hipMemcpy3DAsync_Basic",
-                   "[hipMemcpy3DAsync]",
-                   int, unsigned int, float) {
+TEMPLATE_TEST_CASE("Unit_hipMemcpy3DAsync_Basic", "[hipMemcpy3DAsync]", int, unsigned int, float) {
   CHECK_IMAGE_SUPPORT
   int numDevices = 0;
   HIP_CHECK(hipGetDeviceCount(&numDevices));
   int device = -1;
   HIP_CHECK(hipGetDevice(&device));
   hipDeviceProp_t prop;
-  HIP_CHECK(hipGetDeviceProperties(&prop,device));
+  HIP_CHECK(hipGetDeviceProperties(&prop, device));
   auto i = GENERATE_COPY(10, 100, 1024, prop.maxTexture3D[0]);
   auto j = GENERATE(10, 100);
   if (numDevices > 1) {
-      if (std::is_same<TestType, int>::value)  {
-        Memcpy3DAsync<TestType> memcpy3d_obj(i, j, j,
-                                             hipChannelFormatKindSigned);
-        memcpy3d_obj.simple_Memcpy3DAsync();
-      } else if (std::is_same<TestType, unsigned int>::value)  {
-        Memcpy3DAsync<TestType> memcpy3d_obj(i, j, j,
-                                             hipChannelFormatKindUnsigned);
-        memcpy3d_obj.simple_Memcpy3DAsync();
-      } else if (std::is_same<TestType, float>::value) {
-        Memcpy3DAsync<TestType> memcpy3d_obj(i, j, j,
-                                             hipChannelFormatKindFloat);
-        memcpy3d_obj.simple_Memcpy3DAsync();
-      }
+    if (std::is_same<TestType, int>::value) {
+      Memcpy3DAsync<TestType> memcpy3d_obj(i, j, j, hipChannelFormatKindSigned);
+      memcpy3d_obj.simple_Memcpy3DAsync();
+    } else if (std::is_same<TestType, unsigned int>::value) {
+      Memcpy3DAsync<TestType> memcpy3d_obj(i, j, j, hipChannelFormatKindUnsigned);
+      memcpy3d_obj.simple_Memcpy3DAsync();
+    } else if (std::is_same<TestType, float>::value) {
+      Memcpy3DAsync<TestType> memcpy3d_obj(i, j, j, hipChannelFormatKindFloat);
+      memcpy3d_obj.simple_Memcpy3DAsync();
+    }
   } else {
     SUCCEED("skipping the testcases as numDevices < 2");
   }
@@ -719,8 +675,7 @@ TEMPLATE_TEST_CASE("Unit_hipMemcpy3DAsync_Basic",
 
 TEST_CASE("Unit_hipMemcpy3DAsync_ExtentValidation") {
   CHECK_IMAGE_SUPPORT
-  Memcpy3DAsync<int> memcpy3d(width, height, depth,
-                              hipChannelFormatKindSigned);
+  Memcpy3DAsync<int> memcpy3d(width, height, depth, hipChannelFormatKindSigned);
   memcpy3d.Extent_Validation();
 }
 
@@ -741,8 +696,7 @@ TEST_CASE("Unit_hipMemcpy3DAsync_multiDevice-Negative") {
   int numDevices = 0;
   HIP_CHECK(hipGetDeviceCount(&numDevices));
   if (numDevices > 1) {
-    Memcpy3DAsync<int> memcpy3d(width, height, depth,
-                                hipChannelFormatKindSigned);
+    Memcpy3DAsync<int> memcpy3d(width, height, depth, hipChannelFormatKindSigned);
     memcpy3d.NegativeTests();
   } else {
     SUCCEED("skipping the testcases as numDevices < 2");
@@ -767,14 +721,12 @@ TEST_CASE("Unit_hipMemcpy3DAsync_multiDevice-D2D") {
   HIP_CHECK(hipGetDeviceCount(&numDevices));
   if (numDevices > 1) {
     SECTION("D2D on different Device") {
-      Memcpy3DAsync<float> memcpy3d_d2d_obj(width, height, depth,
-                                            hipChannelFormatKindFloat);
+      Memcpy3DAsync<float> memcpy3d_d2d_obj(width, height, depth, hipChannelFormatKindFloat);
       memcpy3d_d2d_obj.D2D_DeviceMem_OnDiffDevice();
     }
 
     SECTION("D2H and H2D on different device") {
-      Memcpy3DAsync<float> memcpy3d_d2h_obj(width, height, depth,
-                                            hipChannelFormatKindFloat);
+      Memcpy3DAsync<float> memcpy3d_d2h_obj(width, height, depth, hipChannelFormatKindFloat);
       memcpy3d_d2h_obj.D2H_H2D_DeviceMem_OnDiffDevice();
     }
   } else {
@@ -800,8 +752,7 @@ TEST_CASE("Unit_hipMemcpy3DAsync_multiDevice-DiffStream") {
   int numDevices = 0;
   HIP_CHECK(hipGetDeviceCount(&numDevices));
   if (numDevices > 1) {
-    Memcpy3DAsync<float> memcpy3dAsync(width, height, depth,
-                                     hipChannelFormatKindFloat);
+    Memcpy3DAsync<float> memcpy3dAsync(width, height, depth, hipChannelFormatKindFloat);
     memcpy3dAsync.D2D_SameDeviceMem_StreamDiffDevice();
   } else {
     SUCCEED("skipping the testcases as numDevices < 2");
@@ -837,6 +788,6 @@ TEST_CASE("Unit_hipMemcpy3DAsync_Basic_Size_Test") {
 }
 
 /**
-* End doxygen group MemoryTest.
-* @}
-*/
+ * End doxygen group MemoryTest.
+ * @}
+ */
