@@ -21,14 +21,14 @@ THE SOFTWARE.
 #include <hip_test_checkers.hh>
 
 /**
-* @addtogroup hipMemcpyAtoHAsync hipMemcpyAtoHAsync
-* @{
-* @ingroup MemoryTest
-* `hipError_t hipMemcpyAtoHAsync(void* dstHost, hipArray_t srcArray,
-*                                size_t srcOffset, size_t ByteCount,
-*                                hipStream_t stream)` -
-* Copies from one 1D array to host memory.
-*/
+ * @addtogroup hipMemcpyAtoHAsync hipMemcpyAtoHAsync
+ * @{
+ * @ingroup MemoryTest
+ * `hipError_t hipMemcpyAtoHAsync(void* dstHost, hipArray_t srcArray,
+ *                                size_t srcOffset, size_t ByteCount,
+ *                                hipStream_t stream)` -
+ * Copies from one 1D array to host memory.
+ */
 
 /**
  * Test Description
@@ -52,16 +52,16 @@ TEST_CASE("Unit_hipMemcpyAtoHAsync_Basic") {
   int row, col;
   row = 1;
   col = GENERATE(3, 4, 100);
-  int *A_h = reinterpret_cast<int*>(malloc(sizeof(int) * row * col));
-  int *B_h = reinterpret_cast<int*>(malloc(sizeof(int) * row * col));
+  int* A_h = reinterpret_cast<int*>(malloc(sizeof(int) * row * col));
+  int* B_h = reinterpret_cast<int*>(malloc(sizeof(int) * row * col));
   for (int i = 0; i < (row * col); i++) {
     A_h[i] = i;
   }
   hipArray_t A_a;
   hipChannelFormatDesc desc = hipCreateChannelDesc<int>();
   HIP_CHECK(hipMallocArray(&A_a, &desc, col, row, hipArrayDefault));
-  HIP_CHECK(hipMemcpy2DToArray(A_a, 0, 0, A_h, col * sizeof(int),
-                               col * sizeof(int), row, hipMemcpyHostToDevice));
+  HIP_CHECK(hipMemcpy2DToArray(A_a, 0, 0, A_h, col * sizeof(int), col * sizeof(int), row,
+                               hipMemcpyHostToDevice));
   HIP_CHECK(hipMemcpyAtoHAsync(B_h, A_a, 0, sizeof(int) * col * row, 0));
   HIP_CHECK(hipStreamSynchronize(0));
   for (int i = 0; i < (row * col); i++) {
@@ -74,6 +74,6 @@ TEST_CASE("Unit_hipMemcpyAtoHAsync_Basic") {
 }
 
 /**
-* End doxygen group MemoryTest.
-* @}
-*/
+ * End doxygen group MemoryTest.
+ * @}
+ */
