@@ -40,9 +40,9 @@ This testfile verifies the following scenarios
 #include <hip_test_kernels.hh>
 #include <hip_test_checkers.hh>
 
-#include<vector>
-#include<thread>
-#include<chrono>
+#include <vector>
+#include <thread>
+#include <chrono>
 
 #define LEN 64
 #define SIZE LEN << 2
@@ -54,31 +54,29 @@ static const auto MaxGPUDevices{256};
 static constexpr unsigned blocksPerCU{6};  // to hide latency
 static constexpr unsigned threadsPerBlock{256};
 
-enum class ops
-{   TestwithOnestream,
-    TestwithTwoStream,
-    TestOnMultiGPUwithOneStream,
-    TestkindDtoH,
-    TestkindDtoD,
-    TestkindHtoH,
-    TestkindDefault,
-    TestkindDefaultForDtoD,
-    TestDtoDonSameDevice,
-    END_OF_LIST
+enum class ops {
+  TestwithOnestream,
+  TestwithTwoStream,
+  TestOnMultiGPUwithOneStream,
+  TestkindDtoH,
+  TestkindDtoD,
+  TestkindHtoH,
+  TestkindDefault,
+  TestkindDefaultForDtoD,
+  TestDtoDonSameDevice,
+  END_OF_LIST
 };
 
 struct joinable_thread : std::thread {
-    template <class... Xs>
-    explicit joinable_thread(Xs&&... xs) : std::thread(std::forward<Xs>(xs)...)
-    {} // NOLINT
+  template <class... Xs> explicit joinable_thread(Xs&&... xs)
+      : std::thread(std::forward<Xs>(xs)...) {}  // NOLINT
 
-    joinable_thread& operator=(joinable_thread&& other) = default;
-    joinable_thread(joinable_thread&& other)            = default;
+  joinable_thread& operator=(joinable_thread&& other) = default;
+  joinable_thread(joinable_thread&& other) = default;
 
-    ~joinable_thread() {
-        if (this->joinable())
-            this->join();
-    }
+  ~joinable_thread() {
+    if (this->joinable()) this->join();
+  }
 };
 
 void TestwithOnestream(void) {
@@ -92,13 +90,10 @@ void TestwithOnestream(void) {
   hipStream_t stream;
   HIP_CHECK(hipStreamCreate(&stream));
 
-  HIP_CHECK(hipMemcpyWithStream(A_d, A_h, Nbytes,
-                               hipMemcpyHostToDevice, stream));
-  HIP_CHECK(hipMemcpyWithStream(B_d, B_h, Nbytes,
-                               hipMemcpyHostToDevice, stream));
-  hipLaunchKernelGGL(HipTest::vectorADD, dim3(blocks), dim3(threadsPerBlock),
-                     0, stream, static_cast<const int*>(A_d),
-                     static_cast<const int*>(B_d), C_d, N);
+  HIP_CHECK(hipMemcpyWithStream(A_d, A_h, Nbytes, hipMemcpyHostToDevice, stream));
+  HIP_CHECK(hipMemcpyWithStream(B_d, B_h, Nbytes, hipMemcpyHostToDevice, stream));
+  hipLaunchKernelGGL(HipTest::vectorADD, dim3(blocks), dim3(threadsPerBlock), 0, stream,
+                     static_cast<const int*>(A_d), static_cast<const int*>(B_d), C_d, N);
   HIP_CHECK(hipGetLastError());
   HIP_CHECK(hipStreamSynchronize(stream));
   HIP_CHECK(hipMemcpy(C_h, C_d, Nbytes, hipMemcpyDeviceToHost));
@@ -116,37 +111,33 @@ void TestwithTwoStream(void) {
 
   unsigned blocks = HipTest::setNumBlocks(blocksPerCU, threadsPerBlock, N);
 
-  for (int i=0; i < NUM_STREAMS; ++i) {
-    HipTest::initArrays(&A_d[i], &B_d[i], &C_d[i],
-                        &A_h[i], &B_h[i], &C_h[i], N, false);
+  for (int i = 0; i < NUM_STREAMS; ++i) {
+    HipTest::initArrays(&A_d[i], &B_d[i], &C_d[i], &A_h[i], &B_h[i], &C_h[i], N, false);
   }
 
   hipStream_t stream[NUM_STREAMS];
-  for (int i=0; i < NUM_STREAMS; ++i) {
+  for (int i = 0; i < NUM_STREAMS; ++i) {
     HIP_CHECK(hipStreamCreate(&stream[i]));
   }
 
-  for (int i=0; i < NUM_STREAMS; ++i) {
-    HIP_CHECK(hipMemcpyWithStream(A_d[i], A_h[i], Nbytes,
-             hipMemcpyHostToDevice, stream[i]));
-    HIP_CHECK(hipMemcpyWithStream(B_d[i], B_h[i], Nbytes,
-             hipMemcpyHostToDevice, stream[i]));
+  for (int i = 0; i < NUM_STREAMS; ++i) {
+    HIP_CHECK(hipMemcpyWithStream(A_d[i], A_h[i], Nbytes, hipMemcpyHostToDevice, stream[i]));
+    HIP_CHECK(hipMemcpyWithStream(B_d[i], B_h[i], Nbytes, hipMemcpyHostToDevice, stream[i]));
   }
 
-  for (int i=0; i < NUM_STREAMS; ++i) {
-    hipLaunchKernelGGL(HipTest::vectorADD, dim3(blocks), dim3(threadsPerBlock),
-                       0, stream[i], static_cast<const int*>(A_d[i]),
-                       static_cast<const int*>(B_d[i]), C_d[i], N);
+  for (int i = 0; i < NUM_STREAMS; ++i) {
+    hipLaunchKernelGGL(HipTest::vectorADD, dim3(blocks), dim3(threadsPerBlock), 0, stream[i],
+                       static_cast<const int*>(A_d[i]), static_cast<const int*>(B_d[i]), C_d[i], N);
     HIP_CHECK(hipGetLastError());
   }
 
-  for (int i=0; i < NUM_STREAMS; ++i) {
+  for (int i = 0; i < NUM_STREAMS; ++i) {
     HIP_CHECK(hipStreamSynchronize(stream[i]));
     HIP_CHECK(hipMemcpy(C_h[i], C_d[i], Nbytes, hipMemcpyDeviceToHost));
     HipTest::checkVectorADD(A_h[i], B_h[i], C_h[i], N);
   }
 
-  for (int i=0; i < NUM_STREAMS; ++i) {
+  for (int i = 0; i < NUM_STREAMS; ++i) {
     HipTest::freeArrays(A_d[i], B_d[i], C_d[i], A_h[i], B_h[i], C_h[i], false);
     HIP_CHECK(hipStreamDestroy(stream[i]));
   }
@@ -160,12 +151,11 @@ void TestDtoDonSameDevice(void) {
 
   unsigned blocks = HipTest::setNumBlocks(blocksPerCU, threadsPerBlock, N);
 
-  HipTest::initArrays(&A_d[0], &B_d[0], &C_d[0],
-                      &A_h[0], &B_h[0], &C_h[0], N, false);
+  HipTest::initArrays(&A_d[0], &B_d[0], &C_d[0], &A_h[0], &B_h[0], &C_h[0], N, false);
 
 
   hipStream_t stream[NUM_STREAMS];
-  for (int i=0; i < NUM_STREAMS; ++i) {
+  for (int i = 0; i < NUM_STREAMS; ++i) {
     HIP_CHECK(hipSetDevice(0));
     HIP_CHECK(hipStreamCreate(&stream[i]));
   }
@@ -177,26 +167,21 @@ void TestDtoDonSameDevice(void) {
   C_h[1] = reinterpret_cast<int*>(malloc(Nbytes));
   HIP_ASSERT(C_h[1] != NULL);
 
-  HIP_CHECK(hipMemcpyWithStream(A_d[0], A_h[0], Nbytes,
-                               hipMemcpyHostToDevice, stream[0]));
-  HIP_CHECK(hipMemcpyWithStream(B_d[0], B_h[0], Nbytes,
-                               hipMemcpyHostToDevice, stream[0]));
+  HIP_CHECK(hipMemcpyWithStream(A_d[0], A_h[0], Nbytes, hipMemcpyHostToDevice, stream[0]));
+  HIP_CHECK(hipMemcpyWithStream(B_d[0], B_h[0], Nbytes, hipMemcpyHostToDevice, stream[0]));
 
-  HIP_CHECK(hipMemcpyWithStream(A_d[1], A_d[0], Nbytes,
-                               hipMemcpyDeviceToDevice, stream[1]));
-  HIP_CHECK(hipMemcpyWithStream(B_d[1], B_d[0], Nbytes,
-                               hipMemcpyDeviceToDevice, stream[1]));
+  HIP_CHECK(hipMemcpyWithStream(A_d[1], A_d[0], Nbytes, hipMemcpyDeviceToDevice, stream[1]));
+  HIP_CHECK(hipMemcpyWithStream(B_d[1], B_d[0], Nbytes, hipMemcpyDeviceToDevice, stream[1]));
 
 
-  for (int i=0; i < NUM_STREAMS; ++i) {
+  for (int i = 0; i < NUM_STREAMS; ++i) {
     HIP_CHECK(hipSetDevice(0));
-    hipLaunchKernelGGL(HipTest::vectorADD, dim3(blocks), dim3(threadsPerBlock),
-                       0, stream[i], static_cast<const int*>(A_d[i]),
-                       static_cast<const int*>(B_d[i]), C_d[i], N);
+    hipLaunchKernelGGL(HipTest::vectorADD, dim3(blocks), dim3(threadsPerBlock), 0, stream[i],
+                       static_cast<const int*>(A_d[i]), static_cast<const int*>(B_d[i]), C_d[i], N);
     HIP_CHECK(hipGetLastError());
   }
 
-  for (int i=0; i < NUM_STREAMS; ++i) {
+  for (int i = 0; i < NUM_STREAMS; ++i) {
     HIP_CHECK(hipSetDevice(0));
     HIP_CHECK(hipStreamSynchronize(stream[i]));
     HIP_CHECK(hipMemcpy(C_h[i], C_d[i], Nbytes, hipMemcpyDeviceToHost));
@@ -220,7 +205,7 @@ void TestDtoDonSameDevice(void) {
   }
 
 
-  for (int i=0; i < NUM_STREAMS; ++i) {
+  for (int i = 0; i < NUM_STREAMS; ++i) {
     HIP_CHECK(hipStreamDestroy(stream[i]));
   }
 }
@@ -239,46 +224,41 @@ void TestOnMultiGPUwithOneStream(void) {
     int *A_h[MaxGPUDevices], *B_h[MaxGPUDevices], *C_h[MaxGPUDevices];
 
     hipStream_t stream[MaxGPUDevices];
-    for (int i=0; i < NumDevices; ++i) {
+    for (int i = 0; i < NumDevices; ++i) {
       HIP_CHECK(hipSetDevice(i));
       HIP_CHECK(hipStreamCreate(&stream[i]));
     }
 
-    for (int i=0; i < NumDevices; ++i) {
+    for (int i = 0; i < NumDevices; ++i) {
       HIP_CHECK(hipSetDevice(i));
-      HipTest::initArrays(&A_d[i], &B_d[i], &C_d[i],
-                          &A_h[i], &B_h[i], &C_h[i], N, false);
+      HipTest::initArrays(&A_d[i], &B_d[i], &C_d[i], &A_h[i], &B_h[i], &C_h[i], N, false);
     }
 
 
-    for (int i=0; i < NumDevices; ++i) {
+    for (int i = 0; i < NumDevices; ++i) {
       HIP_CHECK(hipSetDevice(i));
-      HIP_CHECK(hipMemcpyWithStream(A_d[i], A_h[i], Nbytes,
-            hipMemcpyHostToDevice, stream[i]));
-      HIP_CHECK(hipMemcpyWithStream(B_d[i], B_h[i], Nbytes,
-            hipMemcpyHostToDevice, stream[i]));
+      HIP_CHECK(hipMemcpyWithStream(A_d[i], A_h[i], Nbytes, hipMemcpyHostToDevice, stream[i]));
+      HIP_CHECK(hipMemcpyWithStream(B_d[i], B_h[i], Nbytes, hipMemcpyHostToDevice, stream[i]));
     }
 
-    for (int i=0; i < NumDevices; ++i) {
+    for (int i = 0; i < NumDevices; ++i) {
       HIP_CHECK(hipSetDevice(i));
-      hipLaunchKernelGGL(HipTest::vectorADD, dim3(blocks),
-                         dim3(threadsPerBlock), 0, stream[i],
-                         static_cast<const int*>(A_d[i]),
-                         static_cast<const int*>(B_d[i]), C_d[i], N);
+      hipLaunchKernelGGL(HipTest::vectorADD, dim3(blocks), dim3(threadsPerBlock), 0, stream[i],
+                         static_cast<const int*>(A_d[i]), static_cast<const int*>(B_d[i]), C_d[i],
+                         N);
       HIP_CHECK(hipGetLastError());
     }
 
-    for (int i=0; i < NumDevices; ++i) {
+    for (int i = 0; i < NumDevices; ++i) {
       HIP_CHECK(hipSetDevice(i));
       HIP_CHECK(hipStreamSynchronize(stream[i]));
       HIP_CHECK(hipMemcpy(C_h[i], C_d[i], Nbytes, hipMemcpyDeviceToHost));
       HipTest::checkVectorADD(A_h[i], B_h[i], C_h[i], N);
     }
 
-    for (int i=0; i < NumDevices; ++i) {
+    for (int i = 0; i < NumDevices; ++i) {
       HIP_CHECK(hipSetDevice(i));
-      HipTest::freeArrays(A_d[i], B_d[i], C_d[i],
-                          A_h[i], B_h[i], C_h[i], false);
+      HipTest::freeArrays(A_d[i], B_d[i], C_d[i], A_h[i], B_h[i], C_h[i], false);
       HIP_CHECK(hipStreamDestroy(stream[i]));
     }
   }
@@ -295,17 +275,13 @@ void TestkindDtoH(void) {
   hipStream_t stream;
   HIP_CHECK(hipStreamCreate(&stream));
 
-  HIP_CHECK(hipMemcpyWithStream(A_d, A_h, Nbytes,
-                               hipMemcpyHostToDevice, stream));
-  HIP_CHECK(hipMemcpyWithStream(B_d, B_h, Nbytes,
-                               hipMemcpyHostToDevice, stream));
-  hipLaunchKernelGGL(HipTest::vectorADD, dim3(blocks), dim3(threadsPerBlock),
-                     0, stream, static_cast<const int*>(A_d),
-                     static_cast<const int*>(B_d), C_d, N);
+  HIP_CHECK(hipMemcpyWithStream(A_d, A_h, Nbytes, hipMemcpyHostToDevice, stream));
+  HIP_CHECK(hipMemcpyWithStream(B_d, B_h, Nbytes, hipMemcpyHostToDevice, stream));
+  hipLaunchKernelGGL(HipTest::vectorADD, dim3(blocks), dim3(threadsPerBlock), 0, stream,
+                     static_cast<const int*>(A_d), static_cast<const int*>(B_d), C_d, N);
   HIP_CHECK(hipGetLastError());
   HIP_CHECK(hipStreamSynchronize(stream));
-  HIP_CHECK(hipMemcpyWithStream(C_h, C_d, Nbytes,
-                               hipMemcpyDeviceToHost, stream));
+  HIP_CHECK(hipMemcpyWithStream(C_h, C_d, Nbytes, hipMemcpyDeviceToHost, stream));
   HipTest::checkVectorADD(A_h, B_h, C_h, N);
 
   HipTest::freeArrays(A_d, B_d, C_d, A_h, B_h, C_h, false);
@@ -326,19 +302,18 @@ void TestkindDtoD(void) {
     int *A_h[MaxGPUDevices], *B_h[MaxGPUDevices], *C_h[MaxGPUDevices];
 
     hipStream_t stream[MaxGPUDevices];
-    for (int i=0; i < NumDevices; ++i) {
+    for (int i = 0; i < NumDevices; ++i) {
       HIP_CHECK(hipSetDevice(i));
       HIP_CHECK(hipStreamCreate(&stream[i]));
     }
 
     // Initialize and create the host and device elements for first device
     HIP_CHECK(hipSetDevice(0));
-    HipTest::initArrays(&A_d[0], &B_d[0], &C_d[0],
-        &A_h[0], &B_h[0], &C_h[0], N, false);
+    HipTest::initArrays(&A_d[0], &B_d[0], &C_d[0], &A_h[0], &B_h[0], &C_h[0], N, false);
 
-    for (int i=1; i < NumDevices; ++i) {
+    for (int i = 1; i < NumDevices; ++i) {
       HIP_CHECK(hipSetDevice(i))
-        HIP_CHECK(hipMalloc(&A_d[i], Nbytes));
+      HIP_CHECK(hipMalloc(&A_d[i], Nbytes));
       HIP_CHECK(hipMalloc(&B_d[i], Nbytes));
       HIP_CHECK(hipMalloc(&C_d[i], Nbytes));
       C_h[i] = reinterpret_cast<int*>(malloc(Nbytes));
@@ -346,34 +321,29 @@ void TestkindDtoD(void) {
     }
 
     HIP_CHECK(hipSetDevice(0));
-    HIP_CHECK(hipMemcpyWithStream(A_d[0], A_h[0], Nbytes,
-          hipMemcpyHostToDevice, stream[0]));
-    HIP_CHECK(hipMemcpyWithStream(B_d[0], B_h[0], Nbytes,
-          hipMemcpyHostToDevice, stream[0]));
+    HIP_CHECK(hipMemcpyWithStream(A_d[0], A_h[0], Nbytes, hipMemcpyHostToDevice, stream[0]));
+    HIP_CHECK(hipMemcpyWithStream(B_d[0], B_h[0], Nbytes, hipMemcpyHostToDevice, stream[0]));
 
     // Copying device data from 1st GPU to the rest of the the GPUs that is
     // NumDevices in the setup. 1st GPU start numbering from 0,1,2..n etc.
-    for (int i=1; i < NumDevices; ++i) {
+    for (int i = 1; i < NumDevices; ++i) {
       HIP_CHECK(hipSetDevice(i));
-      HIP_CHECK(hipMemcpyWithStream(A_d[i], A_d[0], Nbytes,
-            hipMemcpyDeviceToDevice, stream[i]));
-      HIP_CHECK(hipMemcpyWithStream(B_d[i], B_d[0], Nbytes,
-            hipMemcpyDeviceToDevice, stream[i]));
+      HIP_CHECK(hipMemcpyWithStream(A_d[i], A_d[0], Nbytes, hipMemcpyDeviceToDevice, stream[i]));
+      HIP_CHECK(hipMemcpyWithStream(B_d[i], B_d[0], Nbytes, hipMemcpyDeviceToDevice, stream[i]));
     }
 
 
     // Launching the kernel including the 1st GPU to the no of GPUs present
     // in the setup. 1st GPU start numbering from 0,1,2..n etc.
-    for (int i=0; i < NumDevices; ++i) {
+    for (int i = 0; i < NumDevices; ++i) {
       HIP_CHECK(hipSetDevice(i));
-      hipLaunchKernelGGL(HipTest::vectorADD, dim3(blocks),
-                         dim3(threadsPerBlock),
-                         0, stream[i], static_cast<const int*>(A_d[i]),
-                         static_cast<const int*>(B_d[i]), C_d[i], N);
+      hipLaunchKernelGGL(HipTest::vectorADD, dim3(blocks), dim3(threadsPerBlock), 0, stream[i],
+                         static_cast<const int*>(A_d[i]), static_cast<const int*>(B_d[i]), C_d[i],
+                         N);
       HIP_CHECK(hipGetLastError());
     }
 
-    for (int i=0; i < NumDevices; ++i) {
+    for (int i = 0; i < NumDevices; ++i) {
       HIP_CHECK(hipSetDevice(i));
       HIP_CHECK(hipStreamSynchronize(stream[i]));
       HIP_CHECK(hipMemcpy(C_h[i], C_d[i], Nbytes, hipMemcpyDeviceToHost));
@@ -383,7 +353,7 @@ void TestkindDtoD(void) {
     HipTest::freeArrays(A_d[0], B_d[0], C_d[0], A_h[0], B_h[0], C_h[0], false);
     HIP_CHECK(hipStreamDestroy(stream[0]));
 
-    for (int i=1; i < NumDevices; ++i) {
+    for (int i = 1; i < NumDevices; ++i) {
       if (A_d[i]) {
         HIP_CHECK(hipFree(A_d[i]));
       }
@@ -414,9 +384,8 @@ void TestkindDefault(void) {
 
   HIP_CHECK(hipMemcpyWithStream(A_d, A_h, Nbytes, hipMemcpyDefault, stream));
   HIP_CHECK(hipMemcpyWithStream(B_d, B_h, Nbytes, hipMemcpyDefault, stream));
-  hipLaunchKernelGGL(HipTest::vectorADD, dim3(blocks), dim3(threadsPerBlock),
-                     0, stream, static_cast<const int*>(A_d),
-                     static_cast<const int*>(B_d), C_d, N);
+  hipLaunchKernelGGL(HipTest::vectorADD, dim3(blocks), dim3(threadsPerBlock), 0, stream,
+                     static_cast<const int*>(A_d), static_cast<const int*>(B_d), C_d, N);
   HIP_CHECK(hipGetLastError());
   HIP_CHECK(hipStreamSynchronize(stream));
   HIP_CHECK(hipMemcpyWithStream(C_h, C_d, Nbytes, hipMemcpyDefault, stream));
@@ -441,10 +410,9 @@ void TestkindDefaultForDtoD(void) {
 
     // Initialize and create the host and device elements for first device
     HIP_CHECK(hipSetDevice(0));
-    HipTest::initArrays(&A_d[0], &B_d[0], &C_d[0],
-        &A_h[0], &B_h[0], &C_h[0], N, false);
+    HipTest::initArrays(&A_d[0], &B_d[0], &C_d[0], &A_h[0], &B_h[0], &C_h[0], N, false);
 
-    for (int i=1; i < NumDevices; ++i) {
+    for (int i = 1; i < NumDevices; ++i) {
       HIP_CHECK(hipSetDevice(i));
       HIP_CHECK(hipMalloc(&A_d[i], Nbytes));
       HIP_CHECK(hipMalloc(&B_d[i], Nbytes));
@@ -454,35 +422,31 @@ void TestkindDefaultForDtoD(void) {
     }
 
     hipStream_t stream[MaxGPUDevices];
-    for (int i=0; i < NumDevices; ++i) {
+    for (int i = 0; i < NumDevices; ++i) {
       HIP_CHECK(hipSetDevice(i));
       HIP_CHECK(hipStreamCreate(&stream[i]));
     }
 
-    HIP_CHECK(hipMemcpyWithStream(A_d[0], A_h[0], Nbytes,
-          hipMemcpyHostToDevice, stream[0]));
-    HIP_CHECK(hipMemcpyWithStream(B_d[0], B_h[0], Nbytes,
-          hipMemcpyHostToDevice, stream[0]));
+    HIP_CHECK(hipMemcpyWithStream(A_d[0], A_h[0], Nbytes, hipMemcpyHostToDevice, stream[0]));
+    HIP_CHECK(hipMemcpyWithStream(B_d[0], B_h[0], Nbytes, hipMemcpyHostToDevice, stream[0]));
 
     // Copying device data from 1st GPU to the rest of the the GPUs
     // using hipMemcpyDefault kind  that is NumDevices in the setup.
     // 1st GPU start numbering from 0,1,2..n etc.
-    for (int i=1; i < NumDevices; ++i) {
-      HIP_CHECK(hipMemcpyWithStream(A_d[i], A_d[0], Nbytes,
-            hipMemcpyDefault, stream[i]));
-      HIP_CHECK(hipMemcpyWithStream(B_d[i], B_d[0], Nbytes,
-            hipMemcpyDefault, stream[i]));
+    for (int i = 1; i < NumDevices; ++i) {
+      HIP_CHECK(hipMemcpyWithStream(A_d[i], A_d[0], Nbytes, hipMemcpyDefault, stream[i]));
+      HIP_CHECK(hipMemcpyWithStream(B_d[i], B_d[0], Nbytes, hipMemcpyDefault, stream[i]));
     }
 
-    for (int i=0; i < NumDevices; ++i) {
-      hipLaunchKernelGGL(HipTest::vectorADD, dim3(blocks),
-                         dim3(threadsPerBlock),
-                         0, stream[i], static_cast<const int*>(A_d[i]),
-                         static_cast<const int*>(B_d[i]), C_d[i], N);
+    for (int i = 0; i < NumDevices; ++i) {
+      HIP_CHECK(hipSetDevice(i));
+      hipLaunchKernelGGL(HipTest::vectorADD, dim3(blocks), dim3(threadsPerBlock), 0, stream[i],
+                         static_cast<const int*>(A_d[i]), static_cast<const int*>(B_d[i]), C_d[i],
+                         N);
       HIP_CHECK(hipGetLastError());
     }
 
-    for (int i=0; i < NumDevices; ++i) {
+    for (int i = 0; i < NumDevices; ++i) {
       HIP_CHECK(hipSetDevice(i));  // hipMemcpy will be on this device
       HIP_CHECK(hipStreamSynchronize(stream[i]));
       HIP_CHECK(hipMemcpy(C_h[i], C_d[i], Nbytes, hipMemcpyDeviceToHost));
@@ -493,7 +457,7 @@ void TestkindDefaultForDtoD(void) {
     HipTest::freeArrays(A_d[0], B_d[0], C_d[0], A_h[0], B_h[0], C_h[0], false);
     HIP_CHECK(hipStreamDestroy(stream[0]));
 
-    for (int i=1; i < NumDevices; ++i) {
+    for (int i = 1; i < NumDevices; ++i) {
       if (A_d[i]) {
         HIP_CHECK(hipFree(A_d[i]));
       }
@@ -548,39 +512,21 @@ void TestkindHtoH(void) {
 }
 
 
-TEST_CASE("Unit_hipMemcpyWithStream_TestWithOneStream") {
-  TestwithOnestream();
-}
+TEST_CASE("Unit_hipMemcpyWithStream_TestWithOneStream") { TestwithOnestream(); }
 
-TEST_CASE("Unit_hipMemcpyWithStream_TestwithTwoStream") {
-  TestwithTwoStream();
-}
+TEST_CASE("Unit_hipMemcpyWithStream_TestwithTwoStream") { TestwithTwoStream(); }
 
-TEST_CASE("Unit_hipMemcpyWithStream_TestkindDtoH") {
-  TestkindDtoH();
-}
+TEST_CASE("Unit_hipMemcpyWithStream_TestkindDtoH") { TestkindDtoH(); }
 
-TEST_CASE("Unit_hipMemcpyWithStream_TestkindHtoH") {
-  TestkindHtoH();
-}
+TEST_CASE("Unit_hipMemcpyWithStream_TestkindHtoH") { TestkindHtoH(); }
 
-TEST_CASE("Unit_hipMemcpyWithStream_TestkindDtoD") {
-  TestkindDtoD();
-}
+TEST_CASE("Unit_hipMemcpyWithStream_TestkindDtoD") { TestkindDtoD(); }
 
-TEST_CASE("Unit_hipMemcpyWithStream_TestOnMultiGPUwithOneStream") {
-  TestOnMultiGPUwithOneStream();
-}
+TEST_CASE("Unit_hipMemcpyWithStream_TestOnMultiGPUwithOneStream") { TestOnMultiGPUwithOneStream(); }
 
-TEST_CASE("Unit_hipMemcpyWithStream_TestkindDefault") {
-  TestkindDefault();
-}
+TEST_CASE("Unit_hipMemcpyWithStream_TestkindDefault") { TestkindDefault(); }
 #ifndef __HIP_PLATFORM_NVIDIA__
-TEST_CASE("Unit_hipMemcpyWithStream_TestkindDefaultForDtoD") {
-  TestkindDefaultForDtoD();
-}
+TEST_CASE("Unit_hipMemcpyWithStream_TestkindDefaultForDtoD") { TestkindDefaultForDtoD(); }
 #endif
 
-TEST_CASE("Unit_hipMemcpyWithStream_TestDtoDonSameDevice") {
-  TestDtoDonSameDevice();
-}
+TEST_CASE("Unit_hipMemcpyWithStream_TestDtoDonSameDevice") { TestDtoDonSameDevice(); }
