@@ -92,15 +92,15 @@ Testcase Scenarios :
 static void testMemsetWithExtent(bool bAsync, hipExtent tstExtent) {
   hipPitchedPtr devPitchedPtr;
   hipError_t ret;
-  char *A_h;
+  char* A_h;
   size_t numH = NUMH_EXT, numW = NUMW_EXT, depth = DEPTH_EXT;
   size_t width = numW * sizeof(char);
   hipExtent extent = make_hipExtent(width, numH, depth);
 
   size_t sizeElements = width * numH * depth;
-  size_t elements = numW* numH* depth;
+  size_t elements = numW * numH * depth;
 
-  A_h = reinterpret_cast<char *>(malloc(sizeElements));
+  A_h = reinterpret_cast<char*>(malloc(sizeElements));
   REQUIRE(A_h != nullptr);
   memset(A_h, 0, sizeElements);
   HIP_CHECK(hipMalloc3D(&devPitchedPtr, extent));
@@ -109,30 +109,26 @@ static void testMemsetWithExtent(bool bAsync, hipExtent tstExtent) {
     HIP_CHECK(hipStreamCreate(&stream));
 
     ret = hipMemset3DAsync(devPitchedPtr, MEMSETVAL, extent, stream);
-    INFO("testMemsetWithExtent(" << extent.width << "," << extent.height
-                                 << "," << extent.depth << ") memset "
-                                 << MEMSETVAL << ", ret : " << ret);
+    INFO("testMemsetWithExtent(" << extent.width << "," << extent.height << "," << extent.depth
+                                 << ") memset " << MEMSETVAL << ", ret : " << ret);
     REQUIRE(ret == hipSuccess);
 
     ret = hipMemset3DAsync(devPitchedPtr, TESTVAL, tstExtent, stream);
-    INFO("testMemsetWithExtent(" << tstExtent.width << "," << tstExtent.height
-                                 << "," << tstExtent.depth << ") memset "
-                                 << TESTVAL << "ret : " << ret);
+    INFO("testMemsetWithExtent(" << tstExtent.width << "," << tstExtent.height << ","
+                                 << tstExtent.depth << ") memset " << TESTVAL << "ret : " << ret);
     REQUIRE(ret == hipSuccess);
 
     HIP_CHECK(hipStreamSynchronize(stream));
     HIP_CHECK(hipStreamDestroy(stream));
   } else {
     ret = hipMemset3D(devPitchedPtr, MEMSETVAL, extent);
-    INFO("testMemsetWithExtent(" << extent.width << "," << extent.height
-                                 << "," << extent.depth << ") memset "
-                                 << MEMSETVAL << ",ret : " << ret);
+    INFO("testMemsetWithExtent(" << extent.width << "," << extent.height << "," << extent.depth
+                                 << ") memset " << MEMSETVAL << ",ret : " << ret);
     REQUIRE(ret == hipSuccess);
 
     ret = hipMemset3D(devPitchedPtr, TESTVAL, tstExtent);
-    INFO("testMemsetWithExtent(" << tstExtent.width << "," << tstExtent.height
-                                 << "," << tstExtent.depth << ") memset "
-                                 << TESTVAL << ",ret : " << ret);
+    INFO("testMemsetWithExtent(" << tstExtent.width << "," << tstExtent.height << ","
+                                 << tstExtent.depth << ") memset " << TESTVAL << ",ret : " << ret);
     REQUIRE(ret == hipSuccess);
   }
 
@@ -153,9 +149,9 @@ static void testMemsetWithExtent(bool bAsync, hipExtent tstExtent) {
 
   for (size_t i = 0; i < elements; i++) {
     if (A_h[i] != MEMSETVAL) {
-      INFO("testMemsetWithExtent: index:" << i << ",computed:"
-               << std::hex << static_cast<int>(A_h[i]) << ",memsetval:"
-                                            << std::hex << MEMSETVAL);
+      INFO("testMemsetWithExtent: index:" << i << ",computed:" << std::hex
+                                          << static_cast<int>(A_h[i]) << ",memsetval:" << std::hex
+                                          << MEMSETVAL);
       REQUIRE(false);
     }
   }
@@ -170,15 +166,15 @@ static void testMemsetWithExtent(bool bAsync, hipExtent tstExtent) {
  */
 static void testMemsetMaxValue(bool bAsync) {
   hipPitchedPtr devPitchedPtr;
-  unsigned char *A_h;
+  unsigned char* A_h;
   int memsetval = std::numeric_limits<unsigned char>::max();
   size_t numH = NUMH_MAX, numW = NUMW_MAX, depth = DEPTH_MAX;
   size_t width = numW * sizeof(unsigned char);
   hipExtent extent = make_hipExtent(width, numH, depth);
   size_t sizeElements = width * numH * depth;
-  size_t elements = numW* numH* depth;
+  size_t elements = numW * numH * depth;
 
-  A_h = reinterpret_cast<unsigned char *> (malloc(sizeElements));
+  A_h = reinterpret_cast<unsigned char*>(malloc(sizeElements));
   REQUIRE(A_h != nullptr);
   memset(A_h, 0, sizeElements);
 
@@ -215,9 +211,8 @@ static void testMemsetMaxValue(bool bAsync) {
 
   for (size_t i = 0; i < elements; i++) {
     if (A_h[i] != memsetval) {
-      INFO("testMemsetMaxValue: index:" << i << ",computed:"
-               << std::hex << static_cast<int>(A_h[i]) << ",memsetval:"
-                                            << std::hex << memsetval);
+      INFO("testMemsetMaxValue: index:" << i << ",computed:" << std::hex << static_cast<int>(A_h[i])
+                                        << ",memsetval:" << std::hex << memsetval);
       REQUIRE(false);
     }
   }
@@ -232,8 +227,8 @@ static void testMemsetMaxValue(bool bAsync) {
 static void seekAndSet3DArraySlice(bool bAsync) {
   char array3D[ZSIZE_S][YSIZE_S][XSIZE_S]{};
   dim3 arr_dimensions = dim3(ZSIZE_S, YSIZE_S, XSIZE_S);
-  hipExtent extent = make_hipExtent(sizeof(char) * arr_dimensions.x,
-                                    arr_dimensions.y, arr_dimensions.z);
+  hipExtent extent =
+      make_hipExtent(sizeof(char) * arr_dimensions.x, arr_dimensions.y, arr_dimensions.z);
   hipPitchedPtr devicePitchedPointer;
   int memsetval = MEMSETVAL, memsetval4seeked = TESTVAL;
 
@@ -251,19 +246,17 @@ static void seekAndSet3DArraySlice(bool bAsync) {
   size_t slicePitch = pitch * extent.height;
 
   // Point devptr to selected slice
-  char *devPtrSlice = (reinterpret_cast<char *>(devicePitchedPointer.ptr))
-                       + slice_index * slicePitch;
-  hipExtent extentSlice = make_hipExtent(sizeof(char) * arr_dimensions.x,
-                                         arr_dimensions.y, 1);
-  hipPitchedPtr modDevPitchedPtr = make_hipPitchedPtr(devPtrSlice, pitch,
-                                         arr_dimensions.x, arr_dimensions.y);
+  char* devPtrSlice =
+      (reinterpret_cast<char*>(devicePitchedPointer.ptr)) + slice_index * slicePitch;
+  hipExtent extentSlice = make_hipExtent(sizeof(char) * arr_dimensions.x, arr_dimensions.y, 1);
+  hipPitchedPtr modDevPitchedPtr =
+      make_hipPitchedPtr(devPtrSlice, pitch, arr_dimensions.x, arr_dimensions.y);
 
   if (bAsync) {
     // Memset selected slice (Async)
     hipStream_t stream;
     HIP_CHECK(hipStreamCreate(&stream));
-    HIP_CHECK(hipMemset3DAsync(modDevPitchedPtr, memsetval4seeked,
-                              extentSlice, stream));
+    HIP_CHECK(hipMemset3DAsync(modDevPitchedPtr, memsetval4seeked, extentSlice, stream));
     HIP_CHECK(hipStreamSynchronize(stream));
     HIP_CHECK(hipStreamDestroy(stream));
   } else {
@@ -275,8 +268,8 @@ static void seekAndSet3DArraySlice(bool bAsync) {
   hipMemcpy3DParms myparms{};
   myparms.srcPos = make_hipPos(0, 0, 0);
   myparms.dstPos = make_hipPos(0, 0, 0);
-  myparms.dstPtr = make_hipPitchedPtr(array3D, sizeof(char) * arr_dimensions.x,
-                                      arr_dimensions.x, arr_dimensions.y);
+  myparms.dstPtr = make_hipPitchedPtr(array3D, sizeof(char) * arr_dimensions.x, arr_dimensions.x,
+                                      arr_dimensions.y);
   myparms.srcPtr = devicePitchedPointer;
   myparms.extent = extent;
 #if HT_NVIDIA
@@ -292,18 +285,16 @@ static void seekAndSet3DArraySlice(bool bAsync) {
       for (int x = 0; x < XSIZE_S; x++) {
         if (z == slice_index) {
           if (array3D[z][y][x] != memsetval4seeked) {
-            INFO("seekAndSet3DArray Slice: mismatch at index: Arr(" << z
-                   << "," << y << "," << x << ") " << "computed:" << std::hex
-                   << array3D[z][y][x] << ", memsetval:" << std::hex
-                   << memsetval4seeked);
+            INFO("seekAndSet3DArray Slice: mismatch at index: Arr("
+                 << z << "," << y << "," << x << ") " << "computed:" << std::hex << array3D[z][y][x]
+                 << ", memsetval:" << std::hex << memsetval4seeked);
             REQUIRE(false);
           }
         } else {
           if (array3D[z][y][x] != memsetval) {
-            INFO("seekAndSet3DArray Slice: mismatch at index: Arr(" << z
-                   << "," << y << "," << x << ") " << "computed:" << std::hex
-                   << array3D[z][y][x] << ", memsetval:" << std::hex
-                   << memsetval);
+            INFO("seekAndSet3DArray Slice: mismatch at index: Arr("
+                 << z << "," << y << "," << x << ") " << "computed:" << std::hex << array3D[z][y][x]
+                 << ", memsetval:" << std::hex << memsetval);
             REQUIRE(false);
           }
         }
@@ -321,8 +312,8 @@ static void seekAndSet3DArraySlice(bool bAsync) {
 static void seekAndSet3DArrayPortion(bool bAsync) {
   char array3D[ZSIZE_P][YSIZE_P][XSIZE_P]{};
   dim3 arr_dimensions = dim3(ZSIZE_P, YSIZE_P, XSIZE_P);
-  hipExtent extent = make_hipExtent(sizeof(char) * arr_dimensions.x,
-                                    arr_dimensions.y, arr_dimensions.z);
+  hipExtent extent =
+      make_hipExtent(sizeof(char) * arr_dimensions.x, arr_dimensions.y, arr_dimensions.z);
   hipPitchedPtr devicePitchedPointer;
   int memsetval = MEMSETVAL, memsetval4seeked = TESTVAL;
 
@@ -336,27 +327,25 @@ static void seekAndSet3DArrayPortion(bool bAsync) {
   int slice_index = ZPOS_START, y = YPOS_START, x = XPOS_START;
 
   // Select 10th slice
-  char *devPtrSlice = (reinterpret_cast<char *>(devicePitchedPointer.ptr))
-                       + slice_index * slicePitch;
+  char* devPtrSlice =
+      (reinterpret_cast<char*>(devicePitchedPointer.ptr)) + slice_index * slicePitch;
 
   // Now select row at height as 10
-  char *current_row = reinterpret_cast<char *>(devPtrSlice + y * pitch);
+  char* current_row = reinterpret_cast<char*>(devPtrSlice + y * pitch);
 
   // Now select index of selected row as 10
-  char *devPtrIndexed = &current_row[x];
+  char* devPtrIndexed = &current_row[x];
 
   // Make dev Pitchedptr, extent
-  hipPitchedPtr modDevPitchedPtr = make_hipPitchedPtr(devPtrIndexed, pitch,
-                                         arr_dimensions.x, arr_dimensions.y);
-  hipExtent setExtent = make_hipExtent(sizeof(char) * XSET_LEN, YSET_LEN,
-                                       ZSET_LEN);
+  hipPitchedPtr modDevPitchedPtr =
+      make_hipPitchedPtr(devPtrIndexed, pitch, arr_dimensions.x, arr_dimensions.y);
+  hipExtent setExtent = make_hipExtent(sizeof(char) * XSET_LEN, YSET_LEN, ZSET_LEN);
 
   if (bAsync) {
     // Memset selected portion (Async)
     hipStream_t stream;
     HIP_CHECK(hipStreamCreate(&stream));
-    HIP_CHECK(hipMemset3DAsync(modDevPitchedPtr, memsetval4seeked,
-                              setExtent, stream));
+    HIP_CHECK(hipMemset3DAsync(modDevPitchedPtr, memsetval4seeked, setExtent, stream));
     HIP_CHECK(hipStreamSynchronize(stream));
     HIP_CHECK(hipStreamDestroy(stream));
   } else {
@@ -368,8 +357,8 @@ static void seekAndSet3DArrayPortion(bool bAsync) {
   hipMemcpy3DParms myparms{};
   myparms.srcPos = make_hipPos(0, 0, 0);
   myparms.dstPos = make_hipPos(0, 0, 0);
-  myparms.dstPtr = make_hipPitchedPtr(array3D, sizeof(char) * arr_dimensions.x,
-                                      arr_dimensions.y, arr_dimensions.z);
+  myparms.dstPtr = make_hipPitchedPtr(array3D, sizeof(char) * arr_dimensions.x, arr_dimensions.y,
+                                      arr_dimensions.z);
   myparms.srcPtr = devicePitchedPointer;
   myparms.extent = extent;
 #if HT_NVIDIA
@@ -383,24 +372,21 @@ static void seekAndSet3DArrayPortion(bool bAsync) {
   for (int z = 0; z < ZSIZE_P; z++) {
     for (int y = 0; y < YSIZE_P; y++) {
       for (int x = 0; x < XSIZE_P; x++) {
-        if ((z >= ZPOS_START && z <= ZPOS_END) &&
-            (y >= YPOS_START && y <= YPOS_END) &&
+        if ((z >= ZPOS_START && z <= ZPOS_END) && (y >= YPOS_START && y <= YPOS_END) &&
             (x >= XPOS_START && x <= XPOS_END)) {
           if (array3D[z][y][x] != memsetval4seeked) {
-            INFO("seekAndSet3DArray Portion: mismatch at index: Arr(" << z
-                   << "," << y << "," << x << ") " << "computed:" << std::hex
-                   << array3D[z][y][x] << ", memsetval:" << std::hex
-                   << memsetval4seeked);
+            INFO("seekAndSet3DArray Portion: mismatch at index: Arr("
+                 << z << "," << y << "," << x << ") " << "computed:" << std::hex << array3D[z][y][x]
+                 << ", memsetval:" << std::hex << memsetval4seeked);
             REQUIRE(false);
           }
         } else {
-           if (array3D[z][y][x] != memsetval) {
-            INFO("seekAndSet3DArray Portion: mismatch at index: Arr(" << z
-                   << "," << y << "," << x << ") " << "computed:" << std::hex
-                   << array3D[z][y][x] << ", memsetval:" << std::hex
-                   << memsetval);
+          if (array3D[z][y][x] != memsetval) {
+            INFO("seekAndSet3DArray Portion: mismatch at index: Arr("
+                 << z << "," << y << "," << x << ") " << "computed:" << std::hex << array3D[z][y][x]
+                 << ", memsetval:" << std::hex << memsetval);
             REQUIRE(false);
-           }
+          }
         }
       }
     }
@@ -410,7 +396,6 @@ static void seekAndSet3DArrayPortion(bool bAsync) {
 }
 
 
-
 /**
  * Test Memset3D with different combinations of extent
  * taking zero and non-zero fields.
