@@ -61,16 +61,16 @@ static void init_input(float* a, size_t size) {
 }
 
 static bool gPassed = true;
-static void *gusrptr;
-static void *ptr0xff = reinterpret_cast<void *>(0xffffffff);
+static void* gusrptr;
+static void* ptr0xff = reinterpret_cast<void*>(0xffffffff);
 static size_t NSize = GRIDSIZE * BLOCKSIZE;
 static size_t Nbytes = NSize * sizeof(float);
 
 typedef struct userDataStruct {
-  float *A_h;
-  float *C_h;
-  float *A_d;
-  float *C_d;
+  float* A_h;
+  float* C_h;
+  float* A_d;
+  float* C_d;
   bool isPassed;
   bool isOpCompleted;
 } usrDataS;
@@ -78,10 +78,9 @@ typedef struct userDataStruct {
 // Common callback function.
 static void Fn_validateSq(void* userData) {
   REQUIRE(userData != nullptr);
-  usrDataS *ptrUsrData = reinterpret_cast<usrDataS *>(userData);
+  usrDataS* ptrUsrData = reinterpret_cast<usrDataS*>(userData);
   for (size_t i = 0; i < NSize; i++) {
-    if (ptrUsrData->C_h[i] !=
-       (ptrUsrData->A_h[i] * ptrUsrData->A_h[i])) {
+    if (ptrUsrData->C_h[i] != (ptrUsrData->A_h[i] * ptrUsrData->A_h[i])) {
       ptrUsrData->isPassed = false;
       return;
     }
@@ -121,25 +120,19 @@ TEST_CASE("Unit_hipLaunchHostFunc_Negative") {
 }
 
 // Local Function
-static void launchOperationOnStrm(usrDataS *usrDataptr, hipStream_t stream) {
+static void launchOperationOnStrm(usrDataS* usrDataptr, hipStream_t stream) {
   usrDataptr->isPassed = false;
-  HIP_CHECK(hipMallocAsync(reinterpret_cast<void**>(&(usrDataptr->A_d)),
-                            Nbytes, stream));
-  HIP_CHECK(hipMallocAsync(reinterpret_cast<void**>(&(usrDataptr->C_d)),
-                            Nbytes, stream));
-  HIP_CHECK(hipMemcpyAsync(usrDataptr->A_d, usrDataptr->A_h, Nbytes,
-                            hipMemcpyHostToDevice, stream));
-  hipLaunchKernelGGL((HipTest::vector_square), dim3(GRIDSIZE),
-                  dim3(BLOCKSIZE), 0, stream, usrDataptr->A_d,
-                  usrDataptr->C_d, NSize);
-  HIP_CHECK(hipMemcpyAsync(usrDataptr->C_h, usrDataptr->C_d, Nbytes,
-                            hipMemcpyDeviceToHost, stream));
-  HIP_CHECK(hipLaunchHostFunc(stream, Fn_validateSq,
-                            reinterpret_cast<void*>(usrDataptr)));
-  HIP_CHECK(hipFreeAsync(reinterpret_cast<void*>(usrDataptr->A_d),
-                           stream));
-  HIP_CHECK(hipFreeAsync(reinterpret_cast<void*>(usrDataptr->C_d),
-                           stream));
+  HIP_CHECK(hipMallocAsync(reinterpret_cast<void**>(&(usrDataptr->A_d)), Nbytes, stream));
+  HIP_CHECK(hipMallocAsync(reinterpret_cast<void**>(&(usrDataptr->C_d)), Nbytes, stream));
+  HIP_CHECK(
+      hipMemcpyAsync(usrDataptr->A_d, usrDataptr->A_h, Nbytes, hipMemcpyHostToDevice, stream));
+  hipLaunchKernelGGL((HipTest::vector_square), dim3(GRIDSIZE), dim3(BLOCKSIZE), 0, stream,
+                     usrDataptr->A_d, usrDataptr->C_d, NSize);
+  HIP_CHECK(
+      hipMemcpyAsync(usrDataptr->C_h, usrDataptr->C_d, Nbytes, hipMemcpyDeviceToHost, stream));
+  HIP_CHECK(hipLaunchHostFunc(stream, Fn_validateSq, reinterpret_cast<void*>(usrDataptr)));
+  HIP_CHECK(hipFreeAsync(reinterpret_cast<void*>(usrDataptr->A_d), stream));
+  HIP_CHECK(hipFreeAsync(reinterpret_cast<void*>(usrDataptr->C_d), stream));
   HIP_CHECK(hipStreamSynchronize(stream));
   REQUIRE(usrDataptr->isPassed);
 }
@@ -152,8 +145,7 @@ TEST_CASE("Unit_hipLaunchHostFunc_streams") {
   HIP_CHECK(hipStreamCreate(&stream[0]));
   stream[1] = 0;  // Null stream
   stream[2] = hipStreamPerThread;
-  usrDataS *usrDataptr = reinterpret_cast<usrDataS *>(
-                        malloc(sizeof(usrDataS)));
+  usrDataS* usrDataptr = reinterpret_cast<usrDataS*>(malloc(sizeof(usrDataS)));
   REQUIRE(usrDataptr != nullptr);
   usrDataptr->A_h = reinterpret_cast<float*>(malloc(Nbytes));
   REQUIRE(usrDataptr->A_h != nullptr);
@@ -176,10 +168,9 @@ TEST_CASE("Unit_hipLaunchHostFunc_streams") {
 // create 2 different streams and call hipLaunchHostFunc, stream synchronize.
 static void Fn_validateMul_stream(void* userData) {
   REQUIRE(userData != nullptr);
-  usrDataS *ptrUsrData = reinterpret_cast<usrDataS *>(userData);
+  usrDataS* ptrUsrData = reinterpret_cast<usrDataS*>(userData);
   for (size_t i = 0; i < NSize; i++) {
-    if (ptrUsrData->C_h[i] !=
-    (ptrUsrData->A_h[i] * ptrUsrData->A_h[i])) {
+    if (ptrUsrData->C_h[i] != (ptrUsrData->A_h[i] * ptrUsrData->A_h[i])) {
       ptrUsrData->isPassed = false;
       return;
     }
@@ -191,11 +182,9 @@ TEST_CASE("Unit_hipLaunchHostFunc_multistreams") {
   hipStream_t mystream1, mystream2;
   HIP_CHECK(hipStreamCreateWithFlags(&mystream1, hipStreamNonBlocking));
   HIP_CHECK(hipStreamCreateWithFlags(&mystream2, hipStreamNonBlocking));
-  usrDataS *usrDataptr1 = reinterpret_cast<usrDataS *>(
-                        malloc(sizeof(usrDataS)));
+  usrDataS* usrDataptr1 = reinterpret_cast<usrDataS*>(malloc(sizeof(usrDataS)));
   REQUIRE(usrDataptr1 != nullptr);
-  usrDataS *usrDataptr2 = reinterpret_cast<usrDataS *>(
-                        malloc(sizeof(usrDataS)));
+  usrDataS* usrDataptr2 = reinterpret_cast<usrDataS*>(malloc(sizeof(usrDataS)));
   REQUIRE(usrDataptr2 != nullptr);
   usrDataptr1->A_h = reinterpret_cast<float*>(malloc(Nbytes));
   REQUIRE(usrDataptr1->A_h != nullptr);
@@ -207,21 +196,18 @@ TEST_CASE("Unit_hipLaunchHostFunc_multistreams") {
   }
   usrDataptr1->isPassed = false;
   usrDataptr2->isPassed = false;
-  HIP_CHECK(hipMallocAsync(reinterpret_cast<void**>(&(usrDataptr1->A_d)),
-                            Nbytes, mystream1));
-  HIP_CHECK(hipMallocAsync(reinterpret_cast<void**>(&(usrDataptr1->C_d)),
-                            Nbytes, mystream1));
-  HIP_CHECK(hipMemcpyAsync(usrDataptr1->A_d, usrDataptr1->A_h, Nbytes,
-                            hipMemcpyHostToDevice, mystream1));
+  HIP_CHECK(hipMallocAsync(reinterpret_cast<void**>(&(usrDataptr1->A_d)), Nbytes, mystream1));
+  HIP_CHECK(hipMallocAsync(reinterpret_cast<void**>(&(usrDataptr1->C_d)), Nbytes, mystream1));
+  HIP_CHECK(
+      hipMemcpyAsync(usrDataptr1->A_d, usrDataptr1->A_h, Nbytes, hipMemcpyHostToDevice, mystream1));
   const unsigned blocks = GRIDSIZE;
   const unsigned threadsPerBlock = BLOCKSIZE;
-  hipLaunchKernelGGL((HipTest::vector_square), dim3(blocks),
-                dim3(threadsPerBlock), 0, mystream1, usrDataptr1->A_d,
-                usrDataptr1->C_d, NSize);
-  HIP_CHECK(hipMemcpyAsync(usrDataptr1->C_h, usrDataptr1->C_d, Nbytes,
-                            hipMemcpyDeviceToHost, mystream1));
-  HIP_CHECK(hipLaunchHostFunc(mystream1, Fn_validateMul_stream,
-            reinterpret_cast<void*>(usrDataptr1)));
+  hipLaunchKernelGGL((HipTest::vector_square), dim3(blocks), dim3(threadsPerBlock), 0, mystream1,
+                     usrDataptr1->A_d, usrDataptr1->C_d, NSize);
+  HIP_CHECK(
+      hipMemcpyAsync(usrDataptr1->C_h, usrDataptr1->C_d, Nbytes, hipMemcpyDeviceToHost, mystream1));
+  HIP_CHECK(
+      hipLaunchHostFunc(mystream1, Fn_validateMul_stream, reinterpret_cast<void*>(usrDataptr1)));
   // launch kernel function for mystream2
   usrDataptr2->A_h = reinterpret_cast<float*>(malloc(Nbytes));
   REQUIRE(usrDataptr2->A_h != nullptr);
@@ -231,27 +217,20 @@ TEST_CASE("Unit_hipLaunchHostFunc_multistreams") {
   for (size_t i = 0; i < NSize; i++) {
     usrDataptr2->A_h[i] = 9.0f;
   }
-  HIP_CHECK(hipMallocAsync(reinterpret_cast<void**>(&(usrDataptr2->A_d)),
-                            Nbytes, mystream2));
-  HIP_CHECK(hipMallocAsync(reinterpret_cast<void**>(&(usrDataptr2->C_d)),
-                            Nbytes, mystream2));
-  HIP_CHECK(hipMemcpyAsync(usrDataptr2->A_d, usrDataptr2->A_h, Nbytes,
-                            hipMemcpyHostToDevice, mystream2));
-  hipLaunchKernelGGL((HipTest::vector_square), dim3(blocks),
-                dim3(threadsPerBlock), 0, mystream2, usrDataptr2->A_d,
-                usrDataptr2->C_d, NSize);
-  HIP_CHECK(hipMemcpyAsync(usrDataptr2->C_h, usrDataptr2->C_d, Nbytes,
-                        hipMemcpyDeviceToHost, mystream2));
-  HIP_CHECK(hipLaunchHostFunc(mystream2, Fn_validateMul_stream,
-            reinterpret_cast<void*>(usrDataptr2)));
-  HIP_CHECK(hipFreeAsync(reinterpret_cast<void*>(usrDataptr1->A_d),
-                        mystream1));
-  HIP_CHECK(hipFreeAsync(reinterpret_cast<void*>(usrDataptr1->C_d),
-                        mystream1));
-  HIP_CHECK(hipFreeAsync(reinterpret_cast<void*>(usrDataptr2->A_d),
-                        mystream2));
-  HIP_CHECK(hipFreeAsync(reinterpret_cast<void*>(usrDataptr2->C_d),
-                        mystream2));
+  HIP_CHECK(hipMallocAsync(reinterpret_cast<void**>(&(usrDataptr2->A_d)), Nbytes, mystream2));
+  HIP_CHECK(hipMallocAsync(reinterpret_cast<void**>(&(usrDataptr2->C_d)), Nbytes, mystream2));
+  HIP_CHECK(
+      hipMemcpyAsync(usrDataptr2->A_d, usrDataptr2->A_h, Nbytes, hipMemcpyHostToDevice, mystream2));
+  hipLaunchKernelGGL((HipTest::vector_square), dim3(blocks), dim3(threadsPerBlock), 0, mystream2,
+                     usrDataptr2->A_d, usrDataptr2->C_d, NSize);
+  HIP_CHECK(
+      hipMemcpyAsync(usrDataptr2->C_h, usrDataptr2->C_d, Nbytes, hipMemcpyDeviceToHost, mystream2));
+  HIP_CHECK(
+      hipLaunchHostFunc(mystream2, Fn_validateMul_stream, reinterpret_cast<void*>(usrDataptr2)));
+  HIP_CHECK(hipFreeAsync(reinterpret_cast<void*>(usrDataptr1->A_d), mystream1));
+  HIP_CHECK(hipFreeAsync(reinterpret_cast<void*>(usrDataptr1->C_d), mystream1));
+  HIP_CHECK(hipFreeAsync(reinterpret_cast<void*>(usrDataptr2->A_d), mystream2));
+  HIP_CHECK(hipFreeAsync(reinterpret_cast<void*>(usrDataptr2->C_d), mystream2));
   HIP_CHECK(hipStreamSynchronize(mystream1));
   HIP_CHECK(hipStreamSynchronize(mystream2));
   HIP_CHECK(hipStreamDestroy(mystream1));
@@ -271,7 +250,7 @@ TEST_CASE("Unit_hipLaunchHostFunc_multistreams") {
 // validate hipLaunchHostFunc after kernel launch.
 static void Fn_Completion_state(void* userData) {
   REQUIRE(userData != nullptr);
-  usrDataS *ptrUsrData = reinterpret_cast<usrDataS *>(userData);
+  usrDataS* ptrUsrData = reinterpret_cast<usrDataS*>(userData);
   ptrUsrData->isOpCompleted = true;
 }
 
@@ -280,8 +259,7 @@ TEST_CASE("Unit_hipLaunchHostFunc_KernelHost") {
   HIP_CHECK(hipStreamCreate(&stream1));
   HIP_CHECK(hipStreamCreate(&stream2));
   HIP_CHECK(hipStreamCreate(&stream3));
-  usrDataS *usrDataptr = reinterpret_cast<usrDataS *>(
-                        malloc(sizeof(usrDataS)));
+  usrDataS* usrDataptr = reinterpret_cast<usrDataS*>(malloc(sizeof(usrDataS)));
   REQUIRE(usrDataptr != nullptr);
   usrDataptr->A_h = reinterpret_cast<float*>(malloc(Nbytes));
   REQUIRE(usrDataptr->A_h != nullptr);
@@ -292,43 +270,34 @@ TEST_CASE("Unit_hipLaunchHostFunc_KernelHost") {
     usrDataptr->A_h[i] = 7.0f;
   }
   usrDataptr->isOpCompleted = false;
-  HIP_CHECK(hipMallocAsync(reinterpret_cast<void**>(&(usrDataptr->A_d)),
-                        Nbytes, stream1));
-  HIP_CHECK(hipMallocAsync(reinterpret_cast<void**>(&(usrDataptr->C_d)),
-                        Nbytes, stream1));
-  HIP_CHECK(hipMemcpyAsync(usrDataptr->A_d, usrDataptr->A_h, Nbytes,
-                           hipMemcpyHostToDevice, stream1));
-  HIP_CHECK(hipLaunchHostFunc(stream1, Fn_Completion_state,
-                           reinterpret_cast<void*>(usrDataptr)));
+  HIP_CHECK(hipMallocAsync(reinterpret_cast<void**>(&(usrDataptr->A_d)), Nbytes, stream1));
+  HIP_CHECK(hipMallocAsync(reinterpret_cast<void**>(&(usrDataptr->C_d)), Nbytes, stream1));
+  HIP_CHECK(
+      hipMemcpyAsync(usrDataptr->A_d, usrDataptr->A_h, Nbytes, hipMemcpyHostToDevice, stream1));
+  HIP_CHECK(hipLaunchHostFunc(stream1, Fn_Completion_state, reinterpret_cast<void*>(usrDataptr)));
   while (!usrDataptr->isOpCompleted) {
     std::this_thread::sleep_for(std::chrono::microseconds(100000));
   }  // Sleep for 100 ms*/
   usrDataptr->isOpCompleted = false;
   const unsigned blocks = GRIDSIZE;
   const unsigned threadsPerBlock = BLOCKSIZE;
-  hipLaunchKernelGGL((HipTest::vector_square), dim3(blocks),
-                dim3(threadsPerBlock), 0, stream2, usrDataptr->A_d,
-                usrDataptr->C_d, NSize);
-  HIP_CHECK(hipLaunchHostFunc(stream2, Fn_Completion_state,
-                           reinterpret_cast<void*>(usrDataptr)));
+  hipLaunchKernelGGL((HipTest::vector_square), dim3(blocks), dim3(threadsPerBlock), 0, stream2,
+                     usrDataptr->A_d, usrDataptr->C_d, NSize);
+  HIP_CHECK(hipLaunchHostFunc(stream2, Fn_Completion_state, reinterpret_cast<void*>(usrDataptr)));
   while (!usrDataptr->isOpCompleted) {
     std::this_thread::sleep_for(std::chrono::microseconds(100000));
   }  // Sleep for 100 ms*/
   usrDataptr->isOpCompleted = false;
-  HIP_CHECK(hipMemcpyAsync(usrDataptr->C_h, usrDataptr->C_d, Nbytes,
-            hipMemcpyDeviceToHost, stream3));
-  HIP_CHECK(hipLaunchHostFunc(stream2, Fn_Completion_state,
-                        reinterpret_cast<void*>(usrDataptr)));
-  HIP_CHECK(hipFreeAsync(reinterpret_cast<void*>(usrDataptr->A_d),
-                        stream3));
-  HIP_CHECK(hipFreeAsync(reinterpret_cast<void*>(usrDataptr->C_d),
-                        stream3));
+  HIP_CHECK(
+      hipMemcpyAsync(usrDataptr->C_h, usrDataptr->C_d, Nbytes, hipMemcpyDeviceToHost, stream3));
+  HIP_CHECK(hipLaunchHostFunc(stream2, Fn_Completion_state, reinterpret_cast<void*>(usrDataptr)));
+  HIP_CHECK(hipFreeAsync(reinterpret_cast<void*>(usrDataptr->A_d), stream3));
+  HIP_CHECK(hipFreeAsync(reinterpret_cast<void*>(usrDataptr->C_d), stream3));
   while (!usrDataptr->isOpCompleted) {
     std::this_thread::sleep_for(std::chrono::microseconds(100000));
   }  // Sleep for 100 ms*/
   for (size_t i = 0; i < NSize; i++) {
-    if (usrDataptr->C_h[i] !=
-    (usrDataptr->A_h[i] * usrDataptr->A_h[i])) {
+    if (usrDataptr->C_h[i] != (usrDataptr->A_h[i] * usrDataptr->A_h[i])) {
       REQUIRE(false);
     }
   }
@@ -351,8 +320,7 @@ TEST_CASE("Unit_hipLaunchHostFunc_multidevice") {
     SUCCEED("Skipping the testcases as numDevices < 2");
     return;
   }
-  usrDataS *usrDataptr = reinterpret_cast<usrDataS *>(
-                        malloc(sizeof(usrDataS)));
+  usrDataS* usrDataptr = reinterpret_cast<usrDataS*>(malloc(sizeof(usrDataS)));
   REQUIRE(usrDataptr != nullptr);
   usrDataptr->A_h = reinterpret_cast<float*>(malloc(Nbytes));
   REQUIRE(usrDataptr->A_h != nullptr);
@@ -379,8 +347,7 @@ TEST_CASE("Unit_hipLaunchHostFunc_multidevice") {
 TEST_CASE("Unit_hipLaunchHostFunc_Samepriority") {
   int priority = 0;
   unsigned int flags = 0;
-  usrDataS *usrDataptr = reinterpret_cast<usrDataS *>(
-                        malloc(sizeof(usrDataS)));
+  usrDataS* usrDataptr = reinterpret_cast<usrDataS*>(malloc(sizeof(usrDataS)));
   REQUIRE(usrDataptr != nullptr);
   usrDataptr->A_h = reinterpret_cast<float*>(malloc(Nbytes));
   REQUIRE(usrDataptr->A_h != nullptr);
@@ -411,16 +378,14 @@ TEST_CASE("Unit_hipLaunchHostFunc_Diffpriority") {
   HIP_CHECK(hipDeviceGetStreamPriorityRange(&priority_low, &priority_high));
   int numOfPriorities = priority_low - priority_high;
   const float arr_size = numOfPriorities + 1;
-  hipStream_t *stream = reinterpret_cast<hipStream_t*>(
-                       malloc(arr_size*sizeof(hipStream_t)));
+  hipStream_t* stream = reinterpret_cast<hipStream_t*>(malloc(arr_size * sizeof(hipStream_t)));
   stream[0] = 0;
   int count = 1;
   // Create a stream for each of the priority levels
   for (priority = priority_high; priority < priority_low; priority++) {
     HIP_CHECK(hipStreamCreateWithPriority(&stream[count++], flags, priority));
   }
-  usrDataS *usrDataptr = reinterpret_cast<usrDataS *>(
-                         malloc(sizeof(usrDataS)));
+  usrDataS* usrDataptr = reinterpret_cast<usrDataS*>(malloc(sizeof(usrDataS)));
   REQUIRE(usrDataptr != nullptr);
   usrDataptr->A_h = reinterpret_cast<float*>(malloc(Nbytes));
   REQUIRE(usrDataptr->A_h != nullptr);
@@ -491,22 +456,18 @@ TEST_CASE("Unit_hipLaunchHostFunc_Graph") {
   HIP_CHECK(hipStreamWaitEvent(stream2, forkStreamEvent, 0));
   HIP_CHECK(hipStreamWaitEvent(stream3, forkStreamEvent, 0));
   HIP_CHECK(
-         hipMemcpyAsync(inputVec_d, inputVec_h, sizeof(float) * size,
-                        hipMemcpyDefault, stream1));
-  HIP_CHECK(hipMemsetAsync(outputVec_d, 0, sizeof(double) * maxBlocks,
-                               stream2));
+      hipMemcpyAsync(inputVec_d, inputVec_h, sizeof(float) * size, hipMemcpyDefault, stream1));
+  HIP_CHECK(hipMemsetAsync(outputVec_d, 0, sizeof(double) * maxBlocks, stream2));
   HIP_CHECK(hipEventRecord(memsetEvent1, stream2));
   HIP_CHECK(hipMemsetAsync(result_d, 0, sizeof(double), stream3));
   HIP_CHECK(hipEventRecord(memsetEvent2, stream3));
   HIP_CHECK(hipStreamWaitEvent(stream1, memsetEvent1, 0));
-  hipLaunchKernelGGL(reduce, dim3(size / THREADS_PER_BLOCK, 1, 1),
-                     dim3(THREADS_PER_BLOCK, 1, 1), 0, stream1,
-                     inputVec_d, outputVec_d);
+  hipLaunchKernelGGL(reduce, dim3(size / THREADS_PER_BLOCK, 1, 1), dim3(THREADS_PER_BLOCK, 1, 1), 0,
+                     stream1, inputVec_d, outputVec_d);
   HIP_CHECK(hipStreamWaitEvent(stream1, memsetEvent2, 0));
-  hipLaunchKernelGGL(reduceFinal, dim3(1, 1, 1), dim3(THREADS_PER_BLOCK, 1, 1),
-                      0, stream1, outputVec_d, result_d);
-  HIP_CHECK(hipMemcpyAsync(&result_h, result_d, sizeof(double),
-                            hipMemcpyDefault, stream1));
+  hipLaunchKernelGGL(reduceFinal, dim3(1, 1, 1), dim3(THREADS_PER_BLOCK, 1, 1), 0, stream1,
+                     outputVec_d, result_d);
+  HIP_CHECK(hipMemcpyAsync(&result_h, result_d, sizeof(double), hipMemcpyDefault, stream1));
 
   callBackData_t hostFnData;
   hostFnData.data = &result_h;
@@ -518,11 +479,12 @@ TEST_CASE("Unit_hipLaunchHostFunc_Graph") {
   hipGraphNode_t* nodes = NULL;
   size_t numNodes = 0;
   HIP_CHECK(hipGraphGetNodes(graph, nodes, &numNodes));
-  printf("\nNum of nodes in the graph created using stream"
-                   "capture API = %zu\n", numNodes);
+  printf(
+      "\nNum of nodes in the graph created using stream"
+      "capture API = %zu\n",
+      numNodes);
   HIP_CHECK(hipGraphGetRootNodes(graph, nodes, &numNodes));
-  printf("root nodes in the graph created using stream capture API = %zu\n",
-                             numNodes);
+  printf("root nodes in the graph created using stream capture API = %zu\n", numNodes);
   hipGraphExec_t graphExec;
 
   HIP_CHECK(hipGraphInstantiate(&graphExec, graph, NULL, NULL, 0));
@@ -535,9 +497,9 @@ TEST_CASE("Unit_hipLaunchHostFunc_Graph") {
   auto WithInit = std::chrono::duration<double, std::milli>(stop - start);
   auto WithoutInit = std::chrono::duration<double, std::milli>(stop - start1);
   std::cout << "Time taken for hipGraphsUsingStreamCapture with Init: "
-  << std::chrono::duration_cast<std::chrono::milliseconds>(WithInit).count()
+            << std::chrono::duration_cast<std::chrono::milliseconds>(WithInit).count()
             << " milliseconds without Init:"
-  << std::chrono::duration_cast<std::chrono::milliseconds>(WithoutInit).count()
+            << std::chrono::duration_cast<std::chrono::milliseconds>(WithoutInit).count()
             << " milliseconds " << std::endl;
 
   HIP_CHECK(hipGraphExecDestroy(graphExec));
