@@ -1,5 +1,5 @@
 /*
-Copyright (c) 2021 Advanced Micro Devices, Inc. All rights reserved.
+Copyright (c) 2025 Advanced Micro Devices, Inc. All rights reserved.
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
 in the Software without restriction, including without limitation the rights
@@ -26,14 +26,17 @@ static void Copy_to_device() {
   int* A_h = nullptr;
   int* A_d = nullptr;
 
-  HIP_CHECK(hipHostMalloc(&A_h, ele_size*sizeof(int)));
+  HIP_CHECK(hipHostMalloc(&A_h, ele_size * sizeof(int)));
   HIP_CHECK(hipMalloc(&A_d, ele_size * sizeof(int)));
 
   for (unsigned int i = 0; i < ele_size; ++i) {
     A_h[i] = 123;
   }
-  HIP_CHECK(hipMemcpyAsync(A_d, A_h, ele_size * sizeof(int), hipMemcpyHostToDevice,
-                 hipStreamPerThread));
+  HIP_CHECK(
+      hipMemcpyAsync(A_d, A_h, ele_size * sizeof(int), hipMemcpyHostToDevice, hipStreamPerThread));
+  // Clean up
+  HIP_CHECK(hipHostFree(A_h));
+  HIP_CHECK(hipFree(A_d));
 }
 
 /*
@@ -45,7 +48,7 @@ TEST_CASE("Unit_hipStreamPerThread_MultiThread") {
   constexpr unsigned int MAX_THREAD_CNT = 10;
   std::vector<std::thread> threads(MAX_THREAD_CNT);
 
-  for (auto &th : threads) {
+  for (auto& th : threads) {
     th = std::thread(Copy_to_device);
   }
 
