@@ -26,13 +26,15 @@ THE SOFTWARE.
 #pragma clang diagnostic ignored "-Wunused-variable"
 #pragma clang diagnostic ignored "-Wunused-parameter"
 
-//#define TEST_TEXTURE
-static constexpr bool printLog = false; // Print log for debugging
+// #define TEST_TEXTURE
+static constexpr bool printLog = false;  // Print log for debugging
 
 // Populate mipmap next level array
 template <typename T, hipTextureReadMode readMode>
-static __global__ void populateMipmapNextLevelArray(hipSurfaceObject_t surfOut, hipTextureObject_t texIn,
-                          unsigned int width, unsigned int height, unsigned int depth, T* data = nullptr) {
+static __global__ void populateMipmapNextLevelArray(hipSurfaceObject_t surfOut,
+                                                    hipTextureObject_t texIn, unsigned int width,
+                                                    unsigned int height, unsigned int depth,
+                                                    T* data = nullptr) {
 #if !__HIP_NO_IMAGE_SUPPORT
   int x = blockIdx.x * blockDim.x + threadIdx.x;
   int y = blockIdx.y * blockDim.y + threadIdx.y;
@@ -48,7 +50,7 @@ static __global__ void populateMipmapNextLevelArray(hipSurfaceObject_t surfOut,
       printf("(%d/%u, %d/%u):(%f, %f)\n", x, width, y, height, t.x, t.y);
 #endif
       surf3Dwrite<T>(t, surfOut, x * sizeof(T), y, z);
-      if (data) data[z* width * height + y * width + x] = t;  // record it for later verification
+      if (data) data[z * width * height + y * width + x] = t;  // record it for later verification
     }
     if constexpr (readMode == hipReadModeNormalizedFloat) {
       float4 t = tex3D<float4>(texIn, x * px, y * py, z * pz);
@@ -71,9 +73,8 @@ static __global__ void populateMipmapNextLevelArray(hipSurfaceObject_t surfOut,
 
 template <typename T>
 static __global__ void getMipmap(hipTextureObject_t texMipmap, unsigned int width,
-    unsigned int height,
-    unsigned int depth, float offsetX, float offsetY, float offsetZ, float lod,
-    T* data = nullptr) {
+                                 unsigned int height, unsigned int depth, float offsetX,
+                                 float offsetY, float offsetZ, float lod, T* data = nullptr) {
 #if !__HIP_NO_IMAGE_SUPPORT
   int x = blockIdx.x * blockDim.x + threadIdx.x;
   int y = blockIdx.y * blockDim.y + threadIdx.y;
@@ -104,27 +105,27 @@ static void populateMipmaps(hipMipmappedArray_t mipmapArray, hipExtent size,
     HIP_CHECK(hipGetMipmappedArrayLevel(&levelArray, mipmapArray, level));
     HIP_CHECK(hipGetMipmappedArrayLevel(&nextLevelArray, mipmapArray, level + 1));
 
-    hipExtent levelArraySize {0, 0, 0};
+    hipExtent levelArraySize{0, 0, 0};
     HIP_CHECK(hipArrayGetInfo(nullptr, &levelArraySize, nullptr, levelArray));
     if (levelArraySize.width != width || levelArraySize.height != height ||
         levelArraySize.depth != depth) {
       fprintf(stderr, "Level %u: size (%zu, %zu, %zu) != Expected size (%zu, %zu, %zu)\n", level,
-               levelArraySize.width, levelArraySize.height, levelArraySize.depth, width, height,
-               depth);
+              levelArraySize.width, levelArraySize.height, levelArraySize.depth, width, height,
+              depth);
       REQUIRE(false);
     }
 
-    width = width >> 1 ? width >> 1: 1;
+    width = width >> 1 ? width >> 1 : 1;
     height = height >> 1 ? height >> 1 : 1;
     depth = depth >> 1 ? depth >> 1 : 1;
 
-    hipExtent nextLevelArraySize {0, 0, 0};
+    hipExtent nextLevelArraySize{0, 0, 0};
     HIP_CHECK(hipArrayGetInfo(nullptr, &nextLevelArraySize, nullptr, nextLevelArray));
     if (nextLevelArraySize.width != width || nextLevelArraySize.height != height ||
         nextLevelArraySize.depth != depth) {
       fprintf(stderr, "Next level %u: size (%zu, %zu, %zu) != Expected size (%zu, %zu, %zu)\n",
-          level + 1, nextLevelArraySize.width, nextLevelArraySize.height, nextLevelArraySize.depth,
-          width, height, depth);
+              level + 1, nextLevelArraySize.width, nextLevelArraySize.height,
+              nextLevelArraySize.depth, width, height, depth);
       REQUIRE(false);
     }
 
@@ -136,7 +137,7 @@ static void populateMipmaps(hipMipmappedArray_t mipmapArray, hipExtent size,
 
     hipTextureDesc texDescr;
     memset(&texDescr, 0, sizeof(hipTextureDesc));
-    texDescr.normalizedCoords = 1; // To populate next level array smoothly
+    texDescr.normalizedCoords = 1;  // To populate next level array smoothly
     texDescr.filterMode = filterMode;
     texDescr.addressMode[0] = addressMode;
     texDescr.addressMode[1] = addressMode;
@@ -157,8 +158,8 @@ static void populateMipmaps(hipMipmappedArray_t mipmapArray, hipExtent size,
     memset(data.data, 0, size);
 
     dim3 blockSize(16, 16, 4);
-    dim3 gridSize((width + blockSize.x - 1) / blockSize.x,
-        (height + blockSize.y - 1) / blockSize.y, (depth + blockSize.z - 1) / blockSize.z);
+    dim3 gridSize((width + blockSize.x - 1) / blockSize.x, (height + blockSize.y - 1) / blockSize.y,
+                  (depth + blockSize.z - 1) / blockSize.z);
 
     populateMipmapNextLevelArray<T, readMode>
         <<<gridSize, blockSize>>>(surfOut, texIn, width, height, depth, data.data);
@@ -170,31 +171,31 @@ static void populateMipmaps(hipMipmappedArray_t mipmapArray, hipExtent size,
     HIP_CHECK(hipDestroyTextureObject(texIn));
     HIP_CHECK(hipFreeArray(levelArray));
     HIP_CHECK(hipFreeArray(nextLevelArray));
-    mipmapData.push_back(data); // For later verification
+    mipmapData.push_back(data);  // For later verification
     level++;
   }
 }
 
-template <typename T,
-          hipTextureFilterMode filterMode = hipFilterModePoint,
+template <typename T, hipTextureFilterMode filterMode = hipFilterModePoint,
           hipTextureAddressMode addressMode = hipAddressModeClamp>
 static void verifyMipmapLevel(hipTextureObject_t texMipmap, T* data, size_t width, size_t height,
-              size_t depth, float level, float offsetX, float offsetY, float offsetZ) {
+                              size_t depth, float level, float offsetX, float offsetY,
+                              float offsetZ) {
   T* hOutput = nullptr;
   size_t size = width * height * depth * sizeof(T);
   HIP_CHECK(hipHostMalloc((void**)&hOutput, size));
   memset(hOutput, 0, size);
 
   dim3 blockSize(16, 16, 4);
-  dim3 gridSize((width + blockSize.x - 1) / blockSize.x,
-      (height + blockSize.y - 1) / blockSize.y, (depth + blockSize.z - 1) / blockSize.z);
+  dim3 gridSize((width + blockSize.x - 1) / blockSize.x, (height + blockSize.y - 1) / blockSize.y,
+                (depth + blockSize.z - 1) / blockSize.z);
 
-  getMipmap<T><<<gridSize, blockSize>>>(texMipmap, width, height, depth, offsetX,
-                                        offsetY, offsetZ, level, hOutput);
+  getMipmap<T><<<gridSize, blockSize>>>(texMipmap, width, height, depth, offsetX, offsetY, offsetZ,
+                                        level, hOutput);
   HIP_CHECK(hipDeviceSynchronize());
   HIP_CHECK(hipGetLastError());
 
-   for (unsigned int k = 0; k < depth; k++) {
+  for (unsigned int k = 0; k < depth; k++) {
     for (unsigned int j = 0; j < height; j++) {
       for (unsigned int i = 0; i < width; i++) {
         unsigned int index = k * width * height + j * width + i;
@@ -252,7 +253,7 @@ static void testMipmapTextureObj(size_t width, size_t height, size_t depth, floa
       }
     }
   }
-  mipmapData.push_back(data); // record level 0 data for later verification
+  mipmapData.push_back(data);  // record level 0 data for later verification
 
   // Get the max mipmap levels in terms of image size
   const unsigned int maxLevels = 1 + std::log2(std::max(width, std::max(height, depth)));
@@ -260,15 +261,14 @@ static void testMipmapTextureObj(size_t width, size_t height, size_t depth, floa
   // create mipmap array
   hipChannelFormatDesc desc = hipCreateChannelDesc<T>();
   hipMipmappedArray_t mipmapArray = nullptr;
-  hipExtent extent { width, height, depth };
+  hipExtent extent{width, height, depth};
   HIP_CHECK(hipMallocMipmappedArray(&mipmapArray, &desc, extent, maxLevels));
 
   // Initialize level 0
   hipArray_t levelArray;
   HIP_CHECK(hipGetMipmappedArrayLevel(&levelArray, mipmapArray, 0));
   hipMemcpy3DParms copyParams{};
-  copyParams.srcPtr = make_hipPitchedPtr(data.data, width * sizeof(T),
-                                            width, height);
+  copyParams.srcPtr = make_hipPitchedPtr(data.data, width * sizeof(T), width, height);
   copyParams.dstArray = levelArray;
   copyParams.extent.width = width;
   copyParams.extent.height = height;
@@ -279,19 +279,19 @@ static void testMipmapTextureObj(size_t width, size_t height, size_t depth, floa
   // Populate other mipmap levels based on level 0
   populateMipmaps<T, readMode, filterMode, addressMode>(mipmapArray, extent, mipmapData);
 
-  if(maxLevels != mipmapData.size()) {
+  if (maxLevels != mipmapData.size()) {
     fprintf(stderr, "maxLevels %u != mipmapData.size() %zu\n", maxLevels, mipmapData.size());
     REQUIRE(false);
   }
   hipResourceDesc resDescr;
   memset(&resDescr, 0, sizeof(hipResourceDesc));
-  resDescr.resType = hipResourceTypeMipmappedArray; // For mipmap texture
+  resDescr.resType = hipResourceTypeMipmappedArray;  // For mipmap texture
   resDescr.res.mipmap.mipmap = mipmapArray;
 
   hipTextureDesc texDescr;
   memset(&texDescr, 0, sizeof(hipTextureDesc));
 
-  texDescr.normalizedCoords = 1; // normalizedCoords must be 1 for mipmap array
+  texDescr.normalizedCoords = 1;  // normalizedCoords must be 1 for mipmap array
   texDescr.filterMode = filterMode;
   texDescr.mipmapFilterMode = filterMode;
   texDescr.addressMode[0] = addressMode;
@@ -304,8 +304,8 @@ static void testMipmapTextureObj(size_t width, size_t height, size_t depth, floa
   hipTextureObject_t texMipmap = nullptr;
   HIP_CHECK(hipCreateTextureObject(&texMipmap, &resDescr, &texDescr, NULL));
 
-  for(unsigned int level = 0; level < mipmapData.size(); level++){
-    mipmapLevelArray<T> &data = mipmapData.at(level);
+  for (unsigned int level = 0; level < mipmapData.size(); level++) {
+    mipmapLevelArray<T>& data = mipmapData.at(level);
 
     if constexpr (hipReadModeNormalizedFloat == readMode) {
       typedef decltype(getNormalizedFloatType(*data.data)) TargetType;
@@ -324,14 +324,14 @@ static void testMipmapTextureObj(size_t width, size_t height, size_t depth, floa
           }
         }
       }
-      verifyMipmapLevel<TargetType, filterMode, addressMode>(
-          texMipmap, fData.data(), data.e.width, data.e.height, data.e.depth,
-          level, offsetX, offsetY, offsetZ);
+      verifyMipmapLevel<TargetType, filterMode, addressMode>(texMipmap, fData.data(), data.e.width,
+                                                             data.e.height, data.e.depth, level,
+                                                             offsetX, offsetY, offsetZ);
 
     } else {  // hipReadModeElementType == readMode
-      verifyMipmapLevel<T, filterMode, addressMode>(
-          texMipmap, data.data, data.e.width, data.e.height, data.e.depth, level,
-          offsetX, offsetY, offsetZ);
+      verifyMipmapLevel<T, filterMode, addressMode>(texMipmap, data.data, data.e.width,
+                                                    data.e.height, data.e.depth, level, offsetX,
+                                                    offsetY, offsetZ);
     }
     HIP_CHECK(hipHostFree(data.data));
     memset(&data, 0, sizeof(data));
@@ -360,11 +360,10 @@ static void testMipmapTextureObj(size_t width, size_t height, size_t depth, floa
  *  - Textures supported on device
  *  - HIP_VERSION >= 5.7
  */
-TEMPLATE_TEST_CASE("Unit_hipTextureMipmapObj3D_Check - hipReadModeElementType", "",
-                   char, uchar, short, ushort, int, uint, float,
-                   char1, uchar1, short1, ushort1, int1, uint1, float1,
-                   char2, uchar2, short2, ushort2, int2, uint2, float2,
-                   char4, uchar4, short4, ushort4, int4, uint4, float4) {
+TEMPLATE_TEST_CASE("Unit_hipTextureMipmapObj3D_Check - hipReadModeElementType", "", char, uchar,
+                   short, ushort, int, uint, float, char1, uchar1, short1, ushort1, int1, uint1,
+                   float1, char2, uchar2, short2, ushort2, int2, uint2, float2, char4, uchar4,
+                   short4, ushort4, int4, uint4, float4) {
   CHECK_IMAGE_SUPPORT
 
 #if __HIP_NO_IMAGE_SUPPORT
@@ -375,14 +374,14 @@ TEMPLATE_TEST_CASE("Unit_hipTextureMipmapObj3D_Check - hipReadModeElementType",
   SECTION(
       "Unit_hipTextureMipmapObj3D_Check - hipReadModeElementType, hipFilterModePoint, "
       "hipAddressModeClamp 23, 21, 47") {
-    testMipmapTextureObj<TestType, hipReadModeElementType, hipFilterModePoint,
-                         hipAddressModeClamp>(23, 21, 47, 0.4, -0.9, 0.77);
+    testMipmapTextureObj<TestType, hipReadModeElementType, hipFilterModePoint, hipAddressModeClamp>(
+        23, 21, 47, 0.4, -0.9, 0.77);
   }
   SECTION(
       "Unit_hipTextureMipmapObj3D_Check - hipReadModeElementType, hipFilterModePoint, "
       "hipAddressModeClamp 67, 131, 99") {
-    testMipmapTextureObj<TestType, hipReadModeElementType, hipFilterModePoint,
-                         hipAddressModeClamp>(67, 131, 99, -0.3, -0.67, 0.49);
+    testMipmapTextureObj<TestType, hipReadModeElementType, hipFilterModePoint, hipAddressModeClamp>(
+        67, 131, 99, -0.3, -0.67, 0.49);
   }
   SECTION(
       "Unit_hipTextureMipmapObj3D_Check - hipReadModeElementType, hipFilterModePoint, "
@@ -416,10 +415,8 @@ TEMPLATE_TEST_CASE("Unit_hipTextureMipmapObj3D_Check - hipReadModeElementType",
  *  - Textures supported on device
  *  - HIP_VERSION >= 5.7
  */
-TEMPLATE_TEST_CASE("Unit_hipTextureMipmapObj3D_Check - hipReadModeNormalizedFloat", "",
-                   char,  uchar,  short,  ushort,
-                   char1, uchar1, short1, ushort1,
-                   char2, uchar2, short2, ushort2,
+TEMPLATE_TEST_CASE("Unit_hipTextureMipmapObj3D_Check - hipReadModeNormalizedFloat", "", char, uchar,
+                   short, ushort, char1, uchar1, short1, ushort1, char2, uchar2, short2, ushort2,
                    char4, uchar4, short4, ushort4) {
   CHECK_IMAGE_SUPPORT
 
