@@ -22,29 +22,30 @@ THE SOFTWARE.
 #include <hip_test_checkers.hh>
 #include <hip_texture_helper.hh>
 
-template<bool normalizedCoords>
-__global__ void tex1DRGBAKernel(float4 *outputData, hipTextureObject_t textureObject,
-                            int width, float offsetX) {
+template <bool normalizedCoords> __global__ void tex1DRGBAKernel(float4* outputData,
+                                                                 hipTextureObject_t textureObject,
+                                                                 int width, float offsetX) {
 #if !__HIP_NO_IMAGE_SUPPORT
   int x = blockIdx.x * blockDim.x + threadIdx.x;
-  outputData[x] = tex1D<float4>(textureObject,
-                                normalizedCoords ? (x + offsetX) / width : x + offsetX);
+  outputData[x] =
+      tex1D<float4>(textureObject, normalizedCoords ? (x + offsetX) / width : x + offsetX);
 #endif
 }
 
-__global__ void tex1DRGBAKernelFetch(float4 *outputData, hipTextureObject_t textureObject, float offsetX) {
+__global__ void tex1DRGBAKernelFetch(float4* outputData, hipTextureObject_t textureObject,
+                                     float offsetX) {
 #if !__HIP_NO_IMAGE_SUPPORT
   int x = blockIdx.x * blockDim.x + threadIdx.x;
   outputData[x] = tex1Dfetch<float4>(textureObject, int(x + offsetX));
 #endif
 }
 
-template<hipTextureAddressMode addressMode, hipTextureFilterMode filterMode, hipResourceType resType,
-                  bool normalizedCoords, bool sRGB = false>
+template <hipTextureAddressMode addressMode, hipTextureFilterMode filterMode,
+          hipResourceType resType, bool normalizedCoords, bool sRGB = false>
 static void runTest(const int width, const float offsetX = 0) {
   constexpr float uCharMax = UCHAR_MAX;
   unsigned int size = width * sizeof(uchar4);
-  uchar4 *hData = (uchar4*) malloc(size);
+  uchar4* hData = (uchar4*)malloc(size);
   memset(hData, 0, size);
   for (int j = 0; j < width; j++) {
     hData[j].x = static_cast<unsigned char>(j);
@@ -54,32 +55,30 @@ static void runTest(const int width, const float offsetX = 0) {
   }
 
   hipChannelFormatDesc channelDesc = hipCreateChannelDesc<uchar4>();
-  uchar4 *hipBuff = nullptr;
+  uchar4* hipBuff = nullptr;
   hipArray_t hipArray = nullptr;
   hipResourceDesc resDesc;
   memset(&resDesc, 0, sizeof(resDesc));
 
   if (resType == hipResourceTypeArray) {
     HIP_CHECK(hipMallocArray(&hipArray, &channelDesc, width));
-    HIP_CHECK(
-        hipMemcpy2DToArray(hipArray, 0, 0, hData, size, size, 1,
-                           hipMemcpyHostToDevice));
+    HIP_CHECK(hipMemcpy2DToArray(hipArray, 0, 0, hData, size, size, 1, hipMemcpyHostToDevice));
     resDesc.resType = hipResourceTypeArray;  // Will call tex1D in kernel
     resDesc.res.array.array = hipArray;
   } else if (resType == hipResourceTypeLinear) {
-    if (normalizedCoords || filterMode == hipFilterModeLinear
-        || addressMode == hipAddressModeWrap
-        || addressMode == hipAddressModeMirror) {
+    if (normalizedCoords || filterMode == hipFilterModeLinear ||
+        addressMode == hipAddressModeWrap || addressMode == hipAddressModeMirror) {
       free(hData);
       FAIL("One or more unexpected parameters for hipResourceTypeLinear");
     }
-    HIP_CHECK(hipMalloc((void** ) &hipBuff, size));
+    HIP_CHECK(hipMalloc((void**)&hipBuff, size));
     HIP_CHECK(hipMemcpy(hipBuff, hData, size, hipMemcpyHostToDevice));
-    resDesc.resType = hipResourceTypeLinear; // Will call tex1Dfetch in kernel
+    resDesc.resType = hipResourceTypeLinear;  // Will call tex1Dfetch in kernel
     resDesc.res.linear.devPtr = hipBuff;
     resDesc.res.linear.sizeInBytes = size;
     resDesc.res.linear.desc = channelDesc;
-  } else FAIL("Unexpected resource type " << resType);
+  } else
+    FAIL("Unexpected resource type " << resType);
 
   // Specify texture object parameters
   hipTextureDesc texDesc;
@@ -95,7 +94,7 @@ static void runTest(const int width, const float offsetX = 0) {
   hipTextureObject_t textureObject = 0;
   auto ret = hipCreateTextureObject(&textureObject, &resDesc, &texDesc, NULL);
 #if HT_AMD
-  if(ret == hipErrorInvalidValue && resType == hipResourceTypeLinear) {
+  if (ret == hipErrorInvalidValue && resType == hipResourceTypeLinear) {
     free(hData);
     HIP_CHECK(hipFree(hipBuff));
     HipTest::HIP_SKIP_TEST("sRGB is not supported for hipResourceTypeLinear type on AMD devices");
@@ -104,27 +103,27 @@ static void runTest(const int width, const float offsetX = 0) {
 #endif
   HIP_CHECK(ret);
 
-  float4 *dData = nullptr;
+  float4* dData = nullptr;
   size = width * sizeof(float4);
-  HIP_CHECK(hipMalloc((void**) &dData, size));
+  HIP_CHECK(hipMalloc((void**)&dData, size));
 
   dim3 dimBlock(16, 1, 1);
   dim3 dimGrid((width + dimBlock.x - 1) / dimBlock.x, 1, 1);
 
   if (resType == hipResourceTypeArray) {
-    hipLaunchKernelGGL(tex1DRGBAKernel<normalizedCoords>, dimGrid, dimBlock,
-                       0, 0, dData, textureObject, width, offsetX);
-    HIP_CHECK(hipGetLastError()); 
+    hipLaunchKernelGGL(tex1DRGBAKernel<normalizedCoords>, dimGrid, dimBlock, 0, 0, dData,
+                       textureObject, width, offsetX);
+    HIP_CHECK(hipGetLastError());
   } else {
-    hipLaunchKernelGGL(tex1DRGBAKernelFetch, dimGrid, dimBlock,
-                       0, 0, dData, textureObject, offsetX);
-    HIP_CHECK(hipGetLastError()); 
+    hipLaunchKernelGGL(tex1DRGBAKernelFetch, dimGrid, dimBlock, 0, 0, dData, textureObject,
+                       offsetX);
+    HIP_CHECK(hipGetLastError());
   }
 
   HIP_CHECK(hipDeviceSynchronize());
   size = width * sizeof(float4);
-  float4 *hInputData = (float4*) malloc(size);  // CPU expected values
-  float4 *hOutputData = (float4*) malloc(size); // GPU output values
+  float4* hInputData = (float4*)malloc(size);   // CPU expected values
+  float4* hOutputData = (float4*)malloc(size);  // GPU output values
   memset(hInputData, 0, size);
   memset(hOutputData, 0, size);
 
@@ -151,13 +150,11 @@ static void runTest(const int width, const float offsetX = 0) {
     // Convert from [0, 1] back to [0, 255]
     gpuOutput *= uCharMax;
     cpuExpected *= uCharMax;
-    if (!hipTextureSamplingVerify<float4, filterMode, sRGB>(gpuOutput,
-                                                            cpuExpected)) {
-      WARN(
-          "Mismatch at (" << offsetX + j << ") GPU output : "
-          << gpuOutput.x << ", " << gpuOutput.y << ", " << gpuOutput.z << ", " << gpuOutput.w << ", " <<
-          " CPU expected: "
-          << cpuExpected.x << ", " << cpuExpected.y << ", " << cpuExpected.z << ", " << cpuExpected.w << "\n");
+    if (!hipTextureSamplingVerify<float4, filterMode, sRGB>(gpuOutput, cpuExpected)) {
+      WARN("Mismatch at (" << offsetX + j << ") GPU output : " << gpuOutput.x << ", " << gpuOutput.y
+                           << ", " << gpuOutput.z << ", " << gpuOutput.w << ", "
+                           << " CPU expected: " << cpuExpected.x << ", " << cpuExpected.y << ", "
+                           << cpuExpected.z << ", " << cpuExpected.w << "\n");
       result = false;
       goto line1;
     }
@@ -199,30 +196,35 @@ TEST_CASE("Unit_hipTextureObj1DCheckRGBAModes - array") {
 
 #if HT_AMD
   // nvidia RTX2070 has problem in this mode
-  SECTION("RGBA 1D hipAddressModeBorder, hipFilterModeLinear, hipResourceTypeArray, regularCoords") {
+  SECTION(
+      "RGBA 1D hipAddressModeBorder, hipFilterModeLinear, hipResourceTypeArray, regularCoords") {
     runTest<hipAddressModeBorder, hipFilterModeLinear, hipResourceTypeArray, false>(255, 0);
     runTest<hipAddressModeBorder, hipFilterModeLinear, hipResourceTypeArray, false>(255, 12.1);
   }
 #endif
 
-  SECTION("RGBA 1D hipAddressModeClamp, hipFilterModePoint, hipResourceTypeArray, normalizedCoords") {
+  SECTION(
+      "RGBA 1D hipAddressModeClamp, hipFilterModePoint, hipResourceTypeArray, normalizedCoords") {
     runTest<hipAddressModeClamp, hipFilterModePoint, hipResourceTypeArray, true>(255, -3.1);
     runTest<hipAddressModeClamp, hipFilterModePoint, hipResourceTypeArray, true>(255, 4.2);
   }
 
-  SECTION("RGBA 1D hipAddressModeBorder, hipFilterModePoint, hipResourceTypeArray, normalizedCoords") {
+  SECTION(
+      "RGBA 1D hipAddressModeBorder, hipFilterModePoint, hipResourceTypeArray, normalizedCoords") {
     runTest<hipAddressModeBorder, hipFilterModePoint, hipResourceTypeArray, true>(255, -8.15);
     runTest<hipAddressModeBorder, hipFilterModePoint, hipResourceTypeArray, true>(255, 12.35);
   }
 
-  SECTION("RGBA 1D hipAddressModeClamp, hipFilterModeLinear, hipResourceTypeArray, normalizedCoords") {
+  SECTION(
+      "RGBA 1D hipAddressModeClamp, hipFilterModeLinear, hipResourceTypeArray, normalizedCoords") {
     runTest<hipAddressModeClamp, hipFilterModeLinear, hipResourceTypeArray, true>(255, -3.1);
     runTest<hipAddressModeClamp, hipFilterModeLinear, hipResourceTypeArray, true>(255, 4.2);
   }
 
 #if HT_AMD
   // nvidia RTX2070 has problem in this mode
-  SECTION("RGBA 1D hipAddressModeBorder, hipFilterModeLinear, hipResourceTypeArray, normalizedCoords") {
+  SECTION(
+      "RGBA 1D hipAddressModeBorder, hipFilterModeLinear, hipResourceTypeArray, normalizedCoords") {
     runTest<hipAddressModeBorder, hipFilterModeLinear, hipResourceTypeArray, true>(255, 0);
     runTest<hipAddressModeBorder, hipFilterModeLinear, hipResourceTypeArray, true>(255, -6.7);
   }
@@ -243,43 +245,53 @@ TEST_CASE("Unit_hipTextureObj1DCheckSRGBAModes - array") {
     runTest<hipAddressModeClamp, hipFilterModePoint, hipResourceTypeArray, false, true>(255, 4.4);
   }
 
-  SECTION("SRGBA 1D hipAddressModeBorder, hipFilterModePoint, hipResourceTypeArray, regularCoords") {
+  SECTION(
+      "SRGBA 1D hipAddressModeBorder, hipFilterModePoint, hipResourceTypeArray, regularCoords") {
     runTest<hipAddressModeBorder, hipFilterModePoint, hipResourceTypeArray, false, true>(255, -8.5);
     runTest<hipAddressModeBorder, hipFilterModePoint, hipResourceTypeArray, false, true>(255, 12.5);
   }
 
-  SECTION("SRGBA 1D hipAddressModeClamp, hipFilterModeLinear, hipResourceTypeArray, regularCoords") {
+  SECTION(
+      "SRGBA 1D hipAddressModeClamp, hipFilterModeLinear, hipResourceTypeArray, regularCoords") {
     runTest<hipAddressModeClamp, hipFilterModeLinear, hipResourceTypeArray, false, true>(255, -0.4);
     runTest<hipAddressModeClamp, hipFilterModeLinear, hipResourceTypeArray, false, true>(255, 4);
   }
 
 #if HT_AMD
   // nvidia RTX2070 has problem in this mode
-  SECTION("SRGBA 1D hipAddressModeBorder, hipFilterModeLinear, hipResourceTypeArray, regularCoords") {
+  SECTION(
+      "SRGBA 1D hipAddressModeBorder, hipFilterModeLinear, hipResourceTypeArray, regularCoords") {
     runTest<hipAddressModeBorder, hipFilterModeLinear, hipResourceTypeArray, false, true>(255, 0);
-    runTest<hipAddressModeBorder, hipFilterModeLinear, hipResourceTypeArray, false, true>(255, 12.5);
+    runTest<hipAddressModeBorder, hipFilterModeLinear, hipResourceTypeArray, false, true>(255,
+                                                                                          12.5);
   }
 #endif
 
-  SECTION("SRGBA 1D hipAddressModeClamp, hipFilterModePoint, hipResourceTypeArray, normalizedCoords") {
+  SECTION(
+      "SRGBA 1D hipAddressModeClamp, hipFilterModePoint, hipResourceTypeArray, normalizedCoords") {
     runTest<hipAddressModeClamp, hipFilterModePoint, hipResourceTypeArray, true, true>(255, -1.3);
     runTest<hipAddressModeClamp, hipFilterModePoint, hipResourceTypeArray, true, true>(255, 4.1);
   }
 
-  SECTION("SRGBA 1D hipAddressModeBorder, hipFilterModePoint, hipResourceTypeArray, normalizedCoords") {
+  SECTION(
+      "SRGBA 1D hipAddressModeBorder, hipFilterModePoint, hipResourceTypeArray, normalizedCoords") {
     runTest<hipAddressModeBorder, hipFilterModePoint, hipResourceTypeArray, true, true>(255, -8.5);
     runTest<hipAddressModeBorder, hipFilterModePoint, hipResourceTypeArray, true, true>(255, 12.5);
   }
 
-  SECTION("SRGBA 1D hipAddressModeClamp, hipFilterModeLinear, hipResourceTypeArray, normalizedCoords") {
+  SECTION(
+      "SRGBA 1D hipAddressModeClamp, hipFilterModeLinear, hipResourceTypeArray, normalizedCoords") {
     runTest<hipAddressModeClamp, hipFilterModeLinear, hipResourceTypeArray, true, true>(255, -3);
     runTest<hipAddressModeClamp, hipFilterModeLinear, hipResourceTypeArray, true, true>(255, 4);
   }
 #if HT_AMD
   // nvidia RTX2070 has problem in this mode
-  SECTION("SRGBA 1D hipAddressModeBorder, hipFilterModeLinear, hipResourceTypeArray, normalizedCoords") {
+  SECTION(
+      "SRGBA 1D hipAddressModeBorder, hipFilterModeLinear, hipResourceTypeArray, "
+      "normalizedCoords") {
     runTest<hipAddressModeBorder, hipFilterModeLinear, hipResourceTypeArray, true, true>(255, 0);
-    runTest<hipAddressModeBorder, hipFilterModeLinear, hipResourceTypeArray, true, true>(255, 12.35);
+    runTest<hipAddressModeBorder, hipFilterModeLinear, hipResourceTypeArray, true, true>(255,
+                                                                                         12.35);
   }
 #endif
 }
@@ -294,9 +306,10 @@ TEST_CASE("Unit_hipTextureObj1DCheckRGBAModes - buffer") {
 
   SECTION("RGBA 1D hipAddressModeClamp, hipFilterModePoint, hipResourceTypeLinear, regularCoords") {
     runTest<hipAddressModeClamp, hipFilterModePoint, hipResourceTypeLinear, false, false>(255);
- }
+  }
 
-  SECTION("RGBA 1D hipAddressModeBorder, hipFilterModePoint, hipResourceTypeLinear, regularCoords") {
+  SECTION(
+      "RGBA 1D hipAddressModeBorder, hipFilterModePoint, hipResourceTypeLinear, regularCoords") {
     runTest<hipAddressModeBorder, hipFilterModePoint, hipResourceTypeLinear, false, false>(255);
   }
 }
@@ -309,11 +322,13 @@ TEST_CASE("Unit_hipTextureObj1DCheckSRGBAModes - buffer") {
   return;
 #endif
 
-  SECTION("SRGBA 1D hipAddressModeClamp, hipFilterModePoint, hipResourceTypeLinear, regularCoords") {
+  SECTION(
+      "SRGBA 1D hipAddressModeClamp, hipFilterModePoint, hipResourceTypeLinear, regularCoords") {
     runTest<hipAddressModeClamp, hipFilterModePoint, hipResourceTypeLinear, false, true>(255);
   }
 
-  SECTION("SRGBA 1D hipAddressModeBorder, hipFilterModePoint, hipResourceTypeLinear, regularCoords") {
+  SECTION(
+      "SRGBA 1D hipAddressModeBorder, hipFilterModePoint, hipResourceTypeLinear, regularCoords") {
     runTest<hipAddressModeBorder, hipFilterModePoint, hipResourceTypeLinear, false, true>(255);
   }
 }
