@@ -22,7 +22,7 @@ THE SOFTWARE.
 
 #define N 512
 
-static __global__ void tex1dKernel(float *val, hipTextureObject_t obj) {
+static __global__ void tex1dKernel(float* val, hipTextureObject_t obj) {
 #if !__HIP_NO_IMAGE_SUPPORT
   int k = blockIdx.x * blockDim.x + threadIdx.x;
   if (k < N) {
@@ -45,8 +45,8 @@ TEST_CASE("Unit_hipCreateTextureObject_tex1DfetchVerification") {
   float val[N], output[N];
 
   for (int i = 0; i < N; i++) {
-      val[i] = (i + 1) * (i + 1);
-      output[i] = 0.0;
+    val[i] = (i + 1) * (i + 1);
+    output[i] = 0.0;
   }
 
   HIP_CHECK(hipMalloc(&texBuf, N * sizeof(float)));
@@ -58,8 +58,7 @@ TEST_CASE("Unit_hipCreateTextureObject_tex1DfetchVerification") {
   memset(&resDescLinear, 0, sizeof(resDescLinear));
   resDescLinear.resType = hipResourceTypeLinear;
   resDescLinear.res.linear.devPtr = texBuf;
-  resDescLinear.res.linear.desc =
-                  hipCreateChannelDesc(32, 0, 0, 0, hipChannelFormatKindFloat);
+  resDescLinear.res.linear.desc = hipCreateChannelDesc(32, 0, 0, 0, hipChannelFormatKindFloat);
   resDescLinear.res.linear.sizeInBytes = N * sizeof(float);
 
   hipTextureDesc texDesc;
@@ -73,20 +72,17 @@ TEST_CASE("Unit_hipCreateTextureObject_tex1DfetchVerification") {
   dim3 dimBlock(64, 1, 1);
   dim3 dimGrid(N / dimBlock.x, 1, 1);
 
-  hipLaunchKernelGGL(tex1dKernel, dim3(dimGrid), dim3(dimBlock), 0, 0,
-                     texBufOut, texObj);
-  HIP_CHECK(hipGetLastError()); 
+  hipLaunchKernelGGL(tex1dKernel, dim3(dimGrid), dim3(dimBlock), 0, 0, texBufOut, texObj);
+  HIP_CHECK(hipGetLastError());
   HIP_CHECK(hipDeviceSynchronize());
 
-  HIP_CHECK(hipMemcpy(output, texBufOut, N * sizeof(float),
-                                                     hipMemcpyDeviceToHost));
+  HIP_CHECK(hipMemcpy(output, texBufOut, N * sizeof(float), hipMemcpyDeviceToHost));
 
   for (int i = 0; i < N; i++) {
-      if (output[i] != val[i]) {
-        INFO("Mismatch at index : " << i << ", output[i] " << output[i]
-                                               << ", val[i] " << val[i]);
-        REQUIRE(false);
-      }
+    if (output[i] != val[i]) {
+      INFO("Mismatch at index : " << i << ", output[i] " << output[i] << ", val[i] " << val[i]);
+      REQUIRE(false);
+    }
   }
 
   HIP_CHECK(hipDestroyTextureObject(texObj));
