@@ -56,12 +56,10 @@ TEST_CASE("Unit_hipTextureRef2D_Check") {
     }
   }
 
-  hipChannelFormatDesc channelDesc = hipCreateChannelDesc(32, 0, 0, 0,
-                                           hipChannelFormatKindFloat);
+  hipChannelFormatDesc channelDesc = hipCreateChannelDesc(32, 0, 0, 0, hipChannelFormatKindFloat);
   hipArray_t hipArray;
   HIP_CHECK(hipMallocArray(&hipArray, &channelDesc, width, height));
-  HIP_CHECK(hipMemcpyToArray(hipArray, 0, 0, hData, size,
-                             hipMemcpyHostToDevice));
+  HIP_CHECK(hipMemcpyToArray(hipArray, 0, 0, hData, size, hipMemcpyHostToDevice));
 
   tex.addressMode[0] = hipAddressModeWrap;
   tex.addressMode[1] = hipAddressModeWrap;
@@ -76,9 +74,8 @@ TEST_CASE("Unit_hipTextureRef2D_Check") {
 
   dim3 dimBlock(16, 16, 1);
   dim3 dimGrid(width / dimBlock.x, height / dimBlock.y, 1);
-  hipLaunchKernelGGL(tex2DKernel, dim3(dimGrid), dim3(dimBlock), 0, 0,
-                     dData, width);
-  HIP_CHECK(hipGetLastError()); 
+  hipLaunchKernelGGL(tex2DKernel, dim3(dimGrid), dim3(dimBlock), 0, 0, dData, width);
+  HIP_CHECK(hipGetLastError());
   HIP_CHECK(hipDeviceSynchronize());
 
   float* hOutputData = reinterpret_cast<float*>(malloc(size));
@@ -89,8 +86,8 @@ TEST_CASE("Unit_hipTextureRef2D_Check") {
   for (i = 0; i < height; i++) {
     for (j = 0; j < width; j++) {
       if (hData[i * width + j] != hOutputData[i * width + j]) {
-        INFO("Difference found at [ " << i << j << " ]: " <<
-              hData[i * width + j] << hOutputData[i * width + j]);
+        INFO("Difference found at [ " << i << j << " ]: " << hData[i * width + j]
+                                      << hOutputData[i * width + j]);
         REQUIRE(false);
       }
     }
@@ -101,5 +98,4 @@ TEST_CASE("Unit_hipTextureRef2D_Check") {
 }
 
 
-#endif // CUDA_VERSION < CUDA_12000
-
+#endif  // CUDA_VERSION < CUDA_12000
