@@ -136,7 +136,8 @@ TEMPLATE_TEST_CASE("Unit_tex1Dfetch_Positive_ReadModeNormalizedFloat", "", char,
   tex_desc.normalizedCoords = false;
   tex_desc.addressMode[0] = hipAddressModeClamp;
 
-  LinearAllocGuard<vec4<float>> out_alloc_d(LinearAllocs::hipMalloc, tex_h.size() * sizeof(vec4<float>));
+  LinearAllocGuard<vec4<float>> out_alloc_d(LinearAllocs::hipMalloc,
+                                            tex_h.size() * sizeof(vec4<float>));
   TextureGuard tex(&res_desc, &tex_desc);
 
   const auto num_threads = std::min<size_t>(1024, tex_h.size());
@@ -157,6 +158,6 @@ TEMPLATE_TEST_CASE("Unit_tex1Dfetch_Positive_ReadModeNormalizedFloat", "", char,
 }
 
 /**
-* End doxygen group TextureTest.
-* @}
-*/
+ * End doxygen group TextureTest.
+ * @}
+ */
