@@ -363,7 +363,7 @@ void physicalMemoryReuse_MultiDev (hipMemAllocationProp prop) {
  *    - HIP_VERSION >= 7.0
  */
 TEST_CASE("Unit_hipMemMap_PhysicalMemoryReuse_MultiDev") {
-
+  CHECK_P2P_SUPPORT
   SECTION("Memory Allocation Type as hipMemAllocationTypePinned") {
     hipMemAllocationProp prop{};
     prop.type = hipMemAllocationTypePinned;
@@ -447,7 +447,8 @@ TEST_CASE("Unit_hipMemMap_VMMMemoryReuse_SingleGPU") {
     HIP_CHECK(hipMemcpyDtoH(B_h.data(), ptrA, buffer_size));
     REQUIRE(true == std::equal(B_h.begin(), B_h.end(), A_h.data()));
 #if HT_NVIDIA
-    square_kernel<<<dim3(N / threadsPerBlk), dim3(threadsPerBlk), 0, 0>>>(reinterpret_cast<int*>(ptrA));
+    square_kernel<<<dim3(N / threadsPerBlk), dim3(threadsPerBlk), 0, 0>>>(
+        reinterpret_cast<int*>(ptrA));
     HIP_CHECK(hipMemcpyDtoH(B_h.data(), ptrA, buffer_size));
     HIP_CHECK(hipStreamSynchronize(0));
     REQUIRE(true == std::equal(B_h.begin(), B_h.end(), C_h.data()));
@@ -473,6 +474,7 @@ void vMMMemoryReuse_MultiGPU (hipMemAllocationProp prop) {
   size_t granularity = 0;
   size_t buffer_size = N * sizeof(int);
   hipDevice_t device;
+  HIP_CHECK(hipSetDevice(0));
   HIP_CHECK(hipDeviceGet(&device, deviceId));
   checkVMMSupported(device);
   prop.location.id = device;  // Current Devices
@@ -489,9 +491,9 @@ void vMMMemoryReuse_MultiGPU (hipMemAllocationProp prop) {
   }
   // Allocate a physical memory chunk
   for (int dev = 0; dev < devicecount; dev++) {
-    hipDevice_t device;
-    HIP_CHECK(hipDeviceGet(&device, dev));
-    prop.location.id = device;
+    hipDevice_t dev_handle;
+    HIP_CHECK(hipDeviceGet(&dev_handle, dev));
+    prop.location.id = dev_handle;
     HIP_CHECK(hipMemCreate(&handle[dev], size_mem, &prop, 0));
   }
   // Allocate devicecount virtual address ranges
@@ -551,7 +553,7 @@ void vMMMemoryReuse_MultiGPU (hipMemAllocationProp prop) {
  *    - HIP_VERSION >= 7.0
  */
 TEST_CASE("Unit_hipMemMap_VMMMemoryReuse_MultiGPU") {
-
+  CHECK_P2P_SUPPORT
   SECTION("Memory Allocation Type as hipMemAllocationTypePinned") {
     hipMemAllocationProp prop{};
     prop.type = hipMemAllocationTypePinned;
@@ -668,7 +670,7 @@ TEST_CASE("Unit_hipMemMap_negative") {
   HIP_CHECK(hipMemAddressReserve(&ptrA, size_mem, 0, 0, 0));
 
   SECTION("nullptr to ptrA") {
-    REQUIRE(hipMemMap((hipDeviceptr_t)nullptr, size_mem, 0, handle, 0) == hipErrorInvalidValue);
+    REQUIRE(hipMemMap((hipDeviceptr_t) nullptr, size_mem, 0, handle, 0) == hipErrorInvalidValue);
   }
 
   SECTION("pass zero to size") {
@@ -681,6 +683,6 @@ TEST_CASE("Unit_hipMemMap_negative") {
 }
 
 /**
-* End doxygen group VirtualMemoryManagementTest.
-* @}
-*/
+ * End doxygen group VirtualMemoryManagementTest.
+ * @}
+ */
