@@ -23,26 +23,20 @@ THE SOFTWARE.
 // For all threads in the warp, shfl the value "down" by three threads. To
 // account for the end of the warp, we set the delta to zero near the warp-32
 // boundary. This also works for warp-64 since it is a multiple.
-template <typename T>
-__global__ void shflDown_1(T* Input, T *Output) {
+template <typename T> __global__ void shflDown_1(T* Input, T* Output) {
   auto tid = threadIdx.x;
   int srcLane = (tid % 32 + 3 < 32) ? 3 : 0;
   Output[tid] = __shfl_down_sync(AllThreads, Input[tid], srcLane);
 }
 
-template <typename T>
-static void runTestShflDown_1() {
+template <typename T> static void runTestShflDown_1() {
   const int size = 64;
   T Input[size];
   T Output[size];
-  int Values[size] = {3, 4, 5, -6, 7, 8, -9, 10,
-                      11, 12, 13, -14, 15, 16, 17, -18,
-                      19, 20, -21, 22, 23, 24, 25, 26,
-                      -27, 28, 29, 30, 31, 29, 30, 31,
-                      35, -36, 37, 38, -39, 40, 41, 42,
-                      43, -44, -45, 46, 47, 48, 49, 50,
-                      -51, 52, 53, -54, 55, 56, 57, -58,
-                      59, 60, 61, 62, -63, 61, 62, -63};
+  int Values[size] = {3,   4,   5,   -6,  7,   8,  -9, 10,  11,  12,  13,  -14, 15,  16, 17, -18,
+                      19,  20,  -21, 22,  23,  24, 25, 26,  -27, 28,  29,  30,  31,  29, 30, 31,
+                      35,  -36, 37,  38,  -39, 40, 41, 42,  43,  -44, -45, 46,  47,  48, 49, 50,
+                      -51, 52,  53,  -54, 55,  56, 57, -58, 59,  60,  61,  62,  -63, 61, 62, -63};
   T Expected[size];
 
   initializeInput(Input, size);
@@ -62,33 +56,30 @@ static void runTestShflDown_1() {
   for (int i = 0; i != warpSize; ++i) {
     REQUIRE(compareEqual(Output[i], Expected[i]));
   }
+
+  HIP_CHECK(hipFree(d_Input));
+  HIP_CHECK(hipFree(d_Output));
 }
 
 // Use the mask argument to divide the warp into groups of 12 threads, and then
 // shfl "down" by three threads. Account for the boundary within a group as well
 // as withing a warp-32.
 
-template <typename T>
-__global__ void shflDown_2(T* Input, T *Output) {
+template <typename T> __global__ void shflDown_2(T* Input, T* Output) {
   auto tid = threadIdx.x;
   auto mask = __match_any_sync(AllThreads, tid / 12);
   int srcLane = ((tid % 32 + 3 >= 32) || (tid % 12 + 3 >= 12)) ? 0 : 3;
   Output[tid] = __shfl_down_sync(mask, Input[tid], srcLane);
 }
 
-template <typename T>
-static void runTestShflDown_2() {
+template <typename T> static void runTestShflDown_2() {
   const int size = 64;
   T Input[size];
   T Output[size];
-  int Values[size] = {3, 4, 5, -6, 7, 8, -9, 10,
-                      11, -9, 10, 11, 15, 16, 17, -18,
-                      19, 20, -21, 22, 23, -21, 22, 23,
-                      -27, 28, 29, 30, 31, 29, 30, 31,
-                      35, 33, 34, 35, -39, 40, 41, 42,
-                      43, -44, -45, 46, 47, -45, 46, 47,
-                      -51, 52, 53, -54, 55, 56, 57, -58,
-                      59, 57, -58, 59, -63, 61, 62, -63};
+  int Values[size] = {3,   4,  5,   -6,  7,   8,   -9, 10,  11,  -9,  10,  11, 15,  16,  17, -18,
+                      19,  20, -21, 22,  23,  -21, 22, 23,  -27, 28,  29,  30, 31,  29,  30, 31,
+                      35,  33, 34,  35,  -39, 40,  41, 42,  43,  -44, -45, 46, 47,  -45, 46, 47,
+                      -51, 52, 53,  -54, 55,  56,  57, -58, 59,  57,  -58, 59, -63, 61,  62, -63};
   T Expected[size];
 
   initializeInput(Input, size);
@@ -108,42 +99,31 @@ static void runTestShflDown_2() {
   for (int i = 0; i != warpSize; ++i) {
     REQUIRE(compareEqual(Output[i], Expected[i]));
   }
+
+  HIP_CHECK(hipFree(d_Input));
+  HIP_CHECK(hipFree(d_Output));
 }
 
-template <typename T>
-__global__ void shflDown_3(T* Input, T *Output) {
+template <typename T> __global__ void shflDown_3(T* Input, T* Output) {
   auto tid = threadIdx.x;
   auto mask = __match_any_sync(AllThreads, tid / 12);
   int srcLane = ((tid % 12 + 3 >= 12) || (tid % 8 + 3 >= 8)) ? 0 : 3;
   Output[tid] = __shfl_down_sync(mask, Input[tid], srcLane, 8);
 }
 
-template <typename T>
-static void runTestShflDown_3() {
+template <typename T> static void runTestShflDown_3() {
   const int size = 64;
   T Input[size];
   T Output[size];
-  int Values[size] = {3, 4, 5, -6, 7,
-                      5, -6, 7,                        // cannot cross 8
-                      11, -9, 10, 11,              // cannot cross 12
-                      15,
-                      13, -14, 15,                 // cannot cross 8
-                      19, 20, -21, 22,
-                      23, -21, 22, 23,             // canot cross 12
+  int Values[size] = {3, 4, 5, -6, 7, 5, -6, 7,          // cannot cross 8
+                      11, -9, 10, 11,                    // cannot cross 12
+                      15, 13, -14, 15,                   // cannot cross 8
+                      19, 20, -21, 22, 23, -21, 22, 23,  // canot cross 12
                       // pattern repeats
-                      -27, 28, 29, 30, 31,
-                      29, 30, 31,
-                      35, 33, 34, 35,
-                      -39,
-                      37, 38, -39,
-                      43, -44, -45, 46,
-                      47, -45, 46, 47,
+                      -27, 28, 29, 30, 31, 29, 30, 31, 35, 33, 34, 35, -39, 37, 38, -39, 43, -44,
+                      -45, 46, 47, -45, 46, 47,
                       // pattern repeats
-                      -51, 52, 53, -54, 55,
-                      53, -54, 55,
-                      59, 57, -58, 59,
-                      -63,
-                      61, 62, -63};
+                      -51, 52, 53, -54, 55, 53, -54, 55, 59, 57, -58, 59, -63, 61, 62, -63};
   T Expected[size];
 
   initializeInput(Input, size);
@@ -163,11 +143,14 @@ static void runTestShflDown_3() {
   for (int i = 0; i != warpSize; ++i) {
     REQUIRE(compareEqual(Output[i], Expected[i]));
   }
+
+  HIP_CHECK(hipFree(d_Input));
+  HIP_CHECK(hipFree(d_Output));
 }
 
-__global__ void shflDown_4(int *Input, int *Output) {
+__global__ void shflDown_4(int* Input, int* Output) {
   auto tid = threadIdx.x;
-  unsigned long long masks[2] = { Every5thBut9th, Every9thBit };
+  unsigned long long masks[2] = {Every5thBut9th, Every9thBit};
 
   Output[tid] = -1;
   if (tid % 5 == 0 || tid % 9 == 0)
@@ -196,7 +179,7 @@ static void runTestShflDown_4() {
     }
   }
 
-  for (size_t i =  Expected.size() / 2; i < Expected.size(); i++) {
+  for (size_t i = Expected.size() / 2; i < Expected.size(); i++) {
     if (i % 5 == 0) {
       Expected[i] = 0x55 * alignUp(i, 5);
     } else if (i % 9 == 0) {
@@ -214,10 +197,14 @@ static void runTestShflDown_4() {
   HIP_CHECK(hipMemcpy(d_Input, Input.data(), Input.size() * sizeof(Input[0]), hipMemcpyDefault));
   hipLaunchKernelGGL(shflDown_4, 1, warpSize, 0, 0, d_Input, d_Output);
 
-  HIP_CHECK(hipMemcpy(Output.data(), d_Output, Output.size() * sizeof(Output[0]), hipMemcpyDefault));
+  HIP_CHECK(
+      hipMemcpy(Output.data(), d_Output, Output.size() * sizeof(Output[0]), hipMemcpyDefault));
   for (size_t i = 0; i < Output.size(); i++) {
     REQUIRE(Output[i] == Expected[i]);
   }
+
+  HIP_CHECK(hipFree(d_Input));
+  HIP_CHECK(hipFree(d_Output));
 }
 
 /**
@@ -305,7 +292,5 @@ TEST_CASE("Unit_hipShflSync_Down") {
     runTestShflDown_2<__half2>();
     runTestShflDown_3<__half2>();
   }
-  SECTION("run divergent execution tests") {
-    runTestShflDown_4();
-  }
+  SECTION("run divergent execution tests") { runTestShflDown_4(); }
 }
