@@ -20,16 +20,20 @@ THE SOFTWARE.
 #include "warp_common.hh"
 #include <hip_test_common.hh>
 
-__global__ void any_1(int *Input, int *Output) {
+__global__ void any_1(int* Input, int* Output) {
   auto tid = threadIdx.x;
   Output[tid] = __any_sync(AllThreads, Input[tid]);
 }
 
 static void runTestAny_1() {
   const int size = 64;
-  int Input[size] = {0, };
+  int Input[size] = {
+      0,
+  };
   int Output[size];
-  int Expected[size] = {0, };
+  int Expected[size] = {
+      0,
+  };
 
   int* d_Input;
   int* d_Output;
@@ -45,24 +49,30 @@ static void runTestAny_1() {
   for (int i = 0; i != warpSize; ++i) {
     REQUIRE(Output[i] == Expected[i]);
   }
+
+  HIP_CHECK(hipFree(d_Input));
+  HIP_CHECK(hipFree(d_Output));
 }
 
-__global__ void any_2(int *Input, int *Output) {
+__global__ void any_2(int* Input, int* Output) {
   auto tid = threadIdx.x;
   Output[tid] = __any_sync(AllThreads, Input[tid]);
 }
 
 static void runTestAny_2_w64() {
   const int size = 64;
-  int Input[size] = {0, };
+  int Input[size] = {
+      0,
+  };
   int Output[size];
-  int Expected[size] = {0, };
+  int Expected[size] = {
+      0,
+  };
 
   Input[60] = 1;
 
   int warpSize = getWarpSize();
-  if (warpSize == 64)
-    std::fill_n(Expected, size, 1);
+  if (warpSize == 64) std::fill_n(Expected, size, 1);
 
   int* d_Input;
   int* d_Output;
@@ -76,13 +86,20 @@ static void runTestAny_2_w64() {
   for (int i = 0; i != warpSize; ++i) {
     REQUIRE(Output[i] == Expected[i]);
   }
+
+  HIP_CHECK(hipFree(d_Input));
+  HIP_CHECK(hipFree(d_Output));
 }
 
 static void runTestAny_2_w32() {
   const int size = 64;
-  int Input[size] = {0, };
+  int Input[size] = {
+      0,
+  };
   int Output[size];
-  int Expected[size] = {0, };
+  int Expected[size] = {
+      0,
+  };
 
   Input[30] = 1;
   std::fill_n(Expected, size, 1);
@@ -101,37 +118,27 @@ static void runTestAny_2_w32() {
   for (int i = 0; i != warpSize; ++i) {
     REQUIRE(Output[i] == Expected[i]);
   }
+
+  HIP_CHECK(hipFree(d_Input));
+  HIP_CHECK(hipFree(d_Output));
 }
 
-__global__ void any_3(int *Input, int *Output) {
+__global__ void any_3(int* Input, int* Output) {
   auto tid = threadIdx.x;
-  auto mask = __match_any_sync(AllThreads, tid/12);
+  auto mask = __match_any_sync(AllThreads, tid / 12);
   Output[tid] = __any_sync(mask, Input[tid]);
 }
 
 static void runTestAny_3() {
   const int size = 64;
-  int Input[size] = {0, 0, 0, 0, 0, 0, 0, 0,
-                     0, 0, 0, 0, 0, 0, 1, 0,
-                     0, 0, 0, 0, 0, 0, 0, 0,
-                     0, 0, 1, 0, 0, 0, 0, 0,
-                     0, 0, 0, 0, 0, 0, 0, 0,
-                     0, 0, 0, 0, 0, 0, 0, 0,
-                     0, 0, 1, 0, 0, 0, 0, 0,
-                     0, 0, 0, 0, 0, 1, 0, 0};
+  int Input[size] = {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0,
+                     0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
+                     0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0};
 
   int Output[size];
-  int Expected[size] = {0, 0, 0, 0, 0, 0, 0, 0,
-                        0, 0, 0, 0,
-                        1, 1, 1, 1, 1, 1, 1, 1,
-                        1, 1, 1, 1,
-                        1, 1, 1, 1, 1, 1, 1, 1,
-                        1, 1, 1, 1,
-                        0, 0, 0, 0, 0, 0, 0, 0,
-                        0, 0, 0, 0,
-                        1, 1, 1, 1, 1, 1, 1, 1,
-                        1, 1, 1, 1,
-                        1, 1, 1, 1};
+  int Expected[size] = {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
+                        1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0,
+                        0, 0, 0, 0, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1};
   int* d_Input;
   int* d_Output;
   HIP_CHECK(hipMalloc(&d_Input, 4 * size));
@@ -146,20 +153,24 @@ static void runTestAny_3() {
   for (int i = 0; i != warpSize; ++i) {
     REQUIRE(Output[i] == Expected[i]);
   }
+
+  HIP_CHECK(hipFree(d_Input));
+  HIP_CHECK(hipFree(d_Output));
 }
 
-__global__ void any_4(int *Input, int *Output) {
+__global__ void any_4(int* Input, int* Output) {
   auto tid = threadIdx.x;
-  unsigned long long masks[2] = { Every5thBut9th, Every9thBit };
+  unsigned long long masks[2] = {Every5thBut9th, Every9thBit};
 
   Output[tid] = -1;
-  if (tid % 5 == 0 || tid % 9 == 0)
-    Output[tid] = __any_sync(masks[tid % 9 == 0], Input[tid]);
+  if (tid % 5 == 0 || tid % 9 == 0) Output[tid] = __any_sync(masks[tid % 9 == 0], Input[tid]);
 }
 
 static void runTestAny_4() {
   const int size = 64;
-  int Input[size] = {0, };
+  int Input[size] = {
+      0,
+  };
   Input[5] = 1;
 
   int Output[size];
@@ -193,30 +204,29 @@ static void runTestAny_4() {
   for (int i = 0; i != warpSize; ++i) {
     REQUIRE(Output[i] == Expected[i]);
   }
+
+  HIP_CHECK(hipFree(d_Input));
+  HIP_CHECK(hipFree(d_Output));
 }
 
-__global__ void all_1(int *Input, int *Output) {
+__global__ void all_1(int* Input, int* Output) {
   auto tid = threadIdx.x;
   Output[tid] = __all_sync(AllThreads, Input[tid]);
 }
 
 static void runTestAll_1_w64() {
   const int size = 64;
-  int Input[size] = {1, 1, 1, 1, 1, 1, 1, 1,
-                     1, 1, 1, 1, 1, 1, 1, 1,
-                     1, 1, 1, 1, 1, 1, 1, 1,
-                     1, 1, 1, 1, 1, 1, 1, 1,
-                     1, 1, 1, 1, 1, 1, 1, 1,
-                     1, 1, 1, 1, 1, 1, 1, 1,
-                     1, 1, 1, 1, 1, 1, 1, 1,
-                     1, 1, 1, 1, 1, 0, 1, 1};
+  int Input[size] = {1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
+                     1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
+                     1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 0, 1, 1};
 
   int Output[size];
-  int Expected[size] = {0, };
+  int Expected[size] = {
+      0,
+  };
 
   int warpSize = getWarpSize();
-  if (warpSize == 32)
-    std::fill_n(Expected, size, 1);
+  if (warpSize == 32) std::fill_n(Expected, size, 1);
 
   int* d_Input;
   int* d_Output;
@@ -230,21 +240,21 @@ static void runTestAll_1_w64() {
   for (int i = 0; i != warpSize; ++i) {
     REQUIRE(Output[i] == Expected[i]);
   }
+
+  HIP_CHECK(hipFree(d_Input));
+  HIP_CHECK(hipFree(d_Output));
 }
 
 static void runTestAll_1_w32() {
   const int size = 64;
-  int Input[size] = {1, 1, 1, 1, 1, 1, 1, 1,
-                     1, 1, 1, 1, 1, 1, 1, 1,
-                     1, 1, 0, 1, 1, 1, 1, 1,
-                     1, 1, 1, 1, 1, 1, 1, 1,
-                     1, 1, 1, 1, 1, 1, 1, 1,
-                     1, 1, 1, 1, 1, 1, 1, 1,
-                     1, 1, 1, 1, 1, 1, 1, 1,
-                     1, 1, 1, 1, 1, 1, 1, 1};
+  int Input[size] = {1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 0, 1, 1, 1,
+                     1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
+                     1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1};
 
   int Output[size];
-  int Expected[size] = {0, };
+  int Expected[size] = {
+      0,
+  };
 
   int warpSize = getWarpSize();
 
@@ -260,33 +270,26 @@ static void runTestAll_1_w32() {
   for (int i = 0; i != warpSize; ++i) {
     REQUIRE(Output[i] == Expected[i]);
   }
+
+  HIP_CHECK(hipFree(d_Input));
+  HIP_CHECK(hipFree(d_Output));
 }
 
-__global__ void all_2(int *Input, int *Output) {
+__global__ void all_2(int* Input, int* Output) {
   auto tid = threadIdx.x;
   Output[tid] = __all_sync(AllThreads, Input[tid]);
 }
 
 static void runTestAll_2() {
   const int size = 64;
-  int Input[size] = {1, 1, 1, 1, 1, 1, 1, 1,
-                     1, 1, 1, 1, 1, 1, 1, 1,
-                     1, 1, 1, 1, 1, 1, 1, 1,
-                     1, 1, 1, 1, 1, 1, 1, 1,
-                     1, 1, 1, 1, 1, 1, 1, 1,
-                     1, 1, 1, 1, 1, 1, 1, 1,
-                     1, 1, 1, 1, 1, 1, 1, 1,
-                     1, 1, 1, 1, 1, 1, 1, 1};
+  int Input[size] = {1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
+                     1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
+                     1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1};
 
   int Output[size];
-  int Expected[size] = {1, 1, 1, 1, 1, 1, 1, 1,
-                        1, 1, 1, 1, 1, 1, 1, 1,
-                        1, 1, 1, 1, 1, 1, 1, 1,
-                        1, 1, 1, 1, 1, 1, 1, 1,
-                        1, 1, 1, 1, 1, 1, 1, 1,
-                        1, 1, 1, 1, 1, 1, 1, 1,
-                        1, 1, 1, 1, 1, 1, 1, 1,
-                        1, 1, 1, 1, 1, 1, 1, 1};
+  int Expected[size] = {1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
+                        1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
+                        1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1};
 
   int* d_Input;
   int* d_Output;
@@ -302,37 +305,27 @@ static void runTestAll_2() {
   for (int i = 0; i != warpSize; ++i) {
     REQUIRE(Output[i] == Expected[i]);
   }
+
+  HIP_CHECK(hipFree(d_Input));
+  HIP_CHECK(hipFree(d_Output));
 }
 
-__global__ void all_3(int *Input, int *Output) {
+__global__ void all_3(int* Input, int* Output) {
   auto tid = threadIdx.x;
-  auto mask = __match_any_sync(AllThreads, tid/12);
+  auto mask = __match_any_sync(AllThreads, tid / 12);
   Output[tid] = __all_sync(mask, Input[tid]);
 }
 
 static void runTestAll_3() {
   const int size = 64;
-  int Input[size] = {1, 1, 1, 1, 1, 1, 1, 1,
-                     1, 1, 1, 1, 1, 1, 0, 1,
-                     1, 1, 1, 1, 1, 1, 1, 1,
-                     1, 1, 0, 1, 1, 1, 1, 1,
-                     1, 1, 1, 1, 1, 1, 1, 1,
-                     1, 1, 1, 1, 1, 1, 1, 1,
-                     1, 1, 0, 1, 1, 1, 1, 1,
-                     1, 1, 1, 1, 1, 0, 1, 1};
+  int Input[size] = {1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 0, 1, 1, 1, 1, 1, 1, 1,
+                     1, 1, 1, 1, 0, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
+                     1, 1, 1, 1, 1, 1, 0, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 0, 1, 1};
 
   int Output[size];
-  int Expected[size] = {1, 1, 1, 1, 1, 1, 1, 1,
-                        1, 1, 1, 1,
-                        0, 0, 0, 0, 0, 0, 0, 0,
-                        0, 0, 0, 0,
-                        0, 0, 0, 0, 0, 0, 0, 0,
-                        0, 0, 0, 0,
-                        1, 1, 1, 1, 1, 1, 1, 1,
-                        1, 1, 1, 1,
-                        0, 0, 0, 0, 0, 0, 0, 0,
-                        0, 0, 0, 0,
-                        0, 0, 0, 0};
+  int Expected[size] = {1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
+                        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 1, 1, 1, 1, 1, 1,
+                        1, 1, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0};
   int* d_Input;
   int* d_Output;
   HIP_CHECK(hipMalloc(&d_Input, 4 * size));
@@ -347,15 +340,17 @@ static void runTestAll_3() {
   for (int i = 0; i != warpSize; ++i) {
     REQUIRE(Output[i] == Expected[i]);
   }
+
+  HIP_CHECK(hipFree(d_Input));
+  HIP_CHECK(hipFree(d_Output));
 }
 
-__global__ void all_4(int *Input, int *Output) {
+__global__ void all_4(int* Input, int* Output) {
   auto tid = threadIdx.x;
-  unsigned long long masks[2] = { Every5thBut9th, Every9thBit };
+  unsigned long long masks[2] = {Every5thBut9th, Every9thBit};
 
   Output[tid] = -1;
-  if (tid % 5 == 0 || tid % 9 == 0)
-    Output[tid] = __all_sync(masks[tid % 9 == 0], Input[tid]);
+  if (tid % 5 == 0 || tid % 9 == 0) Output[tid] = __all_sync(masks[tid % 9 == 0], Input[tid]);
 }
 
 static void runTestAll_4() {
@@ -395,42 +390,39 @@ static void runTestAll_4() {
   for (int i = 0; i != warpSize; ++i) {
     REQUIRE(Output[i] == Expected[i]);
   }
+
+  HIP_CHECK(hipFree(d_Input));
+  HIP_CHECK(hipFree(d_Output));
 }
 
-__global__ void ballot_1(int *Input, unsigned long long *Output) {
+__global__ void ballot_1(int* Input, unsigned long long* Output) {
   auto tid = threadIdx.x;
   Output[tid] = __ballot_sync(AllThreads, Input[tid]);
 }
 
 static void runTestBallot_1() {
   const int size = 64;
-  int Input[size] = {0, 1, 0, 0, 1, 1, 1, 0,
-                     0, 1, 1, 1, 0, 0, 1, 0,
-                     1, 1, 1, 0, 0, 1, 0, 0,
-                     1, 0, 0, 1, 0, 0, 1, 1,
-                     0, 1, 0, 0, 1, 1, 1, 0,
-                     0, 1, 1, 1, 0, 0, 1, 0,
-                     1, 1, 1, 0, 0, 1, 0, 0,
-                     1, 0, 0, 1, 0, 0, 1, 1};
+  int Input[size] = {0, 1, 0, 0, 1, 1, 1, 0, 0, 1, 1, 1, 0, 0, 1, 0, 1, 1, 1, 0, 0, 1,
+                     0, 0, 1, 0, 0, 1, 0, 0, 1, 1, 0, 1, 0, 0, 1, 1, 1, 0, 0, 1, 1, 1,
+                     0, 0, 1, 0, 1, 1, 1, 0, 0, 1, 0, 0, 1, 0, 0, 1, 0, 0, 1, 1};
   unsigned long long Output[size];
   unsigned long long Expected[size] = {
-    0xc9274e72c9274e72, 0xc9274e72c9274e72, 0xc9274e72c9274e72, 0xc9274e72c9274e72,
-    0xc9274e72c9274e72, 0xc9274e72c9274e72, 0xc9274e72c9274e72, 0xc9274e72c9274e72,
-    0xc9274e72c9274e72, 0xc9274e72c9274e72, 0xc9274e72c9274e72, 0xc9274e72c9274e72,
-    0xc9274e72c9274e72, 0xc9274e72c9274e72, 0xc9274e72c9274e72, 0xc9274e72c9274e72,
-    0xc9274e72c9274e72, 0xc9274e72c9274e72, 0xc9274e72c9274e72, 0xc9274e72c9274e72,
-    0xc9274e72c9274e72, 0xc9274e72c9274e72, 0xc9274e72c9274e72, 0xc9274e72c9274e72,
-    0xc9274e72c9274e72, 0xc9274e72c9274e72, 0xc9274e72c9274e72, 0xc9274e72c9274e72,
-    0xc9274e72c9274e72, 0xc9274e72c9274e72, 0xc9274e72c9274e72, 0xc9274e72c9274e72,
-    0xc9274e72c9274e72, 0xc9274e72c9274e72, 0xc9274e72c9274e72, 0xc9274e72c9274e72,
-    0xc9274e72c9274e72, 0xc9274e72c9274e72, 0xc9274e72c9274e72, 0xc9274e72c9274e72,
-    0xc9274e72c9274e72, 0xc9274e72c9274e72, 0xc9274e72c9274e72, 0xc9274e72c9274e72,
-    0xc9274e72c9274e72, 0xc9274e72c9274e72, 0xc9274e72c9274e72, 0xc9274e72c9274e72,
-    0xc9274e72c9274e72, 0xc9274e72c9274e72, 0xc9274e72c9274e72, 0xc9274e72c9274e72,
-    0xc9274e72c9274e72, 0xc9274e72c9274e72, 0xc9274e72c9274e72, 0xc9274e72c9274e72,
-    0xc9274e72c9274e72, 0xc9274e72c9274e72, 0xc9274e72c9274e72, 0xc9274e72c9274e72,
-    0xc9274e72c9274e72, 0xc9274e72c9274e72, 0xc9274e72c9274e72, 0xc9274e72c9274e72
-  };
+      0xc9274e72c9274e72, 0xc9274e72c9274e72, 0xc9274e72c9274e72, 0xc9274e72c9274e72,
+      0xc9274e72c9274e72, 0xc9274e72c9274e72, 0xc9274e72c9274e72, 0xc9274e72c9274e72,
+      0xc9274e72c9274e72, 0xc9274e72c9274e72, 0xc9274e72c9274e72, 0xc9274e72c9274e72,
+      0xc9274e72c9274e72, 0xc9274e72c9274e72, 0xc9274e72c9274e72, 0xc9274e72c9274e72,
+      0xc9274e72c9274e72, 0xc9274e72c9274e72, 0xc9274e72c9274e72, 0xc9274e72c9274e72,
+      0xc9274e72c9274e72, 0xc9274e72c9274e72, 0xc9274e72c9274e72, 0xc9274e72c9274e72,
+      0xc9274e72c9274e72, 0xc9274e72c9274e72, 0xc9274e72c9274e72, 0xc9274e72c9274e72,
+      0xc9274e72c9274e72, 0xc9274e72c9274e72, 0xc9274e72c9274e72, 0xc9274e72c9274e72,
+      0xc9274e72c9274e72, 0xc9274e72c9274e72, 0xc9274e72c9274e72, 0xc9274e72c9274e72,
+      0xc9274e72c9274e72, 0xc9274e72c9274e72, 0xc9274e72c9274e72, 0xc9274e72c9274e72,
+      0xc9274e72c9274e72, 0xc9274e72c9274e72, 0xc9274e72c9274e72, 0xc9274e72c9274e72,
+      0xc9274e72c9274e72, 0xc9274e72c9274e72, 0xc9274e72c9274e72, 0xc9274e72c9274e72,
+      0xc9274e72c9274e72, 0xc9274e72c9274e72, 0xc9274e72c9274e72, 0xc9274e72c9274e72,
+      0xc9274e72c9274e72, 0xc9274e72c9274e72, 0xc9274e72c9274e72, 0xc9274e72c9274e72,
+      0xc9274e72c9274e72, 0xc9274e72c9274e72, 0xc9274e72c9274e72, 0xc9274e72c9274e72,
+      0xc9274e72c9274e72, 0xc9274e72c9274e72, 0xc9274e72c9274e72, 0xc9274e72c9274e72};
 
   int* d_Input;
   unsigned long long* d_Output;
@@ -446,9 +438,12 @@ static void runTestBallot_1() {
   for (int i = 0; i != warpSize; ++i) {
     REQUIRE(compareMaskEqual(Output, Expected, i, warpSize));
   }
+
+  HIP_CHECK(hipFree(d_Input));
+  HIP_CHECK(hipFree(d_Output));
 }
 
-__global__ void ballot_2(int *Input, unsigned long long *Output) {
+__global__ void ballot_2(int* Input, unsigned long long* Output) {
   auto tid = threadIdx.x;
   auto mask = __match_any_sync(AllThreads, tid / 12);
   Output[tid] = __ballot_sync(mask, Input[tid]);
@@ -456,32 +451,27 @@ __global__ void ballot_2(int *Input, unsigned long long *Output) {
 
 static void runTestBallot_2() {
   const int size = 64;
-  int Input[size] = {0, 1, 0, 0, 1, 1, 1, 0,
-                     0, 1, 1, 1, 0, 0, 1, 0,
-                     1, 1, 1, 0, 0, 1, 0, 0,
-                     1, 0, 0, 1, 0, 0, 1, 1,
-                     0, 1, 0, 0, 1, 1, 1, 0,
-                     0, 1, 1, 1, 0, 0, 1, 0,
-                     1, 1, 1, 0, 0, 1, 0, 0,
-                     1, 0, 0, 1, 0, 0, 1, 1};
+  int Input[size] = {0, 1, 0, 0, 1, 1, 1, 0, 0, 1, 1, 1, 0, 0, 1, 0, 1, 1, 1, 0, 0, 1,
+                     0, 0, 1, 0, 0, 1, 0, 0, 1, 1, 0, 1, 0, 0, 1, 1, 1, 0, 0, 1, 1, 1,
+                     0, 0, 1, 0, 1, 1, 1, 0, 0, 1, 0, 0, 1, 0, 0, 1, 0, 0, 1, 1};
   unsigned long long Output[size];
   unsigned long long Expected[size] = {
-    0x0000000000000e72, 0x0000000000000e72, 0x0000000000000e72, 0x0000000000000e72,
-    0x0000000000000e72, 0x0000000000000e72, 0x0000000000000e72, 0x0000000000000e72,
-    0x0000000000000e72, 0x0000000000000e72, 0x0000000000000e72, 0x0000000000000e72,
-    0x0000000000274000, 0x0000000000274000, 0x0000000000274000, 0x0000000000274000,
-    0x0000000000274000, 0x0000000000274000, 0x0000000000274000, 0x0000000000274000,
-    0x0000000000274000, 0x0000000000274000, 0x0000000000274000, 0x0000000000274000,
-    0x00000002c9000000, 0x00000002c9000000, 0x00000002c9000000, 0x00000002c9000000,
-    0x00000002c9000000, 0x00000002c9000000, 0x00000002c9000000, 0x00000002c9000000,
-    0x00000002c9000000, 0x00000002c9000000, 0x00000002c9000000, 0x00000002c9000000,
-    0x00004e7000000000, 0x00004e7000000000, 0x00004e7000000000, 0x00004e7000000000,
-    0x00004e7000000000, 0x00004e7000000000, 0x00004e7000000000, 0x00004e7000000000,
-    0x00004e7000000000, 0x00004e7000000000, 0x00004e7000000000, 0x00004e7000000000,
-    0x0927000000000000, 0x0927000000000000, 0x0927000000000000, 0x0927000000000000,
-    0x0927000000000000, 0x0927000000000000, 0x0927000000000000, 0x0927000000000000,
-    0x0927000000000000, 0x0927000000000000, 0x0927000000000000, 0x0927000000000000,
-    0xc000000000000000, 0xc000000000000000, 0xc000000000000000, 0xc000000000000000};
+      0x0000000000000e72, 0x0000000000000e72, 0x0000000000000e72, 0x0000000000000e72,
+      0x0000000000000e72, 0x0000000000000e72, 0x0000000000000e72, 0x0000000000000e72,
+      0x0000000000000e72, 0x0000000000000e72, 0x0000000000000e72, 0x0000000000000e72,
+      0x0000000000274000, 0x0000000000274000, 0x0000000000274000, 0x0000000000274000,
+      0x0000000000274000, 0x0000000000274000, 0x0000000000274000, 0x0000000000274000,
+      0x0000000000274000, 0x0000000000274000, 0x0000000000274000, 0x0000000000274000,
+      0x00000002c9000000, 0x00000002c9000000, 0x00000002c9000000, 0x00000002c9000000,
+      0x00000002c9000000, 0x00000002c9000000, 0x00000002c9000000, 0x00000002c9000000,
+      0x00000002c9000000, 0x00000002c9000000, 0x00000002c9000000, 0x00000002c9000000,
+      0x00004e7000000000, 0x00004e7000000000, 0x00004e7000000000, 0x00004e7000000000,
+      0x00004e7000000000, 0x00004e7000000000, 0x00004e7000000000, 0x00004e7000000000,
+      0x00004e7000000000, 0x00004e7000000000, 0x00004e7000000000, 0x00004e7000000000,
+      0x0927000000000000, 0x0927000000000000, 0x0927000000000000, 0x0927000000000000,
+      0x0927000000000000, 0x0927000000000000, 0x0927000000000000, 0x0927000000000000,
+      0x0927000000000000, 0x0927000000000000, 0x0927000000000000, 0x0927000000000000,
+      0xc000000000000000, 0xc000000000000000, 0xc000000000000000, 0xc000000000000000};
 
   int* d_Input;
   unsigned long long* d_Output;
@@ -497,15 +487,17 @@ static void runTestBallot_2() {
   for (int i = 0; i != warpSize; ++i) {
     REQUIRE(compareMaskEqual(Output, Expected, i, warpSize));
   }
+
+  HIP_CHECK(hipFree(d_Input));
+  HIP_CHECK(hipFree(d_Output));
 }
 
-__global__ void ballot_3(int *Input, unsigned long long *Output) {
+__global__ void ballot_3(int* Input, unsigned long long* Output) {
   auto tid = threadIdx.x;
-  unsigned long long masks[2] = { Every5thBut9th, Every9thBit };
+  unsigned long long masks[2] = {Every5thBut9th, Every9thBit};
 
   Output[tid] = -1;
-  if (tid % 5 == 0 || tid % 9 == 0)
-    Output[tid] = __ballot_sync(masks[tid % 9 == 0], Input[tid]);
+  if (tid % 5 == 0 || tid % 9 == 0) Output[tid] = __ballot_sync(masks[tid % 9 == 0], Input[tid]);
 }
 
 static void runTestBallot_3() {
@@ -544,6 +536,9 @@ static void runTestBallot_3() {
   for (int i = 0; i != warpSize; ++i) {
     REQUIRE(compareMaskEqual(Output, Expected, i, warpSize));
   }
+
+  HIP_CHECK(hipFree(d_Input));
+  HIP_CHECK(hipFree(d_Output));
 }
 
 /**
