@@ -31,9 +31,9 @@ THE SOFTWARE.
 
 namespace cg = cooperative_groups;
 
-template <typename T>
-__global__ void shfl_xor(T* const out, const T* const in, const uint64_t* const active_masks,
-                         const int lane_mask, const int width) {
+template <typename T> __global__ void shfl_xor(T* const out, const T* const in,
+                                               const uint64_t* const active_masks,
+                                               const int lane_mask, const int width) {
   if (deactivate_thread(active_masks)) {
     return;
   }
@@ -61,7 +61,7 @@ template <typename T> class WarpShflXOR : public WarpShflTest<WarpShflXOR<T>, T>
       const int warp_target = rank_in_warp ^ this->lane_mask_;
       const int target_offset = warp_target - rank_in_warp;
       const auto mask_idx = this->warps_in_block_ * (i / this->grid_.threads_in_block_count_) +
-          rank_in_block / this->warp_size_;
+                            rank_in_block / this->warp_size_;
       const std::bitset<sizeof(uint64_t) * 8> active_mask(this->active_masks_[mask_idx]);
 
       const auto target_partition = warp_target / width_;
@@ -118,6 +118,6 @@ TEMPLATE_TEST_CASE("Unit_Warp_Shfl_XOR_Positive_Basic", "", int, unsigned int, l
 }
 
 /**
-* End doxygen group DeviceLanguageTest.
-* @}
-*/
+ * End doxygen group DeviceLanguageTest.
+ * @}
+ */
